@@ -1,6 +1,8 @@
 from enum import Enum
 import math
-import string
+
+from ..abstract_unit import AbstractMeasure
+
 
 
 class AccelerationUnits(Enum):
@@ -79,7 +81,7 @@ class AccelerationUnits(Enum):
         """
         
 
-class Acceleration:
+class Acceleration(AbstractMeasure):
     """
     Acceleration, in physics, is the rate at which the velocity of an object changes over time. An object's acceleration is the net result of any and all forces acting on the object, as described by Newton's Second Law. The SI unit for acceleration is the Meter per second squared (m/s²). Accelerations are vector quantities (they have magnitude and direction) and add according to the parallelogram law. As a vector, the calculated net force is equal to the product of the object's mass (a scalar quantity) and the acceleration.
 
@@ -88,9 +90,11 @@ class Acceleration:
         from_unit (AccelerationUnits): The Acceleration unit to create from, The default unit is MeterPerSecondSquared
     """
     def __init__(self, value: float, from_unit: AccelerationUnits = AccelerationUnits.MeterPerSecondSquared):
-        if math.isnan(value):
-            raise ValueError('Invalid unit: value is NaN')
-        self.__value = self.__convert_to_base(value, from_unit)
+        # Do not validate type, to allow working with numpay arrays and similar objects who supports all arithmetic 
+        # operations, but they are not a number, see #14 
+        # if math.isnan(value):
+        #     raise ValueError('Invalid unit: value is NaN')
+        self._value = self.__convert_to_base(value, from_unit)
         
         self.__meters_per_second_squared = None
         
@@ -121,8 +125,11 @@ class Acceleration:
         self.__millistandard_gravity = None
         
 
+    def convert(self, unit: AccelerationUnits) -> float:
+        return self.__convert_from_base(unit)
+
     def __convert_from_base(self, from_unit: AccelerationUnits) -> float:
-        value = self.__value
+        value = self._value
         
         if from_unit == AccelerationUnits.MeterPerSecondSquared:
             return (value)
@@ -218,7 +225,7 @@ class Acceleration:
 
     @property
     def base_value(self) -> float:
-        return self.__value
+        return self._value
 
     
     @staticmethod
@@ -585,7 +592,7 @@ class Acceleration:
         return self.__millistandard_gravity
 
     
-    def to_string(self, unit: AccelerationUnits = AccelerationUnits.MeterPerSecondSquared) -> string:
+    def to_string(self, unit: AccelerationUnits = AccelerationUnits.MeterPerSecondSquared) -> str:
         """
         Format the Acceleration to string.
         Note! the default format for Acceleration is MeterPerSecondSquared.
@@ -614,30 +621,30 @@ class Acceleration:
             return f"""{self.standard_gravity} g"""
         
         if unit == AccelerationUnits.NanometerPerSecondSquared:
-            return f"""{self.nanometers_per_second_squared} """
+            return f"""{self.nanometers_per_second_squared} nm/s²"""
         
         if unit == AccelerationUnits.MicrometerPerSecondSquared:
-            return f"""{self.micrometers_per_second_squared} """
+            return f"""{self.micrometers_per_second_squared} μm/s²"""
         
         if unit == AccelerationUnits.MillimeterPerSecondSquared:
-            return f"""{self.millimeters_per_second_squared} """
+            return f"""{self.millimeters_per_second_squared} mm/s²"""
         
         if unit == AccelerationUnits.CentimeterPerSecondSquared:
-            return f"""{self.centimeters_per_second_squared} """
+            return f"""{self.centimeters_per_second_squared} cm/s²"""
         
         if unit == AccelerationUnits.DecimeterPerSecondSquared:
-            return f"""{self.decimeters_per_second_squared} """
+            return f"""{self.decimeters_per_second_squared} dm/s²"""
         
         if unit == AccelerationUnits.KilometerPerSecondSquared:
-            return f"""{self.kilometers_per_second_squared} """
+            return f"""{self.kilometers_per_second_squared} km/s²"""
         
         if unit == AccelerationUnits.MillistandardGravity:
-            return f"""{self.millistandard_gravity} """
+            return f"""{self.millistandard_gravity} mg"""
         
-        return f'{self.__value}'
+        return f'{self._value}'
 
 
-    def get_unit_abbreviation(self, unit_abbreviation: AccelerationUnits = AccelerationUnits.MeterPerSecondSquared) -> string:
+    def get_unit_abbreviation(self, unit_abbreviation: AccelerationUnits = AccelerationUnits.MeterPerSecondSquared) -> str:
         """
         Get Acceleration unit abbreviation.
         Note! the default abbreviation for Acceleration is MeterPerSecondSquared.
@@ -666,92 +673,23 @@ class Acceleration:
             return """g"""
         
         if unit_abbreviation == AccelerationUnits.NanometerPerSecondSquared:
-            return """"""
+            return """nm/s²"""
         
         if unit_abbreviation == AccelerationUnits.MicrometerPerSecondSquared:
-            return """"""
+            return """μm/s²"""
         
         if unit_abbreviation == AccelerationUnits.MillimeterPerSecondSquared:
-            return """"""
+            return """mm/s²"""
         
         if unit_abbreviation == AccelerationUnits.CentimeterPerSecondSquared:
-            return """"""
+            return """cm/s²"""
         
         if unit_abbreviation == AccelerationUnits.DecimeterPerSecondSquared:
-            return """"""
+            return """dm/s²"""
         
         if unit_abbreviation == AccelerationUnits.KilometerPerSecondSquared:
-            return """"""
+            return """km/s²"""
         
         if unit_abbreviation == AccelerationUnits.MillistandardGravity:
-            return """"""
-        
-
-    def __str__(self):
-        return self.to_string()
-
-
-    def __add__(self, other):
-        if not isinstance(other, Acceleration):
-            raise TypeError("unsupported operand type(s) for +: 'Acceleration' and '{}'".format(type(other).__name__))
-        return Acceleration(self.__value + other.__value)
-
-
-    def __mul__(self, other):
-        if not isinstance(other, Acceleration):
-            raise TypeError("unsupported operand type(s) for *: 'Acceleration' and '{}'".format(type(other).__name__))
-        return Acceleration(self.__value * other.__value)
-
-
-    def __sub__(self, other):
-        if not isinstance(other, Acceleration):
-            raise TypeError("unsupported operand type(s) for -: 'Acceleration' and '{}'".format(type(other).__name__))
-        return Acceleration(self.__value - other.__value)
-
-
-    def __truediv__(self, other):
-        if not isinstance(other, Acceleration):
-            raise TypeError("unsupported operand type(s) for /: 'Acceleration' and '{}'".format(type(other).__name__))
-        return Acceleration(self.__value / other.__value)
-
-
-    def __mod__(self, other):
-        if not isinstance(other, Acceleration):
-            raise TypeError("unsupported operand type(s) for %: 'Acceleration' and '{}'".format(type(other).__name__))
-        return Acceleration(self.__value % other.__value)
-
-
-    def __pow__(self, other):
-        if not isinstance(other, Acceleration):
-            raise TypeError("unsupported operand type(s) for **: 'Acceleration' and '{}'".format(type(other).__name__))
-        return Acceleration(self.__value ** other.__value)
-
-
-    def __eq__(self, other):
-        if not isinstance(other, Acceleration):
-            raise TypeError("unsupported operand type(s) for ==: 'Acceleration' and '{}'".format(type(other).__name__))
-        return self.__value == other.__value
-
-
-    def __lt__(self, other):
-        if not isinstance(other, Acceleration):
-            raise TypeError("unsupported operand type(s) for <: 'Acceleration' and '{}'".format(type(other).__name__))
-        return self.__value < other.__value
-
-
-    def __gt__(self, other):
-        if not isinstance(other, Acceleration):
-            raise TypeError("unsupported operand type(s) for >: 'Acceleration' and '{}'".format(type(other).__name__))
-        return self.__value > other.__value
-
-
-    def __le__(self, other):
-        if not isinstance(other, Acceleration):
-            raise TypeError("unsupported operand type(s) for <=: 'Acceleration' and '{}'".format(type(other).__name__))
-        return self.__value <= other.__value
-
-
-    def __ge__(self, other):
-        if not isinstance(other, Acceleration):
-            raise TypeError("unsupported operand type(s) for >=: 'Acceleration' and '{}'".format(type(other).__name__))
-        return self.__value >= other.__value
\ No newline at end of file
+            return """mg"""
+        
\ No newline at end of file
