@@ -1,6 +1,8 @@
 from enum import Enum
 import math
-import string
+
+from ..abstract_unit import AbstractMeasure
+
 
 
 class AmountOfSubstanceUnits(Enum):
@@ -18,6 +20,16 @@ class AmountOfSubstanceUnits(Enum):
             
         """
         
+        Femtomole = 'femtomole'
+        """
+            
+        """
+        
+        Picomole = 'picomole'
+        """
+            
+        """
+        
         Nanomole = 'nanomole'
         """
             
@@ -84,7 +96,7 @@ class AmountOfSubstanceUnits(Enum):
         """
         
 
-class AmountOfSubstance:
+class AmountOfSubstance(AbstractMeasure):
     """
     Mole is the amount of substance containing Avagadro's Number (6.02 x 10 ^ 23) of real particles such as molecules,atoms, ions or radicals.
 
@@ -93,14 +105,20 @@ class AmountOfSubstance:
         from_unit (AmountOfSubstanceUnits): The AmountOfSubstance unit to create from, The default unit is Mole
     """
     def __init__(self, value: float, from_unit: AmountOfSubstanceUnits = AmountOfSubstanceUnits.Mole):
-        if math.isnan(value):
-            raise ValueError('Invalid unit: value is NaN')
-        self.__value = self.__convert_to_base(value, from_unit)
+        # Do not validate type, to allow working with numpay arrays and similar objects who supports all arithmetic 
+        # operations, but they are not a number, see #14 
+        # if math.isnan(value):
+        #     raise ValueError('Invalid unit: value is NaN')
+        self._value = self.__convert_to_base(value, from_unit)
         
         self.__moles = None
         
         self.__pound_moles = None
         
+        self.__femtomoles = None
+        
+        self.__picomoles = None
+        
         self.__nanomoles = None
         
         self.__micromoles = None
@@ -128,8 +146,11 @@ class AmountOfSubstance:
         self.__kilopound_moles = None
         
 
+    def convert(self, unit: AmountOfSubstanceUnits) -> float:
+        return self.__convert_from_base(unit)
+
     def __convert_from_base(self, from_unit: AmountOfSubstanceUnits) -> float:
-        value = self.__value
+        value = self._value
         
         if from_unit == AmountOfSubstanceUnits.Mole:
             return (value)
@@ -137,6 +158,12 @@ class AmountOfSubstance:
         if from_unit == AmountOfSubstanceUnits.PoundMole:
             return (value / 453.59237)
         
+        if from_unit == AmountOfSubstanceUnits.Femtomole:
+            return ((value) / 1e-15)
+        
+        if from_unit == AmountOfSubstanceUnits.Picomole:
+            return ((value) / 1e-12)
+        
         if from_unit == AmountOfSubstanceUnits.Nanomole:
             return ((value) / 1e-09)
         
@@ -187,6 +214,12 @@ class AmountOfSubstance:
         if to_unit == AmountOfSubstanceUnits.PoundMole:
             return (value * 453.59237)
         
+        if to_unit == AmountOfSubstanceUnits.Femtomole:
+            return ((value) * 1e-15)
+        
+        if to_unit == AmountOfSubstanceUnits.Picomole:
+            return ((value) * 1e-12)
+        
         if to_unit == AmountOfSubstanceUnits.Nanomole:
             return ((value) * 1e-09)
         
@@ -231,7 +264,7 @@ class AmountOfSubstance:
 
     @property
     def base_value(self) -> float:
-        return self.__value
+        return self._value
 
     
     @staticmethod
@@ -264,6 +297,36 @@ class AmountOfSubstance:
         return AmountOfSubstance(pound_moles, AmountOfSubstanceUnits.PoundMole)
 
     
+    @staticmethod
+    def from_femtomoles(femtomoles: float):
+        """
+        Create a new instance of AmountOfSubstance from a value in femtomoles.
+
+        
+
+        :param meters: The AmountOfSubstance value in femtomoles.
+        :type femtomoles: float
+        :return: A new instance of AmountOfSubstance.
+        :rtype: AmountOfSubstance
+        """
+        return AmountOfSubstance(femtomoles, AmountOfSubstanceUnits.Femtomole)
+
+    
+    @staticmethod
+    def from_picomoles(picomoles: float):
+        """
+        Create a new instance of AmountOfSubstance from a value in picomoles.
+
+        
+
+        :param meters: The AmountOfSubstance value in picomoles.
+        :type picomoles: float
+        :return: A new instance of AmountOfSubstance.
+        :rtype: AmountOfSubstance
+        """
+        return AmountOfSubstance(picomoles, AmountOfSubstanceUnits.Picomole)
+
+    
     @staticmethod
     def from_nanomoles(nanomoles: float):
         """
@@ -481,6 +544,28 @@ class AmountOfSubstance:
         return self.__pound_moles
 
     
+    @property
+    def femtomoles(self) -> float:
+        """
+        
+        """
+        if self.__femtomoles != None:
+            return self.__femtomoles
+        self.__femtomoles = self.__convert_from_base(AmountOfSubstanceUnits.Femtomole)
+        return self.__femtomoles
+
+    
+    @property
+    def picomoles(self) -> float:
+        """
+        
+        """
+        if self.__picomoles != None:
+            return self.__picomoles
+        self.__picomoles = self.__convert_from_base(AmountOfSubstanceUnits.Picomole)
+        return self.__picomoles
+
+    
     @property
     def nanomoles(self) -> float:
         """
@@ -624,7 +709,7 @@ class AmountOfSubstance:
         return self.__kilopound_moles
 
     
-    def to_string(self, unit: AmountOfSubstanceUnits = AmountOfSubstanceUnits.Mole) -> string:
+    def to_string(self, unit: AmountOfSubstanceUnits = AmountOfSubstanceUnits.Mole) -> str:
         """
         Format the AmountOfSubstance to string.
         Note! the default format for AmountOfSubstance is Mole.
@@ -637,49 +722,55 @@ class AmountOfSubstance:
         if unit == AmountOfSubstanceUnits.PoundMole:
             return f"""{self.pound_moles} lbmol"""
         
+        if unit == AmountOfSubstanceUnits.Femtomole:
+            return f"""{self.femtomoles} fmol"""
+        
+        if unit == AmountOfSubstanceUnits.Picomole:
+            return f"""{self.picomoles} pmol"""
+        
         if unit == AmountOfSubstanceUnits.Nanomole:
-            return f"""{self.nanomoles} """
+            return f"""{self.nanomoles} nmol"""
         
         if unit == AmountOfSubstanceUnits.Micromole:
-            return f"""{self.micromoles} """
+            return f"""{self.micromoles} μmol"""
         
         if unit == AmountOfSubstanceUnits.Millimole:
-            return f"""{self.millimoles} """
+            return f"""{self.millimoles} mmol"""
         
         if unit == AmountOfSubstanceUnits.Centimole:
-            return f"""{self.centimoles} """
+            return f"""{self.centimoles} cmol"""
         
         if unit == AmountOfSubstanceUnits.Decimole:
-            return f"""{self.decimoles} """
+            return f"""{self.decimoles} dmol"""
         
         if unit == AmountOfSubstanceUnits.Kilomole:
-            return f"""{self.kilomoles} """
+            return f"""{self.kilomoles} kmol"""
         
         if unit == AmountOfSubstanceUnits.Megamole:
-            return f"""{self.megamoles} """
+            return f"""{self.megamoles} Mmol"""
         
         if unit == AmountOfSubstanceUnits.NanopoundMole:
-            return f"""{self.nanopound_moles} """
+            return f"""{self.nanopound_moles} nlbmol"""
         
         if unit == AmountOfSubstanceUnits.MicropoundMole:
-            return f"""{self.micropound_moles} """
+            return f"""{self.micropound_moles} μlbmol"""
         
         if unit == AmountOfSubstanceUnits.MillipoundMole:
-            return f"""{self.millipound_moles} """
+            return f"""{self.millipound_moles} mlbmol"""
         
         if unit == AmountOfSubstanceUnits.CentipoundMole:
-            return f"""{self.centipound_moles} """
+            return f"""{self.centipound_moles} clbmol"""
         
         if unit == AmountOfSubstanceUnits.DecipoundMole:
-            return f"""{self.decipound_moles} """
+            return f"""{self.decipound_moles} dlbmol"""
         
         if unit == AmountOfSubstanceUnits.KilopoundMole:
-            return f"""{self.kilopound_moles} """
+            return f"""{self.kilopound_moles} klbmol"""
         
-        return f'{self.__value}'
+        return f'{self._value}'
 
 
-    def get_unit_abbreviation(self, unit_abbreviation: AmountOfSubstanceUnits = AmountOfSubstanceUnits.Mole) -> string:
+    def get_unit_abbreviation(self, unit_abbreviation: AmountOfSubstanceUnits = AmountOfSubstanceUnits.Mole) -> str:
         """
         Get AmountOfSubstance unit abbreviation.
         Note! the default abbreviation for AmountOfSubstance is Mole.
@@ -692,111 +783,48 @@ class AmountOfSubstance:
         if unit_abbreviation == AmountOfSubstanceUnits.PoundMole:
             return """lbmol"""
         
+        if unit_abbreviation == AmountOfSubstanceUnits.Femtomole:
+            return """fmol"""
+        
+        if unit_abbreviation == AmountOfSubstanceUnits.Picomole:
+            return """pmol"""
+        
         if unit_abbreviation == AmountOfSubstanceUnits.Nanomole:
-            return """"""
+            return """nmol"""
         
         if unit_abbreviation == AmountOfSubstanceUnits.Micromole:
-            return """"""
+            return """μmol"""
         
         if unit_abbreviation == AmountOfSubstanceUnits.Millimole:
-            return """"""
+            return """mmol"""
         
         if unit_abbreviation == AmountOfSubstanceUnits.Centimole:
-            return """"""
+            return """cmol"""
         
         if unit_abbreviation == AmountOfSubstanceUnits.Decimole:
-            return """"""
+            return """dmol"""
         
         if unit_abbreviation == AmountOfSubstanceUnits.Kilomole:
-            return """"""
+            return """kmol"""
         
         if unit_abbreviation == AmountOfSubstanceUnits.Megamole:
-            return """"""
+            return """Mmol"""
         
         if unit_abbreviation == AmountOfSubstanceUnits.NanopoundMole:
-            return """"""
+            return """nlbmol"""
         
         if unit_abbreviation == AmountOfSubstanceUnits.MicropoundMole:
-            return """"""
+            return """μlbmol"""
         
         if unit_abbreviation == AmountOfSubstanceUnits.MillipoundMole:
-            return """"""
+            return """mlbmol"""
         
         if unit_abbreviation == AmountOfSubstanceUnits.CentipoundMole:
-            return """"""
+            return """clbmol"""
         
         if unit_abbreviation == AmountOfSubstanceUnits.DecipoundMole:
-            return """"""
+            return """dlbmol"""
         
         if unit_abbreviation == AmountOfSubstanceUnits.KilopoundMole:
-            return """"""
-        
-
-    def __str__(self):
-        return self.to_string()
-
-
-    def __add__(self, other):
-        if not isinstance(other, AmountOfSubstance):
-            raise TypeError("unsupported operand type(s) for +: 'AmountOfSubstance' and '{}'".format(type(other).__name__))
-        return AmountOfSubstance(self.__value + other.__value)
-
-
-    def __mul__(self, other):
-        if not isinstance(other, AmountOfSubstance):
-            raise TypeError("unsupported operand type(s) for *: 'AmountOfSubstance' and '{}'".format(type(other).__name__))
-        return AmountOfSubstance(self.__value * other.__value)
-
-
-    def __sub__(self, other):
-        if not isinstance(other, AmountOfSubstance):
-            raise TypeError("unsupported operand type(s) for -: 'AmountOfSubstance' and '{}'".format(type(other).__name__))
-        return AmountOfSubstance(self.__value - other.__value)
-
-
-    def __truediv__(self, other):
-        if not isinstance(other, AmountOfSubstance):
-            raise TypeError("unsupported operand type(s) for /: 'AmountOfSubstance' and '{}'".format(type(other).__name__))
-        return AmountOfSubstance(self.__value / other.__value)
-
-
-    def __mod__(self, other):
-        if not isinstance(other, AmountOfSubstance):
-            raise TypeError("unsupported operand type(s) for %: 'AmountOfSubstance' and '{}'".format(type(other).__name__))
-        return AmountOfSubstance(self.__value % other.__value)
-
-
-    def __pow__(self, other):
-        if not isinstance(other, AmountOfSubstance):
-            raise TypeError("unsupported operand type(s) for **: 'AmountOfSubstance' and '{}'".format(type(other).__name__))
-        return AmountOfSubstance(self.__value ** other.__value)
-
-
-    def __eq__(self, other):
-        if not isinstance(other, AmountOfSubstance):
-            raise TypeError("unsupported operand type(s) for ==: 'AmountOfSubstance' and '{}'".format(type(other).__name__))
-        return self.__value == other.__value
-
-
-    def __lt__(self, other):
-        if not isinstance(other, AmountOfSubstance):
-            raise TypeError("unsupported operand type(s) for <: 'AmountOfSubstance' and '{}'".format(type(other).__name__))
-        return self.__value < other.__value
-
-
-    def __gt__(self, other):
-        if not isinstance(other, AmountOfSubstance):
-            raise TypeError("unsupported operand type(s) for >: 'AmountOfSubstance' and '{}'".format(type(other).__name__))
-        return self.__value > other.__value
-
-
-    def __le__(self, other):
-        if not isinstance(other, AmountOfSubstance):
-            raise TypeError("unsupported operand type(s) for <=: 'AmountOfSubstance' and '{}'".format(type(other).__name__))
-        return self.__value <= other.__value
-
-
-    def __ge__(self, other):
-        if not isinstance(other, AmountOfSubstance):
-            raise TypeError("unsupported operand type(s) for >=: 'AmountOfSubstance' and '{}'".format(type(other).__name__))
-        return self.__value >= other.__value
\ No newline at end of file
+            return """klbmol"""
+        
\ No newline at end of file
