@@ -1,6 +1,8 @@
 from enum import Enum
 import math
-import string
+
+from ..abstract_unit import AbstractMeasure
+
 
 
 class AngleUnits(Enum):
@@ -89,7 +91,7 @@ class AngleUnits(Enum):
         """
         
 
-class Angle:
+class Angle(AbstractMeasure):
     """
     In geometry, an angle is the figure formed by two rays, called the sides of the angle, sharing a common endpoint, called the vertex of the angle.
 
@@ -98,9 +100,11 @@ class Angle:
         from_unit (AngleUnits): The Angle unit to create from, The default unit is Degree
     """
     def __init__(self, value: float, from_unit: AngleUnits = AngleUnits.Degree):
-        if math.isnan(value):
-            raise ValueError('Invalid unit: value is NaN')
-        self.__value = self.__convert_to_base(value, from_unit)
+        # Do not validate type, to allow working with numpay arrays and similar objects who supports all arithmetic 
+        # operations, but they are not a number, see #14 
+        # if math.isnan(value):
+        #     raise ValueError('Invalid unit: value is NaN')
+        self._value = self.__convert_to_base(value, from_unit)
         
         self.__radians = None
         
@@ -135,8 +139,11 @@ class Angle:
         self.__millidegrees = None
         
 
+    def convert(self, unit: AngleUnits) -> float:
+        return self.__convert_from_base(unit)
+
     def __convert_from_base(self, from_unit: AngleUnits) -> float:
-        value = self.__value
+        value = self._value
         
         if from_unit == AngleUnits.Radian:
             return (value / 180 * math.pi)
@@ -244,7 +251,7 @@ class Angle:
 
     @property
     def base_value(self) -> float:
-        return self.__value
+        return self._value
 
     
     @staticmethod
@@ -663,7 +670,7 @@ class Angle:
         return self.__millidegrees
 
     
-    def to_string(self, unit: AngleUnits = AngleUnits.Degree) -> string:
+    def to_string(self, unit: AngleUnits = AngleUnits.Degree) -> str:
         """
         Format the Angle to string.
         Note! the default format for Angle is Degree.
@@ -695,33 +702,33 @@ class Angle:
             return f"""{self.tilt} sin(θ)"""
         
         if unit == AngleUnits.Nanoradian:
-            return f"""{self.nanoradians} """
+            return f"""{self.nanoradians} nrad"""
         
         if unit == AngleUnits.Microradian:
-            return f"""{self.microradians} """
+            return f"""{self.microradians} μrad"""
         
         if unit == AngleUnits.Milliradian:
-            return f"""{self.milliradians} """
+            return f"""{self.milliradians} mrad"""
         
         if unit == AngleUnits.Centiradian:
-            return f"""{self.centiradians} """
+            return f"""{self.centiradians} crad"""
         
         if unit == AngleUnits.Deciradian:
-            return f"""{self.deciradians} """
+            return f"""{self.deciradians} drad"""
         
         if unit == AngleUnits.Nanodegree:
-            return f"""{self.nanodegrees} """
+            return f"""{self.nanodegrees} n°"""
         
         if unit == AngleUnits.Microdegree:
-            return f"""{self.microdegrees} """
+            return f"""{self.microdegrees} μ°"""
         
         if unit == AngleUnits.Millidegree:
-            return f"""{self.millidegrees} """
+            return f"""{self.millidegrees} m°"""
         
-        return f'{self.__value}'
+        return f'{self._value}'
 
 
-    def get_unit_abbreviation(self, unit_abbreviation: AngleUnits = AngleUnits.Degree) -> string:
+    def get_unit_abbreviation(self, unit_abbreviation: AngleUnits = AngleUnits.Degree) -> str:
         """
         Get Angle unit abbreviation.
         Note! the default abbreviation for Angle is Degree.
@@ -753,95 +760,26 @@ class Angle:
             return """sin(θ)"""
         
         if unit_abbreviation == AngleUnits.Nanoradian:
-            return """"""
+            return """nrad"""
         
         if unit_abbreviation == AngleUnits.Microradian:
-            return """"""
+            return """μrad"""
         
         if unit_abbreviation == AngleUnits.Milliradian:
-            return """"""
+            return """mrad"""
         
         if unit_abbreviation == AngleUnits.Centiradian:
-            return """"""
+            return """crad"""
         
         if unit_abbreviation == AngleUnits.Deciradian:
-            return """"""
+            return """drad"""
         
         if unit_abbreviation == AngleUnits.Nanodegree:
-            return """"""
+            return """n°"""
         
         if unit_abbreviation == AngleUnits.Microdegree:
-            return """"""
+            return """μ°"""
         
         if unit_abbreviation == AngleUnits.Millidegree:
-            return """"""
-        
-
-    def __str__(self):
-        return self.to_string()
-
-
-    def __add__(self, other):
-        if not isinstance(other, Angle):
-            raise TypeError("unsupported operand type(s) for +: 'Angle' and '{}'".format(type(other).__name__))
-        return Angle(self.__value + other.__value)
-
-
-    def __mul__(self, other):
-        if not isinstance(other, Angle):
-            raise TypeError("unsupported operand type(s) for *: 'Angle' and '{}'".format(type(other).__name__))
-        return Angle(self.__value * other.__value)
-
-
-    def __sub__(self, other):
-        if not isinstance(other, Angle):
-            raise TypeError("unsupported operand type(s) for -: 'Angle' and '{}'".format(type(other).__name__))
-        return Angle(self.__value - other.__value)
-
-
-    def __truediv__(self, other):
-        if not isinstance(other, Angle):
-            raise TypeError("unsupported operand type(s) for /: 'Angle' and '{}'".format(type(other).__name__))
-        return Angle(self.__value / other.__value)
-
-
-    def __mod__(self, other):
-        if not isinstance(other, Angle):
-            raise TypeError("unsupported operand type(s) for %: 'Angle' and '{}'".format(type(other).__name__))
-        return Angle(self.__value % other.__value)
-
-
-    def __pow__(self, other):
-        if not isinstance(other, Angle):
-            raise TypeError("unsupported operand type(s) for **: 'Angle' and '{}'".format(type(other).__name__))
-        return Angle(self.__value ** other.__value)
-
-
-    def __eq__(self, other):
-        if not isinstance(other, Angle):
-            raise TypeError("unsupported operand type(s) for ==: 'Angle' and '{}'".format(type(other).__name__))
-        return self.__value == other.__value
-
-
-    def __lt__(self, other):
-        if not isinstance(other, Angle):
-            raise TypeError("unsupported operand type(s) for <: 'Angle' and '{}'".format(type(other).__name__))
-        return self.__value < other.__value
-
-
-    def __gt__(self, other):
-        if not isinstance(other, Angle):
-            raise TypeError("unsupported operand type(s) for >: 'Angle' and '{}'".format(type(other).__name__))
-        return self.__value > other.__value
-
-
-    def __le__(self, other):
-        if not isinstance(other, Angle):
-            raise TypeError("unsupported operand type(s) for <=: 'Angle' and '{}'".format(type(other).__name__))
-        return self.__value <= other.__value
-
-
-    def __ge__(self, other):
-        if not isinstance(other, Angle):
-            raise TypeError("unsupported operand type(s) for >=: 'Angle' and '{}'".format(type(other).__name__))
-        return self.__value >= other.__value
\ No newline at end of file
+            return """m°"""
+        
\ No newline at end of file
