@@ -1,6 +1,8 @@
 from enum import Enum
 import math
-import string
+
+from ..abstract_unit import AbstractMeasure
+
 
 
 class AreaUnits(Enum):
@@ -79,7 +81,7 @@ class AreaUnits(Enum):
         """
         
 
-class Area:
+class Area(AbstractMeasure):
     """
     Area is a quantity that expresses the extent of a two-dimensional surface or shape, or planar lamina, in the plane. Area can be understood as the amount of material with a given thickness that would be necessary to fashion a model of the shape, or the amount of paint necessary to cover the surface with a single coat.[1] It is the two-dimensional analog of the length of a curve (a one-dimensional concept) or the volume of a solid (a three-dimensional concept).
 
@@ -88,9 +90,11 @@ class Area:
         from_unit (AreaUnits): The Area unit to create from, The default unit is SquareMeter
     """
     def __init__(self, value: float, from_unit: AreaUnits = AreaUnits.SquareMeter):
-        if math.isnan(value):
-            raise ValueError('Invalid unit: value is NaN')
-        self.__value = self.__convert_to_base(value, from_unit)
+        # Do not validate type, to allow working with numpay arrays and similar objects who supports all arithmetic 
+        # operations, but they are not a number, see #14 
+        # if math.isnan(value):
+        #     raise ValueError('Invalid unit: value is NaN')
+        self._value = self.__convert_to_base(value, from_unit)
         
         self.__square_kilometers = None
         
@@ -121,8 +125,11 @@ class Area:
         self.__square_nautical_miles = None
         
 
+    def convert(self, unit: AreaUnits) -> float:
+        return self.__convert_from_base(unit)
+
     def __convert_from_base(self, from_unit: AreaUnits) -> float:
-        value = self.__value
+        value = self._value
         
         if from_unit == AreaUnits.SquareKilometer:
             return (value / 1e6)
@@ -218,7 +225,7 @@ class Area:
 
     @property
     def base_value(self) -> float:
-        return self.__value
+        return self._value
 
     
     @staticmethod
@@ -585,7 +592,7 @@ class Area:
         return self.__square_nautical_miles
 
     
-    def to_string(self, unit: AreaUnits = AreaUnits.SquareMeter) -> string:
+    def to_string(self, unit: AreaUnits = AreaUnits.SquareMeter) -> str:
         """
         Format the Area to string.
         Note! the default format for Area is SquareMeter.
@@ -634,10 +641,10 @@ class Area:
         if unit == AreaUnits.SquareNauticalMile:
             return f"""{self.square_nautical_miles} nmi²"""
         
-        return f'{self.__value}'
+        return f'{self._value}'
 
 
-    def get_unit_abbreviation(self, unit_abbreviation: AreaUnits = AreaUnits.SquareMeter) -> string:
+    def get_unit_abbreviation(self, unit_abbreviation: AreaUnits = AreaUnits.SquareMeter) -> str:
         """
         Get Area unit abbreviation.
         Note! the default abbreviation for Area is SquareMeter.
@@ -685,73 +692,4 @@ class Area:
         
         if unit_abbreviation == AreaUnits.SquareNauticalMile:
             return """nmi²"""
-        
-
-    def __str__(self):
-        return self.to_string()
-
-
-    def __add__(self, other):
-        if not isinstance(other, Area):
-            raise TypeError("unsupported operand type(s) for +: 'Area' and '{}'".format(type(other).__name__))
-        return Area(self.__value + other.__value)
-
-
-    def __mul__(self, other):
-        if not isinstance(other, Area):
-            raise TypeError("unsupported operand type(s) for *: 'Area' and '{}'".format(type(other).__name__))
-        return Area(self.__value * other.__value)
-
-
-    def __sub__(self, other):
-        if not isinstance(other, Area):
-            raise TypeError("unsupported operand type(s) for -: 'Area' and '{}'".format(type(other).__name__))
-        return Area(self.__value - other.__value)
-
-
-    def __truediv__(self, other):
-        if not isinstance(other, Area):
-            raise TypeError("unsupported operand type(s) for /: 'Area' and '{}'".format(type(other).__name__))
-        return Area(self.__value / other.__value)
-
-
-    def __mod__(self, other):
-        if not isinstance(other, Area):
-            raise TypeError("unsupported operand type(s) for %: 'Area' and '{}'".format(type(other).__name__))
-        return Area(self.__value % other.__value)
-
-
-    def __pow__(self, other):
-        if not isinstance(other, Area):
-            raise TypeError("unsupported operand type(s) for **: 'Area' and '{}'".format(type(other).__name__))
-        return Area(self.__value ** other.__value)
-
-
-    def __eq__(self, other):
-        if not isinstance(other, Area):
-            raise TypeError("unsupported operand type(s) for ==: 'Area' and '{}'".format(type(other).__name__))
-        return self.__value == other.__value
-
-
-    def __lt__(self, other):
-        if not isinstance(other, Area):
-            raise TypeError("unsupported operand type(s) for <: 'Area' and '{}'".format(type(other).__name__))
-        return self.__value < other.__value
-
-
-    def __gt__(self, other):
-        if not isinstance(other, Area):
-            raise TypeError("unsupported operand type(s) for >: 'Area' and '{}'".format(type(other).__name__))
-        return self.__value > other.__value
-
-
-    def __le__(self, other):
-        if not isinstance(other, Area):
-            raise TypeError("unsupported operand type(s) for <=: 'Area' and '{}'".format(type(other).__name__))
-        return self.__value <= other.__value
-
-
-    def __ge__(self, other):
-        if not isinstance(other, Area):
-            raise TypeError("unsupported operand type(s) for >=: 'Area' and '{}'".format(type(other).__name__))
-        return self.__value >= other.__value
\ No newline at end of file
+        
\ No newline at end of file
