@@ -1,6 +1,8 @@
 from enum import Enum
 import math
-import string
+
+from ..abstract_unit import AbstractMeasure
+
 
 
 class BitRateUnits(Enum):
@@ -79,7 +81,7 @@ class BitRateUnits(Enum):
         """
         
 
-class BitRate:
+class BitRate(AbstractMeasure):
     """
     In telecommunications and computing, bit rate is the number of bits that are conveyed or processed per unit of time.
 
@@ -88,9 +90,11 @@ class BitRate:
         from_unit (BitRateUnits): The BitRate unit to create from, The default unit is BitPerSecond
     """
     def __init__(self, value: float, from_unit: BitRateUnits = BitRateUnits.BitPerSecond):
-        if math.isnan(value):
-            raise ValueError('Invalid unit: value is NaN')
-        self.__value = self.__convert_to_base(value, from_unit)
+        # Do not validate type, to allow working with numpay arrays and similar objects who supports all arithmetic 
+        # operations, but they are not a number, see #14 
+        # if math.isnan(value):
+        #     raise ValueError('Invalid unit: value is NaN')
+        self._value = self.__convert_to_base(value, from_unit)
         
         self.__bits_per_second = None
         
@@ -121,8 +125,11 @@ class BitRate:
         self.__exabytes_per_second = None
         
 
+    def convert(self, unit: BitRateUnits) -> float:
+        return self.__convert_from_base(unit)
+
     def __convert_from_base(self, from_unit: BitRateUnits) -> float:
-        value = self.__value
+        value = self._value
         
         if from_unit == BitRateUnits.BitPerSecond:
             return (value)
@@ -218,7 +225,7 @@ class BitRate:
 
     @property
     def base_value(self) -> float:
-        return self.__value
+        return self._value
 
     
     @staticmethod
@@ -585,7 +592,7 @@ class BitRate:
         return self.__exabytes_per_second
 
     
-    def to_string(self, unit: BitRateUnits = BitRateUnits.BitPerSecond) -> string:
+    def to_string(self, unit: BitRateUnits = BitRateUnits.BitPerSecond) -> str:
         """
         Format the BitRate to string.
         Note! the default format for BitRate is BitPerSecond.
@@ -599,45 +606,45 @@ class BitRate:
             return f"""{self.bytes_per_second} B/s"""
         
         if unit == BitRateUnits.KilobitPerSecond:
-            return f"""{self.kilobits_per_second} """
+            return f"""{self.kilobits_per_second} kbit/s"""
         
         if unit == BitRateUnits.MegabitPerSecond:
-            return f"""{self.megabits_per_second} """
+            return f"""{self.megabits_per_second} Mbit/s"""
         
         if unit == BitRateUnits.GigabitPerSecond:
-            return f"""{self.gigabits_per_second} """
+            return f"""{self.gigabits_per_second} Gbit/s"""
         
         if unit == BitRateUnits.TerabitPerSecond:
-            return f"""{self.terabits_per_second} """
+            return f"""{self.terabits_per_second} Tbit/s"""
         
         if unit == BitRateUnits.PetabitPerSecond:
-            return f"""{self.petabits_per_second} """
+            return f"""{self.petabits_per_second} Pbit/s"""
         
         if unit == BitRateUnits.ExabitPerSecond:
-            return f"""{self.exabits_per_second} """
+            return f"""{self.exabits_per_second} Ebit/s"""
         
         if unit == BitRateUnits.KilobytePerSecond:
-            return f"""{self.kilobytes_per_second} """
+            return f"""{self.kilobytes_per_second} kB/s"""
         
         if unit == BitRateUnits.MegabytePerSecond:
-            return f"""{self.megabytes_per_second} """
+            return f"""{self.megabytes_per_second} MB/s"""
         
         if unit == BitRateUnits.GigabytePerSecond:
-            return f"""{self.gigabytes_per_second} """
+            return f"""{self.gigabytes_per_second} GB/s"""
         
         if unit == BitRateUnits.TerabytePerSecond:
-            return f"""{self.terabytes_per_second} """
+            return f"""{self.terabytes_per_second} TB/s"""
         
         if unit == BitRateUnits.PetabytePerSecond:
-            return f"""{self.petabytes_per_second} """
+            return f"""{self.petabytes_per_second} PB/s"""
         
         if unit == BitRateUnits.ExabytePerSecond:
-            return f"""{self.exabytes_per_second} """
+            return f"""{self.exabytes_per_second} EB/s"""
         
-        return f'{self.__value}'
+        return f'{self._value}'
 
 
-    def get_unit_abbreviation(self, unit_abbreviation: BitRateUnits = BitRateUnits.BitPerSecond) -> string:
+    def get_unit_abbreviation(self, unit_abbreviation: BitRateUnits = BitRateUnits.BitPerSecond) -> str:
         """
         Get BitRate unit abbreviation.
         Note! the default abbreviation for BitRate is BitPerSecond.
@@ -651,107 +658,38 @@ class BitRate:
             return """B/s"""
         
         if unit_abbreviation == BitRateUnits.KilobitPerSecond:
-            return """"""
+            return """kbit/s"""
         
         if unit_abbreviation == BitRateUnits.MegabitPerSecond:
-            return """"""
+            return """Mbit/s"""
         
         if unit_abbreviation == BitRateUnits.GigabitPerSecond:
-            return """"""
+            return """Gbit/s"""
         
         if unit_abbreviation == BitRateUnits.TerabitPerSecond:
-            return """"""
+            return """Tbit/s"""
         
         if unit_abbreviation == BitRateUnits.PetabitPerSecond:
-            return """"""
+            return """Pbit/s"""
         
         if unit_abbreviation == BitRateUnits.ExabitPerSecond:
-            return """"""
+            return """Ebit/s"""
         
         if unit_abbreviation == BitRateUnits.KilobytePerSecond:
-            return """"""
+            return """kB/s"""
         
         if unit_abbreviation == BitRateUnits.MegabytePerSecond:
-            return """"""
+            return """MB/s"""
         
         if unit_abbreviation == BitRateUnits.GigabytePerSecond:
-            return """"""
+            return """GB/s"""
         
         if unit_abbreviation == BitRateUnits.TerabytePerSecond:
-            return """"""
+            return """TB/s"""
         
         if unit_abbreviation == BitRateUnits.PetabytePerSecond:
-            return """"""
+            return """PB/s"""
         
         if unit_abbreviation == BitRateUnits.ExabytePerSecond:
-            return """"""
-        
-
-    def __str__(self):
-        return self.to_string()
-
-
-    def __add__(self, other):
-        if not isinstance(other, BitRate):
-            raise TypeError("unsupported operand type(s) for +: 'BitRate' and '{}'".format(type(other).__name__))
-        return BitRate(self.__value + other.__value)
-
-
-    def __mul__(self, other):
-        if not isinstance(other, BitRate):
-            raise TypeError("unsupported operand type(s) for *: 'BitRate' and '{}'".format(type(other).__name__))
-        return BitRate(self.__value * other.__value)
-
-
-    def __sub__(self, other):
-        if not isinstance(other, BitRate):
-            raise TypeError("unsupported operand type(s) for -: 'BitRate' and '{}'".format(type(other).__name__))
-        return BitRate(self.__value - other.__value)
-
-
-    def __truediv__(self, other):
-        if not isinstance(other, BitRate):
-            raise TypeError("unsupported operand type(s) for /: 'BitRate' and '{}'".format(type(other).__name__))
-        return BitRate(self.__value / other.__value)
-
-
-    def __mod__(self, other):
-        if not isinstance(other, BitRate):
-            raise TypeError("unsupported operand type(s) for %: 'BitRate' and '{}'".format(type(other).__name__))
-        return BitRate(self.__value % other.__value)
-
-
-    def __pow__(self, other):
-        if not isinstance(other, BitRate):
-            raise TypeError("unsupported operand type(s) for **: 'BitRate' and '{}'".format(type(other).__name__))
-        return BitRate(self.__value ** other.__value)
-
-
-    def __eq__(self, other):
-        if not isinstance(other, BitRate):
-            raise TypeError("unsupported operand type(s) for ==: 'BitRate' and '{}'".format(type(other).__name__))
-        return self.__value == other.__value
-
-
-    def __lt__(self, other):
-        if not isinstance(other, BitRate):
-            raise TypeError("unsupported operand type(s) for <: 'BitRate' and '{}'".format(type(other).__name__))
-        return self.__value < other.__value
-
-
-    def __gt__(self, other):
-        if not isinstance(other, BitRate):
-            raise TypeError("unsupported operand type(s) for >: 'BitRate' and '{}'".format(type(other).__name__))
-        return self.__value > other.__value
-
-
-    def __le__(self, other):
-        if not isinstance(other, BitRate):
-            raise TypeError("unsupported operand type(s) for <=: 'BitRate' and '{}'".format(type(other).__name__))
-        return self.__value <= other.__value
-
-
-    def __ge__(self, other):
-        if not isinstance(other, BitRate):
-            raise TypeError("unsupported operand type(s) for >=: 'BitRate' and '{}'".format(type(other).__name__))
-        return self.__value >= other.__value
\ No newline at end of file
+            return """EB/s"""
+        
\ No newline at end of file
