@@ -1,6 +1,8 @@
 from enum import Enum
 import math
-import string
+
+from ..abstract_unit import AbstractMeasure
+
 
 
 class DensityUnits(Enum):
@@ -33,6 +35,11 @@ class DensityUnits(Enum):
             
         """
         
+        PoundPerCubicYard = 'pound_per_cubic_yard'
+        """
+            Calculated from the definition of <a href="https://en.wikipedia.org/wiki/Pound_(mass)">pound</a> and <a href="https://en.wikipedia.org/wiki/Yard">yard</a> compared to metric kilogram and meter.
+        """
+        
         TonnePerCubicMillimeter = 'tonne_per_cubic_millimeter'
         """
             
@@ -173,6 +180,16 @@ class DensityUnits(Enum):
             
         """
         
+        KilopoundPerCubicYard = 'kilopound_per_cubic_yard'
+        """
+            
+        """
+        
+        FemtogramPerLiter = 'femtogram_per_liter'
+        """
+            
+        """
+        
         PicogramPerLiter = 'picogram_per_liter'
         """
             
@@ -203,6 +220,11 @@ class DensityUnits(Enum):
             
         """
         
+        FemtogramPerDeciliter = 'femtogram_per_deciliter'
+        """
+            
+        """
+        
         PicogramPerDeciliter = 'picogram_per_deciliter'
         """
             
@@ -233,6 +255,11 @@ class DensityUnits(Enum):
             
         """
         
+        FemtogramPerMilliliter = 'femtogram_per_milliliter'
+        """
+            
+        """
+        
         PicogramPerMilliliter = 'picogram_per_milliliter'
         """
             
@@ -264,7 +291,7 @@ class DensityUnits(Enum):
         """
         
 
-class Density:
+class Density(AbstractMeasure):
     """
     The density, or more precisely, the volumetric mass density, of a substance is its mass per unit volume.
 
@@ -273,9 +300,11 @@ class Density:
         from_unit (DensityUnits): The Density unit to create from, The default unit is KilogramPerCubicMeter
     """
     def __init__(self, value: float, from_unit: DensityUnits = DensityUnits.KilogramPerCubicMeter):
-        if math.isnan(value):
-            raise ValueError('Invalid unit: value is NaN')
-        self.__value = self.__convert_to_base(value, from_unit)
+        # Do not validate type, to allow working with numpay arrays and similar objects who supports all arithmetic 
+        # operations, but they are not a number, see #14 
+        # if math.isnan(value):
+        #     raise ValueError('Invalid unit: value is NaN')
+        self._value = self.__convert_to_base(value, from_unit)
         
         self.__grams_per_cubic_millimeter = None
         
@@ -287,6 +316,8 @@ class Density:
         
         self.__pounds_per_cubic_foot = None
         
+        self.__pounds_per_cubic_yard = None
+        
         self.__tonnes_per_cubic_millimeter = None
         
         self.__tonnes_per_cubic_centimeter = None
@@ -343,6 +374,10 @@ class Density:
         
         self.__kilopounds_per_cubic_foot = None
         
+        self.__kilopounds_per_cubic_yard = None
+        
+        self.__femtograms_per_liter = None
+        
         self.__picograms_per_liter = None
         
         self.__nanograms_per_liter = None
@@ -355,6 +390,8 @@ class Density:
         
         self.__decigrams_per_liter = None
         
+        self.__femtograms_per_deci_liter = None
+        
         self.__picograms_per_deci_liter = None
         
         self.__nanograms_per_deci_liter = None
@@ -367,6 +404,8 @@ class Density:
         
         self.__decigrams_per_deci_liter = None
         
+        self.__femtograms_per_milliliter = None
+        
         self.__picograms_per_milliliter = None
         
         self.__nanograms_per_milliliter = None
@@ -380,8 +419,11 @@ class Density:
         self.__decigrams_per_milliliter = None
         
 
+    def convert(self, unit: DensityUnits) -> float:
+        return self.__convert_from_base(unit)
+
     def __convert_from_base(self, from_unit: DensityUnits) -> float:
-        value = self.__value
+        value = self._value
         
         if from_unit == DensityUnits.GramPerCubicMillimeter:
             return (value * 1e-6)
@@ -398,6 +440,9 @@ class Density:
         if from_unit == DensityUnits.PoundPerCubicFoot:
             return (value * 0.062427961)
         
+        if from_unit == DensityUnits.PoundPerCubicYard:
+            return (value / (0.45359237 / 0.9144 / 0.9144 / 0.9144))
+        
         if from_unit == DensityUnits.TonnePerCubicMillimeter:
             return (value * 1e-12)
         
@@ -482,6 +527,12 @@ class Density:
         if from_unit == DensityUnits.KilopoundPerCubicFoot:
             return ((value * 0.062427961) / 1000.0)
         
+        if from_unit == DensityUnits.KilopoundPerCubicYard:
+            return ((value / (0.45359237 / 0.9144 / 0.9144 / 0.9144)) / 1000.0)
+        
+        if from_unit == DensityUnits.FemtogramPerLiter:
+            return ((value * 1) / 1e-15)
+        
         if from_unit == DensityUnits.PicogramPerLiter:
             return ((value * 1) / 1e-12)
         
@@ -500,6 +551,9 @@ class Density:
         if from_unit == DensityUnits.DecigramPerLiter:
             return ((value * 1) / 0.1)
         
+        if from_unit == DensityUnits.FemtogramPerDeciliter:
+            return ((value * 1e-1) / 1e-15)
+        
         if from_unit == DensityUnits.PicogramPerDeciliter:
             return ((value * 1e-1) / 1e-12)
         
@@ -518,6 +572,9 @@ class Density:
         if from_unit == DensityUnits.DecigramPerDeciliter:
             return ((value * 1e-1) / 0.1)
         
+        if from_unit == DensityUnits.FemtogramPerMilliliter:
+            return ((value * 1e-3) / 1e-15)
+        
         if from_unit == DensityUnits.PicogramPerMilliliter:
             return ((value * 1e-3) / 1e-12)
         
@@ -556,6 +613,9 @@ class Density:
         if to_unit == DensityUnits.PoundPerCubicFoot:
             return (value / 0.062427961)
         
+        if to_unit == DensityUnits.PoundPerCubicYard:
+            return (value * (0.45359237 / 0.9144 / 0.9144 / 0.9144))
+        
         if to_unit == DensityUnits.TonnePerCubicMillimeter:
             return (value / 1e-12)
         
@@ -640,6 +700,12 @@ class Density:
         if to_unit == DensityUnits.KilopoundPerCubicFoot:
             return ((value / 0.062427961) * 1000.0)
         
+        if to_unit == DensityUnits.KilopoundPerCubicYard:
+            return ((value * (0.45359237 / 0.9144 / 0.9144 / 0.9144)) * 1000.0)
+        
+        if to_unit == DensityUnits.FemtogramPerLiter:
+            return ((value / 1) * 1e-15)
+        
         if to_unit == DensityUnits.PicogramPerLiter:
             return ((value / 1) * 1e-12)
         
@@ -658,6 +724,9 @@ class Density:
         if to_unit == DensityUnits.DecigramPerLiter:
             return ((value / 1) * 0.1)
         
+        if to_unit == DensityUnits.FemtogramPerDeciliter:
+            return ((value / 1e-1) * 1e-15)
+        
         if to_unit == DensityUnits.PicogramPerDeciliter:
             return ((value / 1e-1) * 1e-12)
         
@@ -676,6 +745,9 @@ class Density:
         if to_unit == DensityUnits.DecigramPerDeciliter:
             return ((value / 1e-1) * 0.1)
         
+        if to_unit == DensityUnits.FemtogramPerMilliliter:
+            return ((value / 1e-3) * 1e-15)
+        
         if to_unit == DensityUnits.PicogramPerMilliliter:
             return ((value / 1e-3) * 1e-12)
         
@@ -699,7 +771,7 @@ class Density:
 
     @property
     def base_value(self) -> float:
-        return self.__value
+        return self._value
 
     
     @staticmethod
@@ -777,6 +849,21 @@ class Density:
         return Density(pounds_per_cubic_foot, DensityUnits.PoundPerCubicFoot)
 
     
+    @staticmethod
+    def from_pounds_per_cubic_yard(pounds_per_cubic_yard: float):
+        """
+        Create a new instance of Density from a value in pounds_per_cubic_yard.
+
+        Calculated from the definition of <a href="https://en.wikipedia.org/wiki/Pound_(mass)">pound</a> and <a href="https://en.wikipedia.org/wiki/Yard">yard</a> compared to metric kilogram and meter.
+
+        :param meters: The Density value in pounds_per_cubic_yard.
+        :type pounds_per_cubic_yard: float
+        :return: A new instance of Density.
+        :rtype: Density
+        """
+        return Density(pounds_per_cubic_yard, DensityUnits.PoundPerCubicYard)
+
+    
     @staticmethod
     def from_tonnes_per_cubic_millimeter(tonnes_per_cubic_millimeter: float):
         """
@@ -1197,6 +1284,36 @@ class Density:
         return Density(kilopounds_per_cubic_foot, DensityUnits.KilopoundPerCubicFoot)
 
     
+    @staticmethod
+    def from_kilopounds_per_cubic_yard(kilopounds_per_cubic_yard: float):
+        """
+        Create a new instance of Density from a value in kilopounds_per_cubic_yard.
+
+        
+
+        :param meters: The Density value in kilopounds_per_cubic_yard.
+        :type kilopounds_per_cubic_yard: float
+        :return: A new instance of Density.
+        :rtype: Density
+        """
+        return Density(kilopounds_per_cubic_yard, DensityUnits.KilopoundPerCubicYard)
+
+    
+    @staticmethod
+    def from_femtograms_per_liter(femtograms_per_liter: float):
+        """
+        Create a new instance of Density from a value in femtograms_per_liter.
+
+        
+
+        :param meters: The Density value in femtograms_per_liter.
+        :type femtograms_per_liter: float
+        :return: A new instance of Density.
+        :rtype: Density
+        """
+        return Density(femtograms_per_liter, DensityUnits.FemtogramPerLiter)
+
+    
     @staticmethod
     def from_picograms_per_liter(picograms_per_liter: float):
         """
@@ -1287,6 +1404,21 @@ class Density:
         return Density(decigrams_per_liter, DensityUnits.DecigramPerLiter)
 
     
+    @staticmethod
+    def from_femtograms_per_deci_liter(femtograms_per_deci_liter: float):
+        """
+        Create a new instance of Density from a value in femtograms_per_deci_liter.
+
+        
+
+        :param meters: The Density value in femtograms_per_deci_liter.
+        :type femtograms_per_deci_liter: float
+        :return: A new instance of Density.
+        :rtype: Density
+        """
+        return Density(femtograms_per_deci_liter, DensityUnits.FemtogramPerDeciliter)
+
+    
     @staticmethod
     def from_picograms_per_deci_liter(picograms_per_deci_liter: float):
         """
@@ -1377,6 +1509,21 @@ class Density:
         return Density(decigrams_per_deci_liter, DensityUnits.DecigramPerDeciliter)
 
     
+    @staticmethod
+    def from_femtograms_per_milliliter(femtograms_per_milliliter: float):
+        """
+        Create a new instance of Density from a value in femtograms_per_milliliter.
+
+        
+
+        :param meters: The Density value in femtograms_per_milliliter.
+        :type femtograms_per_milliliter: float
+        :return: A new instance of Density.
+        :rtype: Density
+        """
+        return Density(femtograms_per_milliliter, DensityUnits.FemtogramPerMilliliter)
+
+    
     @staticmethod
     def from_picograms_per_milliliter(picograms_per_milliliter: float):
         """
@@ -1522,6 +1669,17 @@ class Density:
         return self.__pounds_per_cubic_foot
 
     
+    @property
+    def pounds_per_cubic_yard(self) -> float:
+        """
+        Calculated from the definition of <a href="https://en.wikipedia.org/wiki/Pound_(mass)">pound</a> and <a href="https://en.wikipedia.org/wiki/Yard">yard</a> compared to metric kilogram and meter.
+        """
+        if self.__pounds_per_cubic_yard != None:
+            return self.__pounds_per_cubic_yard
+        self.__pounds_per_cubic_yard = self.__convert_from_base(DensityUnits.PoundPerCubicYard)
+        return self.__pounds_per_cubic_yard
+
+    
     @property
     def tonnes_per_cubic_millimeter(self) -> float:
         """
@@ -1830,6 +1988,28 @@ class Density:
         return self.__kilopounds_per_cubic_foot
 
     
+    @property
+    def kilopounds_per_cubic_yard(self) -> float:
+        """
+        
+        """
+        if self.__kilopounds_per_cubic_yard != None:
+            return self.__kilopounds_per_cubic_yard
+        self.__kilopounds_per_cubic_yard = self.__convert_from_base(DensityUnits.KilopoundPerCubicYard)
+        return self.__kilopounds_per_cubic_yard
+
+    
+    @property
+    def femtograms_per_liter(self) -> float:
+        """
+        
+        """
+        if self.__femtograms_per_liter != None:
+            return self.__femtograms_per_liter
+        self.__femtograms_per_liter = self.__convert_from_base(DensityUnits.FemtogramPerLiter)
+        return self.__femtograms_per_liter
+
+    
     @property
     def picograms_per_liter(self) -> float:
         """
@@ -1896,6 +2076,17 @@ class Density:
         return self.__decigrams_per_liter
 
     
+    @property
+    def femtograms_per_deci_liter(self) -> float:
+        """
+        
+        """
+        if self.__femtograms_per_deci_liter != None:
+            return self.__femtograms_per_deci_liter
+        self.__femtograms_per_deci_liter = self.__convert_from_base(DensityUnits.FemtogramPerDeciliter)
+        return self.__femtograms_per_deci_liter
+
+    
     @property
     def picograms_per_deci_liter(self) -> float:
         """
@@ -1962,6 +2153,17 @@ class Density:
         return self.__decigrams_per_deci_liter
 
     
+    @property
+    def femtograms_per_milliliter(self) -> float:
+        """
+        
+        """
+        if self.__femtograms_per_milliliter != None:
+            return self.__femtograms_per_milliliter
+        self.__femtograms_per_milliliter = self.__convert_from_base(DensityUnits.FemtogramPerMilliliter)
+        return self.__femtograms_per_milliliter
+
+    
     @property
     def picograms_per_milliliter(self) -> float:
         """
@@ -2028,7 +2230,7 @@ class Density:
         return self.__decigrams_per_milliliter
 
     
-    def to_string(self, unit: DensityUnits = DensityUnits.KilogramPerCubicMeter) -> string:
+    def to_string(self, unit: DensityUnits = DensityUnits.KilogramPerCubicMeter) -> str:
         """
         Format the Density to string.
         Note! the default format for Density is KilogramPerCubicMeter.
@@ -2050,6 +2252,9 @@ class Density:
         if unit == DensityUnits.PoundPerCubicFoot:
             return f"""{self.pounds_per_cubic_foot} lb/ft³"""
         
+        if unit == DensityUnits.PoundPerCubicYard:
+            return f"""{self.pounds_per_cubic_yard} lb/yd³"""
+        
         if unit == DensityUnits.TonnePerCubicMillimeter:
             return f"""{self.tonnes_per_cubic_millimeter} t/mm³"""
         
@@ -2114,84 +2319,96 @@ class Density:
             return f"""{self.slugs_per_cubic_inch} slug/in³"""
         
         if unit == DensityUnits.KilogramPerCubicMillimeter:
-            return f"""{self.kilograms_per_cubic_millimeter} """
+            return f"""{self.kilograms_per_cubic_millimeter} kg/mm³"""
         
         if unit == DensityUnits.KilogramPerCubicCentimeter:
-            return f"""{self.kilograms_per_cubic_centimeter} """
+            return f"""{self.kilograms_per_cubic_centimeter} kg/cm³"""
         
         if unit == DensityUnits.KilogramPerCubicMeter:
-            return f"""{self.kilograms_per_cubic_meter} """
+            return f"""{self.kilograms_per_cubic_meter} kg/m³"""
         
         if unit == DensityUnits.MilligramPerCubicMeter:
-            return f"""{self.milligrams_per_cubic_meter} """
+            return f"""{self.milligrams_per_cubic_meter} mg/m³"""
         
         if unit == DensityUnits.MicrogramPerCubicMeter:
-            return f"""{self.micrograms_per_cubic_meter} """
+            return f"""{self.micrograms_per_cubic_meter} μg/m³"""
         
         if unit == DensityUnits.KilopoundPerCubicInch:
-            return f"""{self.kilopounds_per_cubic_inch} """
+            return f"""{self.kilopounds_per_cubic_inch} klb/in³"""
         
         if unit == DensityUnits.KilopoundPerCubicFoot:
-            return f"""{self.kilopounds_per_cubic_foot} """
+            return f"""{self.kilopounds_per_cubic_foot} klb/ft³"""
+        
+        if unit == DensityUnits.KilopoundPerCubicYard:
+            return f"""{self.kilopounds_per_cubic_yard} klb/yd³"""
+        
+        if unit == DensityUnits.FemtogramPerLiter:
+            return f"""{self.femtograms_per_liter} fg/L"""
         
         if unit == DensityUnits.PicogramPerLiter:
-            return f"""{self.picograms_per_liter} """
+            return f"""{self.picograms_per_liter} pg/L"""
         
         if unit == DensityUnits.NanogramPerLiter:
-            return f"""{self.nanograms_per_liter} """
+            return f"""{self.nanograms_per_liter} ng/L"""
         
         if unit == DensityUnits.MicrogramPerLiter:
-            return f"""{self.micrograms_per_liter} """
+            return f"""{self.micrograms_per_liter} μg/L"""
         
         if unit == DensityUnits.MilligramPerLiter:
-            return f"""{self.milligrams_per_liter} """
+            return f"""{self.milligrams_per_liter} mg/L"""
         
         if unit == DensityUnits.CentigramPerLiter:
-            return f"""{self.centigrams_per_liter} """
+            return f"""{self.centigrams_per_liter} cg/L"""
         
         if unit == DensityUnits.DecigramPerLiter:
-            return f"""{self.decigrams_per_liter} """
+            return f"""{self.decigrams_per_liter} dg/L"""
+        
+        if unit == DensityUnits.FemtogramPerDeciliter:
+            return f"""{self.femtograms_per_deci_liter} fg/dl"""
         
         if unit == DensityUnits.PicogramPerDeciliter:
-            return f"""{self.picograms_per_deci_liter} """
+            return f"""{self.picograms_per_deci_liter} pg/dl"""
         
         if unit == DensityUnits.NanogramPerDeciliter:
-            return f"""{self.nanograms_per_deci_liter} """
+            return f"""{self.nanograms_per_deci_liter} ng/dl"""
         
         if unit == DensityUnits.MicrogramPerDeciliter:
-            return f"""{self.micrograms_per_deci_liter} """
+            return f"""{self.micrograms_per_deci_liter} μg/dl"""
         
         if unit == DensityUnits.MilligramPerDeciliter:
-            return f"""{self.milligrams_per_deci_liter} """
+            return f"""{self.milligrams_per_deci_liter} mg/dl"""
         
         if unit == DensityUnits.CentigramPerDeciliter:
-            return f"""{self.centigrams_per_deci_liter} """
+            return f"""{self.centigrams_per_deci_liter} cg/dl"""
         
         if unit == DensityUnits.DecigramPerDeciliter:
-            return f"""{self.decigrams_per_deci_liter} """
+            return f"""{self.decigrams_per_deci_liter} dg/dl"""
+        
+        if unit == DensityUnits.FemtogramPerMilliliter:
+            return f"""{self.femtograms_per_milliliter} fg/ml"""
         
         if unit == DensityUnits.PicogramPerMilliliter:
-            return f"""{self.picograms_per_milliliter} """
+            return f"""{self.picograms_per_milliliter} pg/ml"""
         
         if unit == DensityUnits.NanogramPerMilliliter:
-            return f"""{self.nanograms_per_milliliter} """
+            return f"""{self.nanograms_per_milliliter} ng/ml"""
         
         if unit == DensityUnits.MicrogramPerMilliliter:
-            return f"""{self.micrograms_per_milliliter} """
+            return f"""{self.micrograms_per_milliliter} μg/ml"""
         
         if unit == DensityUnits.MilligramPerMilliliter:
-            return f"""{self.milligrams_per_milliliter} """
+            return f"""{self.milligrams_per_milliliter} mg/ml"""
         
         if unit == DensityUnits.CentigramPerMilliliter:
-            return f"""{self.centigrams_per_milliliter} """
+            return f"""{self.centigrams_per_milliliter} cg/ml"""
         
         if unit == DensityUnits.DecigramPerMilliliter:
-            return f"""{self.decigrams_per_milliliter} """
+            return f"""{self.decigrams_per_milliliter} dg/ml"""
         
-        return f'{self.__value}'
+        return f'{self._value}'
 
 
-    def get_unit_abbreviation(self, unit_abbreviation: DensityUnits = DensityUnits.KilogramPerCubicMeter) -> string:
+    def get_unit_abbreviation(self, unit_abbreviation: DensityUnits = DensityUnits.KilogramPerCubicMeter) -> str:
         """
         Get Density unit abbreviation.
         Note! the default abbreviation for Density is KilogramPerCubicMeter.
@@ -2213,6 +2430,9 @@ class Density:
         if unit_abbreviation == DensityUnits.PoundPerCubicFoot:
             return """lb/ft³"""
         
+        if unit_abbreviation == DensityUnits.PoundPerCubicYard:
+            return """lb/yd³"""
+        
         if unit_abbreviation == DensityUnits.TonnePerCubicMillimeter:
             return """t/mm³"""
         
@@ -2277,146 +2497,89 @@ class Density:
             return """slug/in³"""
         
         if unit_abbreviation == DensityUnits.KilogramPerCubicMillimeter:
-            return """"""
+            return """kg/mm³"""
         
         if unit_abbreviation == DensityUnits.KilogramPerCubicCentimeter:
-            return """"""
+            return """kg/cm³"""
         
         if unit_abbreviation == DensityUnits.KilogramPerCubicMeter:
-            return """"""
+            return """kg/m³"""
         
         if unit_abbreviation == DensityUnits.MilligramPerCubicMeter:
-            return """"""
+            return """mg/m³"""
         
         if unit_abbreviation == DensityUnits.MicrogramPerCubicMeter:
-            return """"""
+            return """μg/m³"""
         
         if unit_abbreviation == DensityUnits.KilopoundPerCubicInch:
-            return """"""
+            return """klb/in³"""
         
         if unit_abbreviation == DensityUnits.KilopoundPerCubicFoot:
-            return """"""
+            return """klb/ft³"""
+        
+        if unit_abbreviation == DensityUnits.KilopoundPerCubicYard:
+            return """klb/yd³"""
+        
+        if unit_abbreviation == DensityUnits.FemtogramPerLiter:
+            return """fg/L"""
         
         if unit_abbreviation == DensityUnits.PicogramPerLiter:
-            return """"""
+            return """pg/L"""
         
         if unit_abbreviation == DensityUnits.NanogramPerLiter:
-            return """"""
+            return """ng/L"""
         
         if unit_abbreviation == DensityUnits.MicrogramPerLiter:
-            return """"""
+            return """μg/L"""
         
         if unit_abbreviation == DensityUnits.MilligramPerLiter:
-            return """"""
+            return """mg/L"""
         
         if unit_abbreviation == DensityUnits.CentigramPerLiter:
-            return """"""
+            return """cg/L"""
         
         if unit_abbreviation == DensityUnits.DecigramPerLiter:
-            return """"""
+            return """dg/L"""
+        
+        if unit_abbreviation == DensityUnits.FemtogramPerDeciliter:
+            return """fg/dl"""
         
         if unit_abbreviation == DensityUnits.PicogramPerDeciliter:
-            return """"""
+            return """pg/dl"""
         
         if unit_abbreviation == DensityUnits.NanogramPerDeciliter:
-            return """"""
+            return """ng/dl"""
         
         if unit_abbreviation == DensityUnits.MicrogramPerDeciliter:
-            return """"""
+            return """μg/dl"""
         
         if unit_abbreviation == DensityUnits.MilligramPerDeciliter:
-            return """"""
+            return """mg/dl"""
         
         if unit_abbreviation == DensityUnits.CentigramPerDeciliter:
-            return """"""
+            return """cg/dl"""
         
         if unit_abbreviation == DensityUnits.DecigramPerDeciliter:
-            return """"""
+            return """dg/dl"""
+        
+        if unit_abbreviation == DensityUnits.FemtogramPerMilliliter:
+            return """fg/ml"""
         
         if unit_abbreviation == DensityUnits.PicogramPerMilliliter:
-            return """"""
+            return """pg/ml"""
         
         if unit_abbreviation == DensityUnits.NanogramPerMilliliter:
-            return """"""
+            return """ng/ml"""
         
         if unit_abbreviation == DensityUnits.MicrogramPerMilliliter:
-            return """"""
+            return """μg/ml"""
         
         if unit_abbreviation == DensityUnits.MilligramPerMilliliter:
-            return """"""
+            return """mg/ml"""
         
         if unit_abbreviation == DensityUnits.CentigramPerMilliliter:
-            return """"""
+            return """cg/ml"""
         
         if unit_abbreviation == DensityUnits.DecigramPerMilliliter:
-            return """"""
-        
-
-    def __str__(self):
-        return self.to_string()
-
-
-    def __add__(self, other):
-        if not isinstance(other, Density):
-            raise TypeError("unsupported operand type(s) for +: 'Density' and '{}'".format(type(other).__name__))
-        return Density(self.__value + other.__value)
-
-
-    def __mul__(self, other):
-        if not isinstance(other, Density):
-            raise TypeError("unsupported operand type(s) for *: 'Density' and '{}'".format(type(other).__name__))
-        return Density(self.__value * other.__value)
-
-
-    def __sub__(self, other):
-        if not isinstance(other, Density):
-            raise TypeError("unsupported operand type(s) for -: 'Density' and '{}'".format(type(other).__name__))
-        return Density(self.__value - other.__value)
-
-
-    def __truediv__(self, other):
-        if not isinstance(other, Density):
-            raise TypeError("unsupported operand type(s) for /: 'Density' and '{}'".format(type(other).__name__))
-        return Density(self.__value / other.__value)
-
-
-    def __mod__(self, other):
-        if not isinstance(other, Density):
-            raise TypeError("unsupported operand type(s) for %: 'Density' and '{}'".format(type(other).__name__))
-        return Density(self.__value % other.__value)
-
-
-    def __pow__(self, other):
-        if not isinstance(other, Density):
-            raise TypeError("unsupported operand type(s) for **: 'Density' and '{}'".format(type(other).__name__))
-        return Density(self.__value ** other.__value)
-
-
-    def __eq__(self, other):
-        if not isinstance(other, Density):
-            raise TypeError("unsupported operand type(s) for ==: 'Density' and '{}'".format(type(other).__name__))
-        return self.__value == other.__value
-
-
-    def __lt__(self, other):
-        if not isinstance(other, Density):
-            raise TypeError("unsupported operand type(s) for <: 'Density' and '{}'".format(type(other).__name__))
-        return self.__value < other.__value
-
-
-    def __gt__(self, other):
-        if not isinstance(other, Density):
-            raise TypeError("unsupported operand type(s) for >: 'Density' and '{}'".format(type(other).__name__))
-        return self.__value > other.__value
-
-
-    def __le__(self, other):
-        if not isinstance(other, Density):
-            raise TypeError("unsupported operand type(s) for <=: 'Density' and '{}'".format(type(other).__name__))
-        return self.__value <= other.__value
-
-
-    def __ge__(self, other):
-        if not isinstance(other, Density):
-            raise TypeError("unsupported operand type(s) for >=: 'Density' and '{}'".format(type(other).__name__))
-        return self.__value >= other.__value
\ No newline at end of file
+            return """dg/ml"""
+        
\ No newline at end of file
