@@ -1,6 +1,8 @@
 from enum import Enum
 import math
-import string
+
+from ..abstract_unit import AbstractMeasure
+
 
 
 class DynamicViscosityUnits(Enum):
@@ -59,7 +61,7 @@ class DynamicViscosityUnits(Enum):
         """
         
 
-class DynamicViscosity:
+class DynamicViscosity(AbstractMeasure):
     """
     The dynamic (shear) viscosity of a fluid expresses its resistance to shearing flows, where adjacent layers move parallel to each other with different speeds
 
@@ -68,9 +70,11 @@ class DynamicViscosity:
         from_unit (DynamicViscosityUnits): The DynamicViscosity unit to create from, The default unit is NewtonSecondPerMeterSquared
     """
     def __init__(self, value: float, from_unit: DynamicViscosityUnits = DynamicViscosityUnits.NewtonSecondPerMeterSquared):
-        if math.isnan(value):
-            raise ValueError('Invalid unit: value is NaN')
-        self.__value = self.__convert_to_base(value, from_unit)
+        # Do not validate type, to allow working with numpay arrays and similar objects who supports all arithmetic 
+        # operations, but they are not a number, see #14 
+        # if math.isnan(value):
+        #     raise ValueError('Invalid unit: value is NaN')
+        self._value = self.__convert_to_base(value, from_unit)
         
         self.__newton_seconds_per_meter_squared = None
         
@@ -93,8 +97,11 @@ class DynamicViscosity:
         self.__centipoise = None
         
 
+    def convert(self, unit: DynamicViscosityUnits) -> float:
+        return self.__convert_from_base(unit)
+
     def __convert_from_base(self, from_unit: DynamicViscosityUnits) -> float:
-        value = self.__value
+        value = self._value
         
         if from_unit == DynamicViscosityUnits.NewtonSecondPerMeterSquared:
             return (value)
@@ -166,7 +173,7 @@ class DynamicViscosity:
 
     @property
     def base_value(self) -> float:
-        return self.__value
+        return self._value
 
     
     @staticmethod
@@ -429,7 +436,7 @@ class DynamicViscosity:
         return self.__centipoise
 
     
-    def to_string(self, unit: DynamicViscosityUnits = DynamicViscosityUnits.NewtonSecondPerMeterSquared) -> string:
+    def to_string(self, unit: DynamicViscosityUnits = DynamicViscosityUnits.NewtonSecondPerMeterSquared) -> str:
         """
         Format the DynamicViscosity to string.
         Note! the default format for DynamicViscosity is NewtonSecondPerMeterSquared.
@@ -458,18 +465,18 @@ class DynamicViscosity:
             return f"""{self.pounds_per_foot_second} lb/ft·s"""
         
         if unit == DynamicViscosityUnits.MillipascalSecond:
-            return f"""{self.millipascal_seconds} """
+            return f"""{self.millipascal_seconds} mPa·s"""
         
         if unit == DynamicViscosityUnits.MicropascalSecond:
-            return f"""{self.micropascal_seconds} """
+            return f"""{self.micropascal_seconds} μPa·s"""
         
         if unit == DynamicViscosityUnits.Centipoise:
-            return f"""{self.centipoise} """
+            return f"""{self.centipoise} cP"""
         
-        return f'{self.__value}'
+        return f'{self._value}'
 
 
-    def get_unit_abbreviation(self, unit_abbreviation: DynamicViscosityUnits = DynamicViscosityUnits.NewtonSecondPerMeterSquared) -> string:
+    def get_unit_abbreviation(self, unit_abbreviation: DynamicViscosityUnits = DynamicViscosityUnits.NewtonSecondPerMeterSquared) -> str:
         """
         Get DynamicViscosity unit abbreviation.
         Note! the default abbreviation for DynamicViscosity is NewtonSecondPerMeterSquared.
@@ -498,80 +505,11 @@ class DynamicViscosity:
             return """lb/ft·s"""
         
         if unit_abbreviation == DynamicViscosityUnits.MillipascalSecond:
-            return """"""
+            return """mPa·s"""
         
         if unit_abbreviation == DynamicViscosityUnits.MicropascalSecond:
-            return """"""
+            return """μPa·s"""
         
         if unit_abbreviation == DynamicViscosityUnits.Centipoise:
-            return """"""
-        
-
-    def __str__(self):
-        return self.to_string()
-
-
-    def __add__(self, other):
-        if not isinstance(other, DynamicViscosity):
-            raise TypeError("unsupported operand type(s) for +: 'DynamicViscosity' and '{}'".format(type(other).__name__))
-        return DynamicViscosity(self.__value + other.__value)
-
-
-    def __mul__(self, other):
-        if not isinstance(other, DynamicViscosity):
-            raise TypeError("unsupported operand type(s) for *: 'DynamicViscosity' and '{}'".format(type(other).__name__))
-        return DynamicViscosity(self.__value * other.__value)
-
-
-    def __sub__(self, other):
-        if not isinstance(other, DynamicViscosity):
-            raise TypeError("unsupported operand type(s) for -: 'DynamicViscosity' and '{}'".format(type(other).__name__))
-        return DynamicViscosity(self.__value - other.__value)
-
-
-    def __truediv__(self, other):
-        if not isinstance(other, DynamicViscosity):
-            raise TypeError("unsupported operand type(s) for /: 'DynamicViscosity' and '{}'".format(type(other).__name__))
-        return DynamicViscosity(self.__value / other.__value)
-
-
-    def __mod__(self, other):
-        if not isinstance(other, DynamicViscosity):
-            raise TypeError("unsupported operand type(s) for %: 'DynamicViscosity' and '{}'".format(type(other).__name__))
-        return DynamicViscosity(self.__value % other.__value)
-
-
-    def __pow__(self, other):
-        if not isinstance(other, DynamicViscosity):
-            raise TypeError("unsupported operand type(s) for **: 'DynamicViscosity' and '{}'".format(type(other).__name__))
-        return DynamicViscosity(self.__value ** other.__value)
-
-
-    def __eq__(self, other):
-        if not isinstance(other, DynamicViscosity):
-            raise TypeError("unsupported operand type(s) for ==: 'DynamicViscosity' and '{}'".format(type(other).__name__))
-        return self.__value == other.__value
-
-
-    def __lt__(self, other):
-        if not isinstance(other, DynamicViscosity):
-            raise TypeError("unsupported operand type(s) for <: 'DynamicViscosity' and '{}'".format(type(other).__name__))
-        return self.__value < other.__value
-
-
-    def __gt__(self, other):
-        if not isinstance(other, DynamicViscosity):
-            raise TypeError("unsupported operand type(s) for >: 'DynamicViscosity' and '{}'".format(type(other).__name__))
-        return self.__value > other.__value
-
-
-    def __le__(self, other):
-        if not isinstance(other, DynamicViscosity):
-            raise TypeError("unsupported operand type(s) for <=: 'DynamicViscosity' and '{}'".format(type(other).__name__))
-        return self.__value <= other.__value
-
-
-    def __ge__(self, other):
-        if not isinstance(other, DynamicViscosity):
-            raise TypeError("unsupported operand type(s) for >=: 'DynamicViscosity' and '{}'".format(type(other).__name__))
-        return self.__value >= other.__value
\ No newline at end of file
+            return """cP"""
+        
\ No newline at end of file
