@@ -1,6 +1,8 @@
 from enum import Enum
 import math
-import string
+
+from ..abstract_unit import AbstractMeasure
+
 
 
 class ElectricChargeUnits(Enum):
@@ -64,7 +66,7 @@ class ElectricChargeUnits(Enum):
         """
         
 
-class ElectricCharge:
+class ElectricCharge(AbstractMeasure):
     """
     Electric charge is the physical property of matter that causes it to experience a force when placed in an electromagnetic field.
 
@@ -73,9 +75,11 @@ class ElectricCharge:
         from_unit (ElectricChargeUnits): The ElectricCharge unit to create from, The default unit is Coulomb
     """
     def __init__(self, value: float, from_unit: ElectricChargeUnits = ElectricChargeUnits.Coulomb):
-        if math.isnan(value):
-            raise ValueError('Invalid unit: value is NaN')
-        self.__value = self.__convert_to_base(value, from_unit)
+        # Do not validate type, to allow working with numpay arrays and similar objects who supports all arithmetic 
+        # operations, but they are not a number, see #14 
+        # if math.isnan(value):
+        #     raise ValueError('Invalid unit: value is NaN')
+        self._value = self.__convert_to_base(value, from_unit)
         
         self.__coulombs = None
         
@@ -100,8 +104,11 @@ class ElectricCharge:
         self.__megaampere_hours = None
         
 
+    def convert(self, unit: ElectricChargeUnits) -> float:
+        return self.__convert_from_base(unit)
+
     def __convert_from_base(self, from_unit: ElectricChargeUnits) -> float:
-        value = self.__value
+        value = self._value
         
         if from_unit == ElectricChargeUnits.Coulomb:
             return (value)
@@ -179,7 +186,7 @@ class ElectricCharge:
 
     @property
     def base_value(self) -> float:
-        return self.__value
+        return self._value
 
     
     @staticmethod
@@ -468,7 +475,7 @@ class ElectricCharge:
         return self.__megaampere_hours
 
     
-    def to_string(self, unit: ElectricChargeUnits = ElectricChargeUnits.Coulomb) -> string:
+    def to_string(self, unit: ElectricChargeUnits = ElectricChargeUnits.Coulomb) -> str:
         """
         Format the ElectricCharge to string.
         Note! the default format for ElectricCharge is Coulomb.
@@ -482,36 +489,36 @@ class ElectricCharge:
             return f"""{self.ampere_hours} A-h"""
         
         if unit == ElectricChargeUnits.Picocoulomb:
-            return f"""{self.picocoulombs} """
+            return f"""{self.picocoulombs} pC"""
         
         if unit == ElectricChargeUnits.Nanocoulomb:
-            return f"""{self.nanocoulombs} """
+            return f"""{self.nanocoulombs} nC"""
         
         if unit == ElectricChargeUnits.Microcoulomb:
-            return f"""{self.microcoulombs} """
+            return f"""{self.microcoulombs} μC"""
         
         if unit == ElectricChargeUnits.Millicoulomb:
-            return f"""{self.millicoulombs} """
+            return f"""{self.millicoulombs} mC"""
         
         if unit == ElectricChargeUnits.Kilocoulomb:
-            return f"""{self.kilocoulombs} """
+            return f"""{self.kilocoulombs} kC"""
         
         if unit == ElectricChargeUnits.Megacoulomb:
-            return f"""{self.megacoulombs} """
+            return f"""{self.megacoulombs} MC"""
         
         if unit == ElectricChargeUnits.MilliampereHour:
-            return f"""{self.milliampere_hours} """
+            return f"""{self.milliampere_hours} mA-h"""
         
         if unit == ElectricChargeUnits.KiloampereHour:
-            return f"""{self.kiloampere_hours} """
+            return f"""{self.kiloampere_hours} kA-h"""
         
         if unit == ElectricChargeUnits.MegaampereHour:
-            return f"""{self.megaampere_hours} """
+            return f"""{self.megaampere_hours} MA-h"""
         
-        return f'{self.__value}'
+        return f'{self._value}'
 
 
-    def get_unit_abbreviation(self, unit_abbreviation: ElectricChargeUnits = ElectricChargeUnits.Coulomb) -> string:
+    def get_unit_abbreviation(self, unit_abbreviation: ElectricChargeUnits = ElectricChargeUnits.Coulomb) -> str:
         """
         Get ElectricCharge unit abbreviation.
         Note! the default abbreviation for ElectricCharge is Coulomb.
@@ -525,98 +532,29 @@ class ElectricCharge:
             return """A-h"""
         
         if unit_abbreviation == ElectricChargeUnits.Picocoulomb:
-            return """"""
+            return """pC"""
         
         if unit_abbreviation == ElectricChargeUnits.Nanocoulomb:
-            return """"""
+            return """nC"""
         
         if unit_abbreviation == ElectricChargeUnits.Microcoulomb:
-            return """"""
+            return """μC"""
         
         if unit_abbreviation == ElectricChargeUnits.Millicoulomb:
-            return """"""
+            return """mC"""
         
         if unit_abbreviation == ElectricChargeUnits.Kilocoulomb:
-            return """"""
+            return """kC"""
         
         if unit_abbreviation == ElectricChargeUnits.Megacoulomb:
-            return """"""
+            return """MC"""
         
         if unit_abbreviation == ElectricChargeUnits.MilliampereHour:
-            return """"""
+            return """mA-h"""
         
         if unit_abbreviation == ElectricChargeUnits.KiloampereHour:
-            return """"""
+            return """kA-h"""
         
         if unit_abbreviation == ElectricChargeUnits.MegaampereHour:
-            return """"""
-        
-
-    def __str__(self):
-        return self.to_string()
-
-
-    def __add__(self, other):
-        if not isinstance(other, ElectricCharge):
-            raise TypeError("unsupported operand type(s) for +: 'ElectricCharge' and '{}'".format(type(other).__name__))
-        return ElectricCharge(self.__value + other.__value)
-
-
-    def __mul__(self, other):
-        if not isinstance(other, ElectricCharge):
-            raise TypeError("unsupported operand type(s) for *: 'ElectricCharge' and '{}'".format(type(other).__name__))
-        return ElectricCharge(self.__value * other.__value)
-
-
-    def __sub__(self, other):
-        if not isinstance(other, ElectricCharge):
-            raise TypeError("unsupported operand type(s) for -: 'ElectricCharge' and '{}'".format(type(other).__name__))
-        return ElectricCharge(self.__value - other.__value)
-
-
-    def __truediv__(self, other):
-        if not isinstance(other, ElectricCharge):
-            raise TypeError("unsupported operand type(s) for /: 'ElectricCharge' and '{}'".format(type(other).__name__))
-        return ElectricCharge(self.__value / other.__value)
-
-
-    def __mod__(self, other):
-        if not isinstance(other, ElectricCharge):
-            raise TypeError("unsupported operand type(s) for %: 'ElectricCharge' and '{}'".format(type(other).__name__))
-        return ElectricCharge(self.__value % other.__value)
-
-
-    def __pow__(self, other):
-        if not isinstance(other, ElectricCharge):
-            raise TypeError("unsupported operand type(s) for **: 'ElectricCharge' and '{}'".format(type(other).__name__))
-        return ElectricCharge(self.__value ** other.__value)
-
-
-    def __eq__(self, other):
-        if not isinstance(other, ElectricCharge):
-            raise TypeError("unsupported operand type(s) for ==: 'ElectricCharge' and '{}'".format(type(other).__name__))
-        return self.__value == other.__value
-
-
-    def __lt__(self, other):
-        if not isinstance(other, ElectricCharge):
-            raise TypeError("unsupported operand type(s) for <: 'ElectricCharge' and '{}'".format(type(other).__name__))
-        return self.__value < other.__value
-
-
-    def __gt__(self, other):
-        if not isinstance(other, ElectricCharge):
-            raise TypeError("unsupported operand type(s) for >: 'ElectricCharge' and '{}'".format(type(other).__name__))
-        return self.__value > other.__value
-
-
-    def __le__(self, other):
-        if not isinstance(other, ElectricCharge):
-            raise TypeError("unsupported operand type(s) for <=: 'ElectricCharge' and '{}'".format(type(other).__name__))
-        return self.__value <= other.__value
-
-
-    def __ge__(self, other):
-        if not isinstance(other, ElectricCharge):
-            raise TypeError("unsupported operand type(s) for >=: 'ElectricCharge' and '{}'".format(type(other).__name__))
-        return self.__value >= other.__value
\ No newline at end of file
+            return """MA-h"""
+        
\ No newline at end of file
