@@ -1,6 +1,8 @@
 from enum import Enum
 import math
-import string
+
+from ..abstract_unit import AbstractMeasure
+
 
 
 class ElectricPotentialChangeRateUnits(Enum):
@@ -109,7 +111,7 @@ class ElectricPotentialChangeRateUnits(Enum):
         """
         
 
-class ElectricPotentialChangeRate:
+class ElectricPotentialChangeRate(AbstractMeasure):
     """
     ElectricPotential change rate is the ratio of the electric potential change to the time during which the change occurred (value of electric potential changes per unit time).
 
@@ -118,9 +120,11 @@ class ElectricPotentialChangeRate:
         from_unit (ElectricPotentialChangeRateUnits): The ElectricPotentialChangeRate unit to create from, The default unit is VoltPerSecond
     """
     def __init__(self, value: float, from_unit: ElectricPotentialChangeRateUnits = ElectricPotentialChangeRateUnits.VoltPerSecond):
-        if math.isnan(value):
-            raise ValueError('Invalid unit: value is NaN')
-        self.__value = self.__convert_to_base(value, from_unit)
+        # Do not validate type, to allow working with numpay arrays and similar objects who supports all arithmetic 
+        # operations, but they are not a number, see #14 
+        # if math.isnan(value):
+        #     raise ValueError('Invalid unit: value is NaN')
+        self._value = self.__convert_to_base(value, from_unit)
         
         self.__volts_per_seconds = None
         
@@ -163,8 +167,11 @@ class ElectricPotentialChangeRate:
         self.__megavolts_per_hours = None
         
 
+    def convert(self, unit: ElectricPotentialChangeRateUnits) -> float:
+        return self.__convert_from_base(unit)
+
     def __convert_from_base(self, from_unit: ElectricPotentialChangeRateUnits) -> float:
-        value = self.__value
+        value = self._value
         
         if from_unit == ElectricPotentialChangeRateUnits.VoltPerSecond:
             return (value)
@@ -296,7 +303,7 @@ class ElectricPotentialChangeRate:
 
     @property
     def base_value(self) -> float:
-        return self.__value
+        return self._value
 
     
     @staticmethod
@@ -819,7 +826,7 @@ class ElectricPotentialChangeRate:
         return self.__megavolts_per_hours
 
     
-    def to_string(self, unit: ElectricPotentialChangeRateUnits = ElectricPotentialChangeRateUnits.VoltPerSecond) -> string:
+    def to_string(self, unit: ElectricPotentialChangeRateUnits = ElectricPotentialChangeRateUnits.VoltPerSecond) -> str:
         """
         Format the ElectricPotentialChangeRate to string.
         Note! the default format for ElectricPotentialChangeRate is VoltPerSecond.
@@ -839,57 +846,57 @@ class ElectricPotentialChangeRate:
             return f"""{self.volts_per_hours} V/h"""
         
         if unit == ElectricPotentialChangeRateUnits.MicrovoltPerSecond:
-            return f"""{self.microvolts_per_seconds} """
+            return f"""{self.microvolts_per_seconds} μV/s"""
         
         if unit == ElectricPotentialChangeRateUnits.MillivoltPerSecond:
-            return f"""{self.millivolts_per_seconds} """
+            return f"""{self.millivolts_per_seconds} mV/s"""
         
         if unit == ElectricPotentialChangeRateUnits.KilovoltPerSecond:
-            return f"""{self.kilovolts_per_seconds} """
+            return f"""{self.kilovolts_per_seconds} kV/s"""
         
         if unit == ElectricPotentialChangeRateUnits.MegavoltPerSecond:
-            return f"""{self.megavolts_per_seconds} """
+            return f"""{self.megavolts_per_seconds} MV/s"""
         
         if unit == ElectricPotentialChangeRateUnits.MicrovoltPerMicrosecond:
-            return f"""{self.microvolts_per_microseconds} """
+            return f"""{self.microvolts_per_microseconds} μV/μs"""
         
         if unit == ElectricPotentialChangeRateUnits.MillivoltPerMicrosecond:
-            return f"""{self.millivolts_per_microseconds} """
+            return f"""{self.millivolts_per_microseconds} mV/μs"""
         
         if unit == ElectricPotentialChangeRateUnits.KilovoltPerMicrosecond:
-            return f"""{self.kilovolts_per_microseconds} """
+            return f"""{self.kilovolts_per_microseconds} kV/μs"""
         
         if unit == ElectricPotentialChangeRateUnits.MegavoltPerMicrosecond:
-            return f"""{self.megavolts_per_microseconds} """
+            return f"""{self.megavolts_per_microseconds} MV/μs"""
         
         if unit == ElectricPotentialChangeRateUnits.MicrovoltPerMinute:
-            return f"""{self.microvolts_per_minutes} """
+            return f"""{self.microvolts_per_minutes} μV/min"""
         
         if unit == ElectricPotentialChangeRateUnits.MillivoltPerMinute:
-            return f"""{self.millivolts_per_minutes} """
+            return f"""{self.millivolts_per_minutes} mV/min"""
         
         if unit == ElectricPotentialChangeRateUnits.KilovoltPerMinute:
-            return f"""{self.kilovolts_per_minutes} """
+            return f"""{self.kilovolts_per_minutes} kV/min"""
         
         if unit == ElectricPotentialChangeRateUnits.MegavoltPerMinute:
-            return f"""{self.megavolts_per_minutes} """
+            return f"""{self.megavolts_per_minutes} MV/min"""
         
         if unit == ElectricPotentialChangeRateUnits.MicrovoltPerHour:
-            return f"""{self.microvolts_per_hours} """
+            return f"""{self.microvolts_per_hours} μV/h"""
         
         if unit == ElectricPotentialChangeRateUnits.MillivoltPerHour:
-            return f"""{self.millivolts_per_hours} """
+            return f"""{self.millivolts_per_hours} mV/h"""
         
         if unit == ElectricPotentialChangeRateUnits.KilovoltPerHour:
-            return f"""{self.kilovolts_per_hours} """
+            return f"""{self.kilovolts_per_hours} kV/h"""
         
         if unit == ElectricPotentialChangeRateUnits.MegavoltPerHour:
-            return f"""{self.megavolts_per_hours} """
+            return f"""{self.megavolts_per_hours} MV/h"""
         
-        return f'{self.__value}'
+        return f'{self._value}'
 
 
-    def get_unit_abbreviation(self, unit_abbreviation: ElectricPotentialChangeRateUnits = ElectricPotentialChangeRateUnits.VoltPerSecond) -> string:
+    def get_unit_abbreviation(self, unit_abbreviation: ElectricPotentialChangeRateUnits = ElectricPotentialChangeRateUnits.VoltPerSecond) -> str:
         """
         Get ElectricPotentialChangeRate unit abbreviation.
         Note! the default abbreviation for ElectricPotentialChangeRate is VoltPerSecond.
@@ -909,119 +916,50 @@ class ElectricPotentialChangeRate:
             return """V/h"""
         
         if unit_abbreviation == ElectricPotentialChangeRateUnits.MicrovoltPerSecond:
-            return """"""
+            return """μV/s"""
         
         if unit_abbreviation == ElectricPotentialChangeRateUnits.MillivoltPerSecond:
-            return """"""
+            return """mV/s"""
         
         if unit_abbreviation == ElectricPotentialChangeRateUnits.KilovoltPerSecond:
-            return """"""
+            return """kV/s"""
         
         if unit_abbreviation == ElectricPotentialChangeRateUnits.MegavoltPerSecond:
-            return """"""
+            return """MV/s"""
         
         if unit_abbreviation == ElectricPotentialChangeRateUnits.MicrovoltPerMicrosecond:
-            return """"""
+            return """μV/μs"""
         
         if unit_abbreviation == ElectricPotentialChangeRateUnits.MillivoltPerMicrosecond:
-            return """"""
+            return """mV/μs"""
         
         if unit_abbreviation == ElectricPotentialChangeRateUnits.KilovoltPerMicrosecond:
-            return """"""
+            return """kV/μs"""
         
         if unit_abbreviation == ElectricPotentialChangeRateUnits.MegavoltPerMicrosecond:
-            return """"""
+            return """MV/μs"""
         
         if unit_abbreviation == ElectricPotentialChangeRateUnits.MicrovoltPerMinute:
-            return """"""
+            return """μV/min"""
         
         if unit_abbreviation == ElectricPotentialChangeRateUnits.MillivoltPerMinute:
-            return """"""
+            return """mV/min"""
         
         if unit_abbreviation == ElectricPotentialChangeRateUnits.KilovoltPerMinute:
-            return """"""
+            return """kV/min"""
         
         if unit_abbreviation == ElectricPotentialChangeRateUnits.MegavoltPerMinute:
-            return """"""
+            return """MV/min"""
         
         if unit_abbreviation == ElectricPotentialChangeRateUnits.MicrovoltPerHour:
-            return """"""
+            return """μV/h"""
         
         if unit_abbreviation == ElectricPotentialChangeRateUnits.MillivoltPerHour:
-            return """"""
+            return """mV/h"""
         
         if unit_abbreviation == ElectricPotentialChangeRateUnits.KilovoltPerHour:
-            return """"""
+            return """kV/h"""
         
         if unit_abbreviation == ElectricPotentialChangeRateUnits.MegavoltPerHour:
-            return """"""
-        
-
-    def __str__(self):
-        return self.to_string()
-
-
-    def __add__(self, other):
-        if not isinstance(other, ElectricPotentialChangeRate):
-            raise TypeError("unsupported operand type(s) for +: 'ElectricPotentialChangeRate' and '{}'".format(type(other).__name__))
-        return ElectricPotentialChangeRate(self.__value + other.__value)
-
-
-    def __mul__(self, other):
-        if not isinstance(other, ElectricPotentialChangeRate):
-            raise TypeError("unsupported operand type(s) for *: 'ElectricPotentialChangeRate' and '{}'".format(type(other).__name__))
-        return ElectricPotentialChangeRate(self.__value * other.__value)
-
-
-    def __sub__(self, other):
-        if not isinstance(other, ElectricPotentialChangeRate):
-            raise TypeError("unsupported operand type(s) for -: 'ElectricPotentialChangeRate' and '{}'".format(type(other).__name__))
-        return ElectricPotentialChangeRate(self.__value - other.__value)
-
-
-    def __truediv__(self, other):
-        if not isinstance(other, ElectricPotentialChangeRate):
-            raise TypeError("unsupported operand type(s) for /: 'ElectricPotentialChangeRate' and '{}'".format(type(other).__name__))
-        return ElectricPotentialChangeRate(self.__value / other.__value)
-
-
-    def __mod__(self, other):
-        if not isinstance(other, ElectricPotentialChangeRate):
-            raise TypeError("unsupported operand type(s) for %: 'ElectricPotentialChangeRate' and '{}'".format(type(other).__name__))
-        return ElectricPotentialChangeRate(self.__value % other.__value)
-
-
-    def __pow__(self, other):
-        if not isinstance(other, ElectricPotentialChangeRate):
-            raise TypeError("unsupported operand type(s) for **: 'ElectricPotentialChangeRate' and '{}'".format(type(other).__name__))
-        return ElectricPotentialChangeRate(self.__value ** other.__value)
-
-
-    def __eq__(self, other):
-        if not isinstance(other, ElectricPotentialChangeRate):
-            raise TypeError("unsupported operand type(s) for ==: 'ElectricPotentialChangeRate' and '{}'".format(type(other).__name__))
-        return self.__value == other.__value
-
-
-    def __lt__(self, other):
-        if not isinstance(other, ElectricPotentialChangeRate):
-            raise TypeError("unsupported operand type(s) for <: 'ElectricPotentialChangeRate' and '{}'".format(type(other).__name__))
-        return self.__value < other.__value
-
-
-    def __gt__(self, other):
-        if not isinstance(other, ElectricPotentialChangeRate):
-            raise TypeError("unsupported operand type(s) for >: 'ElectricPotentialChangeRate' and '{}'".format(type(other).__name__))
-        return self.__value > other.__value
-
-
-    def __le__(self, other):
-        if not isinstance(other, ElectricPotentialChangeRate):
-            raise TypeError("unsupported operand type(s) for <=: 'ElectricPotentialChangeRate' and '{}'".format(type(other).__name__))
-        return self.__value <= other.__value
-
-
-    def __ge__(self, other):
-        if not isinstance(other, ElectricPotentialChangeRate):
-            raise TypeError("unsupported operand type(s) for >=: 'ElectricPotentialChangeRate' and '{}'".format(type(other).__name__))
-        return self.__value >= other.__value
\ No newline at end of file
+            return """MV/h"""
+        
\ No newline at end of file
