@@ -1,6 +1,8 @@
 from enum import Enum
 import math
-import string
+
+from ..abstract_unit import AbstractMeasure
+
 
 
 class ElectricResistivityUnits(Enum):
@@ -79,7 +81,7 @@ class ElectricResistivityUnits(Enum):
         """
         
 
-class ElectricResistivity:
+class ElectricResistivity(AbstractMeasure):
     """
     Electrical resistivity (also known as resistivity, specific electrical resistance, or volume resistivity) is a fundamental property that quantifies how strongly a given material opposes the flow of electric current.
 
@@ -88,9 +90,11 @@ class ElectricResistivity:
         from_unit (ElectricResistivityUnits): The ElectricResistivity unit to create from, The default unit is OhmMeter
     """
     def __init__(self, value: float, from_unit: ElectricResistivityUnits = ElectricResistivityUnits.OhmMeter):
-        if math.isnan(value):
-            raise ValueError('Invalid unit: value is NaN')
-        self.__value = self.__convert_to_base(value, from_unit)
+        # Do not validate type, to allow working with numpay arrays and similar objects who supports all arithmetic 
+        # operations, but they are not a number, see #14 
+        # if math.isnan(value):
+        #     raise ValueError('Invalid unit: value is NaN')
+        self._value = self.__convert_to_base(value, from_unit)
         
         self.__ohm_meters = None
         
@@ -121,8 +125,11 @@ class ElectricResistivity:
         self.__megaohms_centimeter = None
         
 
+    def convert(self, unit: ElectricResistivityUnits) -> float:
+        return self.__convert_from_base(unit)
+
     def __convert_from_base(self, from_unit: ElectricResistivityUnits) -> float:
-        value = self.__value
+        value = self._value
         
         if from_unit == ElectricResistivityUnits.OhmMeter:
             return (value)
@@ -218,7 +225,7 @@ class ElectricResistivity:
 
     @property
     def base_value(self) -> float:
-        return self.__value
+        return self._value
 
     
     @staticmethod
@@ -585,7 +592,7 @@ class ElectricResistivity:
         return self.__megaohms_centimeter
 
     
-    def to_string(self, unit: ElectricResistivityUnits = ElectricResistivityUnits.OhmMeter) -> string:
+    def to_string(self, unit: ElectricResistivityUnits = ElectricResistivityUnits.OhmMeter) -> str:
         """
         Format the ElectricResistivity to string.
         Note! the default format for ElectricResistivity is OhmMeter.
@@ -599,45 +606,45 @@ class ElectricResistivity:
             return f"""{self.ohms_centimeter} Ω·cm"""
         
         if unit == ElectricResistivityUnits.PicoohmMeter:
-            return f"""{self.picoohm_meters} """
+            return f"""{self.picoohm_meters} pΩ·m"""
         
         if unit == ElectricResistivityUnits.NanoohmMeter:
-            return f"""{self.nanoohm_meters} """
+            return f"""{self.nanoohm_meters} nΩ·m"""
         
         if unit == ElectricResistivityUnits.MicroohmMeter:
-            return f"""{self.microohm_meters} """
+            return f"""{self.microohm_meters} μΩ·m"""
         
         if unit == ElectricResistivityUnits.MilliohmMeter:
-            return f"""{self.milliohm_meters} """
+            return f"""{self.milliohm_meters} mΩ·m"""
         
         if unit == ElectricResistivityUnits.KiloohmMeter:
-            return f"""{self.kiloohm_meters} """
+            return f"""{self.kiloohm_meters} kΩ·m"""
         
         if unit == ElectricResistivityUnits.MegaohmMeter:
-            return f"""{self.megaohm_meters} """
+            return f"""{self.megaohm_meters} MΩ·m"""
         
         if unit == ElectricResistivityUnits.PicoohmCentimeter:
-            return f"""{self.picoohms_centimeter} """
+            return f"""{self.picoohms_centimeter} pΩ·cm"""
         
         if unit == ElectricResistivityUnits.NanoohmCentimeter:
-            return f"""{self.nanoohms_centimeter} """
+            return f"""{self.nanoohms_centimeter} nΩ·cm"""
         
         if unit == ElectricResistivityUnits.MicroohmCentimeter:
-            return f"""{self.microohms_centimeter} """
+            return f"""{self.microohms_centimeter} μΩ·cm"""
         
         if unit == ElectricResistivityUnits.MilliohmCentimeter:
-            return f"""{self.milliohms_centimeter} """
+            return f"""{self.milliohms_centimeter} mΩ·cm"""
         
         if unit == ElectricResistivityUnits.KiloohmCentimeter:
-            return f"""{self.kiloohms_centimeter} """
+            return f"""{self.kiloohms_centimeter} kΩ·cm"""
         
         if unit == ElectricResistivityUnits.MegaohmCentimeter:
-            return f"""{self.megaohms_centimeter} """
+            return f"""{self.megaohms_centimeter} MΩ·cm"""
         
-        return f'{self.__value}'
+        return f'{self._value}'
 
 
-    def get_unit_abbreviation(self, unit_abbreviation: ElectricResistivityUnits = ElectricResistivityUnits.OhmMeter) -> string:
+    def get_unit_abbreviation(self, unit_abbreviation: ElectricResistivityUnits = ElectricResistivityUnits.OhmMeter) -> str:
         """
         Get ElectricResistivity unit abbreviation.
         Note! the default abbreviation for ElectricResistivity is OhmMeter.
@@ -651,107 +658,38 @@ class ElectricResistivity:
             return """Ω·cm"""
         
         if unit_abbreviation == ElectricResistivityUnits.PicoohmMeter:
-            return """"""
+            return """pΩ·m"""
         
         if unit_abbreviation == ElectricResistivityUnits.NanoohmMeter:
-            return """"""
+            return """nΩ·m"""
         
         if unit_abbreviation == ElectricResistivityUnits.MicroohmMeter:
-            return """"""
+            return """μΩ·m"""
         
         if unit_abbreviation == ElectricResistivityUnits.MilliohmMeter:
-            return """"""
+            return """mΩ·m"""
         
         if unit_abbreviation == ElectricResistivityUnits.KiloohmMeter:
-            return """"""
+            return """kΩ·m"""
         
         if unit_abbreviation == ElectricResistivityUnits.MegaohmMeter:
-            return """"""
+            return """MΩ·m"""
         
         if unit_abbreviation == ElectricResistivityUnits.PicoohmCentimeter:
-            return """"""
+            return """pΩ·cm"""
         
         if unit_abbreviation == ElectricResistivityUnits.NanoohmCentimeter:
-            return """"""
+            return """nΩ·cm"""
         
         if unit_abbreviation == ElectricResistivityUnits.MicroohmCentimeter:
-            return """"""
+            return """μΩ·cm"""
         
         if unit_abbreviation == ElectricResistivityUnits.MilliohmCentimeter:
-            return """"""
+            return """mΩ·cm"""
         
         if unit_abbreviation == ElectricResistivityUnits.KiloohmCentimeter:
-            return """"""
+            return """kΩ·cm"""
         
         if unit_abbreviation == ElectricResistivityUnits.MegaohmCentimeter:
-            return """"""
-        
-
-    def __str__(self):
-        return self.to_string()
-
-
-    def __add__(self, other):
-        if not isinstance(other, ElectricResistivity):
-            raise TypeError("unsupported operand type(s) for +: 'ElectricResistivity' and '{}'".format(type(other).__name__))
-        return ElectricResistivity(self.__value + other.__value)
-
-
-    def __mul__(self, other):
-        if not isinstance(other, ElectricResistivity):
-            raise TypeError("unsupported operand type(s) for *: 'ElectricResistivity' and '{}'".format(type(other).__name__))
-        return ElectricResistivity(self.__value * other.__value)
-
-
-    def __sub__(self, other):
-        if not isinstance(other, ElectricResistivity):
-            raise TypeError("unsupported operand type(s) for -: 'ElectricResistivity' and '{}'".format(type(other).__name__))
-        return ElectricResistivity(self.__value - other.__value)
-
-
-    def __truediv__(self, other):
-        if not isinstance(other, ElectricResistivity):
-            raise TypeError("unsupported operand type(s) for /: 'ElectricResistivity' and '{}'".format(type(other).__name__))
-        return ElectricResistivity(self.__value / other.__value)
-
-
-    def __mod__(self, other):
-        if not isinstance(other, ElectricResistivity):
-            raise TypeError("unsupported operand type(s) for %: 'ElectricResistivity' and '{}'".format(type(other).__name__))
-        return ElectricResistivity(self.__value % other.__value)
-
-
-    def __pow__(self, other):
-        if not isinstance(other, ElectricResistivity):
-            raise TypeError("unsupported operand type(s) for **: 'ElectricResistivity' and '{}'".format(type(other).__name__))
-        return ElectricResistivity(self.__value ** other.__value)
-
-
-    def __eq__(self, other):
-        if not isinstance(other, ElectricResistivity):
-            raise TypeError("unsupported operand type(s) for ==: 'ElectricResistivity' and '{}'".format(type(other).__name__))
-        return self.__value == other.__value
-
-
-    def __lt__(self, other):
-        if not isinstance(other, ElectricResistivity):
-            raise TypeError("unsupported operand type(s) for <: 'ElectricResistivity' and '{}'".format(type(other).__name__))
-        return self.__value < other.__value
-
-
-    def __gt__(self, other):
-        if not isinstance(other, ElectricResistivity):
-            raise TypeError("unsupported operand type(s) for >: 'ElectricResistivity' and '{}'".format(type(other).__name__))
-        return self.__value > other.__value
-
-
-    def __le__(self, other):
-        if not isinstance(other, ElectricResistivity):
-            raise TypeError("unsupported operand type(s) for <=: 'ElectricResistivity' and '{}'".format(type(other).__name__))
-        return self.__value <= other.__value
-
-
-    def __ge__(self, other):
-        if not isinstance(other, ElectricResistivity):
-            raise TypeError("unsupported operand type(s) for >=: 'ElectricResistivity' and '{}'".format(type(other).__name__))
-        return self.__value >= other.__value
\ No newline at end of file
+            return """MΩ·cm"""
+        
\ No newline at end of file
