@@ -1,6 +1,8 @@
 from enum import Enum
 import math
-import string
+
+from ..abstract_unit import AbstractMeasure
+
 
 
 class EnergyUnits(Enum):
@@ -68,6 +70,16 @@ class EnergyUnits(Enum):
             
         """
         
+        Nanojoule = 'nanojoule'
+        """
+            
+        """
+        
+        Microjoule = 'microjoule'
+        """
+            
+        """
+        
         Millijoule = 'millijoule'
         """
             
@@ -199,7 +211,7 @@ class EnergyUnits(Enum):
         """
         
 
-class Energy:
+class Energy(AbstractMeasure):
     """
     The joule, symbol J, is a derived unit of energy, work, or amount of heat in the International System of Units. It is equal to the energy transferred (or work done) when applying a force of one newton through a distance of one metre (1 newton metre or N·m), or in passing an electric current of one ampere through a resistance of one ohm for one second. Many other units of energy are included. Please do not confuse this definition of the calorie with the one colloquially used by the food industry, the large calorie, which is equivalent to 1 kcal. Thermochemical definition of the calorie is used. For BTU, the IT definition is used.
 
@@ -208,9 +220,11 @@ class Energy:
         from_unit (EnergyUnits): The Energy unit to create from, The default unit is Joule
     """
     def __init__(self, value: float, from_unit: EnergyUnits = EnergyUnits.Joule):
-        if math.isnan(value):
-            raise ValueError('Invalid unit: value is NaN')
-        self.__value = self.__convert_to_base(value, from_unit)
+        # Do not validate type, to allow working with numpay arrays and similar objects who supports all arithmetic 
+        # operations, but they are not a number, see #14 
+        # if math.isnan(value):
+        #     raise ValueError('Invalid unit: value is NaN')
+        self._value = self.__convert_to_base(value, from_unit)
         
         self.__joules = None
         
@@ -236,6 +250,10 @@ class Energy:
         
         self.__horsepower_hours = None
         
+        self.__nanojoules = None
+        
+        self.__microjoules = None
+        
         self.__millijoules = None
         
         self.__kilojoules = None
@@ -289,8 +307,11 @@ class Energy:
         self.__decatherms_imperial = None
         
 
+    def convert(self, unit: EnergyUnits) -> float:
+        return self.__convert_from_base(unit)
+
     def __convert_from_base(self, from_unit: EnergyUnits) -> float:
-        value = self.__value
+        value = self._value
         
         if from_unit == EnergyUnits.Joule:
             return (value)
@@ -328,6 +349,12 @@ class Energy:
         if from_unit == EnergyUnits.HorsepowerHour:
             return (value / 2.6845195377e6)
         
+        if from_unit == EnergyUnits.Nanojoule:
+            return ((value) / 1e-09)
+        
+        if from_unit == EnergyUnits.Microjoule:
+            return ((value) / 1e-06)
+        
         if from_unit == EnergyUnits.Millijoule:
             return ((value) / 0.001)
         
@@ -447,6 +474,12 @@ class Energy:
         if to_unit == EnergyUnits.HorsepowerHour:
             return (value * 2.6845195377e6)
         
+        if to_unit == EnergyUnits.Nanojoule:
+            return ((value) * 1e-09)
+        
+        if to_unit == EnergyUnits.Microjoule:
+            return ((value) * 1e-06)
+        
         if to_unit == EnergyUnits.Millijoule:
             return ((value) * 0.001)
         
@@ -530,7 +563,7 @@ class Energy:
 
     @property
     def base_value(self) -> float:
-        return self.__value
+        return self._value
 
     
     @staticmethod
@@ -713,6 +746,36 @@ class Energy:
         return Energy(horsepower_hours, EnergyUnits.HorsepowerHour)
 
     
+    @staticmethod
+    def from_nanojoules(nanojoules: float):
+        """
+        Create a new instance of Energy from a value in nanojoules.
+
+        
+
+        :param meters: The Energy value in nanojoules.
+        :type nanojoules: float
+        :return: A new instance of Energy.
+        :rtype: Energy
+        """
+        return Energy(nanojoules, EnergyUnits.Nanojoule)
+
+    
+    @staticmethod
+    def from_microjoules(microjoules: float):
+        """
+        Create a new instance of Energy from a value in microjoules.
+
+        
+
+        :param meters: The Energy value in microjoules.
+        :type microjoules: float
+        :return: A new instance of Energy.
+        :rtype: Energy
+        """
+        return Energy(microjoules, EnergyUnits.Microjoule)
+
+    
     @staticmethod
     def from_millijoules(millijoules: float):
         """
@@ -1235,6 +1298,28 @@ class Energy:
         return self.__horsepower_hours
 
     
+    @property
+    def nanojoules(self) -> float:
+        """
+        
+        """
+        if self.__nanojoules != None:
+            return self.__nanojoules
+        self.__nanojoules = self.__convert_from_base(EnergyUnits.Nanojoule)
+        return self.__nanojoules
+
+    
+    @property
+    def microjoules(self) -> float:
+        """
+        
+        """
+        if self.__microjoules != None:
+            return self.__microjoules
+        self.__microjoules = self.__convert_from_base(EnergyUnits.Microjoule)
+        return self.__microjoules
+
+    
     @property
     def millijoules(self) -> float:
         """
@@ -1521,7 +1606,7 @@ class Energy:
         return self.__decatherms_imperial
 
     
-    def to_string(self, unit: EnergyUnits = EnergyUnits.Joule) -> string:
+    def to_string(self, unit: EnergyUnits = EnergyUnits.Joule) -> str:
         """
         Format the Energy to string.
         Note! the default format for Energy is Joule.
@@ -1564,88 +1649,94 @@ class Energy:
         if unit == EnergyUnits.HorsepowerHour:
             return f"""{self.horsepower_hours} hp·h"""
         
+        if unit == EnergyUnits.Nanojoule:
+            return f"""{self.nanojoules} nJ"""
+        
+        if unit == EnergyUnits.Microjoule:
+            return f"""{self.microjoules} μJ"""
+        
         if unit == EnergyUnits.Millijoule:
-            return f"""{self.millijoules} """
+            return f"""{self.millijoules} mJ"""
         
         if unit == EnergyUnits.Kilojoule:
-            return f"""{self.kilojoules} """
+            return f"""{self.kilojoules} kJ"""
         
         if unit == EnergyUnits.Megajoule:
-            return f"""{self.megajoules} """
+            return f"""{self.megajoules} MJ"""
         
         if unit == EnergyUnits.Gigajoule:
-            return f"""{self.gigajoules} """
+            return f"""{self.gigajoules} GJ"""
         
         if unit == EnergyUnits.Terajoule:
-            return f"""{self.terajoules} """
+            return f"""{self.terajoules} TJ"""
         
         if unit == EnergyUnits.Petajoule:
-            return f"""{self.petajoules} """
+            return f"""{self.petajoules} PJ"""
         
         if unit == EnergyUnits.Kilocalorie:
-            return f"""{self.kilocalories} """
+            return f"""{self.kilocalories} kcal"""
         
         if unit == EnergyUnits.Megacalorie:
-            return f"""{self.megacalories} """
+            return f"""{self.megacalories} Mcal"""
         
         if unit == EnergyUnits.KilobritishThermalUnit:
-            return f"""{self.kilobritish_thermal_units} """
+            return f"""{self.kilobritish_thermal_units} kBTU"""
         
         if unit == EnergyUnits.MegabritishThermalUnit:
-            return f"""{self.megabritish_thermal_units} """
+            return f"""{self.megabritish_thermal_units} MBTU"""
         
         if unit == EnergyUnits.GigabritishThermalUnit:
-            return f"""{self.gigabritish_thermal_units} """
+            return f"""{self.gigabritish_thermal_units} GBTU"""
         
         if unit == EnergyUnits.KiloelectronVolt:
-            return f"""{self.kiloelectron_volts} """
+            return f"""{self.kiloelectron_volts} keV"""
         
         if unit == EnergyUnits.MegaelectronVolt:
-            return f"""{self.megaelectron_volts} """
+            return f"""{self.megaelectron_volts} MeV"""
         
         if unit == EnergyUnits.GigaelectronVolt:
-            return f"""{self.gigaelectron_volts} """
+            return f"""{self.gigaelectron_volts} GeV"""
         
         if unit == EnergyUnits.TeraelectronVolt:
-            return f"""{self.teraelectron_volts} """
+            return f"""{self.teraelectron_volts} TeV"""
         
         if unit == EnergyUnits.KilowattHour:
-            return f"""{self.kilowatt_hours} """
+            return f"""{self.kilowatt_hours} kWh"""
         
         if unit == EnergyUnits.MegawattHour:
-            return f"""{self.megawatt_hours} """
+            return f"""{self.megawatt_hours} MWh"""
         
         if unit == EnergyUnits.GigawattHour:
-            return f"""{self.gigawatt_hours} """
+            return f"""{self.gigawatt_hours} GWh"""
         
         if unit == EnergyUnits.TerawattHour:
-            return f"""{self.terawatt_hours} """
+            return f"""{self.terawatt_hours} TWh"""
         
         if unit == EnergyUnits.KilowattDay:
-            return f"""{self.kilowatt_days} """
+            return f"""{self.kilowatt_days} kWd"""
         
         if unit == EnergyUnits.MegawattDay:
-            return f"""{self.megawatt_days} """
+            return f"""{self.megawatt_days} MWd"""
         
         if unit == EnergyUnits.GigawattDay:
-            return f"""{self.gigawatt_days} """
+            return f"""{self.gigawatt_days} GWd"""
         
         if unit == EnergyUnits.TerawattDay:
-            return f"""{self.terawatt_days} """
+            return f"""{self.terawatt_days} TWd"""
         
         if unit == EnergyUnits.DecathermEc:
-            return f"""{self.decatherms_ec} """
+            return f"""{self.decatherms_ec} dath (E.C.)"""
         
         if unit == EnergyUnits.DecathermUs:
-            return f"""{self.decatherms_us} """
+            return f"""{self.decatherms_us} dath (U.S.)"""
         
         if unit == EnergyUnits.DecathermImperial:
-            return f"""{self.decatherms_imperial} """
+            return f"""{self.decatherms_imperial} dath (imp.)"""
         
-        return f'{self.__value}'
+        return f'{self._value}'
 
 
-    def get_unit_abbreviation(self, unit_abbreviation: EnergyUnits = EnergyUnits.Joule) -> string:
+    def get_unit_abbreviation(self, unit_abbreviation: EnergyUnits = EnergyUnits.Joule) -> str:
         """
         Get Energy unit abbreviation.
         Note! the default abbreviation for Energy is Joule.
@@ -1688,150 +1779,87 @@ class Energy:
         if unit_abbreviation == EnergyUnits.HorsepowerHour:
             return """hp·h"""
         
+        if unit_abbreviation == EnergyUnits.Nanojoule:
+            return """nJ"""
+        
+        if unit_abbreviation == EnergyUnits.Microjoule:
+            return """μJ"""
+        
         if unit_abbreviation == EnergyUnits.Millijoule:
-            return """"""
+            return """mJ"""
         
         if unit_abbreviation == EnergyUnits.Kilojoule:
-            return """"""
+            return """kJ"""
         
         if unit_abbreviation == EnergyUnits.Megajoule:
-            return """"""
+            return """MJ"""
         
         if unit_abbreviation == EnergyUnits.Gigajoule:
-            return """"""
+            return """GJ"""
         
         if unit_abbreviation == EnergyUnits.Terajoule:
-            return """"""
+            return """TJ"""
         
         if unit_abbreviation == EnergyUnits.Petajoule:
-            return """"""
+            return """PJ"""
         
         if unit_abbreviation == EnergyUnits.Kilocalorie:
-            return """"""
+            return """kcal"""
         
         if unit_abbreviation == EnergyUnits.Megacalorie:
-            return """"""
+            return """Mcal"""
         
         if unit_abbreviation == EnergyUnits.KilobritishThermalUnit:
-            return """"""
+            return """kBTU"""
         
         if unit_abbreviation == EnergyUnits.MegabritishThermalUnit:
-            return """"""
+            return """MBTU"""
         
         if unit_abbreviation == EnergyUnits.GigabritishThermalUnit:
-            return """"""
+            return """GBTU"""
         
         if unit_abbreviation == EnergyUnits.KiloelectronVolt:
-            return """"""
+            return """keV"""
         
         if unit_abbreviation == EnergyUnits.MegaelectronVolt:
-            return """"""
+            return """MeV"""
         
         if unit_abbreviation == EnergyUnits.GigaelectronVolt:
-            return """"""
+            return """GeV"""
         
         if unit_abbreviation == EnergyUnits.TeraelectronVolt:
-            return """"""
+            return """TeV"""
         
         if unit_abbreviation == EnergyUnits.KilowattHour:
-            return """"""
+            return """kWh"""
         
         if unit_abbreviation == EnergyUnits.MegawattHour:
-            return """"""
+            return """MWh"""
         
         if unit_abbreviation == EnergyUnits.GigawattHour:
-            return """"""
+            return """GWh"""
         
         if unit_abbreviation == EnergyUnits.TerawattHour:
-            return """"""
+            return """TWh"""
         
         if unit_abbreviation == EnergyUnits.KilowattDay:
-            return """"""
+            return """kWd"""
         
         if unit_abbreviation == EnergyUnits.MegawattDay:
-            return """"""
+            return """MWd"""
         
         if unit_abbreviation == EnergyUnits.GigawattDay:
-            return """"""
+            return """GWd"""
         
         if unit_abbreviation == EnergyUnits.TerawattDay:
-            return """"""
+            return """TWd"""
         
         if unit_abbreviation == EnergyUnits.DecathermEc:
-            return """"""
+            return """dath (E.C.)"""
         
         if unit_abbreviation == EnergyUnits.DecathermUs:
-            return """"""
+            return """dath (U.S.)"""
         
         if unit_abbreviation == EnergyUnits.DecathermImperial:
-            return """"""
-        
-
-    def __str__(self):
-        return self.to_string()
-
-
-    def __add__(self, other):
-        if not isinstance(other, Energy):
-            raise TypeError("unsupported operand type(s) for +: 'Energy' and '{}'".format(type(other).__name__))
-        return Energy(self.__value + other.__value)
-
-
-    def __mul__(self, other):
-        if not isinstance(other, Energy):
-            raise TypeError("unsupported operand type(s) for *: 'Energy' and '{}'".format(type(other).__name__))
-        return Energy(self.__value * other.__value)
-
-
-    def __sub__(self, other):
-        if not isinstance(other, Energy):
-            raise TypeError("unsupported operand type(s) for -: 'Energy' and '{}'".format(type(other).__name__))
-        return Energy(self.__value - other.__value)
-
-
-    def __truediv__(self, other):
-        if not isinstance(other, Energy):
-            raise TypeError("unsupported operand type(s) for /: 'Energy' and '{}'".format(type(other).__name__))
-        return Energy(self.__value / other.__value)
-
-
-    def __mod__(self, other):
-        if not isinstance(other, Energy):
-            raise TypeError("unsupported operand type(s) for %: 'Energy' and '{}'".format(type(other).__name__))
-        return Energy(self.__value % other.__value)
-
-
-    def __pow__(self, other):
-        if not isinstance(other, Energy):
-            raise TypeError("unsupported operand type(s) for **: 'Energy' and '{}'".format(type(other).__name__))
-        return Energy(self.__value ** other.__value)
-
-
-    def __eq__(self, other):
-        if not isinstance(other, Energy):
-            raise TypeError("unsupported operand type(s) for ==: 'Energy' and '{}'".format(type(other).__name__))
-        return self.__value == other.__value
-
-
-    def __lt__(self, other):
-        if not isinstance(other, Energy):
-            raise TypeError("unsupported operand type(s) for <: 'Energy' and '{}'".format(type(other).__name__))
-        return self.__value < other.__value
-
-
-    def __gt__(self, other):
-        if not isinstance(other, Energy):
-            raise TypeError("unsupported operand type(s) for >: 'Energy' and '{}'".format(type(other).__name__))
-        return self.__value > other.__value
-
-
-    def __le__(self, other):
-        if not isinstance(other, Energy):
-            raise TypeError("unsupported operand type(s) for <=: 'Energy' and '{}'".format(type(other).__name__))
-        return self.__value <= other.__value
-
-
-    def __ge__(self, other):
-        if not isinstance(other, Energy):
-            raise TypeError("unsupported operand type(s) for >=: 'Energy' and '{}'".format(type(other).__name__))
-        return self.__value >= other.__value
\ No newline at end of file
+            return """dath (imp.)"""
+        
\ No newline at end of file
