@@ -1,6 +1,8 @@
 from enum import Enum
 import math
-import string
+
+from ..abstract_unit import AbstractMeasure
+
 
 
 class EnergyDensityUnits(Enum):
@@ -69,7 +71,7 @@ class EnergyDensityUnits(Enum):
         """
         
 
-class EnergyDensity:
+class EnergyDensity(AbstractMeasure):
     """
     None
 
@@ -78,9 +80,11 @@ class EnergyDensity:
         from_unit (EnergyDensityUnits): The EnergyDensity unit to create from, The default unit is JoulePerCubicMeter
     """
     def __init__(self, value: float, from_unit: EnergyDensityUnits = EnergyDensityUnits.JoulePerCubicMeter):
-        if math.isnan(value):
-            raise ValueError('Invalid unit: value is NaN')
-        self.__value = self.__convert_to_base(value, from_unit)
+        # Do not validate type, to allow working with numpay arrays and similar objects who supports all arithmetic 
+        # operations, but they are not a number, see #14 
+        # if math.isnan(value):
+        #     raise ValueError('Invalid unit: value is NaN')
+        self._value = self.__convert_to_base(value, from_unit)
         
         self.__joules_per_cubic_meter = None
         
@@ -107,8 +111,11 @@ class EnergyDensity:
         self.__petawatt_hours_per_cubic_meter = None
         
 
+    def convert(self, unit: EnergyDensityUnits) -> float:
+        return self.__convert_from_base(unit)
+
     def __convert_from_base(self, from_unit: EnergyDensityUnits) -> float:
-        value = self.__value
+        value = self._value
         
         if from_unit == EnergyDensityUnits.JoulePerCubicMeter:
             return (value)
@@ -192,7 +199,7 @@ class EnergyDensity:
 
     @property
     def base_value(self) -> float:
-        return self.__value
+        return self._value
 
     
     @staticmethod
@@ -507,7 +514,7 @@ class EnergyDensity:
         return self.__petawatt_hours_per_cubic_meter
 
     
-    def to_string(self, unit: EnergyDensityUnits = EnergyDensityUnits.JoulePerCubicMeter) -> string:
+    def to_string(self, unit: EnergyDensityUnits = EnergyDensityUnits.JoulePerCubicMeter) -> str:
         """
         Format the EnergyDensity to string.
         Note! the default format for EnergyDensity is JoulePerCubicMeter.
@@ -521,39 +528,39 @@ class EnergyDensity:
             return f"""{self.watt_hours_per_cubic_meter} Wh/m³"""
         
         if unit == EnergyDensityUnits.KilojoulePerCubicMeter:
-            return f"""{self.kilojoules_per_cubic_meter} """
+            return f"""{self.kilojoules_per_cubic_meter} kJ/m³"""
         
         if unit == EnergyDensityUnits.MegajoulePerCubicMeter:
-            return f"""{self.megajoules_per_cubic_meter} """
+            return f"""{self.megajoules_per_cubic_meter} MJ/m³"""
         
         if unit == EnergyDensityUnits.GigajoulePerCubicMeter:
-            return f"""{self.gigajoules_per_cubic_meter} """
+            return f"""{self.gigajoules_per_cubic_meter} GJ/m³"""
         
         if unit == EnergyDensityUnits.TerajoulePerCubicMeter:
-            return f"""{self.terajoules_per_cubic_meter} """
+            return f"""{self.terajoules_per_cubic_meter} TJ/m³"""
         
         if unit == EnergyDensityUnits.PetajoulePerCubicMeter:
-            return f"""{self.petajoules_per_cubic_meter} """
+            return f"""{self.petajoules_per_cubic_meter} PJ/m³"""
         
         if unit == EnergyDensityUnits.KilowattHourPerCubicMeter:
-            return f"""{self.kilowatt_hours_per_cubic_meter} """
+            return f"""{self.kilowatt_hours_per_cubic_meter} kWh/m³"""
         
         if unit == EnergyDensityUnits.MegawattHourPerCubicMeter:
-            return f"""{self.megawatt_hours_per_cubic_meter} """
+            return f"""{self.megawatt_hours_per_cubic_meter} MWh/m³"""
         
         if unit == EnergyDensityUnits.GigawattHourPerCubicMeter:
-            return f"""{self.gigawatt_hours_per_cubic_meter} """
+            return f"""{self.gigawatt_hours_per_cubic_meter} GWh/m³"""
         
         if unit == EnergyDensityUnits.TerawattHourPerCubicMeter:
-            return f"""{self.terawatt_hours_per_cubic_meter} """
+            return f"""{self.terawatt_hours_per_cubic_meter} TWh/m³"""
         
         if unit == EnergyDensityUnits.PetawattHourPerCubicMeter:
-            return f"""{self.petawatt_hours_per_cubic_meter} """
+            return f"""{self.petawatt_hours_per_cubic_meter} PWh/m³"""
         
-        return f'{self.__value}'
+        return f'{self._value}'
 
 
-    def get_unit_abbreviation(self, unit_abbreviation: EnergyDensityUnits = EnergyDensityUnits.JoulePerCubicMeter) -> string:
+    def get_unit_abbreviation(self, unit_abbreviation: EnergyDensityUnits = EnergyDensityUnits.JoulePerCubicMeter) -> str:
         """
         Get EnergyDensity unit abbreviation.
         Note! the default abbreviation for EnergyDensity is JoulePerCubicMeter.
@@ -567,101 +574,32 @@ class EnergyDensity:
             return """Wh/m³"""
         
         if unit_abbreviation == EnergyDensityUnits.KilojoulePerCubicMeter:
-            return """"""
+            return """kJ/m³"""
         
         if unit_abbreviation == EnergyDensityUnits.MegajoulePerCubicMeter:
-            return """"""
+            return """MJ/m³"""
         
         if unit_abbreviation == EnergyDensityUnits.GigajoulePerCubicMeter:
-            return """"""
+            return """GJ/m³"""
         
         if unit_abbreviation == EnergyDensityUnits.TerajoulePerCubicMeter:
-            return """"""
+            return """TJ/m³"""
         
         if unit_abbreviation == EnergyDensityUnits.PetajoulePerCubicMeter:
-            return """"""
+            return """PJ/m³"""
         
         if unit_abbreviation == EnergyDensityUnits.KilowattHourPerCubicMeter:
-            return """"""
+            return """kWh/m³"""
         
         if unit_abbreviation == EnergyDensityUnits.MegawattHourPerCubicMeter:
-            return """"""
+            return """MWh/m³"""
         
         if unit_abbreviation == EnergyDensityUnits.GigawattHourPerCubicMeter:
-            return """"""
+            return """GWh/m³"""
         
         if unit_abbreviation == EnergyDensityUnits.TerawattHourPerCubicMeter:
-            return """"""
+            return """TWh/m³"""
         
         if unit_abbreviation == EnergyDensityUnits.PetawattHourPerCubicMeter:
-            return """"""
-        
-
-    def __str__(self):
-        return self.to_string()
-
-
-    def __add__(self, other):
-        if not isinstance(other, EnergyDensity):
-            raise TypeError("unsupported operand type(s) for +: 'EnergyDensity' and '{}'".format(type(other).__name__))
-        return EnergyDensity(self.__value + other.__value)
-
-
-    def __mul__(self, other):
-        if not isinstance(other, EnergyDensity):
-            raise TypeError("unsupported operand type(s) for *: 'EnergyDensity' and '{}'".format(type(other).__name__))
-        return EnergyDensity(self.__value * other.__value)
-
-
-    def __sub__(self, other):
-        if not isinstance(other, EnergyDensity):
-            raise TypeError("unsupported operand type(s) for -: 'EnergyDensity' and '{}'".format(type(other).__name__))
-        return EnergyDensity(self.__value - other.__value)
-
-
-    def __truediv__(self, other):
-        if not isinstance(other, EnergyDensity):
-            raise TypeError("unsupported operand type(s) for /: 'EnergyDensity' and '{}'".format(type(other).__name__))
-        return EnergyDensity(self.__value / other.__value)
-
-
-    def __mod__(self, other):
-        if not isinstance(other, EnergyDensity):
-            raise TypeError("unsupported operand type(s) for %: 'EnergyDensity' and '{}'".format(type(other).__name__))
-        return EnergyDensity(self.__value % other.__value)
-
-
-    def __pow__(self, other):
-        if not isinstance(other, EnergyDensity):
-            raise TypeError("unsupported operand type(s) for **: 'EnergyDensity' and '{}'".format(type(other).__name__))
-        return EnergyDensity(self.__value ** other.__value)
-
-
-    def __eq__(self, other):
-        if not isinstance(other, EnergyDensity):
-            raise TypeError("unsupported operand type(s) for ==: 'EnergyDensity' and '{}'".format(type(other).__name__))
-        return self.__value == other.__value
-
-
-    def __lt__(self, other):
-        if not isinstance(other, EnergyDensity):
-            raise TypeError("unsupported operand type(s) for <: 'EnergyDensity' and '{}'".format(type(other).__name__))
-        return self.__value < other.__value
-
-
-    def __gt__(self, other):
-        if not isinstance(other, EnergyDensity):
-            raise TypeError("unsupported operand type(s) for >: 'EnergyDensity' and '{}'".format(type(other).__name__))
-        return self.__value > other.__value
-
-
-    def __le__(self, other):
-        if not isinstance(other, EnergyDensity):
-            raise TypeError("unsupported operand type(s) for <=: 'EnergyDensity' and '{}'".format(type(other).__name__))
-        return self.__value <= other.__value
-
-
-    def __ge__(self, other):
-        if not isinstance(other, EnergyDensity):
-            raise TypeError("unsupported operand type(s) for >=: 'EnergyDensity' and '{}'".format(type(other).__name__))
-        return self.__value >= other.__value
\ No newline at end of file
+            return """PWh/m³"""
+        
\ No newline at end of file
