@@ -1,6 +1,8 @@
 from enum import Enum
 import math
-import string
+
+from ..abstract_unit import AbstractMeasure
+
 
 
 class ForceUnits(Enum):
@@ -10,42 +12,42 @@ class ForceUnits(Enum):
         
         Dyn = 'dyn'
         """
-            
+            One dyne is equal to 10 micronewtons, 10e−5 N or to 10 nsn (nanosthenes) in the old metre–tonne–second system of units.
         """
         
         KilogramForce = 'kilogram_force'
         """
-            
+            The kilogram-force, or kilopond, is equal to the magnitude of the force exerted on one kilogram of mass in a 9.80665 m/s2 gravitational field (standard gravity). Therefore, one kilogram-force is by definition equal to 9.80665 N.
         """
         
         TonneForce = 'tonne_force'
         """
-            
+            The tonne-force, metric ton-force, megagram-force, and megapond (Mp) are each 1000 kilograms-force.
         """
         
         Newton = 'newton'
         """
-            
+            The newton (symbol: N) is the unit of force in the International System of Units (SI). It is defined as 1 kg⋅m/s2, the force which gives a mass of 1 kilogram an acceleration of 1 metre per second per second.
         """
         
         KiloPond = 'kilo_pond'
         """
-            
+            The kilogram-force, or kilopond, is equal to the magnitude of the force exerted on one kilogram of mass in a 9.80665 m/s2 gravitational field (standard gravity). Therefore, one kilogram-force is by definition equal to 9.80665 N.
         """
         
         Poundal = 'poundal'
         """
-            
+            The poundal is defined as the force necessary to accelerate 1 pound-mass at 1 foot per second per second. 1 pdl = 0.138254954376 N exactly.
         """
         
         PoundForce = 'pound_force'
         """
-            
+            The standard values of acceleration of the standard gravitational field (gn) and the international avoirdupois pound (lb) result in a pound-force equal to 4.4482216152605 N.
         """
         
         OunceForce = 'ounce_force'
         """
-            
+            An ounce-force is 1⁄16 of a pound-force, or about 0.2780139 newtons.
         """
         
         ShortTonForce = 'short_ton_force'
@@ -84,7 +86,7 @@ class ForceUnits(Enum):
         """
         
 
-class Force:
+class Force(AbstractMeasure):
     """
     In physics, a force is any influence that causes an object to undergo a certain change, either concerning its movement, direction, or geometrical construction. In other words, a force can cause an object with mass to change its velocity (which includes to begin moving from a state of rest), i.e., to accelerate, or a flexible object to deform, or both. Force can also be described by intuitive concepts such as a push or a pull. A force has both magnitude and direction, making it a vector quantity. It is measured in the SI unit of newtons and represented by the symbol F.
 
@@ -93,9 +95,11 @@ class Force:
         from_unit (ForceUnits): The Force unit to create from, The default unit is Newton
     """
     def __init__(self, value: float, from_unit: ForceUnits = ForceUnits.Newton):
-        if math.isnan(value):
-            raise ValueError('Invalid unit: value is NaN')
-        self.__value = self.__convert_to_base(value, from_unit)
+        # Do not validate type, to allow working with numpay arrays and similar objects who supports all arithmetic 
+        # operations, but they are not a number, see #14 
+        # if math.isnan(value):
+        #     raise ValueError('Invalid unit: value is NaN')
+        self._value = self.__convert_to_base(value, from_unit)
         
         self.__dyne = None
         
@@ -128,35 +132,38 @@ class Force:
         self.__kilopounds_force = None
         
 
+    def convert(self, unit: ForceUnits) -> float:
+        return self.__convert_from_base(unit)
+
     def __convert_from_base(self, from_unit: ForceUnits) -> float:
-        value = self.__value
+        value = self._value
         
         if from_unit == ForceUnits.Dyn:
             return (value * 1e5)
         
         if from_unit == ForceUnits.KilogramForce:
-            return (value / 9.80665002864)
+            return (value / 9.80665)
         
         if from_unit == ForceUnits.TonneForce:
-            return (value / 9.80665002864e3)
+            return (value / (9.80665 * 1000))
         
         if from_unit == ForceUnits.Newton:
             return (value)
         
         if from_unit == ForceUnits.KiloPond:
-            return (value / 9.80665002864)
+            return (value / 9.80665)
         
         if from_unit == ForceUnits.Poundal:
-            return (value / 0.13825502798973041652092282466083)
+            return (value / 0.138254954376)
         
         if from_unit == ForceUnits.PoundForce:
-            return (value / 4.4482216152605095551842641431421)
+            return (value / 4.4482216152605)
         
         if from_unit == ForceUnits.OunceForce:
-            return (value / 2.780138509537812e-1)
+            return (value / (4.4482216152605 / 16))
         
         if from_unit == ForceUnits.ShortTonForce:
-            return (value / 8.896443230521e3)
+            return (value / (4.4482216152605 * 2000))
         
         if from_unit == ForceUnits.Micronewton:
             return ((value) / 1e-06)
@@ -174,7 +181,7 @@ class Force:
             return ((value) / 1000000.0)
         
         if from_unit == ForceUnits.KilopoundForce:
-            return ((value / 4.4482216152605095551842641431421) / 1000.0)
+            return ((value / 4.4482216152605) / 1000.0)
         
         return None
 
@@ -185,28 +192,28 @@ class Force:
             return (value / 1e5)
         
         if to_unit == ForceUnits.KilogramForce:
-            return (value * 9.80665002864)
+            return (value * 9.80665)
         
         if to_unit == ForceUnits.TonneForce:
-            return (value * 9.80665002864e3)
+            return (value * (9.80665 * 1000))
         
         if to_unit == ForceUnits.Newton:
             return (value)
         
         if to_unit == ForceUnits.KiloPond:
-            return (value * 9.80665002864)
+            return (value * 9.80665)
         
         if to_unit == ForceUnits.Poundal:
-            return (value * 0.13825502798973041652092282466083)
+            return (value * 0.138254954376)
         
         if to_unit == ForceUnits.PoundForce:
-            return (value * 4.4482216152605095551842641431421)
+            return (value * 4.4482216152605)
         
         if to_unit == ForceUnits.OunceForce:
-            return (value * 2.780138509537812e-1)
+            return (value * (4.4482216152605 / 16))
         
         if to_unit == ForceUnits.ShortTonForce:
-            return (value * 8.896443230521e3)
+            return (value * (4.4482216152605 * 2000))
         
         if to_unit == ForceUnits.Micronewton:
             return ((value) * 1e-06)
@@ -224,14 +231,14 @@ class Force:
             return ((value) * 1000000.0)
         
         if to_unit == ForceUnits.KilopoundForce:
-            return ((value * 4.4482216152605095551842641431421) * 1000.0)
+            return ((value * 4.4482216152605) * 1000.0)
         
         return None
 
 
     @property
     def base_value(self) -> float:
-        return self.__value
+        return self._value
 
     
     @staticmethod
@@ -239,7 +246,7 @@ class Force:
         """
         Create a new instance of Force from a value in dyne.
 
-        
+        One dyne is equal to 10 micronewtons, 10e−5 N or to 10 nsn (nanosthenes) in the old metre–tonne–second system of units.
 
         :param meters: The Force value in dyne.
         :type dyne: float
@@ -254,7 +261,7 @@ class Force:
         """
         Create a new instance of Force from a value in kilograms_force.
 
-        
+        The kilogram-force, or kilopond, is equal to the magnitude of the force exerted on one kilogram of mass in a 9.80665 m/s2 gravitational field (standard gravity). Therefore, one kilogram-force is by definition equal to 9.80665 N.
 
         :param meters: The Force value in kilograms_force.
         :type kilograms_force: float
@@ -269,7 +276,7 @@ class Force:
         """
         Create a new instance of Force from a value in tonnes_force.
 
-        
+        The tonne-force, metric ton-force, megagram-force, and megapond (Mp) are each 1000 kilograms-force.
 
         :param meters: The Force value in tonnes_force.
         :type tonnes_force: float
@@ -284,7 +291,7 @@ class Force:
         """
         Create a new instance of Force from a value in newtons.
 
-        
+        The newton (symbol: N) is the unit of force in the International System of Units (SI). It is defined as 1 kg⋅m/s2, the force which gives a mass of 1 kilogram an acceleration of 1 metre per second per second.
 
         :param meters: The Force value in newtons.
         :type newtons: float
@@ -299,7 +306,7 @@ class Force:
         """
         Create a new instance of Force from a value in kilo_ponds.
 
-        
+        The kilogram-force, or kilopond, is equal to the magnitude of the force exerted on one kilogram of mass in a 9.80665 m/s2 gravitational field (standard gravity). Therefore, one kilogram-force is by definition equal to 9.80665 N.
 
         :param meters: The Force value in kilo_ponds.
         :type kilo_ponds: float
@@ -314,7 +321,7 @@ class Force:
         """
         Create a new instance of Force from a value in poundals.
 
-        
+        The poundal is defined as the force necessary to accelerate 1 pound-mass at 1 foot per second per second. 1 pdl = 0.138254954376 N exactly.
 
         :param meters: The Force value in poundals.
         :type poundals: float
@@ -329,7 +336,7 @@ class Force:
         """
         Create a new instance of Force from a value in pounds_force.
 
-        
+        The standard values of acceleration of the standard gravitational field (gn) and the international avoirdupois pound (lb) result in a pound-force equal to 4.4482216152605 N.
 
         :param meters: The Force value in pounds_force.
         :type pounds_force: float
@@ -344,7 +351,7 @@ class Force:
         """
         Create a new instance of Force from a value in ounce_force.
 
-        
+        An ounce-force is 1⁄16 of a pound-force, or about 0.2780139 newtons.
 
         :param meters: The Force value in ounce_force.
         :type ounce_force: float
@@ -462,7 +469,7 @@ class Force:
     @property
     def dyne(self) -> float:
         """
-        
+        One dyne is equal to 10 micronewtons, 10e−5 N or to 10 nsn (nanosthenes) in the old metre–tonne–second system of units.
         """
         if self.__dyne != None:
             return self.__dyne
@@ -473,7 +480,7 @@ class Force:
     @property
     def kilograms_force(self) -> float:
         """
-        
+        The kilogram-force, or kilopond, is equal to the magnitude of the force exerted on one kilogram of mass in a 9.80665 m/s2 gravitational field (standard gravity). Therefore, one kilogram-force is by definition equal to 9.80665 N.
         """
         if self.__kilograms_force != None:
             return self.__kilograms_force
@@ -484,7 +491,7 @@ class Force:
     @property
     def tonnes_force(self) -> float:
         """
-        
+        The tonne-force, metric ton-force, megagram-force, and megapond (Mp) are each 1000 kilograms-force.
         """
         if self.__tonnes_force != None:
             return self.__tonnes_force
@@ -495,7 +502,7 @@ class Force:
     @property
     def newtons(self) -> float:
         """
-        
+        The newton (symbol: N) is the unit of force in the International System of Units (SI). It is defined as 1 kg⋅m/s2, the force which gives a mass of 1 kilogram an acceleration of 1 metre per second per second.
         """
         if self.__newtons != None:
             return self.__newtons
@@ -506,7 +513,7 @@ class Force:
     @property
     def kilo_ponds(self) -> float:
         """
-        
+        The kilogram-force, or kilopond, is equal to the magnitude of the force exerted on one kilogram of mass in a 9.80665 m/s2 gravitational field (standard gravity). Therefore, one kilogram-force is by definition equal to 9.80665 N.
         """
         if self.__kilo_ponds != None:
             return self.__kilo_ponds
@@ -517,7 +524,7 @@ class Force:
     @property
     def poundals(self) -> float:
         """
-        
+        The poundal is defined as the force necessary to accelerate 1 pound-mass at 1 foot per second per second. 1 pdl = 0.138254954376 N exactly.
         """
         if self.__poundals != None:
             return self.__poundals
@@ -528,7 +535,7 @@ class Force:
     @property
     def pounds_force(self) -> float:
         """
-        
+        The standard values of acceleration of the standard gravitational field (gn) and the international avoirdupois pound (lb) result in a pound-force equal to 4.4482216152605 N.
         """
         if self.__pounds_force != None:
             return self.__pounds_force
@@ -539,7 +546,7 @@ class Force:
     @property
     def ounce_force(self) -> float:
         """
-        
+        An ounce-force is 1⁄16 of a pound-force, or about 0.2780139 newtons.
         """
         if self.__ounce_force != None:
             return self.__ounce_force
@@ -624,7 +631,7 @@ class Force:
         return self.__kilopounds_force
 
     
-    def to_string(self, unit: ForceUnits = ForceUnits.Newton) -> string:
+    def to_string(self, unit: ForceUnits = ForceUnits.Newton) -> str:
         """
         Format the Force to string.
         Note! the default format for Force is Newton.
@@ -659,27 +666,27 @@ class Force:
             return f"""{self.short_tons_force} tf (short)"""
         
         if unit == ForceUnits.Micronewton:
-            return f"""{self.micronewtons} """
+            return f"""{self.micronewtons} μN"""
         
         if unit == ForceUnits.Millinewton:
-            return f"""{self.millinewtons} """
+            return f"""{self.millinewtons} mN"""
         
         if unit == ForceUnits.Decanewton:
-            return f"""{self.decanewtons} """
+            return f"""{self.decanewtons} daN"""
         
         if unit == ForceUnits.Kilonewton:
-            return f"""{self.kilonewtons} """
+            return f"""{self.kilonewtons} kN"""
         
         if unit == ForceUnits.Meganewton:
-            return f"""{self.meganewtons} """
+            return f"""{self.meganewtons} MN"""
         
         if unit == ForceUnits.KilopoundForce:
-            return f"""{self.kilopounds_force} """
+            return f"""{self.kilopounds_force} klbf"""
         
-        return f'{self.__value}'
+        return f'{self._value}'
 
 
-    def get_unit_abbreviation(self, unit_abbreviation: ForceUnits = ForceUnits.Newton) -> string:
+    def get_unit_abbreviation(self, unit_abbreviation: ForceUnits = ForceUnits.Newton) -> str:
         """
         Get Force unit abbreviation.
         Note! the default abbreviation for Force is Newton.
@@ -714,89 +721,20 @@ class Force:
             return """tf (short)"""
         
         if unit_abbreviation == ForceUnits.Micronewton:
-            return """"""
+            return """μN"""
         
         if unit_abbreviation == ForceUnits.Millinewton:
-            return """"""
+            return """mN"""
         
         if unit_abbreviation == ForceUnits.Decanewton:
-            return """"""
+            return """daN"""
         
         if unit_abbreviation == ForceUnits.Kilonewton:
-            return """"""
+            return """kN"""
         
         if unit_abbreviation == ForceUnits.Meganewton:
-            return """"""
+            return """MN"""
         
         if unit_abbreviation == ForceUnits.KilopoundForce:
-            return """"""
-        
-
-    def __str__(self):
-        return self.to_string()
-
-
-    def __add__(self, other):
-        if not isinstance(other, Force):
-            raise TypeError("unsupported operand type(s) for +: 'Force' and '{}'".format(type(other).__name__))
-        return Force(self.__value + other.__value)
-
-
-    def __mul__(self, other):
-        if not isinstance(other, Force):
-            raise TypeError("unsupported operand type(s) for *: 'Force' and '{}'".format(type(other).__name__))
-        return Force(self.__value * other.__value)
-
-
-    def __sub__(self, other):
-        if not isinstance(other, Force):
-            raise TypeError("unsupported operand type(s) for -: 'Force' and '{}'".format(type(other).__name__))
-        return Force(self.__value - other.__value)
-
-
-    def __truediv__(self, other):
-        if not isinstance(other, Force):
-            raise TypeError("unsupported operand type(s) for /: 'Force' and '{}'".format(type(other).__name__))
-        return Force(self.__value / other.__value)
-
-
-    def __mod__(self, other):
-        if not isinstance(other, Force):
-            raise TypeError("unsupported operand type(s) for %: 'Force' and '{}'".format(type(other).__name__))
-        return Force(self.__value % other.__value)
-
-
-    def __pow__(self, other):
-        if not isinstance(other, Force):
-            raise TypeError("unsupported operand type(s) for **: 'Force' and '{}'".format(type(other).__name__))
-        return Force(self.__value ** other.__value)
-
-
-    def __eq__(self, other):
-        if not isinstance(other, Force):
-            raise TypeError("unsupported operand type(s) for ==: 'Force' and '{}'".format(type(other).__name__))
-        return self.__value == other.__value
-
-
-    def __lt__(self, other):
-        if not isinstance(other, Force):
-            raise TypeError("unsupported operand type(s) for <: 'Force' and '{}'".format(type(other).__name__))
-        return self.__value < other.__value
-
-
-    def __gt__(self, other):
-        if not isinstance(other, Force):
-            raise TypeError("unsupported operand type(s) for >: 'Force' and '{}'".format(type(other).__name__))
-        return self.__value > other.__value
-
-
-    def __le__(self, other):
-        if not isinstance(other, Force):
-            raise TypeError("unsupported operand type(s) for <=: 'Force' and '{}'".format(type(other).__name__))
-        return self.__value <= other.__value
-
-
-    def __ge__(self, other):
-        if not isinstance(other, Force):
-            raise TypeError("unsupported operand type(s) for >=: 'Force' and '{}'".format(type(other).__name__))
-        return self.__value >= other.__value
\ No newline at end of file
+            return """klbf"""
+        
\ No newline at end of file
