@@ -1,6 +1,8 @@
 from enum import Enum
 import math
-import string
+
+from ..abstract_unit import AbstractMeasure
+
 
 
 class ForceChangeRateUnits(Enum):
@@ -84,7 +86,7 @@ class ForceChangeRateUnits(Enum):
         """
         
 
-class ForceChangeRate:
+class ForceChangeRate(AbstractMeasure):
     """
     Force change rate is the ratio of the force change to the time during which the change occurred (value of force changes per unit time).
 
@@ -93,9 +95,11 @@ class ForceChangeRate:
         from_unit (ForceChangeRateUnits): The ForceChangeRate unit to create from, The default unit is NewtonPerSecond
     """
     def __init__(self, value: float, from_unit: ForceChangeRateUnits = ForceChangeRateUnits.NewtonPerSecond):
-        if math.isnan(value):
-            raise ValueError('Invalid unit: value is NaN')
-        self.__value = self.__convert_to_base(value, from_unit)
+        # Do not validate type, to allow working with numpay arrays and similar objects who supports all arithmetic 
+        # operations, but they are not a number, see #14 
+        # if math.isnan(value):
+        #     raise ValueError('Invalid unit: value is NaN')
+        self._value = self.__convert_to_base(value, from_unit)
         
         self.__newtons_per_minute = None
         
@@ -128,8 +132,11 @@ class ForceChangeRate:
         self.__kilopounds_force_per_second = None
         
 
+    def convert(self, unit: ForceChangeRateUnits) -> float:
+        return self.__convert_from_base(unit)
+
     def __convert_from_base(self, from_unit: ForceChangeRateUnits) -> float:
-        value = self.__value
+        value = self._value
         
         if from_unit == ForceChangeRateUnits.NewtonPerMinute:
             return (value * 60)
@@ -231,7 +238,7 @@ class ForceChangeRate:
 
     @property
     def base_value(self) -> float:
-        return self.__value
+        return self._value
 
     
     @staticmethod
@@ -624,7 +631,7 @@ class ForceChangeRate:
         return self.__kilopounds_force_per_second
 
     
-    def to_string(self, unit: ForceChangeRateUnits = ForceChangeRateUnits.NewtonPerSecond) -> string:
+    def to_string(self, unit: ForceChangeRateUnits = ForceChangeRateUnits.NewtonPerSecond) -> str:
         """
         Format the ForceChangeRate to string.
         Note! the default format for ForceChangeRate is NewtonPerSecond.
@@ -644,42 +651,42 @@ class ForceChangeRate:
             return f"""{self.pounds_force_per_second} lbf/s"""
         
         if unit == ForceChangeRateUnits.DecanewtonPerMinute:
-            return f"""{self.decanewtons_per_minute} """
+            return f"""{self.decanewtons_per_minute} daN/min"""
         
         if unit == ForceChangeRateUnits.KilonewtonPerMinute:
-            return f"""{self.kilonewtons_per_minute} """
+            return f"""{self.kilonewtons_per_minute} kN/min"""
         
         if unit == ForceChangeRateUnits.NanonewtonPerSecond:
-            return f"""{self.nanonewtons_per_second} """
+            return f"""{self.nanonewtons_per_second} nN/s"""
         
         if unit == ForceChangeRateUnits.MicronewtonPerSecond:
-            return f"""{self.micronewtons_per_second} """
+            return f"""{self.micronewtons_per_second} μN/s"""
         
         if unit == ForceChangeRateUnits.MillinewtonPerSecond:
-            return f"""{self.millinewtons_per_second} """
+            return f"""{self.millinewtons_per_second} mN/s"""
         
         if unit == ForceChangeRateUnits.CentinewtonPerSecond:
-            return f"""{self.centinewtons_per_second} """
+            return f"""{self.centinewtons_per_second} cN/s"""
         
         if unit == ForceChangeRateUnits.DecinewtonPerSecond:
-            return f"""{self.decinewtons_per_second} """
+            return f"""{self.decinewtons_per_second} dN/s"""
         
         if unit == ForceChangeRateUnits.DecanewtonPerSecond:
-            return f"""{self.decanewtons_per_second} """
+            return f"""{self.decanewtons_per_second} daN/s"""
         
         if unit == ForceChangeRateUnits.KilonewtonPerSecond:
-            return f"""{self.kilonewtons_per_second} """
+            return f"""{self.kilonewtons_per_second} kN/s"""
         
         if unit == ForceChangeRateUnits.KilopoundForcePerMinute:
-            return f"""{self.kilopounds_force_per_minute} """
+            return f"""{self.kilopounds_force_per_minute} klbf/min"""
         
         if unit == ForceChangeRateUnits.KilopoundForcePerSecond:
-            return f"""{self.kilopounds_force_per_second} """
+            return f"""{self.kilopounds_force_per_second} klbf/s"""
         
-        return f'{self.__value}'
+        return f'{self._value}'
 
 
-    def get_unit_abbreviation(self, unit_abbreviation: ForceChangeRateUnits = ForceChangeRateUnits.NewtonPerSecond) -> string:
+    def get_unit_abbreviation(self, unit_abbreviation: ForceChangeRateUnits = ForceChangeRateUnits.NewtonPerSecond) -> str:
         """
         Get ForceChangeRate unit abbreviation.
         Note! the default abbreviation for ForceChangeRate is NewtonPerSecond.
@@ -699,104 +706,35 @@ class ForceChangeRate:
             return """lbf/s"""
         
         if unit_abbreviation == ForceChangeRateUnits.DecanewtonPerMinute:
-            return """"""
+            return """daN/min"""
         
         if unit_abbreviation == ForceChangeRateUnits.KilonewtonPerMinute:
-            return """"""
+            return """kN/min"""
         
         if unit_abbreviation == ForceChangeRateUnits.NanonewtonPerSecond:
-            return """"""
+            return """nN/s"""
         
         if unit_abbreviation == ForceChangeRateUnits.MicronewtonPerSecond:
-            return """"""
+            return """μN/s"""
         
         if unit_abbreviation == ForceChangeRateUnits.MillinewtonPerSecond:
-            return """"""
+            return """mN/s"""
         
         if unit_abbreviation == ForceChangeRateUnits.CentinewtonPerSecond:
-            return """"""
+            return """cN/s"""
         
         if unit_abbreviation == ForceChangeRateUnits.DecinewtonPerSecond:
-            return """"""
+            return """dN/s"""
         
         if unit_abbreviation == ForceChangeRateUnits.DecanewtonPerSecond:
-            return """"""
+            return """daN/s"""
         
         if unit_abbreviation == ForceChangeRateUnits.KilonewtonPerSecond:
-            return """"""
+            return """kN/s"""
         
         if unit_abbreviation == ForceChangeRateUnits.KilopoundForcePerMinute:
-            return """"""
+            return """klbf/min"""
         
         if unit_abbreviation == ForceChangeRateUnits.KilopoundForcePerSecond:
-            return """"""
-        
-
-    def __str__(self):
-        return self.to_string()
-
-
-    def __add__(self, other):
-        if not isinstance(other, ForceChangeRate):
-            raise TypeError("unsupported operand type(s) for +: 'ForceChangeRate' and '{}'".format(type(other).__name__))
-        return ForceChangeRate(self.__value + other.__value)
-
-
-    def __mul__(self, other):
-        if not isinstance(other, ForceChangeRate):
-            raise TypeError("unsupported operand type(s) for *: 'ForceChangeRate' and '{}'".format(type(other).__name__))
-        return ForceChangeRate(self.__value * other.__value)
-
-
-    def __sub__(self, other):
-        if not isinstance(other, ForceChangeRate):
-            raise TypeError("unsupported operand type(s) for -: 'ForceChangeRate' and '{}'".format(type(other).__name__))
-        return ForceChangeRate(self.__value - other.__value)
-
-
-    def __truediv__(self, other):
-        if not isinstance(other, ForceChangeRate):
-            raise TypeError("unsupported operand type(s) for /: 'ForceChangeRate' and '{}'".format(type(other).__name__))
-        return ForceChangeRate(self.__value / other.__value)
-
-
-    def __mod__(self, other):
-        if not isinstance(other, ForceChangeRate):
-            raise TypeError("unsupported operand type(s) for %: 'ForceChangeRate' and '{}'".format(type(other).__name__))
-        return ForceChangeRate(self.__value % other.__value)
-
-
-    def __pow__(self, other):
-        if not isinstance(other, ForceChangeRate):
-            raise TypeError("unsupported operand type(s) for **: 'ForceChangeRate' and '{}'".format(type(other).__name__))
-        return ForceChangeRate(self.__value ** other.__value)
-
-
-    def __eq__(self, other):
-        if not isinstance(other, ForceChangeRate):
-            raise TypeError("unsupported operand type(s) for ==: 'ForceChangeRate' and '{}'".format(type(other).__name__))
-        return self.__value == other.__value
-
-
-    def __lt__(self, other):
-        if not isinstance(other, ForceChangeRate):
-            raise TypeError("unsupported operand type(s) for <: 'ForceChangeRate' and '{}'".format(type(other).__name__))
-        return self.__value < other.__value
-
-
-    def __gt__(self, other):
-        if not isinstance(other, ForceChangeRate):
-            raise TypeError("unsupported operand type(s) for >: 'ForceChangeRate' and '{}'".format(type(other).__name__))
-        return self.__value > other.__value
-
-
-    def __le__(self, other):
-        if not isinstance(other, ForceChangeRate):
-            raise TypeError("unsupported operand type(s) for <=: 'ForceChangeRate' and '{}'".format(type(other).__name__))
-        return self.__value <= other.__value
-
-
-    def __ge__(self, other):
-        if not isinstance(other, ForceChangeRate):
-            raise TypeError("unsupported operand type(s) for >=: 'ForceChangeRate' and '{}'".format(type(other).__name__))
-        return self.__value >= other.__value
\ No newline at end of file
+            return """klbf/s"""
+        
\ No newline at end of file
