@@ -1,6 +1,8 @@
 from enum import Enum
 import math
-import string
+
+from ..abstract_unit import AbstractMeasure
+
 
 
 class FrequencyUnits(Enum):
@@ -74,7 +76,7 @@ class FrequencyUnits(Enum):
         """
         
 
-class Frequency:
+class Frequency(AbstractMeasure):
     """
     The number of occurrences of a repeating event per unit time.
 
@@ -83,9 +85,11 @@ class Frequency:
         from_unit (FrequencyUnits): The Frequency unit to create from, The default unit is Hertz
     """
     def __init__(self, value: float, from_unit: FrequencyUnits = FrequencyUnits.Hertz):
-        if math.isnan(value):
-            raise ValueError('Invalid unit: value is NaN')
-        self.__value = self.__convert_to_base(value, from_unit)
+        # Do not validate type, to allow working with numpay arrays and similar objects who supports all arithmetic 
+        # operations, but they are not a number, see #14 
+        # if math.isnan(value):
+        #     raise ValueError('Invalid unit: value is NaN')
+        self._value = self.__convert_to_base(value, from_unit)
         
         self.__hertz = None
         
@@ -114,8 +118,11 @@ class Frequency:
         self.__terahertz = None
         
 
+    def convert(self, unit: FrequencyUnits) -> float:
+        return self.__convert_from_base(unit)
+
     def __convert_from_base(self, from_unit: FrequencyUnits) -> float:
-        value = self.__value
+        value = self._value
         
         if from_unit == FrequencyUnits.Hertz:
             return (value)
@@ -205,7 +212,7 @@ class Frequency:
 
     @property
     def base_value(self) -> float:
-        return self.__value
+        return self._value
 
     
     @staticmethod
@@ -546,7 +553,7 @@ class Frequency:
         return self.__terahertz
 
     
-    def to_string(self, unit: FrequencyUnits = FrequencyUnits.Hertz) -> string:
+    def to_string(self, unit: FrequencyUnits = FrequencyUnits.Hertz) -> str:
         """
         Format the Frequency to string.
         Note! the default format for Frequency is Hertz.
@@ -575,27 +582,27 @@ class Frequency:
             return f"""{self.b_units} B Units"""
         
         if unit == FrequencyUnits.Microhertz:
-            return f"""{self.microhertz} """
+            return f"""{self.microhertz} μHz"""
         
         if unit == FrequencyUnits.Millihertz:
-            return f"""{self.millihertz} """
+            return f"""{self.millihertz} mHz"""
         
         if unit == FrequencyUnits.Kilohertz:
-            return f"""{self.kilohertz} """
+            return f"""{self.kilohertz} kHz"""
         
         if unit == FrequencyUnits.Megahertz:
-            return f"""{self.megahertz} """
+            return f"""{self.megahertz} MHz"""
         
         if unit == FrequencyUnits.Gigahertz:
-            return f"""{self.gigahertz} """
+            return f"""{self.gigahertz} GHz"""
         
         if unit == FrequencyUnits.Terahertz:
-            return f"""{self.terahertz} """
+            return f"""{self.terahertz} THz"""
         
-        return f'{self.__value}'
+        return f'{self._value}'
 
 
-    def get_unit_abbreviation(self, unit_abbreviation: FrequencyUnits = FrequencyUnits.Hertz) -> string:
+    def get_unit_abbreviation(self, unit_abbreviation: FrequencyUnits = FrequencyUnits.Hertz) -> str:
         """
         Get Frequency unit abbreviation.
         Note! the default abbreviation for Frequency is Hertz.
@@ -624,89 +631,20 @@ class Frequency:
             return """B Units"""
         
         if unit_abbreviation == FrequencyUnits.Microhertz:
-            return """"""
+            return """μHz"""
         
         if unit_abbreviation == FrequencyUnits.Millihertz:
-            return """"""
+            return """mHz"""
         
         if unit_abbreviation == FrequencyUnits.Kilohertz:
-            return """"""
+            return """kHz"""
         
         if unit_abbreviation == FrequencyUnits.Megahertz:
-            return """"""
+            return """MHz"""
         
         if unit_abbreviation == FrequencyUnits.Gigahertz:
-            return """"""
+            return """GHz"""
         
         if unit_abbreviation == FrequencyUnits.Terahertz:
-            return """"""
-        
-
-    def __str__(self):
-        return self.to_string()
-
-
-    def __add__(self, other):
-        if not isinstance(other, Frequency):
-            raise TypeError("unsupported operand type(s) for +: 'Frequency' and '{}'".format(type(other).__name__))
-        return Frequency(self.__value + other.__value)
-
-
-    def __mul__(self, other):
-        if not isinstance(other, Frequency):
-            raise TypeError("unsupported operand type(s) for *: 'Frequency' and '{}'".format(type(other).__name__))
-        return Frequency(self.__value * other.__value)
-
-
-    def __sub__(self, other):
-        if not isinstance(other, Frequency):
-            raise TypeError("unsupported operand type(s) for -: 'Frequency' and '{}'".format(type(other).__name__))
-        return Frequency(self.__value - other.__value)
-
-
-    def __truediv__(self, other):
-        if not isinstance(other, Frequency):
-            raise TypeError("unsupported operand type(s) for /: 'Frequency' and '{}'".format(type(other).__name__))
-        return Frequency(self.__value / other.__value)
-
-
-    def __mod__(self, other):
-        if not isinstance(other, Frequency):
-            raise TypeError("unsupported operand type(s) for %: 'Frequency' and '{}'".format(type(other).__name__))
-        return Frequency(self.__value % other.__value)
-
-
-    def __pow__(self, other):
-        if not isinstance(other, Frequency):
-            raise TypeError("unsupported operand type(s) for **: 'Frequency' and '{}'".format(type(other).__name__))
-        return Frequency(self.__value ** other.__value)
-
-
-    def __eq__(self, other):
-        if not isinstance(other, Frequency):
-            raise TypeError("unsupported operand type(s) for ==: 'Frequency' and '{}'".format(type(other).__name__))
-        return self.__value == other.__value
-
-
-    def __lt__(self, other):
-        if not isinstance(other, Frequency):
-            raise TypeError("unsupported operand type(s) for <: 'Frequency' and '{}'".format(type(other).__name__))
-        return self.__value < other.__value
-
-
-    def __gt__(self, other):
-        if not isinstance(other, Frequency):
-            raise TypeError("unsupported operand type(s) for >: 'Frequency' and '{}'".format(type(other).__name__))
-        return self.__value > other.__value
-
-
-    def __le__(self, other):
-        if not isinstance(other, Frequency):
-            raise TypeError("unsupported operand type(s) for <=: 'Frequency' and '{}'".format(type(other).__name__))
-        return self.__value <= other.__value
-
-
-    def __ge__(self, other):
-        if not isinstance(other, Frequency):
-            raise TypeError("unsupported operand type(s) for >=: 'Frequency' and '{}'".format(type(other).__name__))
-        return self.__value >= other.__value
\ No newline at end of file
+            return """THz"""
+        
\ No newline at end of file
