@@ -1,6 +1,8 @@
 from enum import Enum
 import math
-import string
+
+from ..abstract_unit import AbstractMeasure
+
 
 
 class HeatFluxUnits(Enum):
@@ -99,7 +101,7 @@ class HeatFluxUnits(Enum):
         """
         
 
-class HeatFlux:
+class HeatFlux(AbstractMeasure):
     """
     Heat flux is the flow of energy per unit of area per unit of time
 
@@ -108,9 +110,11 @@ class HeatFlux:
         from_unit (HeatFluxUnits): The HeatFlux unit to create from, The default unit is WattPerSquareMeter
     """
     def __init__(self, value: float, from_unit: HeatFluxUnits = HeatFluxUnits.WattPerSquareMeter):
-        if math.isnan(value):
-            raise ValueError('Invalid unit: value is NaN')
-        self.__value = self.__convert_to_base(value, from_unit)
+        # Do not validate type, to allow working with numpay arrays and similar objects who supports all arithmetic 
+        # operations, but they are not a number, see #14 
+        # if math.isnan(value):
+        #     raise ValueError('Invalid unit: value is NaN')
+        self._value = self.__convert_to_base(value, from_unit)
         
         self.__watts_per_square_meter = None
         
@@ -149,8 +153,11 @@ class HeatFlux:
         self.__kilocalories_per_second_square_centimeter = None
         
 
+    def convert(self, unit: HeatFluxUnits) -> float:
+        return self.__convert_from_base(unit)
+
     def __convert_from_base(self, from_unit: HeatFluxUnits) -> float:
-        value = self.__value
+        value = self._value
         
         if from_unit == HeatFluxUnits.WattPerSquareMeter:
             return (value)
@@ -270,7 +277,7 @@ class HeatFlux:
 
     @property
     def base_value(self) -> float:
-        return self.__value
+        return self._value
 
     
     @staticmethod
@@ -741,7 +748,7 @@ class HeatFlux:
         return self.__kilocalories_per_second_square_centimeter
 
     
-    def to_string(self, unit: HeatFluxUnits = HeatFluxUnits.WattPerSquareMeter) -> string:
+    def to_string(self, unit: HeatFluxUnits = HeatFluxUnits.WattPerSquareMeter) -> str:
         """
         Format the HeatFlux to string.
         Note! the default format for HeatFlux is WattPerSquareMeter.
@@ -782,30 +789,30 @@ class HeatFlux:
             return f"""{self.pounds_per_second_cubed} lb/s³"""
         
         if unit == HeatFluxUnits.NanowattPerSquareMeter:
-            return f"""{self.nanowatts_per_square_meter} """
+            return f"""{self.nanowatts_per_square_meter} nW/m²"""
         
         if unit == HeatFluxUnits.MicrowattPerSquareMeter:
-            return f"""{self.microwatts_per_square_meter} """
+            return f"""{self.microwatts_per_square_meter} μW/m²"""
         
         if unit == HeatFluxUnits.MilliwattPerSquareMeter:
-            return f"""{self.milliwatts_per_square_meter} """
+            return f"""{self.milliwatts_per_square_meter} mW/m²"""
         
         if unit == HeatFluxUnits.CentiwattPerSquareMeter:
-            return f"""{self.centiwatts_per_square_meter} """
+            return f"""{self.centiwatts_per_square_meter} cW/m²"""
         
         if unit == HeatFluxUnits.DeciwattPerSquareMeter:
-            return f"""{self.deciwatts_per_square_meter} """
+            return f"""{self.deciwatts_per_square_meter} dW/m²"""
         
         if unit == HeatFluxUnits.KilowattPerSquareMeter:
-            return f"""{self.kilowatts_per_square_meter} """
+            return f"""{self.kilowatts_per_square_meter} kW/m²"""
         
         if unit == HeatFluxUnits.KilocaloriePerSecondSquareCentimeter:
-            return f"""{self.kilocalories_per_second_square_centimeter} """
+            return f"""{self.kilocalories_per_second_square_centimeter} kcal/s·cm²"""
         
-        return f'{self.__value}'
+        return f'{self._value}'
 
 
-    def get_unit_abbreviation(self, unit_abbreviation: HeatFluxUnits = HeatFluxUnits.WattPerSquareMeter) -> string:
+    def get_unit_abbreviation(self, unit_abbreviation: HeatFluxUnits = HeatFluxUnits.WattPerSquareMeter) -> str:
         """
         Get HeatFlux unit abbreviation.
         Note! the default abbreviation for HeatFlux is WattPerSquareMeter.
@@ -846,92 +853,23 @@ class HeatFlux:
             return """lb/s³"""
         
         if unit_abbreviation == HeatFluxUnits.NanowattPerSquareMeter:
-            return """"""
+            return """nW/m²"""
         
         if unit_abbreviation == HeatFluxUnits.MicrowattPerSquareMeter:
-            return """"""
+            return """μW/m²"""
         
         if unit_abbreviation == HeatFluxUnits.MilliwattPerSquareMeter:
-            return """"""
+            return """mW/m²"""
         
         if unit_abbreviation == HeatFluxUnits.CentiwattPerSquareMeter:
-            return """"""
+            return """cW/m²"""
         
         if unit_abbreviation == HeatFluxUnits.DeciwattPerSquareMeter:
-            return """"""
+            return """dW/m²"""
         
         if unit_abbreviation == HeatFluxUnits.KilowattPerSquareMeter:
-            return """"""
+            return """kW/m²"""
         
         if unit_abbreviation == HeatFluxUnits.KilocaloriePerSecondSquareCentimeter:
-            return """"""
-        
-
-    def __str__(self):
-        return self.to_string()
-
-
-    def __add__(self, other):
-        if not isinstance(other, HeatFlux):
-            raise TypeError("unsupported operand type(s) for +: 'HeatFlux' and '{}'".format(type(other).__name__))
-        return HeatFlux(self.__value + other.__value)
-
-
-    def __mul__(self, other):
-        if not isinstance(other, HeatFlux):
-            raise TypeError("unsupported operand type(s) for *: 'HeatFlux' and '{}'".format(type(other).__name__))
-        return HeatFlux(self.__value * other.__value)
-
-
-    def __sub__(self, other):
-        if not isinstance(other, HeatFlux):
-            raise TypeError("unsupported operand type(s) for -: 'HeatFlux' and '{}'".format(type(other).__name__))
-        return HeatFlux(self.__value - other.__value)
-
-
-    def __truediv__(self, other):
-        if not isinstance(other, HeatFlux):
-            raise TypeError("unsupported operand type(s) for /: 'HeatFlux' and '{}'".format(type(other).__name__))
-        return HeatFlux(self.__value / other.__value)
-
-
-    def __mod__(self, other):
-        if not isinstance(other, HeatFlux):
-            raise TypeError("unsupported operand type(s) for %: 'HeatFlux' and '{}'".format(type(other).__name__))
-        return HeatFlux(self.__value % other.__value)
-
-
-    def __pow__(self, other):
-        if not isinstance(other, HeatFlux):
-            raise TypeError("unsupported operand type(s) for **: 'HeatFlux' and '{}'".format(type(other).__name__))
-        return HeatFlux(self.__value ** other.__value)
-
-
-    def __eq__(self, other):
-        if not isinstance(other, HeatFlux):
-            raise TypeError("unsupported operand type(s) for ==: 'HeatFlux' and '{}'".format(type(other).__name__))
-        return self.__value == other.__value
-
-
-    def __lt__(self, other):
-        if not isinstance(other, HeatFlux):
-            raise TypeError("unsupported operand type(s) for <: 'HeatFlux' and '{}'".format(type(other).__name__))
-        return self.__value < other.__value
-
-
-    def __gt__(self, other):
-        if not isinstance(other, HeatFlux):
-            raise TypeError("unsupported operand type(s) for >: 'HeatFlux' and '{}'".format(type(other).__name__))
-        return self.__value > other.__value
-
-
-    def __le__(self, other):
-        if not isinstance(other, HeatFlux):
-            raise TypeError("unsupported operand type(s) for <=: 'HeatFlux' and '{}'".format(type(other).__name__))
-        return self.__value <= other.__value
-
-
-    def __ge__(self, other):
-        if not isinstance(other, HeatFlux):
-            raise TypeError("unsupported operand type(s) for >=: 'HeatFlux' and '{}'".format(type(other).__name__))
-        return self.__value >= other.__value
\ No newline at end of file
+            return """kcal/s·cm²"""
+        
\ No newline at end of file
