@@ -1,6 +1,8 @@
 from enum import Enum
 import math
-import string
+
+from ..abstract_unit import AbstractMeasure
+
 
 
 class ImpulseUnits(Enum):
@@ -74,7 +76,7 @@ class ImpulseUnits(Enum):
         """
         
 
-class Impulse:
+class Impulse(AbstractMeasure):
     """
     In classical mechanics, impulse is the integral of a force, F, over the time interval, t, for which it acts. Impulse applied to an object produces an equivalent vector change in its linear momentum, also in the resultant direction.
 
@@ -83,9 +85,11 @@ class Impulse:
         from_unit (ImpulseUnits): The Impulse unit to create from, The default unit is NewtonSecond
     """
     def __init__(self, value: float, from_unit: ImpulseUnits = ImpulseUnits.NewtonSecond):
-        if math.isnan(value):
-            raise ValueError('Invalid unit: value is NaN')
-        self.__value = self.__convert_to_base(value, from_unit)
+        # Do not validate type, to allow working with numpay arrays and similar objects who supports all arithmetic 
+        # operations, but they are not a number, see #14 
+        # if math.isnan(value):
+        #     raise ValueError('Invalid unit: value is NaN')
+        self._value = self.__convert_to_base(value, from_unit)
         
         self.__kilogram_meters_per_second = None
         
@@ -114,8 +118,11 @@ class Impulse:
         self.__meganewton_seconds = None
         
 
+    def convert(self, unit: ImpulseUnits) -> float:
+        return self.__convert_from_base(unit)
+
     def __convert_from_base(self, from_unit: ImpulseUnits) -> float:
-        value = self.__value
+        value = self._value
         
         if from_unit == ImpulseUnits.KilogramMeterPerSecond:
             return (value)
@@ -205,7 +212,7 @@ class Impulse:
 
     @property
     def base_value(self) -> float:
-        return self.__value
+        return self._value
 
     
     @staticmethod
@@ -546,7 +553,7 @@ class Impulse:
         return self.__meganewton_seconds
 
     
-    def to_string(self, unit: ImpulseUnits = ImpulseUnits.NewtonSecond) -> string:
+    def to_string(self, unit: ImpulseUnits = ImpulseUnits.NewtonSecond) -> str:
         """
         Format the Impulse to string.
         Note! the default format for Impulse is NewtonSecond.
@@ -569,33 +576,33 @@ class Impulse:
             return f"""{self.slug_feet_per_second} slug·ft/s"""
         
         if unit == ImpulseUnits.NanonewtonSecond:
-            return f"""{self.nanonewton_seconds} """
+            return f"""{self.nanonewton_seconds} nN·s"""
         
         if unit == ImpulseUnits.MicronewtonSecond:
-            return f"""{self.micronewton_seconds} """
+            return f"""{self.micronewton_seconds} μN·s"""
         
         if unit == ImpulseUnits.MillinewtonSecond:
-            return f"""{self.millinewton_seconds} """
+            return f"""{self.millinewton_seconds} mN·s"""
         
         if unit == ImpulseUnits.CentinewtonSecond:
-            return f"""{self.centinewton_seconds} """
+            return f"""{self.centinewton_seconds} cN·s"""
         
         if unit == ImpulseUnits.DecinewtonSecond:
-            return f"""{self.decinewton_seconds} """
+            return f"""{self.decinewton_seconds} dN·s"""
         
         if unit == ImpulseUnits.DecanewtonSecond:
-            return f"""{self.decanewton_seconds} """
+            return f"""{self.decanewton_seconds} daN·s"""
         
         if unit == ImpulseUnits.KilonewtonSecond:
-            return f"""{self.kilonewton_seconds} """
+            return f"""{self.kilonewton_seconds} kN·s"""
         
         if unit == ImpulseUnits.MeganewtonSecond:
-            return f"""{self.meganewton_seconds} """
+            return f"""{self.meganewton_seconds} MN·s"""
         
-        return f'{self.__value}'
+        return f'{self._value}'
 
 
-    def get_unit_abbreviation(self, unit_abbreviation: ImpulseUnits = ImpulseUnits.NewtonSecond) -> string:
+    def get_unit_abbreviation(self, unit_abbreviation: ImpulseUnits = ImpulseUnits.NewtonSecond) -> str:
         """
         Get Impulse unit abbreviation.
         Note! the default abbreviation for Impulse is NewtonSecond.
@@ -618,95 +625,26 @@ class Impulse:
             return """slug·ft/s"""
         
         if unit_abbreviation == ImpulseUnits.NanonewtonSecond:
-            return """"""
+            return """nN·s"""
         
         if unit_abbreviation == ImpulseUnits.MicronewtonSecond:
-            return """"""
+            return """μN·s"""
         
         if unit_abbreviation == ImpulseUnits.MillinewtonSecond:
-            return """"""
+            return """mN·s"""
         
         if unit_abbreviation == ImpulseUnits.CentinewtonSecond:
-            return """"""
+            return """cN·s"""
         
         if unit_abbreviation == ImpulseUnits.DecinewtonSecond:
-            return """"""
+            return """dN·s"""
         
         if unit_abbreviation == ImpulseUnits.DecanewtonSecond:
-            return """"""
+            return """daN·s"""
         
         if unit_abbreviation == ImpulseUnits.KilonewtonSecond:
-            return """"""
+            return """kN·s"""
         
         if unit_abbreviation == ImpulseUnits.MeganewtonSecond:
-            return """"""
-        
-
-    def __str__(self):
-        return self.to_string()
-
-
-    def __add__(self, other):
-        if not isinstance(other, Impulse):
-            raise TypeError("unsupported operand type(s) for +: 'Impulse' and '{}'".format(type(other).__name__))
-        return Impulse(self.__value + other.__value)
-
-
-    def __mul__(self, other):
-        if not isinstance(other, Impulse):
-            raise TypeError("unsupported operand type(s) for *: 'Impulse' and '{}'".format(type(other).__name__))
-        return Impulse(self.__value * other.__value)
-
-
-    def __sub__(self, other):
-        if not isinstance(other, Impulse):
-            raise TypeError("unsupported operand type(s) for -: 'Impulse' and '{}'".format(type(other).__name__))
-        return Impulse(self.__value - other.__value)
-
-
-    def __truediv__(self, other):
-        if not isinstance(other, Impulse):
-            raise TypeError("unsupported operand type(s) for /: 'Impulse' and '{}'".format(type(other).__name__))
-        return Impulse(self.__value / other.__value)
-
-
-    def __mod__(self, other):
-        if not isinstance(other, Impulse):
-            raise TypeError("unsupported operand type(s) for %: 'Impulse' and '{}'".format(type(other).__name__))
-        return Impulse(self.__value % other.__value)
-
-
-    def __pow__(self, other):
-        if not isinstance(other, Impulse):
-            raise TypeError("unsupported operand type(s) for **: 'Impulse' and '{}'".format(type(other).__name__))
-        return Impulse(self.__value ** other.__value)
-
-
-    def __eq__(self, other):
-        if not isinstance(other, Impulse):
-            raise TypeError("unsupported operand type(s) for ==: 'Impulse' and '{}'".format(type(other).__name__))
-        return self.__value == other.__value
-
-
-    def __lt__(self, other):
-        if not isinstance(other, Impulse):
-            raise TypeError("unsupported operand type(s) for <: 'Impulse' and '{}'".format(type(other).__name__))
-        return self.__value < other.__value
-
-
-    def __gt__(self, other):
-        if not isinstance(other, Impulse):
-            raise TypeError("unsupported operand type(s) for >: 'Impulse' and '{}'".format(type(other).__name__))
-        return self.__value > other.__value
-
-
-    def __le__(self, other):
-        if not isinstance(other, Impulse):
-            raise TypeError("unsupported operand type(s) for <=: 'Impulse' and '{}'".format(type(other).__name__))
-        return self.__value <= other.__value
-
-
-    def __ge__(self, other):
-        if not isinstance(other, Impulse):
-            raise TypeError("unsupported operand type(s) for >=: 'Impulse' and '{}'".format(type(other).__name__))
-        return self.__value >= other.__value
\ No newline at end of file
+            return """MN·s"""
+        
\ No newline at end of file
