@@ -1,6 +1,8 @@
 from enum import Enum
 import math
-import string
+
+from ..abstract_unit import AbstractMeasure
+
 
 
 class InformationUnits(Enum):
@@ -79,7 +81,7 @@ class InformationUnits(Enum):
         """
         
 
-class Information:
+class Information(AbstractMeasure):
     """
     In computing and telecommunications, a unit of information is the capacity of some standard data storage system or communication channel, used to measure the capacities of other systems and channels. In information theory, units of information are also used to measure the information contents or entropy of random variables.
 
@@ -88,9 +90,11 @@ class Information:
         from_unit (InformationUnits): The Information unit to create from, The default unit is Bit
     """
     def __init__(self, value: float, from_unit: InformationUnits = InformationUnits.Bit):
-        if math.isnan(value):
-            raise ValueError('Invalid unit: value is NaN')
-        self.__value = self.__convert_to_base(value, from_unit)
+        # Do not validate type, to allow working with numpay arrays and similar objects who supports all arithmetic 
+        # operations, but they are not a number, see #14 
+        # if math.isnan(value):
+        #     raise ValueError('Invalid unit: value is NaN')
+        self._value = self.__convert_to_base(value, from_unit)
         
         self.__bytes = None
         
@@ -121,8 +125,11 @@ class Information:
         self.__exabits = None
         
 
+    def convert(self, unit: InformationUnits) -> float:
+        return self.__convert_from_base(unit)
+
     def __convert_from_base(self, from_unit: InformationUnits) -> float:
-        value = self.__value
+        value = self._value
         
         if from_unit == InformationUnits.Byte:
             return (value / 8)
@@ -218,7 +225,7 @@ class Information:
 
     @property
     def base_value(self) -> float:
-        return self.__value
+        return self._value
 
     
     @staticmethod
@@ -585,7 +592,7 @@ class Information:
         return self.__exabits
 
     
-    def to_string(self, unit: InformationUnits = InformationUnits.Bit) -> string:
+    def to_string(self, unit: InformationUnits = InformationUnits.Bit) -> str:
         """
         Format the Information to string.
         Note! the default format for Information is Bit.
@@ -599,45 +606,45 @@ class Information:
             return f"""{self.bits} b"""
         
         if unit == InformationUnits.Kilobyte:
-            return f"""{self.kilobytes} """
+            return f"""{self.kilobytes} kB"""
         
         if unit == InformationUnits.Megabyte:
-            return f"""{self.megabytes} """
+            return f"""{self.megabytes} MB"""
         
         if unit == InformationUnits.Gigabyte:
-            return f"""{self.gigabytes} """
+            return f"""{self.gigabytes} GB"""
         
         if unit == InformationUnits.Terabyte:
-            return f"""{self.terabytes} """
+            return f"""{self.terabytes} TB"""
         
         if unit == InformationUnits.Petabyte:
-            return f"""{self.petabytes} """
+            return f"""{self.petabytes} PB"""
         
         if unit == InformationUnits.Exabyte:
-            return f"""{self.exabytes} """
+            return f"""{self.exabytes} EB"""
         
         if unit == InformationUnits.Kilobit:
-            return f"""{self.kilobits} """
+            return f"""{self.kilobits} kb"""
         
         if unit == InformationUnits.Megabit:
-            return f"""{self.megabits} """
+            return f"""{self.megabits} Mb"""
         
         if unit == InformationUnits.Gigabit:
-            return f"""{self.gigabits} """
+            return f"""{self.gigabits} Gb"""
         
         if unit == InformationUnits.Terabit:
-            return f"""{self.terabits} """
+            return f"""{self.terabits} Tb"""
         
         if unit == InformationUnits.Petabit:
-            return f"""{self.petabits} """
+            return f"""{self.petabits} Pb"""
         
         if unit == InformationUnits.Exabit:
-            return f"""{self.exabits} """
+            return f"""{self.exabits} Eb"""
         
-        return f'{self.__value}'
+        return f'{self._value}'
 
 
-    def get_unit_abbreviation(self, unit_abbreviation: InformationUnits = InformationUnits.Bit) -> string:
+    def get_unit_abbreviation(self, unit_abbreviation: InformationUnits = InformationUnits.Bit) -> str:
         """
         Get Information unit abbreviation.
         Note! the default abbreviation for Information is Bit.
@@ -651,107 +658,38 @@ class Information:
             return """b"""
         
         if unit_abbreviation == InformationUnits.Kilobyte:
-            return """"""
+            return """kB"""
         
         if unit_abbreviation == InformationUnits.Megabyte:
-            return """"""
+            return """MB"""
         
         if unit_abbreviation == InformationUnits.Gigabyte:
-            return """"""
+            return """GB"""
         
         if unit_abbreviation == InformationUnits.Terabyte:
-            return """"""
+            return """TB"""
         
         if unit_abbreviation == InformationUnits.Petabyte:
-            return """"""
+            return """PB"""
         
         if unit_abbreviation == InformationUnits.Exabyte:
-            return """"""
+            return """EB"""
         
         if unit_abbreviation == InformationUnits.Kilobit:
-            return """"""
+            return """kb"""
         
         if unit_abbreviation == InformationUnits.Megabit:
-            return """"""
+            return """Mb"""
         
         if unit_abbreviation == InformationUnits.Gigabit:
-            return """"""
+            return """Gb"""
         
         if unit_abbreviation == InformationUnits.Terabit:
-            return """"""
+            return """Tb"""
         
         if unit_abbreviation == InformationUnits.Petabit:
-            return """"""
+            return """Pb"""
         
         if unit_abbreviation == InformationUnits.Exabit:
-            return """"""
-        
-
-    def __str__(self):
-        return self.to_string()
-
-
-    def __add__(self, other):
-        if not isinstance(other, Information):
-            raise TypeError("unsupported operand type(s) for +: 'Information' and '{}'".format(type(other).__name__))
-        return Information(self.__value + other.__value)
-
-
-    def __mul__(self, other):
-        if not isinstance(other, Information):
-            raise TypeError("unsupported operand type(s) for *: 'Information' and '{}'".format(type(other).__name__))
-        return Information(self.__value * other.__value)
-
-
-    def __sub__(self, other):
-        if not isinstance(other, Information):
-            raise TypeError("unsupported operand type(s) for -: 'Information' and '{}'".format(type(other).__name__))
-        return Information(self.__value - other.__value)
-
-
-    def __truediv__(self, other):
-        if not isinstance(other, Information):
-            raise TypeError("unsupported operand type(s) for /: 'Information' and '{}'".format(type(other).__name__))
-        return Information(self.__value / other.__value)
-
-
-    def __mod__(self, other):
-        if not isinstance(other, Information):
-            raise TypeError("unsupported operand type(s) for %: 'Information' and '{}'".format(type(other).__name__))
-        return Information(self.__value % other.__value)
-
-
-    def __pow__(self, other):
-        if not isinstance(other, Information):
-            raise TypeError("unsupported operand type(s) for **: 'Information' and '{}'".format(type(other).__name__))
-        return Information(self.__value ** other.__value)
-
-
-    def __eq__(self, other):
-        if not isinstance(other, Information):
-            raise TypeError("unsupported operand type(s) for ==: 'Information' and '{}'".format(type(other).__name__))
-        return self.__value == other.__value
-
-
-    def __lt__(self, other):
-        if not isinstance(other, Information):
-            raise TypeError("unsupported operand type(s) for <: 'Information' and '{}'".format(type(other).__name__))
-        return self.__value < other.__value
-
-
-    def __gt__(self, other):
-        if not isinstance(other, Information):
-            raise TypeError("unsupported operand type(s) for >: 'Information' and '{}'".format(type(other).__name__))
-        return self.__value > other.__value
-
-
-    def __le__(self, other):
-        if not isinstance(other, Information):
-            raise TypeError("unsupported operand type(s) for <=: 'Information' and '{}'".format(type(other).__name__))
-        return self.__value <= other.__value
-
-
-    def __ge__(self, other):
-        if not isinstance(other, Information):
-            raise TypeError("unsupported operand type(s) for >=: 'Information' and '{}'".format(type(other).__name__))
-        return self.__value >= other.__value
\ No newline at end of file
+            return """Eb"""
+        
\ No newline at end of file
