@@ -1,6 +1,8 @@
 from enum import Enum
 import math
-import string
+
+from ..abstract_unit import AbstractMeasure
+
 
 
 class IrradianceUnits(Enum):
@@ -79,7 +81,7 @@ class IrradianceUnits(Enum):
         """
         
 
-class Irradiance:
+class Irradiance(AbstractMeasure):
     """
     Irradiance is the intensity of ultraviolet (UV) or visible light incident on a surface.
 
@@ -88,9 +90,11 @@ class Irradiance:
         from_unit (IrradianceUnits): The Irradiance unit to create from, The default unit is WattPerSquareMeter
     """
     def __init__(self, value: float, from_unit: IrradianceUnits = IrradianceUnits.WattPerSquareMeter):
-        if math.isnan(value):
-            raise ValueError('Invalid unit: value is NaN')
-        self.__value = self.__convert_to_base(value, from_unit)
+        # Do not validate type, to allow working with numpay arrays and similar objects who supports all arithmetic 
+        # operations, but they are not a number, see #14 
+        # if math.isnan(value):
+        #     raise ValueError('Invalid unit: value is NaN')
+        self._value = self.__convert_to_base(value, from_unit)
         
         self.__watts_per_square_meter = None
         
@@ -121,8 +125,11 @@ class Irradiance:
         self.__megawatts_per_square_centimeter = None
         
 
+    def convert(self, unit: IrradianceUnits) -> float:
+        return self.__convert_from_base(unit)
+
     def __convert_from_base(self, from_unit: IrradianceUnits) -> float:
-        value = self.__value
+        value = self._value
         
         if from_unit == IrradianceUnits.WattPerSquareMeter:
             return (value)
@@ -218,7 +225,7 @@ class Irradiance:
 
     @property
     def base_value(self) -> float:
-        return self.__value
+        return self._value
 
     
     @staticmethod
@@ -585,7 +592,7 @@ class Irradiance:
         return self.__megawatts_per_square_centimeter
 
     
-    def to_string(self, unit: IrradianceUnits = IrradianceUnits.WattPerSquareMeter) -> string:
+    def to_string(self, unit: IrradianceUnits = IrradianceUnits.WattPerSquareMeter) -> str:
         """
         Format the Irradiance to string.
         Note! the default format for Irradiance is WattPerSquareMeter.
@@ -599,45 +606,45 @@ class Irradiance:
             return f"""{self.watts_per_square_centimeter} W/cm²"""
         
         if unit == IrradianceUnits.PicowattPerSquareMeter:
-            return f"""{self.picowatts_per_square_meter} """
+            return f"""{self.picowatts_per_square_meter} pW/m²"""
         
         if unit == IrradianceUnits.NanowattPerSquareMeter:
-            return f"""{self.nanowatts_per_square_meter} """
+            return f"""{self.nanowatts_per_square_meter} nW/m²"""
         
         if unit == IrradianceUnits.MicrowattPerSquareMeter:
-            return f"""{self.microwatts_per_square_meter} """
+            return f"""{self.microwatts_per_square_meter} μW/m²"""
         
         if unit == IrradianceUnits.MilliwattPerSquareMeter:
-            return f"""{self.milliwatts_per_square_meter} """
+            return f"""{self.milliwatts_per_square_meter} mW/m²"""
         
         if unit == IrradianceUnits.KilowattPerSquareMeter:
-            return f"""{self.kilowatts_per_square_meter} """
+            return f"""{self.kilowatts_per_square_meter} kW/m²"""
         
         if unit == IrradianceUnits.MegawattPerSquareMeter:
-            return f"""{self.megawatts_per_square_meter} """
+            return f"""{self.megawatts_per_square_meter} MW/m²"""
         
         if unit == IrradianceUnits.PicowattPerSquareCentimeter:
-            return f"""{self.picowatts_per_square_centimeter} """
+            return f"""{self.picowatts_per_square_centimeter} pW/cm²"""
         
         if unit == IrradianceUnits.NanowattPerSquareCentimeter:
-            return f"""{self.nanowatts_per_square_centimeter} """
+            return f"""{self.nanowatts_per_square_centimeter} nW/cm²"""
         
         if unit == IrradianceUnits.MicrowattPerSquareCentimeter:
-            return f"""{self.microwatts_per_square_centimeter} """
+            return f"""{self.microwatts_per_square_centimeter} μW/cm²"""
         
         if unit == IrradianceUnits.MilliwattPerSquareCentimeter:
-            return f"""{self.milliwatts_per_square_centimeter} """
+            return f"""{self.milliwatts_per_square_centimeter} mW/cm²"""
         
         if unit == IrradianceUnits.KilowattPerSquareCentimeter:
-            return f"""{self.kilowatts_per_square_centimeter} """
+            return f"""{self.kilowatts_per_square_centimeter} kW/cm²"""
         
         if unit == IrradianceUnits.MegawattPerSquareCentimeter:
-            return f"""{self.megawatts_per_square_centimeter} """
+            return f"""{self.megawatts_per_square_centimeter} MW/cm²"""
         
-        return f'{self.__value}'
+        return f'{self._value}'
 
 
-    def get_unit_abbreviation(self, unit_abbreviation: IrradianceUnits = IrradianceUnits.WattPerSquareMeter) -> string:
+    def get_unit_abbreviation(self, unit_abbreviation: IrradianceUnits = IrradianceUnits.WattPerSquareMeter) -> str:
         """
         Get Irradiance unit abbreviation.
         Note! the default abbreviation for Irradiance is WattPerSquareMeter.
@@ -651,107 +658,38 @@ class Irradiance:
             return """W/cm²"""
         
         if unit_abbreviation == IrradianceUnits.PicowattPerSquareMeter:
-            return """"""
+            return """pW/m²"""
         
         if unit_abbreviation == IrradianceUnits.NanowattPerSquareMeter:
-            return """"""
+            return """nW/m²"""
         
         if unit_abbreviation == IrradianceUnits.MicrowattPerSquareMeter:
-            return """"""
+            return """μW/m²"""
         
         if unit_abbreviation == IrradianceUnits.MilliwattPerSquareMeter:
-            return """"""
+            return """mW/m²"""
         
         if unit_abbreviation == IrradianceUnits.KilowattPerSquareMeter:
-            return """"""
+            return """kW/m²"""
         
         if unit_abbreviation == IrradianceUnits.MegawattPerSquareMeter:
-            return """"""
+            return """MW/m²"""
         
         if unit_abbreviation == IrradianceUnits.PicowattPerSquareCentimeter:
-            return """"""
+            return """pW/cm²"""
         
         if unit_abbreviation == IrradianceUnits.NanowattPerSquareCentimeter:
-            return """"""
+            return """nW/cm²"""
         
         if unit_abbreviation == IrradianceUnits.MicrowattPerSquareCentimeter:
-            return """"""
+            return """μW/cm²"""
         
         if unit_abbreviation == IrradianceUnits.MilliwattPerSquareCentimeter:
-            return """"""
+            return """mW/cm²"""
         
         if unit_abbreviation == IrradianceUnits.KilowattPerSquareCentimeter:
-            return """"""
+            return """kW/cm²"""
         
         if unit_abbreviation == IrradianceUnits.MegawattPerSquareCentimeter:
-            return """"""
-        
-
-    def __str__(self):
-        return self.to_string()
-
-
-    def __add__(self, other):
-        if not isinstance(other, Irradiance):
-            raise TypeError("unsupported operand type(s) for +: 'Irradiance' and '{}'".format(type(other).__name__))
-        return Irradiance(self.__value + other.__value)
-
-
-    def __mul__(self, other):
-        if not isinstance(other, Irradiance):
-            raise TypeError("unsupported operand type(s) for *: 'Irradiance' and '{}'".format(type(other).__name__))
-        return Irradiance(self.__value * other.__value)
-
-
-    def __sub__(self, other):
-        if not isinstance(other, Irradiance):
-            raise TypeError("unsupported operand type(s) for -: 'Irradiance' and '{}'".format(type(other).__name__))
-        return Irradiance(self.__value - other.__value)
-
-
-    def __truediv__(self, other):
-        if not isinstance(other, Irradiance):
-            raise TypeError("unsupported operand type(s) for /: 'Irradiance' and '{}'".format(type(other).__name__))
-        return Irradiance(self.__value / other.__value)
-
-
-    def __mod__(self, other):
-        if not isinstance(other, Irradiance):
-            raise TypeError("unsupported operand type(s) for %: 'Irradiance' and '{}'".format(type(other).__name__))
-        return Irradiance(self.__value % other.__value)
-
-
-    def __pow__(self, other):
-        if not isinstance(other, Irradiance):
-            raise TypeError("unsupported operand type(s) for **: 'Irradiance' and '{}'".format(type(other).__name__))
-        return Irradiance(self.__value ** other.__value)
-
-
-    def __eq__(self, other):
-        if not isinstance(other, Irradiance):
-            raise TypeError("unsupported operand type(s) for ==: 'Irradiance' and '{}'".format(type(other).__name__))
-        return self.__value == other.__value
-
-
-    def __lt__(self, other):
-        if not isinstance(other, Irradiance):
-            raise TypeError("unsupported operand type(s) for <: 'Irradiance' and '{}'".format(type(other).__name__))
-        return self.__value < other.__value
-
-
-    def __gt__(self, other):
-        if not isinstance(other, Irradiance):
-            raise TypeError("unsupported operand type(s) for >: 'Irradiance' and '{}'".format(type(other).__name__))
-        return self.__value > other.__value
-
-
-    def __le__(self, other):
-        if not isinstance(other, Irradiance):
-            raise TypeError("unsupported operand type(s) for <=: 'Irradiance' and '{}'".format(type(other).__name__))
-        return self.__value <= other.__value
-
-
-    def __ge__(self, other):
-        if not isinstance(other, Irradiance):
-            raise TypeError("unsupported operand type(s) for >=: 'Irradiance' and '{}'".format(type(other).__name__))
-        return self.__value >= other.__value
\ No newline at end of file
+            return """MW/cm²"""
+        
\ No newline at end of file
