@@ -1,6 +1,8 @@
 from enum import Enum
 import math
-import string
+
+from ..abstract_unit import AbstractMeasure
+
 
 
 class JerkUnits(Enum):
@@ -64,7 +66,7 @@ class JerkUnits(Enum):
         """
         
 
-class Jerk:
+class Jerk(AbstractMeasure):
     """
     None
 
@@ -73,9 +75,11 @@ class Jerk:
         from_unit (JerkUnits): The Jerk unit to create from, The default unit is MeterPerSecondCubed
     """
     def __init__(self, value: float, from_unit: JerkUnits = JerkUnits.MeterPerSecondCubed):
-        if math.isnan(value):
-            raise ValueError('Invalid unit: value is NaN')
-        self.__value = self.__convert_to_base(value, from_unit)
+        # Do not validate type, to allow working with numpay arrays and similar objects who supports all arithmetic 
+        # operations, but they are not a number, see #14 
+        # if math.isnan(value):
+        #     raise ValueError('Invalid unit: value is NaN')
+        self._value = self.__convert_to_base(value, from_unit)
         
         self.__meters_per_second_cubed = None
         
@@ -100,8 +104,11 @@ class Jerk:
         self.__millistandard_gravities_per_second = None
         
 
+    def convert(self, unit: JerkUnits) -> float:
+        return self.__convert_from_base(unit)
+
     def __convert_from_base(self, from_unit: JerkUnits) -> float:
-        value = self.__value
+        value = self._value
         
         if from_unit == JerkUnits.MeterPerSecondCubed:
             return (value)
@@ -179,7 +186,7 @@ class Jerk:
 
     @property
     def base_value(self) -> float:
-        return self.__value
+        return self._value
 
     
     @staticmethod
@@ -468,7 +475,7 @@ class Jerk:
         return self.__millistandard_gravities_per_second
 
     
-    def to_string(self, unit: JerkUnits = JerkUnits.MeterPerSecondCubed) -> string:
+    def to_string(self, unit: JerkUnits = JerkUnits.MeterPerSecondCubed) -> str:
         """
         Format the Jerk to string.
         Note! the default format for Jerk is MeterPerSecondCubed.
@@ -488,30 +495,30 @@ class Jerk:
             return f"""{self.standard_gravities_per_second} g/s"""
         
         if unit == JerkUnits.NanometerPerSecondCubed:
-            return f"""{self.nanometers_per_second_cubed} """
+            return f"""{self.nanometers_per_second_cubed} nm/s³"""
         
         if unit == JerkUnits.MicrometerPerSecondCubed:
-            return f"""{self.micrometers_per_second_cubed} """
+            return f"""{self.micrometers_per_second_cubed} μm/s³"""
         
         if unit == JerkUnits.MillimeterPerSecondCubed:
-            return f"""{self.millimeters_per_second_cubed} """
+            return f"""{self.millimeters_per_second_cubed} mm/s³"""
         
         if unit == JerkUnits.CentimeterPerSecondCubed:
-            return f"""{self.centimeters_per_second_cubed} """
+            return f"""{self.centimeters_per_second_cubed} cm/s³"""
         
         if unit == JerkUnits.DecimeterPerSecondCubed:
-            return f"""{self.decimeters_per_second_cubed} """
+            return f"""{self.decimeters_per_second_cubed} dm/s³"""
         
         if unit == JerkUnits.KilometerPerSecondCubed:
-            return f"""{self.kilometers_per_second_cubed} """
+            return f"""{self.kilometers_per_second_cubed} km/s³"""
         
         if unit == JerkUnits.MillistandardGravitiesPerSecond:
-            return f"""{self.millistandard_gravities_per_second} """
+            return f"""{self.millistandard_gravities_per_second} mg/s"""
         
-        return f'{self.__value}'
+        return f'{self._value}'
 
 
-    def get_unit_abbreviation(self, unit_abbreviation: JerkUnits = JerkUnits.MeterPerSecondCubed) -> string:
+    def get_unit_abbreviation(self, unit_abbreviation: JerkUnits = JerkUnits.MeterPerSecondCubed) -> str:
         """
         Get Jerk unit abbreviation.
         Note! the default abbreviation for Jerk is MeterPerSecondCubed.
@@ -531,92 +538,23 @@ class Jerk:
             return """g/s"""
         
         if unit_abbreviation == JerkUnits.NanometerPerSecondCubed:
-            return """"""
+            return """nm/s³"""
         
         if unit_abbreviation == JerkUnits.MicrometerPerSecondCubed:
-            return """"""
+            return """μm/s³"""
         
         if unit_abbreviation == JerkUnits.MillimeterPerSecondCubed:
-            return """"""
+            return """mm/s³"""
         
         if unit_abbreviation == JerkUnits.CentimeterPerSecondCubed:
-            return """"""
+            return """cm/s³"""
         
         if unit_abbreviation == JerkUnits.DecimeterPerSecondCubed:
-            return """"""
+            return """dm/s³"""
         
         if unit_abbreviation == JerkUnits.KilometerPerSecondCubed:
-            return """"""
+            return """km/s³"""
         
         if unit_abbreviation == JerkUnits.MillistandardGravitiesPerSecond:
-            return """"""
-        
-
-    def __str__(self):
-        return self.to_string()
-
-
-    def __add__(self, other):
-        if not isinstance(other, Jerk):
-            raise TypeError("unsupported operand type(s) for +: 'Jerk' and '{}'".format(type(other).__name__))
-        return Jerk(self.__value + other.__value)
-
-
-    def __mul__(self, other):
-        if not isinstance(other, Jerk):
-            raise TypeError("unsupported operand type(s) for *: 'Jerk' and '{}'".format(type(other).__name__))
-        return Jerk(self.__value * other.__value)
-
-
-    def __sub__(self, other):
-        if not isinstance(other, Jerk):
-            raise TypeError("unsupported operand type(s) for -: 'Jerk' and '{}'".format(type(other).__name__))
-        return Jerk(self.__value - other.__value)
-
-
-    def __truediv__(self, other):
-        if not isinstance(other, Jerk):
-            raise TypeError("unsupported operand type(s) for /: 'Jerk' and '{}'".format(type(other).__name__))
-        return Jerk(self.__value / other.__value)
-
-
-    def __mod__(self, other):
-        if not isinstance(other, Jerk):
-            raise TypeError("unsupported operand type(s) for %: 'Jerk' and '{}'".format(type(other).__name__))
-        return Jerk(self.__value % other.__value)
-
-
-    def __pow__(self, other):
-        if not isinstance(other, Jerk):
-            raise TypeError("unsupported operand type(s) for **: 'Jerk' and '{}'".format(type(other).__name__))
-        return Jerk(self.__value ** other.__value)
-
-
-    def __eq__(self, other):
-        if not isinstance(other, Jerk):
-            raise TypeError("unsupported operand type(s) for ==: 'Jerk' and '{}'".format(type(other).__name__))
-        return self.__value == other.__value
-
-
-    def __lt__(self, other):
-        if not isinstance(other, Jerk):
-            raise TypeError("unsupported operand type(s) for <: 'Jerk' and '{}'".format(type(other).__name__))
-        return self.__value < other.__value
-
-
-    def __gt__(self, other):
-        if not isinstance(other, Jerk):
-            raise TypeError("unsupported operand type(s) for >: 'Jerk' and '{}'".format(type(other).__name__))
-        return self.__value > other.__value
-
-
-    def __le__(self, other):
-        if not isinstance(other, Jerk):
-            raise TypeError("unsupported operand type(s) for <=: 'Jerk' and '{}'".format(type(other).__name__))
-        return self.__value <= other.__value
-
-
-    def __ge__(self, other):
-        if not isinstance(other, Jerk):
-            raise TypeError("unsupported operand type(s) for >=: 'Jerk' and '{}'".format(type(other).__name__))
-        return self.__value >= other.__value
\ No newline at end of file
+            return """mg/s"""
+        
\ No newline at end of file
