@@ -1,6 +1,8 @@
 from enum import Enum
 import math
-import string
+
+from ..abstract_unit import AbstractMeasure
+
 
 
 class LengthUnits(Enum):
@@ -128,6 +130,16 @@ class LengthUnits(Enum):
             In radar-related subjects and in JTIDS, a data mile is a unit of distance equal to 6000 feet (1.8288 kilometres or 0.987 nautical miles).
         """
         
+        Femtometer = 'femtometer'
+        """
+            
+        """
+        
+        Picometer = 'picometer'
+        """
+            
+        """
+        
         Nanometer = 'nanometer'
         """
             
@@ -173,6 +185,21 @@ class LengthUnits(Enum):
             
         """
         
+        Gigameter = 'gigameter'
+        """
+            
+        """
+        
+        Kiloyard = 'kiloyard'
+        """
+            
+        """
+        
+        Kilofoot = 'kilofoot'
+        """
+            
+        """
+        
         Kiloparsec = 'kiloparsec'
         """
             
@@ -194,7 +221,7 @@ class LengthUnits(Enum):
         """
         
 
-class Length:
+class Length(AbstractMeasure):
     """
     Many different units of length have been used around the world. The main units in modern use are U.S. customary units in the United States and the Metric system elsewhere. British Imperial units are still used for some purposes in the United Kingdom and some other countries. The metric system is sub-divided into SI and non-SI units.
 
@@ -203,9 +230,11 @@ class Length:
         from_unit (LengthUnits): The Length unit to create from, The default unit is Meter
     """
     def __init__(self, value: float, from_unit: LengthUnits = LengthUnits.Meter):
-        if math.isnan(value):
-            raise ValueError('Invalid unit: value is NaN')
-        self.__value = self.__convert_to_base(value, from_unit)
+        # Do not validate type, to allow working with numpay arrays and similar objects who supports all arithmetic 
+        # operations, but they are not a number, see #14 
+        # if math.isnan(value):
+        #     raise ValueError('Invalid unit: value is NaN')
+        self._value = self.__convert_to_base(value, from_unit)
         
         self.__meters = None
         
@@ -255,6 +284,10 @@ class Length:
         
         self.__data_miles = None
         
+        self.__femtometers = None
+        
+        self.__picometers = None
+        
         self.__nanometers = None
         
         self.__micrometers = None
@@ -273,6 +306,12 @@ class Length:
         
         self.__megameters = None
         
+        self.__gigameters = None
+        
+        self.__kiloyards = None
+        
+        self.__kilofeet = None
+        
         self.__kiloparsecs = None
         
         self.__megaparsecs = None
@@ -282,8 +321,11 @@ class Length:
         self.__megalight_years = None
         
 
+    def convert(self, unit: LengthUnits) -> float:
+        return self.__convert_from_base(unit)
+
     def __convert_from_base(self, from_unit: LengthUnits) -> float:
-        value = self.__value
+        value = self._value
         
         if from_unit == LengthUnits.Meter:
             return (value)
@@ -357,6 +399,12 @@ class Length:
         if from_unit == LengthUnits.DataMile:
             return (value / 1828.8)
         
+        if from_unit == LengthUnits.Femtometer:
+            return ((value) / 1e-15)
+        
+        if from_unit == LengthUnits.Picometer:
+            return ((value) / 1e-12)
+        
         if from_unit == LengthUnits.Nanometer:
             return ((value) / 1e-09)
         
@@ -384,6 +432,15 @@ class Length:
         if from_unit == LengthUnits.Megameter:
             return ((value) / 1000000.0)
         
+        if from_unit == LengthUnits.Gigameter:
+            return ((value) / 1000000000.0)
+        
+        if from_unit == LengthUnits.Kiloyard:
+            return ((value / 0.9144) / 1000.0)
+        
+        if from_unit == LengthUnits.Kilofoot:
+            return ((value / 0.3048) / 1000.0)
+        
         if from_unit == LengthUnits.Kiloparsec:
             return ((value / 3.08567758128e16) / 1000.0)
         
@@ -473,6 +530,12 @@ class Length:
         if to_unit == LengthUnits.DataMile:
             return (value * 1828.8)
         
+        if to_unit == LengthUnits.Femtometer:
+            return ((value) * 1e-15)
+        
+        if to_unit == LengthUnits.Picometer:
+            return ((value) * 1e-12)
+        
         if to_unit == LengthUnits.Nanometer:
             return ((value) * 1e-09)
         
@@ -500,6 +563,15 @@ class Length:
         if to_unit == LengthUnits.Megameter:
             return ((value) * 1000000.0)
         
+        if to_unit == LengthUnits.Gigameter:
+            return ((value) * 1000000000.0)
+        
+        if to_unit == LengthUnits.Kiloyard:
+            return ((value * 0.9144) * 1000.0)
+        
+        if to_unit == LengthUnits.Kilofoot:
+            return ((value * 0.3048) * 1000.0)
+        
         if to_unit == LengthUnits.Kiloparsec:
             return ((value * 3.08567758128e16) * 1000.0)
         
@@ -517,7 +589,7 @@ class Length:
 
     @property
     def base_value(self) -> float:
-        return self.__value
+        return self._value
 
     
     @staticmethod
@@ -880,6 +952,36 @@ class Length:
         return Length(data_miles, LengthUnits.DataMile)
 
     
+    @staticmethod
+    def from_femtometers(femtometers: float):
+        """
+        Create a new instance of Length from a value in femtometers.
+
+        
+
+        :param meters: The Length value in femtometers.
+        :type femtometers: float
+        :return: A new instance of Length.
+        :rtype: Length
+        """
+        return Length(femtometers, LengthUnits.Femtometer)
+
+    
+    @staticmethod
+    def from_picometers(picometers: float):
+        """
+        Create a new instance of Length from a value in picometers.
+
+        
+
+        :param meters: The Length value in picometers.
+        :type picometers: float
+        :return: A new instance of Length.
+        :rtype: Length
+        """
+        return Length(picometers, LengthUnits.Picometer)
+
+    
     @staticmethod
     def from_nanometers(nanometers: float):
         """
@@ -1015,6 +1117,51 @@ class Length:
         return Length(megameters, LengthUnits.Megameter)
 
     
+    @staticmethod
+    def from_gigameters(gigameters: float):
+        """
+        Create a new instance of Length from a value in gigameters.
+
+        
+
+        :param meters: The Length value in gigameters.
+        :type gigameters: float
+        :return: A new instance of Length.
+        :rtype: Length
+        """
+        return Length(gigameters, LengthUnits.Gigameter)
+
+    
+    @staticmethod
+    def from_kiloyards(kiloyards: float):
+        """
+        Create a new instance of Length from a value in kiloyards.
+
+        
+
+        :param meters: The Length value in kiloyards.
+        :type kiloyards: float
+        :return: A new instance of Length.
+        :rtype: Length
+        """
+        return Length(kiloyards, LengthUnits.Kiloyard)
+
+    
+    @staticmethod
+    def from_kilofeet(kilofeet: float):
+        """
+        Create a new instance of Length from a value in kilofeet.
+
+        
+
+        :param meters: The Length value in kilofeet.
+        :type kilofeet: float
+        :return: A new instance of Length.
+        :rtype: Length
+        """
+        return Length(kilofeet, LengthUnits.Kilofoot)
+
+    
     @staticmethod
     def from_kiloparsecs(kiloparsecs: float):
         """
@@ -1339,6 +1486,28 @@ class Length:
         return self.__data_miles
 
     
+    @property
+    def femtometers(self) -> float:
+        """
+        
+        """
+        if self.__femtometers != None:
+            return self.__femtometers
+        self.__femtometers = self.__convert_from_base(LengthUnits.Femtometer)
+        return self.__femtometers
+
+    
+    @property
+    def picometers(self) -> float:
+        """
+        
+        """
+        if self.__picometers != None:
+            return self.__picometers
+        self.__picometers = self.__convert_from_base(LengthUnits.Picometer)
+        return self.__picometers
+
+    
     @property
     def nanometers(self) -> float:
         """
@@ -1438,6 +1607,39 @@ class Length:
         return self.__megameters
 
     
+    @property
+    def gigameters(self) -> float:
+        """
+        
+        """
+        if self.__gigameters != None:
+            return self.__gigameters
+        self.__gigameters = self.__convert_from_base(LengthUnits.Gigameter)
+        return self.__gigameters
+
+    
+    @property
+    def kiloyards(self) -> float:
+        """
+        
+        """
+        if self.__kiloyards != None:
+            return self.__kiloyards
+        self.__kiloyards = self.__convert_from_base(LengthUnits.Kiloyard)
+        return self.__kiloyards
+
+    
+    @property
+    def kilofeet(self) -> float:
+        """
+        
+        """
+        if self.__kilofeet != None:
+            return self.__kilofeet
+        self.__kilofeet = self.__convert_from_base(LengthUnits.Kilofoot)
+        return self.__kilofeet
+
+    
     @property
     def kiloparsecs(self) -> float:
         """
@@ -1482,7 +1684,7 @@ class Length:
         return self.__megalight_years
 
     
-    def to_string(self, unit: LengthUnits = LengthUnits.Meter) -> string:
+    def to_string(self, unit: LengthUnits = LengthUnits.Meter) -> str:
         """
         Format the Length to string.
         Note! the default format for Length is Meter.
@@ -1561,49 +1763,64 @@ class Length:
         if unit == LengthUnits.DataMile:
             return f"""{self.data_miles} DM"""
         
+        if unit == LengthUnits.Femtometer:
+            return f"""{self.femtometers} fm"""
+        
+        if unit == LengthUnits.Picometer:
+            return f"""{self.picometers} pm"""
+        
         if unit == LengthUnits.Nanometer:
-            return f"""{self.nanometers} """
+            return f"""{self.nanometers} nm"""
         
         if unit == LengthUnits.Micrometer:
-            return f"""{self.micrometers} """
+            return f"""{self.micrometers} μm"""
         
         if unit == LengthUnits.Millimeter:
-            return f"""{self.millimeters} """
+            return f"""{self.millimeters} mm"""
         
         if unit == LengthUnits.Centimeter:
-            return f"""{self.centimeters} """
+            return f"""{self.centimeters} cm"""
         
         if unit == LengthUnits.Decimeter:
-            return f"""{self.decimeters} """
+            return f"""{self.decimeters} dm"""
         
         if unit == LengthUnits.Decameter:
-            return f"""{self.decameters} """
+            return f"""{self.decameters} dam"""
         
         if unit == LengthUnits.Hectometer:
-            return f"""{self.hectometers} """
+            return f"""{self.hectometers} hm"""
         
         if unit == LengthUnits.Kilometer:
-            return f"""{self.kilometers} """
+            return f"""{self.kilometers} km"""
         
         if unit == LengthUnits.Megameter:
-            return f"""{self.megameters} """
+            return f"""{self.megameters} Mm"""
+        
+        if unit == LengthUnits.Gigameter:
+            return f"""{self.gigameters} Gm"""
+        
+        if unit == LengthUnits.Kiloyard:
+            return f"""{self.kiloyards} kyd"""
+        
+        if unit == LengthUnits.Kilofoot:
+            return f"""{self.kilofeet} kft"""
         
         if unit == LengthUnits.Kiloparsec:
-            return f"""{self.kiloparsecs} """
+            return f"""{self.kiloparsecs} kpc"""
         
         if unit == LengthUnits.Megaparsec:
-            return f"""{self.megaparsecs} """
+            return f"""{self.megaparsecs} Mpc"""
         
         if unit == LengthUnits.KilolightYear:
-            return f"""{self.kilolight_years} """
+            return f"""{self.kilolight_years} kly"""
         
         if unit == LengthUnits.MegalightYear:
-            return f"""{self.megalight_years} """
+            return f"""{self.megalight_years} Mly"""
         
-        return f'{self.__value}'
+        return f'{self._value}'
 
 
-    def get_unit_abbreviation(self, unit_abbreviation: LengthUnits = LengthUnits.Meter) -> string:
+    def get_unit_abbreviation(self, unit_abbreviation: LengthUnits = LengthUnits.Meter) -> str:
         """
         Get Length unit abbreviation.
         Note! the default abbreviation for Length is Meter.
@@ -1682,111 +1899,57 @@ class Length:
         if unit_abbreviation == LengthUnits.DataMile:
             return """DM"""
         
+        if unit_abbreviation == LengthUnits.Femtometer:
+            return """fm"""
+        
+        if unit_abbreviation == LengthUnits.Picometer:
+            return """pm"""
+        
         if unit_abbreviation == LengthUnits.Nanometer:
-            return """"""
+            return """nm"""
         
         if unit_abbreviation == LengthUnits.Micrometer:
-            return """"""
+            return """μm"""
         
         if unit_abbreviation == LengthUnits.Millimeter:
-            return """"""
+            return """mm"""
         
         if unit_abbreviation == LengthUnits.Centimeter:
-            return """"""
+            return """cm"""
         
         if unit_abbreviation == LengthUnits.Decimeter:
-            return """"""
+            return """dm"""
         
         if unit_abbreviation == LengthUnits.Decameter:
-            return """"""
+            return """dam"""
         
         if unit_abbreviation == LengthUnits.Hectometer:
-            return """"""
+            return """hm"""
         
         if unit_abbreviation == LengthUnits.Kilometer:
-            return """"""
+            return """km"""
         
         if unit_abbreviation == LengthUnits.Megameter:
-            return """"""
+            return """Mm"""
+        
+        if unit_abbreviation == LengthUnits.Gigameter:
+            return """Gm"""
+        
+        if unit_abbreviation == LengthUnits.Kiloyard:
+            return """kyd"""
+        
+        if unit_abbreviation == LengthUnits.Kilofoot:
+            return """kft"""
         
         if unit_abbreviation == LengthUnits.Kiloparsec:
-            return """"""
+            return """kpc"""
         
         if unit_abbreviation == LengthUnits.Megaparsec:
-            return """"""
+            return """Mpc"""
         
         if unit_abbreviation == LengthUnits.KilolightYear:
-            return """"""
+            return """kly"""
         
         if unit_abbreviation == LengthUnits.MegalightYear:
-            return """"""
-        
-
-    def __str__(self):
-        return self.to_string()
-
-
-    def __add__(self, other):
-        if not isinstance(other, Length):
-            raise TypeError("unsupported operand type(s) for +: 'Length' and '{}'".format(type(other).__name__))
-        return Length(self.__value + other.__value)
-
-
-    def __mul__(self, other):
-        if not isinstance(other, Length):
-            raise TypeError("unsupported operand type(s) for *: 'Length' and '{}'".format(type(other).__name__))
-        return Length(self.__value * other.__value)
-
-
-    def __sub__(self, other):
-        if not isinstance(other, Length):
-            raise TypeError("unsupported operand type(s) for -: 'Length' and '{}'".format(type(other).__name__))
-        return Length(self.__value - other.__value)
-
-
-    def __truediv__(self, other):
-        if not isinstance(other, Length):
-            raise TypeError("unsupported operand type(s) for /: 'Length' and '{}'".format(type(other).__name__))
-        return Length(self.__value / other.__value)
-
-
-    def __mod__(self, other):
-        if not isinstance(other, Length):
-            raise TypeError("unsupported operand type(s) for %: 'Length' and '{}'".format(type(other).__name__))
-        return Length(self.__value % other.__value)
-
-
-    def __pow__(self, other):
-        if not isinstance(other, Length):
-            raise TypeError("unsupported operand type(s) for **: 'Length' and '{}'".format(type(other).__name__))
-        return Length(self.__value ** other.__value)
-
-
-    def __eq__(self, other):
-        if not isinstance(other, Length):
-            raise TypeError("unsupported operand type(s) for ==: 'Length' and '{}'".format(type(other).__name__))
-        return self.__value == other.__value
-
-
-    def __lt__(self, other):
-        if not isinstance(other, Length):
-            raise TypeError("unsupported operand type(s) for <: 'Length' and '{}'".format(type(other).__name__))
-        return self.__value < other.__value
-
-
-    def __gt__(self, other):
-        if not isinstance(other, Length):
-            raise TypeError("unsupported operand type(s) for >: 'Length' and '{}'".format(type(other).__name__))
-        return self.__value > other.__value
-
-
-    def __le__(self, other):
-        if not isinstance(other, Length):
-            raise TypeError("unsupported operand type(s) for <=: 'Length' and '{}'".format(type(other).__name__))
-        return self.__value <= other.__value
-
-
-    def __ge__(self, other):
-        if not isinstance(other, Length):
-            raise TypeError("unsupported operand type(s) for >=: 'Length' and '{}'".format(type(other).__name__))
-        return self.__value >= other.__value
\ No newline at end of file
+            return """Mly"""
+        
\ No newline at end of file
