@@ -1,6 +1,8 @@
 from enum import Enum
 import math
-import string
+
+from ..abstract_unit import AbstractMeasure
+
 
 
 class LinearDensityUnits(Enum):
@@ -79,7 +81,7 @@ class LinearDensityUnits(Enum):
         """
         
 
-class LinearDensity:
+class LinearDensity(AbstractMeasure):
     """
     The Linear Density, or more precisely, the linear mass density, of a substance is its mass per unit length.  The term linear density is most often used when describing the characteristics of one-dimensional objects, although linear density can also be used to describe the density of a three-dimensional quantity along one particular dimension.
 
@@ -88,9 +90,11 @@ class LinearDensity:
         from_unit (LinearDensityUnits): The LinearDensity unit to create from, The default unit is KilogramPerMeter
     """
     def __init__(self, value: float, from_unit: LinearDensityUnits = LinearDensityUnits.KilogramPerMeter):
-        if math.isnan(value):
-            raise ValueError('Invalid unit: value is NaN')
-        self.__value = self.__convert_to_base(value, from_unit)
+        # Do not validate type, to allow working with numpay arrays and similar objects who supports all arithmetic 
+        # operations, but they are not a number, see #14 
+        # if math.isnan(value):
+        #     raise ValueError('Invalid unit: value is NaN')
+        self._value = self.__convert_to_base(value, from_unit)
         
         self.__grams_per_millimeter = None
         
@@ -121,8 +125,11 @@ class LinearDensity:
         self.__kilograms_per_meter = None
         
 
+    def convert(self, unit: LinearDensityUnits) -> float:
+        return self.__convert_from_base(unit)
+
     def __convert_from_base(self, from_unit: LinearDensityUnits) -> float:
-        value = self.__value
+        value = self._value
         
         if from_unit == LinearDensityUnits.GramPerMillimeter:
             return (value)
@@ -218,7 +225,7 @@ class LinearDensity:
 
     @property
     def base_value(self) -> float:
-        return self.__value
+        return self._value
 
     
     @staticmethod
@@ -585,7 +592,7 @@ class LinearDensity:
         return self.__kilograms_per_meter
 
     
-    def to_string(self, unit: LinearDensityUnits = LinearDensityUnits.KilogramPerMeter) -> string:
+    def to_string(self, unit: LinearDensityUnits = LinearDensityUnits.KilogramPerMeter) -> str:
         """
         Format the LinearDensity to string.
         Note! the default format for LinearDensity is KilogramPerMeter.
@@ -608,36 +615,36 @@ class LinearDensity:
             return f"""{self.pounds_per_foot} lb/ft"""
         
         if unit == LinearDensityUnits.MicrogramPerMillimeter:
-            return f"""{self.micrograms_per_millimeter} """
+            return f"""{self.micrograms_per_millimeter} μg/mm"""
         
         if unit == LinearDensityUnits.MilligramPerMillimeter:
-            return f"""{self.milligrams_per_millimeter} """
+            return f"""{self.milligrams_per_millimeter} mg/mm"""
         
         if unit == LinearDensityUnits.KilogramPerMillimeter:
-            return f"""{self.kilograms_per_millimeter} """
+            return f"""{self.kilograms_per_millimeter} kg/mm"""
         
         if unit == LinearDensityUnits.MicrogramPerCentimeter:
-            return f"""{self.micrograms_per_centimeter} """
+            return f"""{self.micrograms_per_centimeter} μg/cm"""
         
         if unit == LinearDensityUnits.MilligramPerCentimeter:
-            return f"""{self.milligrams_per_centimeter} """
+            return f"""{self.milligrams_per_centimeter} mg/cm"""
         
         if unit == LinearDensityUnits.KilogramPerCentimeter:
-            return f"""{self.kilograms_per_centimeter} """
+            return f"""{self.kilograms_per_centimeter} kg/cm"""
         
         if unit == LinearDensityUnits.MicrogramPerMeter:
-            return f"""{self.micrograms_per_meter} """
+            return f"""{self.micrograms_per_meter} μg/m"""
         
         if unit == LinearDensityUnits.MilligramPerMeter:
-            return f"""{self.milligrams_per_meter} """
+            return f"""{self.milligrams_per_meter} mg/m"""
         
         if unit == LinearDensityUnits.KilogramPerMeter:
-            return f"""{self.kilograms_per_meter} """
+            return f"""{self.kilograms_per_meter} kg/m"""
         
-        return f'{self.__value}'
+        return f'{self._value}'
 
 
-    def get_unit_abbreviation(self, unit_abbreviation: LinearDensityUnits = LinearDensityUnits.KilogramPerMeter) -> string:
+    def get_unit_abbreviation(self, unit_abbreviation: LinearDensityUnits = LinearDensityUnits.KilogramPerMeter) -> str:
         """
         Get LinearDensity unit abbreviation.
         Note! the default abbreviation for LinearDensity is KilogramPerMeter.
@@ -660,98 +667,29 @@ class LinearDensity:
             return """lb/ft"""
         
         if unit_abbreviation == LinearDensityUnits.MicrogramPerMillimeter:
-            return """"""
+            return """μg/mm"""
         
         if unit_abbreviation == LinearDensityUnits.MilligramPerMillimeter:
-            return """"""
+            return """mg/mm"""
         
         if unit_abbreviation == LinearDensityUnits.KilogramPerMillimeter:
-            return """"""
+            return """kg/mm"""
         
         if unit_abbreviation == LinearDensityUnits.MicrogramPerCentimeter:
-            return """"""
+            return """μg/cm"""
         
         if unit_abbreviation == LinearDensityUnits.MilligramPerCentimeter:
-            return """"""
+            return """mg/cm"""
         
         if unit_abbreviation == LinearDensityUnits.KilogramPerCentimeter:
-            return """"""
+            return """kg/cm"""
         
         if unit_abbreviation == LinearDensityUnits.MicrogramPerMeter:
-            return """"""
+            return """μg/m"""
         
         if unit_abbreviation == LinearDensityUnits.MilligramPerMeter:
-            return """"""
+            return """mg/m"""
         
         if unit_abbreviation == LinearDensityUnits.KilogramPerMeter:
-            return """"""
-        
-
-    def __str__(self):
-        return self.to_string()
-
-
-    def __add__(self, other):
-        if not isinstance(other, LinearDensity):
-            raise TypeError("unsupported operand type(s) for +: 'LinearDensity' and '{}'".format(type(other).__name__))
-        return LinearDensity(self.__value + other.__value)
-
-
-    def __mul__(self, other):
-        if not isinstance(other, LinearDensity):
-            raise TypeError("unsupported operand type(s) for *: 'LinearDensity' and '{}'".format(type(other).__name__))
-        return LinearDensity(self.__value * other.__value)
-
-
-    def __sub__(self, other):
-        if not isinstance(other, LinearDensity):
-            raise TypeError("unsupported operand type(s) for -: 'LinearDensity' and '{}'".format(type(other).__name__))
-        return LinearDensity(self.__value - other.__value)
-
-
-    def __truediv__(self, other):
-        if not isinstance(other, LinearDensity):
-            raise TypeError("unsupported operand type(s) for /: 'LinearDensity' and '{}'".format(type(other).__name__))
-        return LinearDensity(self.__value / other.__value)
-
-
-    def __mod__(self, other):
-        if not isinstance(other, LinearDensity):
-            raise TypeError("unsupported operand type(s) for %: 'LinearDensity' and '{}'".format(type(other).__name__))
-        return LinearDensity(self.__value % other.__value)
-
-
-    def __pow__(self, other):
-        if not isinstance(other, LinearDensity):
-            raise TypeError("unsupported operand type(s) for **: 'LinearDensity' and '{}'".format(type(other).__name__))
-        return LinearDensity(self.__value ** other.__value)
-
-
-    def __eq__(self, other):
-        if not isinstance(other, LinearDensity):
-            raise TypeError("unsupported operand type(s) for ==: 'LinearDensity' and '{}'".format(type(other).__name__))
-        return self.__value == other.__value
-
-
-    def __lt__(self, other):
-        if not isinstance(other, LinearDensity):
-            raise TypeError("unsupported operand type(s) for <: 'LinearDensity' and '{}'".format(type(other).__name__))
-        return self.__value < other.__value
-
-
-    def __gt__(self, other):
-        if not isinstance(other, LinearDensity):
-            raise TypeError("unsupported operand type(s) for >: 'LinearDensity' and '{}'".format(type(other).__name__))
-        return self.__value > other.__value
-
-
-    def __le__(self, other):
-        if not isinstance(other, LinearDensity):
-            raise TypeError("unsupported operand type(s) for <=: 'LinearDensity' and '{}'".format(type(other).__name__))
-        return self.__value <= other.__value
-
-
-    def __ge__(self, other):
-        if not isinstance(other, LinearDensity):
-            raise TypeError("unsupported operand type(s) for >=: 'LinearDensity' and '{}'".format(type(other).__name__))
-        return self.__value >= other.__value
\ No newline at end of file
+            return """kg/m"""
+        
\ No newline at end of file
