@@ -1,6 +1,8 @@
 from enum import Enum
 import math
-import string
+
+from ..abstract_unit import AbstractMeasure
+
 
 
 class LinearPowerDensityUnits(Enum):
@@ -134,7 +136,7 @@ class LinearPowerDensityUnits(Enum):
         """
         
 
-class LinearPowerDensity:
+class LinearPowerDensity(AbstractMeasure):
     """
     The Linear Power Density of a substance is its power per unit length.  The term linear density is most often used when describing the characteristics of one-dimensional objects, although linear density can also be used to describe the density of a three-dimensional quantity along one particular dimension.
 
@@ -143,9 +145,11 @@ class LinearPowerDensity:
         from_unit (LinearPowerDensityUnits): The LinearPowerDensity unit to create from, The default unit is WattPerMeter
     """
     def __init__(self, value: float, from_unit: LinearPowerDensityUnits = LinearPowerDensityUnits.WattPerMeter):
-        if math.isnan(value):
-            raise ValueError('Invalid unit: value is NaN')
-        self.__value = self.__convert_to_base(value, from_unit)
+        # Do not validate type, to allow working with numpay arrays and similar objects who supports all arithmetic 
+        # operations, but they are not a number, see #14 
+        # if math.isnan(value):
+        #     raise ValueError('Invalid unit: value is NaN')
+        self._value = self.__convert_to_base(value, from_unit)
         
         self.__watts_per_meter = None
         
@@ -198,8 +202,11 @@ class LinearPowerDensity:
         self.__gigawatts_per_foot = None
         
 
+    def convert(self, unit: LinearPowerDensityUnits) -> float:
+        return self.__convert_from_base(unit)
+
     def __convert_from_base(self, from_unit: LinearPowerDensityUnits) -> float:
-        value = self.__value
+        value = self._value
         
         if from_unit == LinearPowerDensityUnits.WattPerMeter:
             return (value)
@@ -361,7 +368,7 @@ class LinearPowerDensity:
 
     @property
     def base_value(self) -> float:
-        return self.__value
+        return self._value
 
     
     @staticmethod
@@ -1014,7 +1021,7 @@ class LinearPowerDensity:
         return self.__gigawatts_per_foot
 
     
-    def to_string(self, unit: LinearPowerDensityUnits = LinearPowerDensityUnits.WattPerMeter) -> string:
+    def to_string(self, unit: LinearPowerDensityUnits = LinearPowerDensityUnits.WattPerMeter) -> str:
         """
         Format the LinearPowerDensity to string.
         Note! the default format for LinearPowerDensity is WattPerMeter.
@@ -1037,69 +1044,69 @@ class LinearPowerDensity:
             return f"""{self.watts_per_foot} W/ft"""
         
         if unit == LinearPowerDensityUnits.MilliwattPerMeter:
-            return f"""{self.milliwatts_per_meter} """
+            return f"""{self.milliwatts_per_meter} mW/m"""
         
         if unit == LinearPowerDensityUnits.KilowattPerMeter:
-            return f"""{self.kilowatts_per_meter} """
+            return f"""{self.kilowatts_per_meter} kW/m"""
         
         if unit == LinearPowerDensityUnits.MegawattPerMeter:
-            return f"""{self.megawatts_per_meter} """
+            return f"""{self.megawatts_per_meter} MW/m"""
         
         if unit == LinearPowerDensityUnits.GigawattPerMeter:
-            return f"""{self.gigawatts_per_meter} """
+            return f"""{self.gigawatts_per_meter} GW/m"""
         
         if unit == LinearPowerDensityUnits.MilliwattPerCentimeter:
-            return f"""{self.milliwatts_per_centimeter} """
+            return f"""{self.milliwatts_per_centimeter} mW/cm"""
         
         if unit == LinearPowerDensityUnits.KilowattPerCentimeter:
-            return f"""{self.kilowatts_per_centimeter} """
+            return f"""{self.kilowatts_per_centimeter} kW/cm"""
         
         if unit == LinearPowerDensityUnits.MegawattPerCentimeter:
-            return f"""{self.megawatts_per_centimeter} """
+            return f"""{self.megawatts_per_centimeter} MW/cm"""
         
         if unit == LinearPowerDensityUnits.GigawattPerCentimeter:
-            return f"""{self.gigawatts_per_centimeter} """
+            return f"""{self.gigawatts_per_centimeter} GW/cm"""
         
         if unit == LinearPowerDensityUnits.MilliwattPerMillimeter:
-            return f"""{self.milliwatts_per_millimeter} """
+            return f"""{self.milliwatts_per_millimeter} mW/mm"""
         
         if unit == LinearPowerDensityUnits.KilowattPerMillimeter:
-            return f"""{self.kilowatts_per_millimeter} """
+            return f"""{self.kilowatts_per_millimeter} kW/mm"""
         
         if unit == LinearPowerDensityUnits.MegawattPerMillimeter:
-            return f"""{self.megawatts_per_millimeter} """
+            return f"""{self.megawatts_per_millimeter} MW/mm"""
         
         if unit == LinearPowerDensityUnits.GigawattPerMillimeter:
-            return f"""{self.gigawatts_per_millimeter} """
+            return f"""{self.gigawatts_per_millimeter} GW/mm"""
         
         if unit == LinearPowerDensityUnits.MilliwattPerInch:
-            return f"""{self.milliwatts_per_inch} """
+            return f"""{self.milliwatts_per_inch} mW/in"""
         
         if unit == LinearPowerDensityUnits.KilowattPerInch:
-            return f"""{self.kilowatts_per_inch} """
+            return f"""{self.kilowatts_per_inch} kW/in"""
         
         if unit == LinearPowerDensityUnits.MegawattPerInch:
-            return f"""{self.megawatts_per_inch} """
+            return f"""{self.megawatts_per_inch} MW/in"""
         
         if unit == LinearPowerDensityUnits.GigawattPerInch:
-            return f"""{self.gigawatts_per_inch} """
+            return f"""{self.gigawatts_per_inch} GW/in"""
         
         if unit == LinearPowerDensityUnits.MilliwattPerFoot:
-            return f"""{self.milliwatts_per_foot} """
+            return f"""{self.milliwatts_per_foot} mW/ft"""
         
         if unit == LinearPowerDensityUnits.KilowattPerFoot:
-            return f"""{self.kilowatts_per_foot} """
+            return f"""{self.kilowatts_per_foot} kW/ft"""
         
         if unit == LinearPowerDensityUnits.MegawattPerFoot:
-            return f"""{self.megawatts_per_foot} """
+            return f"""{self.megawatts_per_foot} MW/ft"""
         
         if unit == LinearPowerDensityUnits.GigawattPerFoot:
-            return f"""{self.gigawatts_per_foot} """
+            return f"""{self.gigawatts_per_foot} GW/ft"""
         
-        return f'{self.__value}'
+        return f'{self._value}'
 
 
-    def get_unit_abbreviation(self, unit_abbreviation: LinearPowerDensityUnits = LinearPowerDensityUnits.WattPerMeter) -> string:
+    def get_unit_abbreviation(self, unit_abbreviation: LinearPowerDensityUnits = LinearPowerDensityUnits.WattPerMeter) -> str:
         """
         Get LinearPowerDensity unit abbreviation.
         Note! the default abbreviation for LinearPowerDensity is WattPerMeter.
@@ -1122,131 +1129,62 @@ class LinearPowerDensity:
             return """W/ft"""
         
         if unit_abbreviation == LinearPowerDensityUnits.MilliwattPerMeter:
-            return """"""
+            return """mW/m"""
         
         if unit_abbreviation == LinearPowerDensityUnits.KilowattPerMeter:
-            return """"""
+            return """kW/m"""
         
         if unit_abbreviation == LinearPowerDensityUnits.MegawattPerMeter:
-            return """"""
+            return """MW/m"""
         
         if unit_abbreviation == LinearPowerDensityUnits.GigawattPerMeter:
-            return """"""
+            return """GW/m"""
         
         if unit_abbreviation == LinearPowerDensityUnits.MilliwattPerCentimeter:
-            return """"""
+            return """mW/cm"""
         
         if unit_abbreviation == LinearPowerDensityUnits.KilowattPerCentimeter:
-            return """"""
+            return """kW/cm"""
         
         if unit_abbreviation == LinearPowerDensityUnits.MegawattPerCentimeter:
-            return """"""
+            return """MW/cm"""
         
         if unit_abbreviation == LinearPowerDensityUnits.GigawattPerCentimeter:
-            return """"""
+            return """GW/cm"""
         
         if unit_abbreviation == LinearPowerDensityUnits.MilliwattPerMillimeter:
-            return """"""
+            return """mW/mm"""
         
         if unit_abbreviation == LinearPowerDensityUnits.KilowattPerMillimeter:
-            return """"""
+            return """kW/mm"""
         
         if unit_abbreviation == LinearPowerDensityUnits.MegawattPerMillimeter:
-            return """"""
+            return """MW/mm"""
         
         if unit_abbreviation == LinearPowerDensityUnits.GigawattPerMillimeter:
-            return """"""
+            return """GW/mm"""
         
         if unit_abbreviation == LinearPowerDensityUnits.MilliwattPerInch:
-            return """"""
+            return """mW/in"""
         
         if unit_abbreviation == LinearPowerDensityUnits.KilowattPerInch:
-            return """"""
+            return """kW/in"""
         
         if unit_abbreviation == LinearPowerDensityUnits.MegawattPerInch:
-            return """"""
+            return """MW/in"""
         
         if unit_abbreviation == LinearPowerDensityUnits.GigawattPerInch:
-            return """"""
+            return """GW/in"""
         
         if unit_abbreviation == LinearPowerDensityUnits.MilliwattPerFoot:
-            return """"""
+            return """mW/ft"""
         
         if unit_abbreviation == LinearPowerDensityUnits.KilowattPerFoot:
-            return """"""
+            return """kW/ft"""
         
         if unit_abbreviation == LinearPowerDensityUnits.MegawattPerFoot:
-            return """"""
+            return """MW/ft"""
         
         if unit_abbreviation == LinearPowerDensityUnits.GigawattPerFoot:
-            return """"""
-        
-
-    def __str__(self):
-        return self.to_string()
-
-
-    def __add__(self, other):
-        if not isinstance(other, LinearPowerDensity):
-            raise TypeError("unsupported operand type(s) for +: 'LinearPowerDensity' and '{}'".format(type(other).__name__))
-        return LinearPowerDensity(self.__value + other.__value)
-
-
-    def __mul__(self, other):
-        if not isinstance(other, LinearPowerDensity):
-            raise TypeError("unsupported operand type(s) for *: 'LinearPowerDensity' and '{}'".format(type(other).__name__))
-        return LinearPowerDensity(self.__value * other.__value)
-
-
-    def __sub__(self, other):
-        if not isinstance(other, LinearPowerDensity):
-            raise TypeError("unsupported operand type(s) for -: 'LinearPowerDensity' and '{}'".format(type(other).__name__))
-        return LinearPowerDensity(self.__value - other.__value)
-
-
-    def __truediv__(self, other):
-        if not isinstance(other, LinearPowerDensity):
-            raise TypeError("unsupported operand type(s) for /: 'LinearPowerDensity' and '{}'".format(type(other).__name__))
-        return LinearPowerDensity(self.__value / other.__value)
-
-
-    def __mod__(self, other):
-        if not isinstance(other, LinearPowerDensity):
-            raise TypeError("unsupported operand type(s) for %: 'LinearPowerDensity' and '{}'".format(type(other).__name__))
-        return LinearPowerDensity(self.__value % other.__value)
-
-
-    def __pow__(self, other):
-        if not isinstance(other, LinearPowerDensity):
-            raise TypeError("unsupported operand type(s) for **: 'LinearPowerDensity' and '{}'".format(type(other).__name__))
-        return LinearPowerDensity(self.__value ** other.__value)
-
-
-    def __eq__(self, other):
-        if not isinstance(other, LinearPowerDensity):
-            raise TypeError("unsupported operand type(s) for ==: 'LinearPowerDensity' and '{}'".format(type(other).__name__))
-        return self.__value == other.__value
-
-
-    def __lt__(self, other):
-        if not isinstance(other, LinearPowerDensity):
-            raise TypeError("unsupported operand type(s) for <: 'LinearPowerDensity' and '{}'".format(type(other).__name__))
-        return self.__value < other.__value
-
-
-    def __gt__(self, other):
-        if not isinstance(other, LinearPowerDensity):
-            raise TypeError("unsupported operand type(s) for >: 'LinearPowerDensity' and '{}'".format(type(other).__name__))
-        return self.__value > other.__value
-
-
-    def __le__(self, other):
-        if not isinstance(other, LinearPowerDensity):
-            raise TypeError("unsupported operand type(s) for <=: 'LinearPowerDensity' and '{}'".format(type(other).__name__))
-        return self.__value <= other.__value
-
-
-    def __ge__(self, other):
-        if not isinstance(other, LinearPowerDensity):
-            raise TypeError("unsupported operand type(s) for >=: 'LinearPowerDensity' and '{}'".format(type(other).__name__))
-        return self.__value >= other.__value
\ No newline at end of file
+            return """GW/ft"""
+        
\ No newline at end of file
