@@ -1,6 +1,8 @@
 from enum import Enum
 import math
-import string
+
+from ..abstract_unit import AbstractMeasure
+
 
 
 class LuminanceUnits(Enum):
@@ -59,7 +61,7 @@ class LuminanceUnits(Enum):
         """
         
 
-class Luminance:
+class Luminance(AbstractMeasure):
     """
     None
 
@@ -68,9 +70,11 @@ class Luminance:
         from_unit (LuminanceUnits): The Luminance unit to create from, The default unit is CandelaPerSquareMeter
     """
     def __init__(self, value: float, from_unit: LuminanceUnits = LuminanceUnits.CandelaPerSquareMeter):
-        if math.isnan(value):
-            raise ValueError('Invalid unit: value is NaN')
-        self.__value = self.__convert_to_base(value, from_unit)
+        # Do not validate type, to allow working with numpay arrays and similar objects who supports all arithmetic 
+        # operations, but they are not a number, see #14 
+        # if math.isnan(value):
+        #     raise ValueError('Invalid unit: value is NaN')
+        self._value = self.__convert_to_base(value, from_unit)
         
         self.__candelas_per_square_meter = None
         
@@ -93,8 +97,11 @@ class Luminance:
         self.__kilocandelas_per_square_meter = None
         
 
+    def convert(self, unit: LuminanceUnits) -> float:
+        return self.__convert_from_base(unit)
+
     def __convert_from_base(self, from_unit: LuminanceUnits) -> float:
-        value = self.__value
+        value = self._value
         
         if from_unit == LuminanceUnits.CandelaPerSquareMeter:
             return (value)
@@ -166,7 +173,7 @@ class Luminance:
 
     @property
     def base_value(self) -> float:
-        return self.__value
+        return self._value
 
     
     @staticmethod
@@ -429,7 +436,7 @@ class Luminance:
         return self.__kilocandelas_per_square_meter
 
     
-    def to_string(self, unit: LuminanceUnits = LuminanceUnits.CandelaPerSquareMeter) -> string:
+    def to_string(self, unit: LuminanceUnits = LuminanceUnits.CandelaPerSquareMeter) -> str:
         """
         Format the Luminance to string.
         Note! the default format for Luminance is CandelaPerSquareMeter.
@@ -449,27 +456,27 @@ class Luminance:
             return f"""{self.nits} nt"""
         
         if unit == LuminanceUnits.NanocandelaPerSquareMeter:
-            return f"""{self.nanocandelas_per_square_meter} """
+            return f"""{self.nanocandelas_per_square_meter} nCd/m²"""
         
         if unit == LuminanceUnits.MicrocandelaPerSquareMeter:
-            return f"""{self.microcandelas_per_square_meter} """
+            return f"""{self.microcandelas_per_square_meter} μCd/m²"""
         
         if unit == LuminanceUnits.MillicandelaPerSquareMeter:
-            return f"""{self.millicandelas_per_square_meter} """
+            return f"""{self.millicandelas_per_square_meter} mCd/m²"""
         
         if unit == LuminanceUnits.CenticandelaPerSquareMeter:
-            return f"""{self.centicandelas_per_square_meter} """
+            return f"""{self.centicandelas_per_square_meter} cCd/m²"""
         
         if unit == LuminanceUnits.DecicandelaPerSquareMeter:
-            return f"""{self.decicandelas_per_square_meter} """
+            return f"""{self.decicandelas_per_square_meter} dCd/m²"""
         
         if unit == LuminanceUnits.KilocandelaPerSquareMeter:
-            return f"""{self.kilocandelas_per_square_meter} """
+            return f"""{self.kilocandelas_per_square_meter} kCd/m²"""
         
-        return f'{self.__value}'
+        return f'{self._value}'
 
 
-    def get_unit_abbreviation(self, unit_abbreviation: LuminanceUnits = LuminanceUnits.CandelaPerSquareMeter) -> string:
+    def get_unit_abbreviation(self, unit_abbreviation: LuminanceUnits = LuminanceUnits.CandelaPerSquareMeter) -> str:
         """
         Get Luminance unit abbreviation.
         Note! the default abbreviation for Luminance is CandelaPerSquareMeter.
@@ -489,89 +496,20 @@ class Luminance:
             return """nt"""
         
         if unit_abbreviation == LuminanceUnits.NanocandelaPerSquareMeter:
-            return """"""
+            return """nCd/m²"""
         
         if unit_abbreviation == LuminanceUnits.MicrocandelaPerSquareMeter:
-            return """"""
+            return """μCd/m²"""
         
         if unit_abbreviation == LuminanceUnits.MillicandelaPerSquareMeter:
-            return """"""
+            return """mCd/m²"""
         
         if unit_abbreviation == LuminanceUnits.CenticandelaPerSquareMeter:
-            return """"""
+            return """cCd/m²"""
         
         if unit_abbreviation == LuminanceUnits.DecicandelaPerSquareMeter:
-            return """"""
+            return """dCd/m²"""
         
         if unit_abbreviation == LuminanceUnits.KilocandelaPerSquareMeter:
-            return """"""
-        
-
-    def __str__(self):
-        return self.to_string()
-
-
-    def __add__(self, other):
-        if not isinstance(other, Luminance):
-            raise TypeError("unsupported operand type(s) for +: 'Luminance' and '{}'".format(type(other).__name__))
-        return Luminance(self.__value + other.__value)
-
-
-    def __mul__(self, other):
-        if not isinstance(other, Luminance):
-            raise TypeError("unsupported operand type(s) for *: 'Luminance' and '{}'".format(type(other).__name__))
-        return Luminance(self.__value * other.__value)
-
-
-    def __sub__(self, other):
-        if not isinstance(other, Luminance):
-            raise TypeError("unsupported operand type(s) for -: 'Luminance' and '{}'".format(type(other).__name__))
-        return Luminance(self.__value - other.__value)
-
-
-    def __truediv__(self, other):
-        if not isinstance(other, Luminance):
-            raise TypeError("unsupported operand type(s) for /: 'Luminance' and '{}'".format(type(other).__name__))
-        return Luminance(self.__value / other.__value)
-
-
-    def __mod__(self, other):
-        if not isinstance(other, Luminance):
-            raise TypeError("unsupported operand type(s) for %: 'Luminance' and '{}'".format(type(other).__name__))
-        return Luminance(self.__value % other.__value)
-
-
-    def __pow__(self, other):
-        if not isinstance(other, Luminance):
-            raise TypeError("unsupported operand type(s) for **: 'Luminance' and '{}'".format(type(other).__name__))
-        return Luminance(self.__value ** other.__value)
-
-
-    def __eq__(self, other):
-        if not isinstance(other, Luminance):
-            raise TypeError("unsupported operand type(s) for ==: 'Luminance' and '{}'".format(type(other).__name__))
-        return self.__value == other.__value
-
-
-    def __lt__(self, other):
-        if not isinstance(other, Luminance):
-            raise TypeError("unsupported operand type(s) for <: 'Luminance' and '{}'".format(type(other).__name__))
-        return self.__value < other.__value
-
-
-    def __gt__(self, other):
-        if not isinstance(other, Luminance):
-            raise TypeError("unsupported operand type(s) for >: 'Luminance' and '{}'".format(type(other).__name__))
-        return self.__value > other.__value
-
-
-    def __le__(self, other):
-        if not isinstance(other, Luminance):
-            raise TypeError("unsupported operand type(s) for <=: 'Luminance' and '{}'".format(type(other).__name__))
-        return self.__value <= other.__value
-
-
-    def __ge__(self, other):
-        if not isinstance(other, Luminance):
-            raise TypeError("unsupported operand type(s) for >=: 'Luminance' and '{}'".format(type(other).__name__))
-        return self.__value >= other.__value
\ No newline at end of file
+            return """kCd/m²"""
+        
\ No newline at end of file
