@@ -1,6 +1,8 @@
 from enum import Enum
 import math
-import string
+
+from ..abstract_unit import AbstractMeasure
+
 
 
 class LuminosityUnits(Enum):
@@ -79,7 +81,7 @@ class LuminosityUnits(Enum):
         """
         
 
-class Luminosity:
+class Luminosity(AbstractMeasure):
     """
     Luminosity is an absolute measure of radiated electromagnetic power (light), the radiant power emitted by a light-emitting object.
 
@@ -88,9 +90,11 @@ class Luminosity:
         from_unit (LuminosityUnits): The Luminosity unit to create from, The default unit is Watt
     """
     def __init__(self, value: float, from_unit: LuminosityUnits = LuminosityUnits.Watt):
-        if math.isnan(value):
-            raise ValueError('Invalid unit: value is NaN')
-        self.__value = self.__convert_to_base(value, from_unit)
+        # Do not validate type, to allow working with numpay arrays and similar objects who supports all arithmetic 
+        # operations, but they are not a number, see #14 
+        # if math.isnan(value):
+        #     raise ValueError('Invalid unit: value is NaN')
+        self._value = self.__convert_to_base(value, from_unit)
         
         self.__watts = None
         
@@ -121,8 +125,11 @@ class Luminosity:
         self.__petawatts = None
         
 
+    def convert(self, unit: LuminosityUnits) -> float:
+        return self.__convert_from_base(unit)
+
     def __convert_from_base(self, from_unit: LuminosityUnits) -> float:
-        value = self.__value
+        value = self._value
         
         if from_unit == LuminosityUnits.Watt:
             return (value)
@@ -218,7 +225,7 @@ class Luminosity:
 
     @property
     def base_value(self) -> float:
-        return self.__value
+        return self._value
 
     
     @staticmethod
@@ -585,7 +592,7 @@ class Luminosity:
         return self.__petawatts
 
     
-    def to_string(self, unit: LuminosityUnits = LuminosityUnits.Watt) -> string:
+    def to_string(self, unit: LuminosityUnits = LuminosityUnits.Watt) -> str:
         """
         Format the Luminosity to string.
         Note! the default format for Luminosity is Watt.
@@ -599,45 +606,45 @@ class Luminosity:
             return f"""{self.solar_luminosities} L⊙"""
         
         if unit == LuminosityUnits.Femtowatt:
-            return f"""{self.femtowatts} """
+            return f"""{self.femtowatts} fW"""
         
         if unit == LuminosityUnits.Picowatt:
-            return f"""{self.picowatts} """
+            return f"""{self.picowatts} pW"""
         
         if unit == LuminosityUnits.Nanowatt:
-            return f"""{self.nanowatts} """
+            return f"""{self.nanowatts} nW"""
         
         if unit == LuminosityUnits.Microwatt:
-            return f"""{self.microwatts} """
+            return f"""{self.microwatts} μW"""
         
         if unit == LuminosityUnits.Milliwatt:
-            return f"""{self.milliwatts} """
+            return f"""{self.milliwatts} mW"""
         
         if unit == LuminosityUnits.Deciwatt:
-            return f"""{self.deciwatts} """
+            return f"""{self.deciwatts} dW"""
         
         if unit == LuminosityUnits.Decawatt:
-            return f"""{self.decawatts} """
+            return f"""{self.decawatts} daW"""
         
         if unit == LuminosityUnits.Kilowatt:
-            return f"""{self.kilowatts} """
+            return f"""{self.kilowatts} kW"""
         
         if unit == LuminosityUnits.Megawatt:
-            return f"""{self.megawatts} """
+            return f"""{self.megawatts} MW"""
         
         if unit == LuminosityUnits.Gigawatt:
-            return f"""{self.gigawatts} """
+            return f"""{self.gigawatts} GW"""
         
         if unit == LuminosityUnits.Terawatt:
-            return f"""{self.terawatts} """
+            return f"""{self.terawatts} TW"""
         
         if unit == LuminosityUnits.Petawatt:
-            return f"""{self.petawatts} """
+            return f"""{self.petawatts} PW"""
         
-        return f'{self.__value}'
+        return f'{self._value}'
 
 
-    def get_unit_abbreviation(self, unit_abbreviation: LuminosityUnits = LuminosityUnits.Watt) -> string:
+    def get_unit_abbreviation(self, unit_abbreviation: LuminosityUnits = LuminosityUnits.Watt) -> str:
         """
         Get Luminosity unit abbreviation.
         Note! the default abbreviation for Luminosity is Watt.
@@ -651,107 +658,38 @@ class Luminosity:
             return """L⊙"""
         
         if unit_abbreviation == LuminosityUnits.Femtowatt:
-            return """"""
+            return """fW"""
         
         if unit_abbreviation == LuminosityUnits.Picowatt:
-            return """"""
+            return """pW"""
         
         if unit_abbreviation == LuminosityUnits.Nanowatt:
-            return """"""
+            return """nW"""
         
         if unit_abbreviation == LuminosityUnits.Microwatt:
-            return """"""
+            return """μW"""
         
         if unit_abbreviation == LuminosityUnits.Milliwatt:
-            return """"""
+            return """mW"""
         
         if unit_abbreviation == LuminosityUnits.Deciwatt:
-            return """"""
+            return """dW"""
         
         if unit_abbreviation == LuminosityUnits.Decawatt:
-            return """"""
+            return """daW"""
         
         if unit_abbreviation == LuminosityUnits.Kilowatt:
-            return """"""
+            return """kW"""
         
         if unit_abbreviation == LuminosityUnits.Megawatt:
-            return """"""
+            return """MW"""
         
         if unit_abbreviation == LuminosityUnits.Gigawatt:
-            return """"""
+            return """GW"""
         
         if unit_abbreviation == LuminosityUnits.Terawatt:
-            return """"""
+            return """TW"""
         
         if unit_abbreviation == LuminosityUnits.Petawatt:
-            return """"""
-        
-
-    def __str__(self):
-        return self.to_string()
-
-
-    def __add__(self, other):
-        if not isinstance(other, Luminosity):
-            raise TypeError("unsupported operand type(s) for +: 'Luminosity' and '{}'".format(type(other).__name__))
-        return Luminosity(self.__value + other.__value)
-
-
-    def __mul__(self, other):
-        if not isinstance(other, Luminosity):
-            raise TypeError("unsupported operand type(s) for *: 'Luminosity' and '{}'".format(type(other).__name__))
-        return Luminosity(self.__value * other.__value)
-
-
-    def __sub__(self, other):
-        if not isinstance(other, Luminosity):
-            raise TypeError("unsupported operand type(s) for -: 'Luminosity' and '{}'".format(type(other).__name__))
-        return Luminosity(self.__value - other.__value)
-
-
-    def __truediv__(self, other):
-        if not isinstance(other, Luminosity):
-            raise TypeError("unsupported operand type(s) for /: 'Luminosity' and '{}'".format(type(other).__name__))
-        return Luminosity(self.__value / other.__value)
-
-
-    def __mod__(self, other):
-        if not isinstance(other, Luminosity):
-            raise TypeError("unsupported operand type(s) for %: 'Luminosity' and '{}'".format(type(other).__name__))
-        return Luminosity(self.__value % other.__value)
-
-
-    def __pow__(self, other):
-        if not isinstance(other, Luminosity):
-            raise TypeError("unsupported operand type(s) for **: 'Luminosity' and '{}'".format(type(other).__name__))
-        return Luminosity(self.__value ** other.__value)
-
-
-    def __eq__(self, other):
-        if not isinstance(other, Luminosity):
-            raise TypeError("unsupported operand type(s) for ==: 'Luminosity' and '{}'".format(type(other).__name__))
-        return self.__value == other.__value
-
-
-    def __lt__(self, other):
-        if not isinstance(other, Luminosity):
-            raise TypeError("unsupported operand type(s) for <: 'Luminosity' and '{}'".format(type(other).__name__))
-        return self.__value < other.__value
-
-
-    def __gt__(self, other):
-        if not isinstance(other, Luminosity):
-            raise TypeError("unsupported operand type(s) for >: 'Luminosity' and '{}'".format(type(other).__name__))
-        return self.__value > other.__value
-
-
-    def __le__(self, other):
-        if not isinstance(other, Luminosity):
-            raise TypeError("unsupported operand type(s) for <=: 'Luminosity' and '{}'".format(type(other).__name__))
-        return self.__value <= other.__value
-
-
-    def __ge__(self, other):
-        if not isinstance(other, Luminosity):
-            raise TypeError("unsupported operand type(s) for >=: 'Luminosity' and '{}'".format(type(other).__name__))
-        return self.__value >= other.__value
\ No newline at end of file
+            return """PW"""
+        
\ No newline at end of file
