@@ -1,6 +1,8 @@
 from enum import Enum
 import math
-import string
+
+from ..abstract_unit import AbstractMeasure
+
 
 
 class MassUnits(Enum):
@@ -73,6 +75,16 @@ class MassUnits(Enum):
             Earth mass is a ratio unit to the mass of planet Earth.
         """
         
+        Femtogram = 'femtogram'
+        """
+            
+        """
+        
+        Picogram = 'picogram'
+        """
+            
+        """
+        
         Nanogram = 'nanogram'
         """
             
@@ -134,7 +146,7 @@ class MassUnits(Enum):
         """
         
 
-class Mass:
+class Mass(AbstractMeasure):
     """
     In physics, mass (from Greek μᾶζα "barley cake, lump [of dough]") is a property of a physical system or body, giving rise to the phenomena of the body's resistance to being accelerated by a force and the strength of its mutual gravitational attraction with other bodies. Instruments such as mass balances or scales use those phenomena to measure mass. The SI unit of mass is the kilogram (kg).
 
@@ -143,9 +155,11 @@ class Mass:
         from_unit (MassUnits): The Mass unit to create from, The default unit is Kilogram
     """
     def __init__(self, value: float, from_unit: MassUnits = MassUnits.Kilogram):
-        if math.isnan(value):
-            raise ValueError('Invalid unit: value is NaN')
-        self.__value = self.__convert_to_base(value, from_unit)
+        # Do not validate type, to allow working with numpay arrays and similar objects who supports all arithmetic 
+        # operations, but they are not a number, see #14 
+        # if math.isnan(value):
+        #     raise ValueError('Invalid unit: value is NaN')
+        self._value = self.__convert_to_base(value, from_unit)
         
         self.__grams = None
         
@@ -173,6 +187,10 @@ class Mass:
         
         self.__earth_masses = None
         
+        self.__femtograms = None
+        
+        self.__picograms = None
+        
         self.__nanograms = None
         
         self.__micrograms = None
@@ -198,8 +216,11 @@ class Mass:
         self.__megapounds = None
         
 
+    def convert(self, unit: MassUnits) -> float:
+        return self.__convert_from_base(unit)
+
     def __convert_from_base(self, from_unit: MassUnits) -> float:
-        value = self.__value
+        value = self._value
         
         if from_unit == MassUnits.Gram:
             return (value * 1e3)
@@ -240,6 +261,12 @@ class Mass:
         if from_unit == MassUnits.EarthMass:
             return (value / 5.9722e+24)
         
+        if from_unit == MassUnits.Femtogram:
+            return ((value * 1e3) / 1e-15)
+        
+        if from_unit == MassUnits.Picogram:
+            return ((value * 1e3) / 1e-12)
+        
         if from_unit == MassUnits.Nanogram:
             return ((value * 1e3) / 1e-09)
         
@@ -320,6 +347,12 @@ class Mass:
         if to_unit == MassUnits.EarthMass:
             return (value * 5.9722e+24)
         
+        if to_unit == MassUnits.Femtogram:
+            return ((value / 1e3) * 1e-15)
+        
+        if to_unit == MassUnits.Picogram:
+            return ((value / 1e3) * 1e-12)
+        
         if to_unit == MassUnits.Nanogram:
             return ((value / 1e3) * 1e-09)
         
@@ -361,7 +394,7 @@ class Mass:
 
     @property
     def base_value(self) -> float:
-        return self.__value
+        return self._value
 
     
     @staticmethod
@@ -559,6 +592,36 @@ class Mass:
         return Mass(earth_masses, MassUnits.EarthMass)
 
     
+    @staticmethod
+    def from_femtograms(femtograms: float):
+        """
+        Create a new instance of Mass from a value in femtograms.
+
+        
+
+        :param meters: The Mass value in femtograms.
+        :type femtograms: float
+        :return: A new instance of Mass.
+        :rtype: Mass
+        """
+        return Mass(femtograms, MassUnits.Femtogram)
+
+    
+    @staticmethod
+    def from_picograms(picograms: float):
+        """
+        Create a new instance of Mass from a value in picograms.
+
+        
+
+        :param meters: The Mass value in picograms.
+        :type picograms: float
+        :return: A new instance of Mass.
+        :rtype: Mass
+        """
+        return Mass(picograms, MassUnits.Picogram)
+
+    
     @staticmethod
     def from_nanograms(nanograms: float):
         """
@@ -882,6 +945,28 @@ class Mass:
         return self.__earth_masses
 
     
+    @property
+    def femtograms(self) -> float:
+        """
+        
+        """
+        if self.__femtograms != None:
+            return self.__femtograms
+        self.__femtograms = self.__convert_from_base(MassUnits.Femtogram)
+        return self.__femtograms
+
+    
+    @property
+    def picograms(self) -> float:
+        """
+        
+        """
+        if self.__picograms != None:
+            return self.__picograms
+        self.__picograms = self.__convert_from_base(MassUnits.Picogram)
+        return self.__picograms
+
+    
     @property
     def nanograms(self) -> float:
         """
@@ -1014,7 +1099,7 @@ class Mass:
         return self.__megapounds
 
     
-    def to_string(self, unit: MassUnits = MassUnits.Kilogram) -> string:
+    def to_string(self, unit: MassUnits = MassUnits.Kilogram) -> str:
         """
         Format the Mass to string.
         Note! the default format for Mass is Kilogram.
@@ -1060,46 +1145,52 @@ class Mass:
         if unit == MassUnits.EarthMass:
             return f"""{self.earth_masses} em"""
         
+        if unit == MassUnits.Femtogram:
+            return f"""{self.femtograms} fg"""
+        
+        if unit == MassUnits.Picogram:
+            return f"""{self.picograms} pg"""
+        
         if unit == MassUnits.Nanogram:
-            return f"""{self.nanograms} """
+            return f"""{self.nanograms} ng"""
         
         if unit == MassUnits.Microgram:
-            return f"""{self.micrograms} """
+            return f"""{self.micrograms} μg"""
         
         if unit == MassUnits.Milligram:
-            return f"""{self.milligrams} """
+            return f"""{self.milligrams} mg"""
         
         if unit == MassUnits.Centigram:
-            return f"""{self.centigrams} """
+            return f"""{self.centigrams} cg"""
         
         if unit == MassUnits.Decigram:
-            return f"""{self.decigrams} """
+            return f"""{self.decigrams} dg"""
         
         if unit == MassUnits.Decagram:
-            return f"""{self.decagrams} """
+            return f"""{self.decagrams} dag"""
         
         if unit == MassUnits.Hectogram:
-            return f"""{self.hectograms} """
+            return f"""{self.hectograms} hg"""
         
         if unit == MassUnits.Kilogram:
-            return f"""{self.kilograms} """
+            return f"""{self.kilograms} kg"""
         
         if unit == MassUnits.Kilotonne:
-            return f"""{self.kilotonnes} """
+            return f"""{self.kilotonnes} kt"""
         
         if unit == MassUnits.Megatonne:
-            return f"""{self.megatonnes} """
+            return f"""{self.megatonnes} Mt"""
         
         if unit == MassUnits.Kilopound:
-            return f"""{self.kilopounds} """
+            return f"""{self.kilopounds} klb"""
         
         if unit == MassUnits.Megapound:
-            return f"""{self.megapounds} """
+            return f"""{self.megapounds} Mlb"""
         
-        return f'{self.__value}'
+        return f'{self._value}'
 
 
-    def get_unit_abbreviation(self, unit_abbreviation: MassUnits = MassUnits.Kilogram) -> string:
+    def get_unit_abbreviation(self, unit_abbreviation: MassUnits = MassUnits.Kilogram) -> str:
         """
         Get Mass unit abbreviation.
         Note! the default abbreviation for Mass is Kilogram.
@@ -1145,108 +1236,45 @@ class Mass:
         if unit_abbreviation == MassUnits.EarthMass:
             return """em"""
         
+        if unit_abbreviation == MassUnits.Femtogram:
+            return """fg"""
+        
+        if unit_abbreviation == MassUnits.Picogram:
+            return """pg"""
+        
         if unit_abbreviation == MassUnits.Nanogram:
-            return """"""
+            return """ng"""
         
         if unit_abbreviation == MassUnits.Microgram:
-            return """"""
+            return """μg"""
         
         if unit_abbreviation == MassUnits.Milligram:
-            return """"""
+            return """mg"""
         
         if unit_abbreviation == MassUnits.Centigram:
-            return """"""
+            return """cg"""
         
         if unit_abbreviation == MassUnits.Decigram:
-            return """"""
+            return """dg"""
         
         if unit_abbreviation == MassUnits.Decagram:
-            return """"""
+            return """dag"""
         
         if unit_abbreviation == MassUnits.Hectogram:
-            return """"""
+            return """hg"""
         
         if unit_abbreviation == MassUnits.Kilogram:
-            return """"""
+            return """kg"""
         
         if unit_abbreviation == MassUnits.Kilotonne:
-            return """"""
+            return """kt"""
         
         if unit_abbreviation == MassUnits.Megatonne:
-            return """"""
+            return """Mt"""
         
         if unit_abbreviation == MassUnits.Kilopound:
-            return """"""
+            return """klb"""
         
         if unit_abbreviation == MassUnits.Megapound:
-            return """"""
-        
-
-    def __str__(self):
-        return self.to_string()
-
-
-    def __add__(self, other):
-        if not isinstance(other, Mass):
-            raise TypeError("unsupported operand type(s) for +: 'Mass' and '{}'".format(type(other).__name__))
-        return Mass(self.__value + other.__value)
-
-
-    def __mul__(self, other):
-        if not isinstance(other, Mass):
-            raise TypeError("unsupported operand type(s) for *: 'Mass' and '{}'".format(type(other).__name__))
-        return Mass(self.__value * other.__value)
-
-
-    def __sub__(self, other):
-        if not isinstance(other, Mass):
-            raise TypeError("unsupported operand type(s) for -: 'Mass' and '{}'".format(type(other).__name__))
-        return Mass(self.__value - other.__value)
-
-
-    def __truediv__(self, other):
-        if not isinstance(other, Mass):
-            raise TypeError("unsupported operand type(s) for /: 'Mass' and '{}'".format(type(other).__name__))
-        return Mass(self.__value / other.__value)
-
-
-    def __mod__(self, other):
-        if not isinstance(other, Mass):
-            raise TypeError("unsupported operand type(s) for %: 'Mass' and '{}'".format(type(other).__name__))
-        return Mass(self.__value % other.__value)
-
-
-    def __pow__(self, other):
-        if not isinstance(other, Mass):
-            raise TypeError("unsupported operand type(s) for **: 'Mass' and '{}'".format(type(other).__name__))
-        return Mass(self.__value ** other.__value)
-
-
-    def __eq__(self, other):
-        if not isinstance(other, Mass):
-            raise TypeError("unsupported operand type(s) for ==: 'Mass' and '{}'".format(type(other).__name__))
-        return self.__value == other.__value
-
-
-    def __lt__(self, other):
-        if not isinstance(other, Mass):
-            raise TypeError("unsupported operand type(s) for <: 'Mass' and '{}'".format(type(other).__name__))
-        return self.__value < other.__value
-
-
-    def __gt__(self, other):
-        if not isinstance(other, Mass):
-            raise TypeError("unsupported operand type(s) for >: 'Mass' and '{}'".format(type(other).__name__))
-        return self.__value > other.__value
-
-
-    def __le__(self, other):
-        if not isinstance(other, Mass):
-            raise TypeError("unsupported operand type(s) for <=: 'Mass' and '{}'".format(type(other).__name__))
-        return self.__value <= other.__value
-
-
-    def __ge__(self, other):
-        if not isinstance(other, Mass):
-            raise TypeError("unsupported operand type(s) for >=: 'Mass' and '{}'".format(type(other).__name__))
-        return self.__value >= other.__value
\ No newline at end of file
+            return """Mlb"""
+        
\ No newline at end of file
