@@ -1,6 +1,8 @@
 from enum import Enum
 import math
-import string
+
+from ..abstract_unit import AbstractMeasure
+
 
 
 class MassFlowUnits(Enum):
@@ -174,7 +176,7 @@ class MassFlowUnits(Enum):
         """
         
 
-class MassFlow:
+class MassFlow(AbstractMeasure):
     """
     Mass flow is the ratio of the mass change to the time during which the change occurred (value of mass changes per unit time).
 
@@ -183,9 +185,11 @@ class MassFlow:
         from_unit (MassFlowUnits): The MassFlow unit to create from, The default unit is GramPerSecond
     """
     def __init__(self, value: float, from_unit: MassFlowUnits = MassFlowUnits.GramPerSecond):
-        if math.isnan(value):
-            raise ValueError('Invalid unit: value is NaN')
-        self.__value = self.__convert_to_base(value, from_unit)
+        # Do not validate type, to allow working with numpay arrays and similar objects who supports all arithmetic 
+        # operations, but they are not a number, see #14 
+        # if math.isnan(value):
+        #     raise ValueError('Invalid unit: value is NaN')
+        self._value = self.__convert_to_base(value, from_unit)
         
         self.__grams_per_second = None
         
@@ -254,8 +258,11 @@ class MassFlow:
         self.__megapounds_per_second = None
         
 
+    def convert(self, unit: MassFlowUnits) -> float:
+        return self.__convert_from_base(unit)
+
     def __convert_from_base(self, from_unit: MassFlowUnits) -> float:
-        value = self.__value
+        value = self._value
         
         if from_unit == MassFlowUnits.GramPerSecond:
             return (value)
@@ -465,7 +472,7 @@ class MassFlow:
 
     @property
     def base_value(self) -> float:
-        return self.__value
+        return self._value
 
     
     @staticmethod
@@ -1326,7 +1333,7 @@ class MassFlow:
         return self.__megapounds_per_second
 
     
-    def to_string(self, unit: MassFlowUnits = MassFlowUnits.GramPerSecond) -> string:
+    def to_string(self, unit: MassFlowUnits = MassFlowUnits.GramPerSecond) -> str:
         """
         Format the MassFlow to string.
         Note! the default format for MassFlow is GramPerSecond.
@@ -1370,72 +1377,72 @@ class MassFlow:
             return f"""{self.short_tons_per_hour} short tn/h"""
         
         if unit == MassFlowUnits.NanogramPerSecond:
-            return f"""{self.nanograms_per_second} """
+            return f"""{self.nanograms_per_second} ng/s"""
         
         if unit == MassFlowUnits.MicrogramPerSecond:
-            return f"""{self.micrograms_per_second} """
+            return f"""{self.micrograms_per_second} μg/s"""
         
         if unit == MassFlowUnits.MilligramPerSecond:
-            return f"""{self.milligrams_per_second} """
+            return f"""{self.milligrams_per_second} mg/s"""
         
         if unit == MassFlowUnits.CentigramPerSecond:
-            return f"""{self.centigrams_per_second} """
+            return f"""{self.centigrams_per_second} cg/s"""
         
         if unit == MassFlowUnits.DecigramPerSecond:
-            return f"""{self.decigrams_per_second} """
+            return f"""{self.decigrams_per_second} dg/s"""
         
         if unit == MassFlowUnits.DecagramPerSecond:
-            return f"""{self.decagrams_per_second} """
+            return f"""{self.decagrams_per_second} dag/s"""
         
         if unit == MassFlowUnits.HectogramPerSecond:
-            return f"""{self.hectograms_per_second} """
+            return f"""{self.hectograms_per_second} hg/s"""
         
         if unit == MassFlowUnits.KilogramPerSecond:
-            return f"""{self.kilograms_per_second} """
+            return f"""{self.kilograms_per_second} kg/s"""
         
         if unit == MassFlowUnits.NanogramPerDay:
-            return f"""{self.nanograms_per_day} """
+            return f"""{self.nanograms_per_day} ng/d"""
         
         if unit == MassFlowUnits.MicrogramPerDay:
-            return f"""{self.micrograms_per_day} """
+            return f"""{self.micrograms_per_day} μg/d"""
         
         if unit == MassFlowUnits.MilligramPerDay:
-            return f"""{self.milligrams_per_day} """
+            return f"""{self.milligrams_per_day} mg/d"""
         
         if unit == MassFlowUnits.CentigramPerDay:
-            return f"""{self.centigrams_per_day} """
+            return f"""{self.centigrams_per_day} cg/d"""
         
         if unit == MassFlowUnits.DecigramPerDay:
-            return f"""{self.decigrams_per_day} """
+            return f"""{self.decigrams_per_day} dg/d"""
         
         if unit == MassFlowUnits.DecagramPerDay:
-            return f"""{self.decagrams_per_day} """
+            return f"""{self.decagrams_per_day} dag/d"""
         
         if unit == MassFlowUnits.HectogramPerDay:
-            return f"""{self.hectograms_per_day} """
+            return f"""{self.hectograms_per_day} hg/d"""
         
         if unit == MassFlowUnits.KilogramPerDay:
-            return f"""{self.kilograms_per_day} """
+            return f"""{self.kilograms_per_day} kg/d"""
         
         if unit == MassFlowUnits.MegagramPerDay:
-            return f"""{self.megagrams_per_day} """
+            return f"""{self.megagrams_per_day} Mg/d"""
         
         if unit == MassFlowUnits.MegapoundPerDay:
-            return f"""{self.megapounds_per_day} """
+            return f"""{self.megapounds_per_day} Mlb/d"""
         
         if unit == MassFlowUnits.MegapoundPerHour:
-            return f"""{self.megapounds_per_hour} """
+            return f"""{self.megapounds_per_hour} Mlb/h"""
         
         if unit == MassFlowUnits.MegapoundPerMinute:
-            return f"""{self.megapounds_per_minute} """
+            return f"""{self.megapounds_per_minute} Mlb/min"""
         
         if unit == MassFlowUnits.MegapoundPerSecond:
-            return f"""{self.megapounds_per_second} """
+            return f"""{self.megapounds_per_second} Mlb/s"""
         
-        return f'{self.__value}'
+        return f'{self._value}'
 
 
-    def get_unit_abbreviation(self, unit_abbreviation: MassFlowUnits = MassFlowUnits.GramPerSecond) -> string:
+    def get_unit_abbreviation(self, unit_abbreviation: MassFlowUnits = MassFlowUnits.GramPerSecond) -> str:
         """
         Get MassFlow unit abbreviation.
         Note! the default abbreviation for MassFlow is GramPerSecond.
@@ -1479,134 +1486,65 @@ class MassFlow:
             return """short tn/h"""
         
         if unit_abbreviation == MassFlowUnits.NanogramPerSecond:
-            return """"""
+            return """ng/s"""
         
         if unit_abbreviation == MassFlowUnits.MicrogramPerSecond:
-            return """"""
+            return """μg/s"""
         
         if unit_abbreviation == MassFlowUnits.MilligramPerSecond:
-            return """"""
+            return """mg/s"""
         
         if unit_abbreviation == MassFlowUnits.CentigramPerSecond:
-            return """"""
+            return """cg/s"""
         
         if unit_abbreviation == MassFlowUnits.DecigramPerSecond:
-            return """"""
+            return """dg/s"""
         
         if unit_abbreviation == MassFlowUnits.DecagramPerSecond:
-            return """"""
+            return """dag/s"""
         
         if unit_abbreviation == MassFlowUnits.HectogramPerSecond:
-            return """"""
+            return """hg/s"""
         
         if unit_abbreviation == MassFlowUnits.KilogramPerSecond:
-            return """"""
+            return """kg/s"""
         
         if unit_abbreviation == MassFlowUnits.NanogramPerDay:
-            return """"""
+            return """ng/d"""
         
         if unit_abbreviation == MassFlowUnits.MicrogramPerDay:
-            return """"""
+            return """μg/d"""
         
         if unit_abbreviation == MassFlowUnits.MilligramPerDay:
-            return """"""
+            return """mg/d"""
         
         if unit_abbreviation == MassFlowUnits.CentigramPerDay:
-            return """"""
+            return """cg/d"""
         
         if unit_abbreviation == MassFlowUnits.DecigramPerDay:
-            return """"""
+            return """dg/d"""
         
         if unit_abbreviation == MassFlowUnits.DecagramPerDay:
-            return """"""
+            return """dag/d"""
         
         if unit_abbreviation == MassFlowUnits.HectogramPerDay:
-            return """"""
+            return """hg/d"""
         
         if unit_abbreviation == MassFlowUnits.KilogramPerDay:
-            return """"""
+            return """kg/d"""
         
         if unit_abbreviation == MassFlowUnits.MegagramPerDay:
-            return """"""
+            return """Mg/d"""
         
         if unit_abbreviation == MassFlowUnits.MegapoundPerDay:
-            return """"""
+            return """Mlb/d"""
         
         if unit_abbreviation == MassFlowUnits.MegapoundPerHour:
-            return """"""
+            return """Mlb/h"""
         
         if unit_abbreviation == MassFlowUnits.MegapoundPerMinute:
-            return """"""
+            return """Mlb/min"""
         
         if unit_abbreviation == MassFlowUnits.MegapoundPerSecond:
-            return """"""
-        
-
-    def __str__(self):
-        return self.to_string()
-
-
-    def __add__(self, other):
-        if not isinstance(other, MassFlow):
-            raise TypeError("unsupported operand type(s) for +: 'MassFlow' and '{}'".format(type(other).__name__))
-        return MassFlow(self.__value + other.__value)
-
-
-    def __mul__(self, other):
-        if not isinstance(other, MassFlow):
-            raise TypeError("unsupported operand type(s) for *: 'MassFlow' and '{}'".format(type(other).__name__))
-        return MassFlow(self.__value * other.__value)
-
-
-    def __sub__(self, other):
-        if not isinstance(other, MassFlow):
-            raise TypeError("unsupported operand type(s) for -: 'MassFlow' and '{}'".format(type(other).__name__))
-        return MassFlow(self.__value - other.__value)
-
-
-    def __truediv__(self, other):
-        if not isinstance(other, MassFlow):
-            raise TypeError("unsupported operand type(s) for /: 'MassFlow' and '{}'".format(type(other).__name__))
-        return MassFlow(self.__value / other.__value)
-
-
-    def __mod__(self, other):
-        if not isinstance(other, MassFlow):
-            raise TypeError("unsupported operand type(s) for %: 'MassFlow' and '{}'".format(type(other).__name__))
-        return MassFlow(self.__value % other.__value)
-
-
-    def __pow__(self, other):
-        if not isinstance(other, MassFlow):
-            raise TypeError("unsupported operand type(s) for **: 'MassFlow' and '{}'".format(type(other).__name__))
-        return MassFlow(self.__value ** other.__value)
-
-
-    def __eq__(self, other):
-        if not isinstance(other, MassFlow):
-            raise TypeError("unsupported operand type(s) for ==: 'MassFlow' and '{}'".format(type(other).__name__))
-        return self.__value == other.__value
-
-
-    def __lt__(self, other):
-        if not isinstance(other, MassFlow):
-            raise TypeError("unsupported operand type(s) for <: 'MassFlow' and '{}'".format(type(other).__name__))
-        return self.__value < other.__value
-
-
-    def __gt__(self, other):
-        if not isinstance(other, MassFlow):
-            raise TypeError("unsupported operand type(s) for >: 'MassFlow' and '{}'".format(type(other).__name__))
-        return self.__value > other.__value
-
-
-    def __le__(self, other):
-        if not isinstance(other, MassFlow):
-            raise TypeError("unsupported operand type(s) for <=: 'MassFlow' and '{}'".format(type(other).__name__))
-        return self.__value <= other.__value
-
-
-    def __ge__(self, other):
-        if not isinstance(other, MassFlow):
-            raise TypeError("unsupported operand type(s) for >=: 'MassFlow' and '{}'".format(type(other).__name__))
-        return self.__value >= other.__value
\ No newline at end of file
+            return """Mlb/s"""
+        
\ No newline at end of file
