@@ -1,6 +1,8 @@
 from enum import Enum
 import math
-import string
+
+from ..abstract_unit import AbstractMeasure
+
 
 
 class MassFluxUnits(Enum):
@@ -69,7 +71,7 @@ class MassFluxUnits(Enum):
         """
         
 
-class MassFlux:
+class MassFlux(AbstractMeasure):
     """
     Mass flux is the mass flow rate per unit area.
 
@@ -78,9 +80,11 @@ class MassFlux:
         from_unit (MassFluxUnits): The MassFlux unit to create from, The default unit is KilogramPerSecondPerSquareMeter
     """
     def __init__(self, value: float, from_unit: MassFluxUnits = MassFluxUnits.KilogramPerSecondPerSquareMeter):
-        if math.isnan(value):
-            raise ValueError('Invalid unit: value is NaN')
-        self.__value = self.__convert_to_base(value, from_unit)
+        # Do not validate type, to allow working with numpay arrays and similar objects who supports all arithmetic 
+        # operations, but they are not a number, see #14 
+        # if math.isnan(value):
+        #     raise ValueError('Invalid unit: value is NaN')
+        self._value = self.__convert_to_base(value, from_unit)
         
         self.__grams_per_second_per_square_meter = None
         
@@ -107,8 +111,11 @@ class MassFlux:
         self.__kilograms_per_hour_per_square_millimeter = None
         
 
+    def convert(self, unit: MassFluxUnits) -> float:
+        return self.__convert_from_base(unit)
+
     def __convert_from_base(self, from_unit: MassFluxUnits) -> float:
-        value = self.__value
+        value = self._value
         
         if from_unit == MassFluxUnits.GramPerSecondPerSquareMeter:
             return (value * 1e3)
@@ -192,7 +199,7 @@ class MassFlux:
 
     @property
     def base_value(self) -> float:
-        return self.__value
+        return self._value
 
     
     @staticmethod
@@ -507,7 +514,7 @@ class MassFlux:
         return self.__kilograms_per_hour_per_square_millimeter
 
     
-    def to_string(self, unit: MassFluxUnits = MassFluxUnits.KilogramPerSecondPerSquareMeter) -> string:
+    def to_string(self, unit: MassFluxUnits = MassFluxUnits.KilogramPerSecondPerSquareMeter) -> str:
         """
         Format the MassFlux to string.
         Note! the default format for MassFlux is KilogramPerSecondPerSquareMeter.
@@ -533,27 +540,27 @@ class MassFlux:
             return f"""{self.grams_per_hour_per_square_millimeter} g·h⁻¹·mm⁻²"""
         
         if unit == MassFluxUnits.KilogramPerSecondPerSquareMeter:
-            return f"""{self.kilograms_per_second_per_square_meter} """
+            return f"""{self.kilograms_per_second_per_square_meter} kg·s⁻¹·m⁻²"""
         
         if unit == MassFluxUnits.KilogramPerSecondPerSquareCentimeter:
-            return f"""{self.kilograms_per_second_per_square_centimeter} """
+            return f"""{self.kilograms_per_second_per_square_centimeter} kg·s⁻¹·cm⁻²"""
         
         if unit == MassFluxUnits.KilogramPerSecondPerSquareMillimeter:
-            return f"""{self.kilograms_per_second_per_square_millimeter} """
+            return f"""{self.kilograms_per_second_per_square_millimeter} kg·s⁻¹·mm⁻²"""
         
         if unit == MassFluxUnits.KilogramPerHourPerSquareMeter:
-            return f"""{self.kilograms_per_hour_per_square_meter} """
+            return f"""{self.kilograms_per_hour_per_square_meter} kg·h⁻¹·m⁻²"""
         
         if unit == MassFluxUnits.KilogramPerHourPerSquareCentimeter:
-            return f"""{self.kilograms_per_hour_per_square_centimeter} """
+            return f"""{self.kilograms_per_hour_per_square_centimeter} kg·h⁻¹·cm⁻²"""
         
         if unit == MassFluxUnits.KilogramPerHourPerSquareMillimeter:
-            return f"""{self.kilograms_per_hour_per_square_millimeter} """
+            return f"""{self.kilograms_per_hour_per_square_millimeter} kg·h⁻¹·mm⁻²"""
         
-        return f'{self.__value}'
+        return f'{self._value}'
 
 
-    def get_unit_abbreviation(self, unit_abbreviation: MassFluxUnits = MassFluxUnits.KilogramPerSecondPerSquareMeter) -> string:
+    def get_unit_abbreviation(self, unit_abbreviation: MassFluxUnits = MassFluxUnits.KilogramPerSecondPerSquareMeter) -> str:
         """
         Get MassFlux unit abbreviation.
         Note! the default abbreviation for MassFlux is KilogramPerSecondPerSquareMeter.
@@ -579,89 +586,20 @@ class MassFlux:
             return """g·h⁻¹·mm⁻²"""
         
         if unit_abbreviation == MassFluxUnits.KilogramPerSecondPerSquareMeter:
-            return """"""
+            return """kg·s⁻¹·m⁻²"""
         
         if unit_abbreviation == MassFluxUnits.KilogramPerSecondPerSquareCentimeter:
-            return """"""
+            return """kg·s⁻¹·cm⁻²"""
         
         if unit_abbreviation == MassFluxUnits.KilogramPerSecondPerSquareMillimeter:
-            return """"""
+            return """kg·s⁻¹·mm⁻²"""
         
         if unit_abbreviation == MassFluxUnits.KilogramPerHourPerSquareMeter:
-            return """"""
+            return """kg·h⁻¹·m⁻²"""
         
         if unit_abbreviation == MassFluxUnits.KilogramPerHourPerSquareCentimeter:
-            return """"""
+            return """kg·h⁻¹·cm⁻²"""
         
         if unit_abbreviation == MassFluxUnits.KilogramPerHourPerSquareMillimeter:
-            return """"""
-        
-
-    def __str__(self):
-        return self.to_string()
-
-
-    def __add__(self, other):
-        if not isinstance(other, MassFlux):
-            raise TypeError("unsupported operand type(s) for +: 'MassFlux' and '{}'".format(type(other).__name__))
-        return MassFlux(self.__value + other.__value)
-
-
-    def __mul__(self, other):
-        if not isinstance(other, MassFlux):
-            raise TypeError("unsupported operand type(s) for *: 'MassFlux' and '{}'".format(type(other).__name__))
-        return MassFlux(self.__value * other.__value)
-
-
-    def __sub__(self, other):
-        if not isinstance(other, MassFlux):
-            raise TypeError("unsupported operand type(s) for -: 'MassFlux' and '{}'".format(type(other).__name__))
-        return MassFlux(self.__value - other.__value)
-
-
-    def __truediv__(self, other):
-        if not isinstance(other, MassFlux):
-            raise TypeError("unsupported operand type(s) for /: 'MassFlux' and '{}'".format(type(other).__name__))
-        return MassFlux(self.__value / other.__value)
-
-
-    def __mod__(self, other):
-        if not isinstance(other, MassFlux):
-            raise TypeError("unsupported operand type(s) for %: 'MassFlux' and '{}'".format(type(other).__name__))
-        return MassFlux(self.__value % other.__value)
-
-
-    def __pow__(self, other):
-        if not isinstance(other, MassFlux):
-            raise TypeError("unsupported operand type(s) for **: 'MassFlux' and '{}'".format(type(other).__name__))
-        return MassFlux(self.__value ** other.__value)
-
-
-    def __eq__(self, other):
-        if not isinstance(other, MassFlux):
-            raise TypeError("unsupported operand type(s) for ==: 'MassFlux' and '{}'".format(type(other).__name__))
-        return self.__value == other.__value
-
-
-    def __lt__(self, other):
-        if not isinstance(other, MassFlux):
-            raise TypeError("unsupported operand type(s) for <: 'MassFlux' and '{}'".format(type(other).__name__))
-        return self.__value < other.__value
-
-
-    def __gt__(self, other):
-        if not isinstance(other, MassFlux):
-            raise TypeError("unsupported operand type(s) for >: 'MassFlux' and '{}'".format(type(other).__name__))
-        return self.__value > other.__value
-
-
-    def __le__(self, other):
-        if not isinstance(other, MassFlux):
-            raise TypeError("unsupported operand type(s) for <=: 'MassFlux' and '{}'".format(type(other).__name__))
-        return self.__value <= other.__value
-
-
-    def __ge__(self, other):
-        if not isinstance(other, MassFlux):
-            raise TypeError("unsupported operand type(s) for >=: 'MassFlux' and '{}'".format(type(other).__name__))
-        return self.__value >= other.__value
\ No newline at end of file
+            return """kg·h⁻¹·mm⁻²"""
+        
\ No newline at end of file
