@@ -1,6 +1,8 @@
 from enum import Enum
 import math
-import string
+
+from ..abstract_unit import AbstractMeasure
+
 
 
 class MassFractionUnits(Enum):
@@ -129,7 +131,7 @@ class MassFractionUnits(Enum):
         """
         
 
-class MassFraction:
+class MassFraction(AbstractMeasure):
     """
     The mass fraction is defined as the mass of a constituent divided by the total mass of the mixture.
 
@@ -138,9 +140,11 @@ class MassFraction:
         from_unit (MassFractionUnits): The MassFraction unit to create from, The default unit is DecimalFraction
     """
     def __init__(self, value: float, from_unit: MassFractionUnits = MassFractionUnits.DecimalFraction):
-        if math.isnan(value):
-            raise ValueError('Invalid unit: value is NaN')
-        self.__value = self.__convert_to_base(value, from_unit)
+        # Do not validate type, to allow working with numpay arrays and similar objects who supports all arithmetic 
+        # operations, but they are not a number, see #14 
+        # if math.isnan(value):
+        #     raise ValueError('Invalid unit: value is NaN')
+        self._value = self.__convert_to_base(value, from_unit)
         
         self.__decimal_fractions = None
         
@@ -191,8 +195,11 @@ class MassFraction:
         self.__kilograms_per_kilogram = None
         
 
+    def convert(self, unit: MassFractionUnits) -> float:
+        return self.__convert_from_base(unit)
+
     def __convert_from_base(self, from_unit: MassFractionUnits) -> float:
-        value = self.__value
+        value = self._value
         
         if from_unit == MassFractionUnits.DecimalFraction:
             return (value)
@@ -348,7 +355,7 @@ class MassFraction:
 
     @property
     def base_value(self) -> float:
-        return self.__value
+        return self._value
 
     
     @staticmethod
@@ -975,7 +982,7 @@ class MassFraction:
         return self.__kilograms_per_kilogram
 
     
-    def to_string(self, unit: MassFractionUnits = MassFractionUnits.DecimalFraction) -> string:
+    def to_string(self, unit: MassFractionUnits = MassFractionUnits.DecimalFraction) -> str:
         """
         Format the MassFraction to string.
         Note! the default format for MassFraction is DecimalFraction.
@@ -1007,57 +1014,57 @@ class MassFraction:
             return f"""{self.parts_per_trillion} ppt"""
         
         if unit == MassFractionUnits.NanogramPerGram:
-            return f"""{self.nanograms_per_gram} """
+            return f"""{self.nanograms_per_gram} ng/g"""
         
         if unit == MassFractionUnits.MicrogramPerGram:
-            return f"""{self.micrograms_per_gram} """
+            return f"""{self.micrograms_per_gram} μg/g"""
         
         if unit == MassFractionUnits.MilligramPerGram:
-            return f"""{self.milligrams_per_gram} """
+            return f"""{self.milligrams_per_gram} mg/g"""
         
         if unit == MassFractionUnits.CentigramPerGram:
-            return f"""{self.centigrams_per_gram} """
+            return f"""{self.centigrams_per_gram} cg/g"""
         
         if unit == MassFractionUnits.DecigramPerGram:
-            return f"""{self.decigrams_per_gram} """
+            return f"""{self.decigrams_per_gram} dg/g"""
         
         if unit == MassFractionUnits.DecagramPerGram:
-            return f"""{self.decagrams_per_gram} """
+            return f"""{self.decagrams_per_gram} dag/g"""
         
         if unit == MassFractionUnits.HectogramPerGram:
-            return f"""{self.hectograms_per_gram} """
+            return f"""{self.hectograms_per_gram} hg/g"""
         
         if unit == MassFractionUnits.KilogramPerGram:
-            return f"""{self.kilograms_per_gram} """
+            return f"""{self.kilograms_per_gram} kg/g"""
         
         if unit == MassFractionUnits.NanogramPerKilogram:
-            return f"""{self.nanograms_per_kilogram} """
+            return f"""{self.nanograms_per_kilogram} ng/kg"""
         
         if unit == MassFractionUnits.MicrogramPerKilogram:
-            return f"""{self.micrograms_per_kilogram} """
+            return f"""{self.micrograms_per_kilogram} μg/kg"""
         
         if unit == MassFractionUnits.MilligramPerKilogram:
-            return f"""{self.milligrams_per_kilogram} """
+            return f"""{self.milligrams_per_kilogram} mg/kg"""
         
         if unit == MassFractionUnits.CentigramPerKilogram:
-            return f"""{self.centigrams_per_kilogram} """
+            return f"""{self.centigrams_per_kilogram} cg/kg"""
         
         if unit == MassFractionUnits.DecigramPerKilogram:
-            return f"""{self.decigrams_per_kilogram} """
+            return f"""{self.decigrams_per_kilogram} dg/kg"""
         
         if unit == MassFractionUnits.DecagramPerKilogram:
-            return f"""{self.decagrams_per_kilogram} """
+            return f"""{self.decagrams_per_kilogram} dag/kg"""
         
         if unit == MassFractionUnits.HectogramPerKilogram:
-            return f"""{self.hectograms_per_kilogram} """
+            return f"""{self.hectograms_per_kilogram} hg/kg"""
         
         if unit == MassFractionUnits.KilogramPerKilogram:
-            return f"""{self.kilograms_per_kilogram} """
+            return f"""{self.kilograms_per_kilogram} kg/kg"""
         
-        return f'{self.__value}'
+        return f'{self._value}'
 
 
-    def get_unit_abbreviation(self, unit_abbreviation: MassFractionUnits = MassFractionUnits.DecimalFraction) -> string:
+    def get_unit_abbreviation(self, unit_abbreviation: MassFractionUnits = MassFractionUnits.DecimalFraction) -> str:
         """
         Get MassFraction unit abbreviation.
         Note! the default abbreviation for MassFraction is DecimalFraction.
@@ -1089,119 +1096,50 @@ class MassFraction:
             return """ppt"""
         
         if unit_abbreviation == MassFractionUnits.NanogramPerGram:
-            return """"""
+            return """ng/g"""
         
         if unit_abbreviation == MassFractionUnits.MicrogramPerGram:
-            return """"""
+            return """μg/g"""
         
         if unit_abbreviation == MassFractionUnits.MilligramPerGram:
-            return """"""
+            return """mg/g"""
         
         if unit_abbreviation == MassFractionUnits.CentigramPerGram:
-            return """"""
+            return """cg/g"""
         
         if unit_abbreviation == MassFractionUnits.DecigramPerGram:
-            return """"""
+            return """dg/g"""
         
         if unit_abbreviation == MassFractionUnits.DecagramPerGram:
-            return """"""
+            return """dag/g"""
         
         if unit_abbreviation == MassFractionUnits.HectogramPerGram:
-            return """"""
+            return """hg/g"""
         
         if unit_abbreviation == MassFractionUnits.KilogramPerGram:
-            return """"""
+            return """kg/g"""
         
         if unit_abbreviation == MassFractionUnits.NanogramPerKilogram:
-            return """"""
+            return """ng/kg"""
         
         if unit_abbreviation == MassFractionUnits.MicrogramPerKilogram:
-            return """"""
+            return """μg/kg"""
         
         if unit_abbreviation == MassFractionUnits.MilligramPerKilogram:
-            return """"""
+            return """mg/kg"""
         
         if unit_abbreviation == MassFractionUnits.CentigramPerKilogram:
-            return """"""
+            return """cg/kg"""
         
         if unit_abbreviation == MassFractionUnits.DecigramPerKilogram:
-            return """"""
+            return """dg/kg"""
         
         if unit_abbreviation == MassFractionUnits.DecagramPerKilogram:
-            return """"""
+            return """dag/kg"""
         
         if unit_abbreviation == MassFractionUnits.HectogramPerKilogram:
-            return """"""
+            return """hg/kg"""
         
         if unit_abbreviation == MassFractionUnits.KilogramPerKilogram:
-            return """"""
-        
-
-    def __str__(self):
-        return self.to_string()
-
-
-    def __add__(self, other):
-        if not isinstance(other, MassFraction):
-            raise TypeError("unsupported operand type(s) for +: 'MassFraction' and '{}'".format(type(other).__name__))
-        return MassFraction(self.__value + other.__value)
-
-
-    def __mul__(self, other):
-        if not isinstance(other, MassFraction):
-            raise TypeError("unsupported operand type(s) for *: 'MassFraction' and '{}'".format(type(other).__name__))
-        return MassFraction(self.__value * other.__value)
-
-
-    def __sub__(self, other):
-        if not isinstance(other, MassFraction):
-            raise TypeError("unsupported operand type(s) for -: 'MassFraction' and '{}'".format(type(other).__name__))
-        return MassFraction(self.__value - other.__value)
-
-
-    def __truediv__(self, other):
-        if not isinstance(other, MassFraction):
-            raise TypeError("unsupported operand type(s) for /: 'MassFraction' and '{}'".format(type(other).__name__))
-        return MassFraction(self.__value / other.__value)
-
-
-    def __mod__(self, other):
-        if not isinstance(other, MassFraction):
-            raise TypeError("unsupported operand type(s) for %: 'MassFraction' and '{}'".format(type(other).__name__))
-        return MassFraction(self.__value % other.__value)
-
-
-    def __pow__(self, other):
-        if not isinstance(other, MassFraction):
-            raise TypeError("unsupported operand type(s) for **: 'MassFraction' and '{}'".format(type(other).__name__))
-        return MassFraction(self.__value ** other.__value)
-
-
-    def __eq__(self, other):
-        if not isinstance(other, MassFraction):
-            raise TypeError("unsupported operand type(s) for ==: 'MassFraction' and '{}'".format(type(other).__name__))
-        return self.__value == other.__value
-
-
-    def __lt__(self, other):
-        if not isinstance(other, MassFraction):
-            raise TypeError("unsupported operand type(s) for <: 'MassFraction' and '{}'".format(type(other).__name__))
-        return self.__value < other.__value
-
-
-    def __gt__(self, other):
-        if not isinstance(other, MassFraction):
-            raise TypeError("unsupported operand type(s) for >: 'MassFraction' and '{}'".format(type(other).__name__))
-        return self.__value > other.__value
-
-
-    def __le__(self, other):
-        if not isinstance(other, MassFraction):
-            raise TypeError("unsupported operand type(s) for <=: 'MassFraction' and '{}'".format(type(other).__name__))
-        return self.__value <= other.__value
-
-
-    def __ge__(self, other):
-        if not isinstance(other, MassFraction):
-            raise TypeError("unsupported operand type(s) for >=: 'MassFraction' and '{}'".format(type(other).__name__))
-        return self.__value >= other.__value
\ No newline at end of file
+            return """kg/kg"""
+        
\ No newline at end of file
