@@ -1,6 +1,8 @@
 from enum import Enum
 import math
-import string
+
+from ..abstract_unit import AbstractMeasure
+
 
 
 class MassMomentOfInertiaUnits(Enum):
@@ -149,7 +151,7 @@ class MassMomentOfInertiaUnits(Enum):
         """
         
 
-class MassMomentOfInertia:
+class MassMomentOfInertia(AbstractMeasure):
     """
     A property of body reflects how its mass is distributed with regard to an axis.
 
@@ -158,9 +160,11 @@ class MassMomentOfInertia:
         from_unit (MassMomentOfInertiaUnits): The MassMomentOfInertia unit to create from, The default unit is KilogramSquareMeter
     """
     def __init__(self, value: float, from_unit: MassMomentOfInertiaUnits = MassMomentOfInertiaUnits.KilogramSquareMeter):
-        if math.isnan(value):
-            raise ValueError('Invalid unit: value is NaN')
-        self.__value = self.__convert_to_base(value, from_unit)
+        # Do not validate type, to allow working with numpay arrays and similar objects who supports all arithmetic 
+        # operations, but they are not a number, see #14 
+        # if math.isnan(value):
+        #     raise ValueError('Invalid unit: value is NaN')
+        self._value = self.__convert_to_base(value, from_unit)
         
         self.__gram_square_meters = None
         
@@ -219,8 +223,11 @@ class MassMomentOfInertia:
         self.__megatonne_square_milimeters = None
         
 
+    def convert(self, unit: MassMomentOfInertiaUnits) -> float:
+        return self.__convert_from_base(unit)
+
     def __convert_from_base(self, from_unit: MassMomentOfInertiaUnits) -> float:
-        value = self.__value
+        value = self._value
         
         if from_unit == MassMomentOfInertiaUnits.GramSquareMeter:
             return (value * 1e3)
@@ -400,7 +407,7 @@ class MassMomentOfInertia:
 
     @property
     def base_value(self) -> float:
-        return self.__value
+        return self._value
 
     
     @staticmethod
@@ -1131,7 +1138,7 @@ class MassMomentOfInertia:
         return self.__megatonne_square_milimeters
 
     
-    def to_string(self, unit: MassMomentOfInertiaUnits = MassMomentOfInertiaUnits.KilogramSquareMeter) -> string:
+    def to_string(self, unit: MassMomentOfInertiaUnits = MassMomentOfInertiaUnits.KilogramSquareMeter) -> str:
         """
         Format the MassMomentOfInertia to string.
         Note! the default format for MassMomentOfInertia is KilogramSquareMeter.
@@ -1175,57 +1182,57 @@ class MassMomentOfInertia:
             return f"""{self.slug_square_inches} slug·in²"""
         
         if unit == MassMomentOfInertiaUnits.MilligramSquareMeter:
-            return f"""{self.milligram_square_meters} """
+            return f"""{self.milligram_square_meters} mg·m²"""
         
         if unit == MassMomentOfInertiaUnits.KilogramSquareMeter:
-            return f"""{self.kilogram_square_meters} """
+            return f"""{self.kilogram_square_meters} kg·m²"""
         
         if unit == MassMomentOfInertiaUnits.MilligramSquareDecimeter:
-            return f"""{self.milligram_square_decimeters} """
+            return f"""{self.milligram_square_decimeters} mg·dm²"""
         
         if unit == MassMomentOfInertiaUnits.KilogramSquareDecimeter:
-            return f"""{self.kilogram_square_decimeters} """
+            return f"""{self.kilogram_square_decimeters} kg·dm²"""
         
         if unit == MassMomentOfInertiaUnits.MilligramSquareCentimeter:
-            return f"""{self.milligram_square_centimeters} """
+            return f"""{self.milligram_square_centimeters} mg·cm²"""
         
         if unit == MassMomentOfInertiaUnits.KilogramSquareCentimeter:
-            return f"""{self.kilogram_square_centimeters} """
+            return f"""{self.kilogram_square_centimeters} kg·cm²"""
         
         if unit == MassMomentOfInertiaUnits.MilligramSquareMillimeter:
-            return f"""{self.milligram_square_millimeters} """
+            return f"""{self.milligram_square_millimeters} mg·mm²"""
         
         if unit == MassMomentOfInertiaUnits.KilogramSquareMillimeter:
-            return f"""{self.kilogram_square_millimeters} """
+            return f"""{self.kilogram_square_millimeters} kg·mm²"""
         
         if unit == MassMomentOfInertiaUnits.KilotonneSquareMeter:
-            return f"""{self.kilotonne_square_meters} """
+            return f"""{self.kilotonne_square_meters} kt·m²"""
         
         if unit == MassMomentOfInertiaUnits.MegatonneSquareMeter:
-            return f"""{self.megatonne_square_meters} """
+            return f"""{self.megatonne_square_meters} Mt·m²"""
         
         if unit == MassMomentOfInertiaUnits.KilotonneSquareDecimeter:
-            return f"""{self.kilotonne_square_decimeters} """
+            return f"""{self.kilotonne_square_decimeters} kt·dm²"""
         
         if unit == MassMomentOfInertiaUnits.MegatonneSquareDecimeter:
-            return f"""{self.megatonne_square_decimeters} """
+            return f"""{self.megatonne_square_decimeters} Mt·dm²"""
         
         if unit == MassMomentOfInertiaUnits.KilotonneSquareCentimeter:
-            return f"""{self.kilotonne_square_centimeters} """
+            return f"""{self.kilotonne_square_centimeters} kt·cm²"""
         
         if unit == MassMomentOfInertiaUnits.MegatonneSquareCentimeter:
-            return f"""{self.megatonne_square_centimeters} """
+            return f"""{self.megatonne_square_centimeters} Mt·cm²"""
         
         if unit == MassMomentOfInertiaUnits.KilotonneSquareMilimeter:
-            return f"""{self.kilotonne_square_milimeters} """
+            return f"""{self.kilotonne_square_milimeters} kt·mm²"""
         
         if unit == MassMomentOfInertiaUnits.MegatonneSquareMilimeter:
-            return f"""{self.megatonne_square_milimeters} """
+            return f"""{self.megatonne_square_milimeters} Mt·mm²"""
         
-        return f'{self.__value}'
+        return f'{self._value}'
 
 
-    def get_unit_abbreviation(self, unit_abbreviation: MassMomentOfInertiaUnits = MassMomentOfInertiaUnits.KilogramSquareMeter) -> string:
+    def get_unit_abbreviation(self, unit_abbreviation: MassMomentOfInertiaUnits = MassMomentOfInertiaUnits.KilogramSquareMeter) -> str:
         """
         Get MassMomentOfInertia unit abbreviation.
         Note! the default abbreviation for MassMomentOfInertia is KilogramSquareMeter.
@@ -1269,119 +1276,50 @@ class MassMomentOfInertia:
             return """slug·in²"""
         
         if unit_abbreviation == MassMomentOfInertiaUnits.MilligramSquareMeter:
-            return """"""
+            return """mg·m²"""
         
         if unit_abbreviation == MassMomentOfInertiaUnits.KilogramSquareMeter:
-            return """"""
+            return """kg·m²"""
         
         if unit_abbreviation == MassMomentOfInertiaUnits.MilligramSquareDecimeter:
-            return """"""
+            return """mg·dm²"""
         
         if unit_abbreviation == MassMomentOfInertiaUnits.KilogramSquareDecimeter:
-            return """"""
+            return """kg·dm²"""
         
         if unit_abbreviation == MassMomentOfInertiaUnits.MilligramSquareCentimeter:
-            return """"""
+            return """mg·cm²"""
         
         if unit_abbreviation == MassMomentOfInertiaUnits.KilogramSquareCentimeter:
-            return """"""
+            return """kg·cm²"""
         
         if unit_abbreviation == MassMomentOfInertiaUnits.MilligramSquareMillimeter:
-            return """"""
+            return """mg·mm²"""
         
         if unit_abbreviation == MassMomentOfInertiaUnits.KilogramSquareMillimeter:
-            return """"""
+            return """kg·mm²"""
         
         if unit_abbreviation == MassMomentOfInertiaUnits.KilotonneSquareMeter:
-            return """"""
+            return """kt·m²"""
         
         if unit_abbreviation == MassMomentOfInertiaUnits.MegatonneSquareMeter:
-            return """"""
+            return """Mt·m²"""
         
         if unit_abbreviation == MassMomentOfInertiaUnits.KilotonneSquareDecimeter:
-            return """"""
+            return """kt·dm²"""
         
         if unit_abbreviation == MassMomentOfInertiaUnits.MegatonneSquareDecimeter:
-            return """"""
+            return """Mt·dm²"""
         
         if unit_abbreviation == MassMomentOfInertiaUnits.KilotonneSquareCentimeter:
-            return """"""
+            return """kt·cm²"""
         
         if unit_abbreviation == MassMomentOfInertiaUnits.MegatonneSquareCentimeter:
-            return """"""
+            return """Mt·cm²"""
         
         if unit_abbreviation == MassMomentOfInertiaUnits.KilotonneSquareMilimeter:
-            return """"""
+            return """kt·mm²"""
         
         if unit_abbreviation == MassMomentOfInertiaUnits.MegatonneSquareMilimeter:
-            return """"""
-        
-
-    def __str__(self):
-        return self.to_string()
-
-
-    def __add__(self, other):
-        if not isinstance(other, MassMomentOfInertia):
-            raise TypeError("unsupported operand type(s) for +: 'MassMomentOfInertia' and '{}'".format(type(other).__name__))
-        return MassMomentOfInertia(self.__value + other.__value)
-
-
-    def __mul__(self, other):
-        if not isinstance(other, MassMomentOfInertia):
-            raise TypeError("unsupported operand type(s) for *: 'MassMomentOfInertia' and '{}'".format(type(other).__name__))
-        return MassMomentOfInertia(self.__value * other.__value)
-
-
-    def __sub__(self, other):
-        if not isinstance(other, MassMomentOfInertia):
-            raise TypeError("unsupported operand type(s) for -: 'MassMomentOfInertia' and '{}'".format(type(other).__name__))
-        return MassMomentOfInertia(self.__value - other.__value)
-
-
-    def __truediv__(self, other):
-        if not isinstance(other, MassMomentOfInertia):
-            raise TypeError("unsupported operand type(s) for /: 'MassMomentOfInertia' and '{}'".format(type(other).__name__))
-        return MassMomentOfInertia(self.__value / other.__value)
-
-
-    def __mod__(self, other):
-        if not isinstance(other, MassMomentOfInertia):
-            raise TypeError("unsupported operand type(s) for %: 'MassMomentOfInertia' and '{}'".format(type(other).__name__))
-        return MassMomentOfInertia(self.__value % other.__value)
-
-
-    def __pow__(self, other):
-        if not isinstance(other, MassMomentOfInertia):
-            raise TypeError("unsupported operand type(s) for **: 'MassMomentOfInertia' and '{}'".format(type(other).__name__))
-        return MassMomentOfInertia(self.__value ** other.__value)
-
-
-    def __eq__(self, other):
-        if not isinstance(other, MassMomentOfInertia):
-            raise TypeError("unsupported operand type(s) for ==: 'MassMomentOfInertia' and '{}'".format(type(other).__name__))
-        return self.__value == other.__value
-
-
-    def __lt__(self, other):
-        if not isinstance(other, MassMomentOfInertia):
-            raise TypeError("unsupported operand type(s) for <: 'MassMomentOfInertia' and '{}'".format(type(other).__name__))
-        return self.__value < other.__value
-
-
-    def __gt__(self, other):
-        if not isinstance(other, MassMomentOfInertia):
-            raise TypeError("unsupported operand type(s) for >: 'MassMomentOfInertia' and '{}'".format(type(other).__name__))
-        return self.__value > other.__value
-
-
-    def __le__(self, other):
-        if not isinstance(other, MassMomentOfInertia):
-            raise TypeError("unsupported operand type(s) for <=: 'MassMomentOfInertia' and '{}'".format(type(other).__name__))
-        return self.__value <= other.__value
-
-
-    def __ge__(self, other):
-        if not isinstance(other, MassMomentOfInertia):
-            raise TypeError("unsupported operand type(s) for >=: 'MassMomentOfInertia' and '{}'".format(type(other).__name__))
-        return self.__value >= other.__value
\ No newline at end of file
+            return """Mt·mm²"""
+        
\ No newline at end of file
