@@ -1,6 +1,8 @@
 from enum import Enum
 import math
-import string
+
+from ..abstract_unit import AbstractMeasure
+
 
 
 class MolarMassUnits(Enum):
@@ -74,7 +76,7 @@ class MolarMassUnits(Enum):
         """
         
 
-class MolarMass:
+class MolarMass(AbstractMeasure):
     """
     In chemistry, the molar mass M is a physical property defined as the mass of a given substance (chemical element or chemical compound) divided by the amount of substance.
 
@@ -83,9 +85,11 @@ class MolarMass:
         from_unit (MolarMassUnits): The MolarMass unit to create from, The default unit is KilogramPerMole
     """
     def __init__(self, value: float, from_unit: MolarMassUnits = MolarMassUnits.KilogramPerMole):
-        if math.isnan(value):
-            raise ValueError('Invalid unit: value is NaN')
-        self.__value = self.__convert_to_base(value, from_unit)
+        # Do not validate type, to allow working with numpay arrays and similar objects who supports all arithmetic 
+        # operations, but they are not a number, see #14 
+        # if math.isnan(value):
+        #     raise ValueError('Invalid unit: value is NaN')
+        self._value = self.__convert_to_base(value, from_unit)
         
         self.__grams_per_mole = None
         
@@ -114,8 +118,11 @@ class MolarMass:
         self.__megapounds_per_mole = None
         
 
+    def convert(self, unit: MolarMassUnits) -> float:
+        return self.__convert_from_base(unit)
+
     def __convert_from_base(self, from_unit: MolarMassUnits) -> float:
-        value = self.__value
+        value = self._value
         
         if from_unit == MolarMassUnits.GramPerMole:
             return (value * 1e3)
@@ -205,7 +212,7 @@ class MolarMass:
 
     @property
     def base_value(self) -> float:
-        return self.__value
+        return self._value
 
     
     @staticmethod
@@ -546,7 +553,7 @@ class MolarMass:
         return self.__megapounds_per_mole
 
     
-    def to_string(self, unit: MolarMassUnits = MolarMassUnits.KilogramPerMole) -> string:
+    def to_string(self, unit: MolarMassUnits = MolarMassUnits.KilogramPerMole) -> str:
         """
         Format the MolarMass to string.
         Note! the default format for MolarMass is KilogramPerMole.
@@ -563,39 +570,39 @@ class MolarMass:
             return f"""{self.pounds_per_mole} lb/mol"""
         
         if unit == MolarMassUnits.NanogramPerMole:
-            return f"""{self.nanograms_per_mole} """
+            return f"""{self.nanograms_per_mole} ng/mol"""
         
         if unit == MolarMassUnits.MicrogramPerMole:
-            return f"""{self.micrograms_per_mole} """
+            return f"""{self.micrograms_per_mole} μg/mol"""
         
         if unit == MolarMassUnits.MilligramPerMole:
-            return f"""{self.milligrams_per_mole} """
+            return f"""{self.milligrams_per_mole} mg/mol"""
         
         if unit == MolarMassUnits.CentigramPerMole:
-            return f"""{self.centigrams_per_mole} """
+            return f"""{self.centigrams_per_mole} cg/mol"""
         
         if unit == MolarMassUnits.DecigramPerMole:
-            return f"""{self.decigrams_per_mole} """
+            return f"""{self.decigrams_per_mole} dg/mol"""
         
         if unit == MolarMassUnits.DecagramPerMole:
-            return f"""{self.decagrams_per_mole} """
+            return f"""{self.decagrams_per_mole} dag/mol"""
         
         if unit == MolarMassUnits.HectogramPerMole:
-            return f"""{self.hectograms_per_mole} """
+            return f"""{self.hectograms_per_mole} hg/mol"""
         
         if unit == MolarMassUnits.KilogramPerMole:
-            return f"""{self.kilograms_per_mole} """
+            return f"""{self.kilograms_per_mole} kg/mol"""
         
         if unit == MolarMassUnits.KilopoundPerMole:
-            return f"""{self.kilopounds_per_mole} """
+            return f"""{self.kilopounds_per_mole} klb/mol"""
         
         if unit == MolarMassUnits.MegapoundPerMole:
-            return f"""{self.megapounds_per_mole} """
+            return f"""{self.megapounds_per_mole} Mlb/mol"""
         
-        return f'{self.__value}'
+        return f'{self._value}'
 
 
-    def get_unit_abbreviation(self, unit_abbreviation: MolarMassUnits = MolarMassUnits.KilogramPerMole) -> string:
+    def get_unit_abbreviation(self, unit_abbreviation: MolarMassUnits = MolarMassUnits.KilogramPerMole) -> str:
         """
         Get MolarMass unit abbreviation.
         Note! the default abbreviation for MolarMass is KilogramPerMole.
@@ -612,101 +619,32 @@ class MolarMass:
             return """lb/mol"""
         
         if unit_abbreviation == MolarMassUnits.NanogramPerMole:
-            return """"""
+            return """ng/mol"""
         
         if unit_abbreviation == MolarMassUnits.MicrogramPerMole:
-            return """"""
+            return """μg/mol"""
         
         if unit_abbreviation == MolarMassUnits.MilligramPerMole:
-            return """"""
+            return """mg/mol"""
         
         if unit_abbreviation == MolarMassUnits.CentigramPerMole:
-            return """"""
+            return """cg/mol"""
         
         if unit_abbreviation == MolarMassUnits.DecigramPerMole:
-            return """"""
+            return """dg/mol"""
         
         if unit_abbreviation == MolarMassUnits.DecagramPerMole:
-            return """"""
+            return """dag/mol"""
         
         if unit_abbreviation == MolarMassUnits.HectogramPerMole:
-            return """"""
+            return """hg/mol"""
         
         if unit_abbreviation == MolarMassUnits.KilogramPerMole:
-            return """"""
+            return """kg/mol"""
         
         if unit_abbreviation == MolarMassUnits.KilopoundPerMole:
-            return """"""
+            return """klb/mol"""
         
         if unit_abbreviation == MolarMassUnits.MegapoundPerMole:
-            return """"""
-        
-
-    def __str__(self):
-        return self.to_string()
-
-
-    def __add__(self, other):
-        if not isinstance(other, MolarMass):
-            raise TypeError("unsupported operand type(s) for +: 'MolarMass' and '{}'".format(type(other).__name__))
-        return MolarMass(self.__value + other.__value)
-
-
-    def __mul__(self, other):
-        if not isinstance(other, MolarMass):
-            raise TypeError("unsupported operand type(s) for *: 'MolarMass' and '{}'".format(type(other).__name__))
-        return MolarMass(self.__value * other.__value)
-
-
-    def __sub__(self, other):
-        if not isinstance(other, MolarMass):
-            raise TypeError("unsupported operand type(s) for -: 'MolarMass' and '{}'".format(type(other).__name__))
-        return MolarMass(self.__value - other.__value)
-
-
-    def __truediv__(self, other):
-        if not isinstance(other, MolarMass):
-            raise TypeError("unsupported operand type(s) for /: 'MolarMass' and '{}'".format(type(other).__name__))
-        return MolarMass(self.__value / other.__value)
-
-
-    def __mod__(self, other):
-        if not isinstance(other, MolarMass):
-            raise TypeError("unsupported operand type(s) for %: 'MolarMass' and '{}'".format(type(other).__name__))
-        return MolarMass(self.__value % other.__value)
-
-
-    def __pow__(self, other):
-        if not isinstance(other, MolarMass):
-            raise TypeError("unsupported operand type(s) for **: 'MolarMass' and '{}'".format(type(other).__name__))
-        return MolarMass(self.__value ** other.__value)
-
-
-    def __eq__(self, other):
-        if not isinstance(other, MolarMass):
-            raise TypeError("unsupported operand type(s) for ==: 'MolarMass' and '{}'".format(type(other).__name__))
-        return self.__value == other.__value
-
-
-    def __lt__(self, other):
-        if not isinstance(other, MolarMass):
-            raise TypeError("unsupported operand type(s) for <: 'MolarMass' and '{}'".format(type(other).__name__))
-        return self.__value < other.__value
-
-
-    def __gt__(self, other):
-        if not isinstance(other, MolarMass):
-            raise TypeError("unsupported operand type(s) for >: 'MolarMass' and '{}'".format(type(other).__name__))
-        return self.__value > other.__value
-
-
-    def __le__(self, other):
-        if not isinstance(other, MolarMass):
-            raise TypeError("unsupported operand type(s) for <=: 'MolarMass' and '{}'".format(type(other).__name__))
-        return self.__value <= other.__value
-
-
-    def __ge__(self, other):
-        if not isinstance(other, MolarMass):
-            raise TypeError("unsupported operand type(s) for >=: 'MolarMass' and '{}'".format(type(other).__name__))
-        return self.__value >= other.__value
\ No newline at end of file
+            return """Mlb/mol"""
+        
\ No newline at end of file
