@@ -1,6 +1,8 @@
 from enum import Enum
 import math
-import string
+
+from ..abstract_unit import AbstractMeasure
+
 
 
 class MolarityUnits(Enum):
@@ -64,18 +66,20 @@ class MolarityUnits(Enum):
         """
         
 
-class Molarity:
+class Molarity(AbstractMeasure):
     """
-    Molar concentration, also called molarity, amount concentration or substance concentration, is a measure of the concentration of a solute in a solution, or of any chemical species, in terms of amount of substance in a given volume. 
+    Molar concentration, also called molarity, amount concentration or substance concentration, is a measure of the concentration of a solute in a solution, or of any chemical species, in terms of amount of substance in a given volume.
 
     Args:
         value (float): The value.
         from_unit (MolarityUnits): The Molarity unit to create from, The default unit is MolePerCubicMeter
     """
     def __init__(self, value: float, from_unit: MolarityUnits = MolarityUnits.MolePerCubicMeter):
-        if math.isnan(value):
-            raise ValueError('Invalid unit: value is NaN')
-        self.__value = self.__convert_to_base(value, from_unit)
+        # Do not validate type, to allow working with numpay arrays and similar objects who supports all arithmetic 
+        # operations, but they are not a number, see #14 
+        # if math.isnan(value):
+        #     raise ValueError('Invalid unit: value is NaN')
+        self._value = self.__convert_to_base(value, from_unit)
         
         self.__moles_per_cubic_meter = None
         
@@ -100,8 +104,11 @@ class Molarity:
         self.__decimoles_per_liter = None
         
 
+    def convert(self, unit: MolarityUnits) -> float:
+        return self.__convert_from_base(unit)
+
     def __convert_from_base(self, from_unit: MolarityUnits) -> float:
-        value = self.__value
+        value = self._value
         
         if from_unit == MolarityUnits.MolePerCubicMeter:
             return (value)
@@ -179,7 +186,7 @@ class Molarity:
 
     @property
     def base_value(self) -> float:
-        return self.__value
+        return self._value
 
     
     @staticmethod
@@ -468,7 +475,7 @@ class Molarity:
         return self.__decimoles_per_liter
 
     
-    def to_string(self, unit: MolarityUnits = MolarityUnits.MolePerCubicMeter) -> string:
+    def to_string(self, unit: MolarityUnits = MolarityUnits.MolePerCubicMeter) -> str:
         """
         Format the Molarity to string.
         Note! the default format for Molarity is MolePerCubicMeter.
@@ -485,33 +492,33 @@ class Molarity:
             return f"""{self.pound_moles_per_cubic_foot} lbmol/ft³"""
         
         if unit == MolarityUnits.KilomolePerCubicMeter:
-            return f"""{self.kilomoles_per_cubic_meter} """
+            return f"""{self.kilomoles_per_cubic_meter} kmol/m³"""
         
         if unit == MolarityUnits.FemtomolePerLiter:
-            return f"""{self.femtomoles_per_liter} """
+            return f"""{self.femtomoles_per_liter} fmol/L"""
         
         if unit == MolarityUnits.PicomolePerLiter:
-            return f"""{self.picomoles_per_liter} """
+            return f"""{self.picomoles_per_liter} pmol/L"""
         
         if unit == MolarityUnits.NanomolePerLiter:
-            return f"""{self.nanomoles_per_liter} """
+            return f"""{self.nanomoles_per_liter} nmol/L"""
         
         if unit == MolarityUnits.MicromolePerLiter:
-            return f"""{self.micromoles_per_liter} """
+            return f"""{self.micromoles_per_liter} μmol/L"""
         
         if unit == MolarityUnits.MillimolePerLiter:
-            return f"""{self.millimoles_per_liter} """
+            return f"""{self.millimoles_per_liter} mmol/L"""
         
         if unit == MolarityUnits.CentimolePerLiter:
-            return f"""{self.centimoles_per_liter} """
+            return f"""{self.centimoles_per_liter} cmol/L"""
         
         if unit == MolarityUnits.DecimolePerLiter:
-            return f"""{self.decimoles_per_liter} """
+            return f"""{self.decimoles_per_liter} dmol/L"""
         
-        return f'{self.__value}'
+        return f'{self._value}'
 
 
-    def get_unit_abbreviation(self, unit_abbreviation: MolarityUnits = MolarityUnits.MolePerCubicMeter) -> string:
+    def get_unit_abbreviation(self, unit_abbreviation: MolarityUnits = MolarityUnits.MolePerCubicMeter) -> str:
         """
         Get Molarity unit abbreviation.
         Note! the default abbreviation for Molarity is MolePerCubicMeter.
@@ -528,95 +535,26 @@ class Molarity:
             return """lbmol/ft³"""
         
         if unit_abbreviation == MolarityUnits.KilomolePerCubicMeter:
-            return """"""
+            return """kmol/m³"""
         
         if unit_abbreviation == MolarityUnits.FemtomolePerLiter:
-            return """"""
+            return """fmol/L"""
         
         if unit_abbreviation == MolarityUnits.PicomolePerLiter:
-            return """"""
+            return """pmol/L"""
         
         if unit_abbreviation == MolarityUnits.NanomolePerLiter:
-            return """"""
+            return """nmol/L"""
         
         if unit_abbreviation == MolarityUnits.MicromolePerLiter:
-            return """"""
+            return """μmol/L"""
         
         if unit_abbreviation == MolarityUnits.MillimolePerLiter:
-            return """"""
+            return """mmol/L"""
         
         if unit_abbreviation == MolarityUnits.CentimolePerLiter:
-            return """"""
+            return """cmol/L"""
         
         if unit_abbreviation == MolarityUnits.DecimolePerLiter:
-            return """"""
-        
-
-    def __str__(self):
-        return self.to_string()
-
-
-    def __add__(self, other):
-        if not isinstance(other, Molarity):
-            raise TypeError("unsupported operand type(s) for +: 'Molarity' and '{}'".format(type(other).__name__))
-        return Molarity(self.__value + other.__value)
-
-
-    def __mul__(self, other):
-        if not isinstance(other, Molarity):
-            raise TypeError("unsupported operand type(s) for *: 'Molarity' and '{}'".format(type(other).__name__))
-        return Molarity(self.__value * other.__value)
-
-
-    def __sub__(self, other):
-        if not isinstance(other, Molarity):
-            raise TypeError("unsupported operand type(s) for -: 'Molarity' and '{}'".format(type(other).__name__))
-        return Molarity(self.__value - other.__value)
-
-
-    def __truediv__(self, other):
-        if not isinstance(other, Molarity):
-            raise TypeError("unsupported operand type(s) for /: 'Molarity' and '{}'".format(type(other).__name__))
-        return Molarity(self.__value / other.__value)
-
-
-    def __mod__(self, other):
-        if not isinstance(other, Molarity):
-            raise TypeError("unsupported operand type(s) for %: 'Molarity' and '{}'".format(type(other).__name__))
-        return Molarity(self.__value % other.__value)
-
-
-    def __pow__(self, other):
-        if not isinstance(other, Molarity):
-            raise TypeError("unsupported operand type(s) for **: 'Molarity' and '{}'".format(type(other).__name__))
-        return Molarity(self.__value ** other.__value)
-
-
-    def __eq__(self, other):
-        if not isinstance(other, Molarity):
-            raise TypeError("unsupported operand type(s) for ==: 'Molarity' and '{}'".format(type(other).__name__))
-        return self.__value == other.__value
-
-
-    def __lt__(self, other):
-        if not isinstance(other, Molarity):
-            raise TypeError("unsupported operand type(s) for <: 'Molarity' and '{}'".format(type(other).__name__))
-        return self.__value < other.__value
-
-
-    def __gt__(self, other):
-        if not isinstance(other, Molarity):
-            raise TypeError("unsupported operand type(s) for >: 'Molarity' and '{}'".format(type(other).__name__))
-        return self.__value > other.__value
-
-
-    def __le__(self, other):
-        if not isinstance(other, Molarity):
-            raise TypeError("unsupported operand type(s) for <=: 'Molarity' and '{}'".format(type(other).__name__))
-        return self.__value <= other.__value
-
-
-    def __ge__(self, other):
-        if not isinstance(other, Molarity):
-            raise TypeError("unsupported operand type(s) for >=: 'Molarity' and '{}'".format(type(other).__name__))
-        return self.__value >= other.__value
\ No newline at end of file
+            return """dmol/L"""
+        
\ No newline at end of file
