@@ -1,6 +1,8 @@
 from enum import Enum
 import math
-import string
+
+from ..abstract_unit import AbstractMeasure
+
 
 
 class PowerUnits(Enum):
@@ -139,7 +141,7 @@ class PowerUnits(Enum):
         """
         
 
-class Power:
+class Power(AbstractMeasure):
     """
     In physics, power is the rate of doing work. It is equivalent to an amount of energy consumed per unit time.
 
@@ -148,9 +150,11 @@ class Power:
         from_unit (PowerUnits): The Power unit to create from, The default unit is Watt
     """
     def __init__(self, value: float, from_unit: PowerUnits = PowerUnits.Watt):
-        if math.isnan(value):
-            raise ValueError('Invalid unit: value is NaN')
-        self.__value = self.__convert_to_base(value, from_unit)
+        # Do not validate type, to allow working with numpay arrays and similar objects who supports all arithmetic 
+        # operations, but they are not a number, see #14 
+        # if math.isnan(value):
+        #     raise ValueError('Invalid unit: value is NaN')
+        self._value = self.__convert_to_base(value, from_unit)
         
         self.__watts = None
         
@@ -205,8 +209,11 @@ class Power:
         self.__gigajoules_per_hour = None
         
 
+    def convert(self, unit: PowerUnits) -> float:
+        return self.__convert_from_base(unit)
+
     def __convert_from_base(self, from_unit: PowerUnits) -> float:
-        value = self.__value
+        value = self._value
         
         if from_unit == PowerUnits.Watt:
             return (value)
@@ -374,7 +381,7 @@ class Power:
 
     @property
     def base_value(self) -> float:
-        return self.__value
+        return self._value
 
     
     @staticmethod
@@ -1053,7 +1060,7 @@ class Power:
         return self.__gigajoules_per_hour
 
     
-    def to_string(self, unit: PowerUnits = PowerUnits.Watt) -> string:
+    def to_string(self, unit: PowerUnits = PowerUnits.Watt) -> str:
         """
         Format the Power to string.
         Note! the default format for Power is Watt.
@@ -1085,63 +1092,63 @@ class Power:
             return f"""{self.joules_per_hour} J/h"""
         
         if unit == PowerUnits.Femtowatt:
-            return f"""{self.femtowatts} """
+            return f"""{self.femtowatts} fW"""
         
         if unit == PowerUnits.Picowatt:
-            return f"""{self.picowatts} """
+            return f"""{self.picowatts} pW"""
         
         if unit == PowerUnits.Nanowatt:
-            return f"""{self.nanowatts} """
+            return f"""{self.nanowatts} nW"""
         
         if unit == PowerUnits.Microwatt:
-            return f"""{self.microwatts} """
+            return f"""{self.microwatts} μW"""
         
         if unit == PowerUnits.Milliwatt:
-            return f"""{self.milliwatts} """
+            return f"""{self.milliwatts} mW"""
         
         if unit == PowerUnits.Deciwatt:
-            return f"""{self.deciwatts} """
+            return f"""{self.deciwatts} dW"""
         
         if unit == PowerUnits.Decawatt:
-            return f"""{self.decawatts} """
+            return f"""{self.decawatts} daW"""
         
         if unit == PowerUnits.Kilowatt:
-            return f"""{self.kilowatts} """
+            return f"""{self.kilowatts} kW"""
         
         if unit == PowerUnits.Megawatt:
-            return f"""{self.megawatts} """
+            return f"""{self.megawatts} MW"""
         
         if unit == PowerUnits.Gigawatt:
-            return f"""{self.gigawatts} """
+            return f"""{self.gigawatts} GW"""
         
         if unit == PowerUnits.Terawatt:
-            return f"""{self.terawatts} """
+            return f"""{self.terawatts} TW"""
         
         if unit == PowerUnits.Petawatt:
-            return f"""{self.petawatts} """
+            return f"""{self.petawatts} PW"""
         
         if unit == PowerUnits.KilobritishThermalUnitPerHour:
-            return f"""{self.kilobritish_thermal_units_per_hour} """
+            return f"""{self.kilobritish_thermal_units_per_hour} kBtu/h"""
         
         if unit == PowerUnits.MegabritishThermalUnitPerHour:
-            return f"""{self.megabritish_thermal_units_per_hour} """
+            return f"""{self.megabritish_thermal_units_per_hour} MBtu/h"""
         
         if unit == PowerUnits.MillijoulePerHour:
-            return f"""{self.millijoules_per_hour} """
+            return f"""{self.millijoules_per_hour} mJ/h"""
         
         if unit == PowerUnits.KilojoulePerHour:
-            return f"""{self.kilojoules_per_hour} """
+            return f"""{self.kilojoules_per_hour} kJ/h"""
         
         if unit == PowerUnits.MegajoulePerHour:
-            return f"""{self.megajoules_per_hour} """
+            return f"""{self.megajoules_per_hour} MJ/h"""
         
         if unit == PowerUnits.GigajoulePerHour:
-            return f"""{self.gigajoules_per_hour} """
+            return f"""{self.gigajoules_per_hour} GJ/h"""
         
-        return f'{self.__value}'
+        return f'{self._value}'
 
 
-    def get_unit_abbreviation(self, unit_abbreviation: PowerUnits = PowerUnits.Watt) -> string:
+    def get_unit_abbreviation(self, unit_abbreviation: PowerUnits = PowerUnits.Watt) -> str:
         """
         Get Power unit abbreviation.
         Note! the default abbreviation for Power is Watt.
@@ -1173,125 +1180,56 @@ class Power:
             return """J/h"""
         
         if unit_abbreviation == PowerUnits.Femtowatt:
-            return """"""
+            return """fW"""
         
         if unit_abbreviation == PowerUnits.Picowatt:
-            return """"""
+            return """pW"""
         
         if unit_abbreviation == PowerUnits.Nanowatt:
-            return """"""
+            return """nW"""
         
         if unit_abbreviation == PowerUnits.Microwatt:
-            return """"""
+            return """μW"""
         
         if unit_abbreviation == PowerUnits.Milliwatt:
-            return """"""
+            return """mW"""
         
         if unit_abbreviation == PowerUnits.Deciwatt:
-            return """"""
+            return """dW"""
         
         if unit_abbreviation == PowerUnits.Decawatt:
-            return """"""
+            return """daW"""
         
         if unit_abbreviation == PowerUnits.Kilowatt:
-            return """"""
+            return """kW"""
         
         if unit_abbreviation == PowerUnits.Megawatt:
-            return """"""
+            return """MW"""
         
         if unit_abbreviation == PowerUnits.Gigawatt:
-            return """"""
+            return """GW"""
         
         if unit_abbreviation == PowerUnits.Terawatt:
-            return """"""
+            return """TW"""
         
         if unit_abbreviation == PowerUnits.Petawatt:
-            return """"""
+            return """PW"""
         
         if unit_abbreviation == PowerUnits.KilobritishThermalUnitPerHour:
-            return """"""
+            return """kBtu/h"""
         
         if unit_abbreviation == PowerUnits.MegabritishThermalUnitPerHour:
-            return """"""
+            return """MBtu/h"""
         
         if unit_abbreviation == PowerUnits.MillijoulePerHour:
-            return """"""
+            return """mJ/h"""
         
         if unit_abbreviation == PowerUnits.KilojoulePerHour:
-            return """"""
+            return """kJ/h"""
         
         if unit_abbreviation == PowerUnits.MegajoulePerHour:
-            return """"""
+            return """MJ/h"""
         
         if unit_abbreviation == PowerUnits.GigajoulePerHour:
-            return """"""
-        
-
-    def __str__(self):
-        return self.to_string()
-
-
-    def __add__(self, other):
-        if not isinstance(other, Power):
-            raise TypeError("unsupported operand type(s) for +: 'Power' and '{}'".format(type(other).__name__))
-        return Power(self.__value + other.__value)
-
-
-    def __mul__(self, other):
-        if not isinstance(other, Power):
-            raise TypeError("unsupported operand type(s) for *: 'Power' and '{}'".format(type(other).__name__))
-        return Power(self.__value * other.__value)
-
-
-    def __sub__(self, other):
-        if not isinstance(other, Power):
-            raise TypeError("unsupported operand type(s) for -: 'Power' and '{}'".format(type(other).__name__))
-        return Power(self.__value - other.__value)
-
-
-    def __truediv__(self, other):
-        if not isinstance(other, Power):
-            raise TypeError("unsupported operand type(s) for /: 'Power' and '{}'".format(type(other).__name__))
-        return Power(self.__value / other.__value)
-
-
-    def __mod__(self, other):
-        if not isinstance(other, Power):
-            raise TypeError("unsupported operand type(s) for %: 'Power' and '{}'".format(type(other).__name__))
-        return Power(self.__value % other.__value)
-
-
-    def __pow__(self, other):
-        if not isinstance(other, Power):
-            raise TypeError("unsupported operand type(s) for **: 'Power' and '{}'".format(type(other).__name__))
-        return Power(self.__value ** other.__value)
-
-
-    def __eq__(self, other):
-        if not isinstance(other, Power):
-            raise TypeError("unsupported operand type(s) for ==: 'Power' and '{}'".format(type(other).__name__))
-        return self.__value == other.__value
-
-
-    def __lt__(self, other):
-        if not isinstance(other, Power):
-            raise TypeError("unsupported operand type(s) for <: 'Power' and '{}'".format(type(other).__name__))
-        return self.__value < other.__value
-
-
-    def __gt__(self, other):
-        if not isinstance(other, Power):
-            raise TypeError("unsupported operand type(s) for >: 'Power' and '{}'".format(type(other).__name__))
-        return self.__value > other.__value
-
-
-    def __le__(self, other):
-        if not isinstance(other, Power):
-            raise TypeError("unsupported operand type(s) for <=: 'Power' and '{}'".format(type(other).__name__))
-        return self.__value <= other.__value
-
-
-    def __ge__(self, other):
-        if not isinstance(other, Power):
-            raise TypeError("unsupported operand type(s) for >=: 'Power' and '{}'".format(type(other).__name__))
-        return self.__value >= other.__value
\ No newline at end of file
+            return """GJ/h"""
+        
\ No newline at end of file
