@@ -1,6 +1,8 @@
 from enum import Enum
 import math
-import string
+
+from ..abstract_unit import AbstractMeasure
+
 
 
 class PowerDensityUnits(Enum):
@@ -229,7 +231,7 @@ class PowerDensityUnits(Enum):
         """
         
 
-class PowerDensity:
+class PowerDensity(AbstractMeasure):
     """
     The amount of power in a volume.
 
@@ -238,9 +240,11 @@ class PowerDensity:
         from_unit (PowerDensityUnits): The PowerDensity unit to create from, The default unit is WattPerCubicMeter
     """
     def __init__(self, value: float, from_unit: PowerDensityUnits = PowerDensityUnits.WattPerCubicMeter):
-        if math.isnan(value):
-            raise ValueError('Invalid unit: value is NaN')
-        self.__value = self.__convert_to_base(value, from_unit)
+        # Do not validate type, to allow working with numpay arrays and similar objects who supports all arithmetic 
+        # operations, but they are not a number, see #14 
+        # if math.isnan(value):
+        #     raise ValueError('Invalid unit: value is NaN')
+        self._value = self.__convert_to_base(value, from_unit)
         
         self.__watts_per_cubic_meter = None
         
@@ -331,8 +335,11 @@ class PowerDensity:
         self.__terawatts_per_liter = None
         
 
+    def convert(self, unit: PowerDensityUnits) -> float:
+        return self.__convert_from_base(unit)
+
     def __convert_from_base(self, from_unit: PowerDensityUnits) -> float:
-        value = self.__value
+        value = self._value
         
         if from_unit == PowerDensityUnits.WattPerCubicMeter:
             return (value)
@@ -608,7 +615,7 @@ class PowerDensity:
 
     @property
     def base_value(self) -> float:
-        return self.__value
+        return self._value
 
     
     @staticmethod
@@ -1755,7 +1762,7 @@ class PowerDensity:
         return self.__terawatts_per_liter
 
     
-    def to_string(self, unit: PowerDensityUnits = PowerDensityUnits.WattPerCubicMeter) -> string:
+    def to_string(self, unit: PowerDensityUnits = PowerDensityUnits.WattPerCubicMeter) -> str:
         """
         Format the PowerDensity to string.
         Note! the default format for PowerDensity is WattPerCubicMeter.
@@ -1775,129 +1782,129 @@ class PowerDensity:
             return f"""{self.watts_per_liter} W/l"""
         
         if unit == PowerDensityUnits.PicowattPerCubicMeter:
-            return f"""{self.picowatts_per_cubic_meter} """
+            return f"""{self.picowatts_per_cubic_meter} pW/m³"""
         
         if unit == PowerDensityUnits.NanowattPerCubicMeter:
-            return f"""{self.nanowatts_per_cubic_meter} """
+            return f"""{self.nanowatts_per_cubic_meter} nW/m³"""
         
         if unit == PowerDensityUnits.MicrowattPerCubicMeter:
-            return f"""{self.microwatts_per_cubic_meter} """
+            return f"""{self.microwatts_per_cubic_meter} μW/m³"""
         
         if unit == PowerDensityUnits.MilliwattPerCubicMeter:
-            return f"""{self.milliwatts_per_cubic_meter} """
+            return f"""{self.milliwatts_per_cubic_meter} mW/m³"""
         
         if unit == PowerDensityUnits.DeciwattPerCubicMeter:
-            return f"""{self.deciwatts_per_cubic_meter} """
+            return f"""{self.deciwatts_per_cubic_meter} dW/m³"""
         
         if unit == PowerDensityUnits.DecawattPerCubicMeter:
-            return f"""{self.decawatts_per_cubic_meter} """
+            return f"""{self.decawatts_per_cubic_meter} daW/m³"""
         
         if unit == PowerDensityUnits.KilowattPerCubicMeter:
-            return f"""{self.kilowatts_per_cubic_meter} """
+            return f"""{self.kilowatts_per_cubic_meter} kW/m³"""
         
         if unit == PowerDensityUnits.MegawattPerCubicMeter:
-            return f"""{self.megawatts_per_cubic_meter} """
+            return f"""{self.megawatts_per_cubic_meter} MW/m³"""
         
         if unit == PowerDensityUnits.GigawattPerCubicMeter:
-            return f"""{self.gigawatts_per_cubic_meter} """
+            return f"""{self.gigawatts_per_cubic_meter} GW/m³"""
         
         if unit == PowerDensityUnits.TerawattPerCubicMeter:
-            return f"""{self.terawatts_per_cubic_meter} """
+            return f"""{self.terawatts_per_cubic_meter} TW/m³"""
         
         if unit == PowerDensityUnits.PicowattPerCubicInch:
-            return f"""{self.picowatts_per_cubic_inch} """
+            return f"""{self.picowatts_per_cubic_inch} pW/in³"""
         
         if unit == PowerDensityUnits.NanowattPerCubicInch:
-            return f"""{self.nanowatts_per_cubic_inch} """
+            return f"""{self.nanowatts_per_cubic_inch} nW/in³"""
         
         if unit == PowerDensityUnits.MicrowattPerCubicInch:
-            return f"""{self.microwatts_per_cubic_inch} """
+            return f"""{self.microwatts_per_cubic_inch} μW/in³"""
         
         if unit == PowerDensityUnits.MilliwattPerCubicInch:
-            return f"""{self.milliwatts_per_cubic_inch} """
+            return f"""{self.milliwatts_per_cubic_inch} mW/in³"""
         
         if unit == PowerDensityUnits.DeciwattPerCubicInch:
-            return f"""{self.deciwatts_per_cubic_inch} """
+            return f"""{self.deciwatts_per_cubic_inch} dW/in³"""
         
         if unit == PowerDensityUnits.DecawattPerCubicInch:
-            return f"""{self.decawatts_per_cubic_inch} """
+            return f"""{self.decawatts_per_cubic_inch} daW/in³"""
         
         if unit == PowerDensityUnits.KilowattPerCubicInch:
-            return f"""{self.kilowatts_per_cubic_inch} """
+            return f"""{self.kilowatts_per_cubic_inch} kW/in³"""
         
         if unit == PowerDensityUnits.MegawattPerCubicInch:
-            return f"""{self.megawatts_per_cubic_inch} """
+            return f"""{self.megawatts_per_cubic_inch} MW/in³"""
         
         if unit == PowerDensityUnits.GigawattPerCubicInch:
-            return f"""{self.gigawatts_per_cubic_inch} """
+            return f"""{self.gigawatts_per_cubic_inch} GW/in³"""
         
         if unit == PowerDensityUnits.TerawattPerCubicInch:
-            return f"""{self.terawatts_per_cubic_inch} """
+            return f"""{self.terawatts_per_cubic_inch} TW/in³"""
         
         if unit == PowerDensityUnits.PicowattPerCubicFoot:
-            return f"""{self.picowatts_per_cubic_foot} """
+            return f"""{self.picowatts_per_cubic_foot} pW/ft³"""
         
         if unit == PowerDensityUnits.NanowattPerCubicFoot:
-            return f"""{self.nanowatts_per_cubic_foot} """
+            return f"""{self.nanowatts_per_cubic_foot} nW/ft³"""
         
         if unit == PowerDensityUnits.MicrowattPerCubicFoot:
-            return f"""{self.microwatts_per_cubic_foot} """
+            return f"""{self.microwatts_per_cubic_foot} μW/ft³"""
         
         if unit == PowerDensityUnits.MilliwattPerCubicFoot:
-            return f"""{self.milliwatts_per_cubic_foot} """
+            return f"""{self.milliwatts_per_cubic_foot} mW/ft³"""
         
         if unit == PowerDensityUnits.DeciwattPerCubicFoot:
-            return f"""{self.deciwatts_per_cubic_foot} """
+            return f"""{self.deciwatts_per_cubic_foot} dW/ft³"""
         
         if unit == PowerDensityUnits.DecawattPerCubicFoot:
-            return f"""{self.decawatts_per_cubic_foot} """
+            return f"""{self.decawatts_per_cubic_foot} daW/ft³"""
         
         if unit == PowerDensityUnits.KilowattPerCubicFoot:
-            return f"""{self.kilowatts_per_cubic_foot} """
+            return f"""{self.kilowatts_per_cubic_foot} kW/ft³"""
         
         if unit == PowerDensityUnits.MegawattPerCubicFoot:
-            return f"""{self.megawatts_per_cubic_foot} """
+            return f"""{self.megawatts_per_cubic_foot} MW/ft³"""
         
         if unit == PowerDensityUnits.GigawattPerCubicFoot:
-            return f"""{self.gigawatts_per_cubic_foot} """
+            return f"""{self.gigawatts_per_cubic_foot} GW/ft³"""
         
         if unit == PowerDensityUnits.TerawattPerCubicFoot:
-            return f"""{self.terawatts_per_cubic_foot} """
+            return f"""{self.terawatts_per_cubic_foot} TW/ft³"""
         
         if unit == PowerDensityUnits.PicowattPerLiter:
-            return f"""{self.picowatts_per_liter} """
+            return f"""{self.picowatts_per_liter} pW/l"""
         
         if unit == PowerDensityUnits.NanowattPerLiter:
-            return f"""{self.nanowatts_per_liter} """
+            return f"""{self.nanowatts_per_liter} nW/l"""
         
         if unit == PowerDensityUnits.MicrowattPerLiter:
-            return f"""{self.microwatts_per_liter} """
+            return f"""{self.microwatts_per_liter} μW/l"""
         
         if unit == PowerDensityUnits.MilliwattPerLiter:
-            return f"""{self.milliwatts_per_liter} """
+            return f"""{self.milliwatts_per_liter} mW/l"""
         
         if unit == PowerDensityUnits.DeciwattPerLiter:
-            return f"""{self.deciwatts_per_liter} """
+            return f"""{self.deciwatts_per_liter} dW/l"""
         
         if unit == PowerDensityUnits.DecawattPerLiter:
-            return f"""{self.decawatts_per_liter} """
+            return f"""{self.decawatts_per_liter} daW/l"""
         
         if unit == PowerDensityUnits.KilowattPerLiter:
-            return f"""{self.kilowatts_per_liter} """
+            return f"""{self.kilowatts_per_liter} kW/l"""
         
         if unit == PowerDensityUnits.MegawattPerLiter:
-            return f"""{self.megawatts_per_liter} """
+            return f"""{self.megawatts_per_liter} MW/l"""
         
         if unit == PowerDensityUnits.GigawattPerLiter:
-            return f"""{self.gigawatts_per_liter} """
+            return f"""{self.gigawatts_per_liter} GW/l"""
         
         if unit == PowerDensityUnits.TerawattPerLiter:
-            return f"""{self.terawatts_per_liter} """
+            return f"""{self.terawatts_per_liter} TW/l"""
         
-        return f'{self.__value}'
+        return f'{self._value}'
 
 
-    def get_unit_abbreviation(self, unit_abbreviation: PowerDensityUnits = PowerDensityUnits.WattPerCubicMeter) -> string:
+    def get_unit_abbreviation(self, unit_abbreviation: PowerDensityUnits = PowerDensityUnits.WattPerCubicMeter) -> str:
         """
         Get PowerDensity unit abbreviation.
         Note! the default abbreviation for PowerDensity is WattPerCubicMeter.
@@ -1917,191 +1924,122 @@ class PowerDensity:
             return """W/l"""
         
         if unit_abbreviation == PowerDensityUnits.PicowattPerCubicMeter:
-            return """"""
+            return """pW/m³"""
         
         if unit_abbreviation == PowerDensityUnits.NanowattPerCubicMeter:
-            return """"""
+            return """nW/m³"""
         
         if unit_abbreviation == PowerDensityUnits.MicrowattPerCubicMeter:
-            return """"""
+            return """μW/m³"""
         
         if unit_abbreviation == PowerDensityUnits.MilliwattPerCubicMeter:
-            return """"""
+            return """mW/m³"""
         
         if unit_abbreviation == PowerDensityUnits.DeciwattPerCubicMeter:
-            return """"""
+            return """dW/m³"""
         
         if unit_abbreviation == PowerDensityUnits.DecawattPerCubicMeter:
-            return """"""
+            return """daW/m³"""
         
         if unit_abbreviation == PowerDensityUnits.KilowattPerCubicMeter:
-            return """"""
+            return """kW/m³"""
         
         if unit_abbreviation == PowerDensityUnits.MegawattPerCubicMeter:
-            return """"""
+            return """MW/m³"""
         
         if unit_abbreviation == PowerDensityUnits.GigawattPerCubicMeter:
-            return """"""
+            return """GW/m³"""
         
         if unit_abbreviation == PowerDensityUnits.TerawattPerCubicMeter:
-            return """"""
+            return """TW/m³"""
         
         if unit_abbreviation == PowerDensityUnits.PicowattPerCubicInch:
-            return """"""
+            return """pW/in³"""
         
         if unit_abbreviation == PowerDensityUnits.NanowattPerCubicInch:
-            return """"""
+            return """nW/in³"""
         
         if unit_abbreviation == PowerDensityUnits.MicrowattPerCubicInch:
-            return """"""
+            return """μW/in³"""
         
         if unit_abbreviation == PowerDensityUnits.MilliwattPerCubicInch:
-            return """"""
+            return """mW/in³"""
         
         if unit_abbreviation == PowerDensityUnits.DeciwattPerCubicInch:
-            return """"""
+            return """dW/in³"""
         
         if unit_abbreviation == PowerDensityUnits.DecawattPerCubicInch:
-            return """"""
+            return """daW/in³"""
         
         if unit_abbreviation == PowerDensityUnits.KilowattPerCubicInch:
-            return """"""
+            return """kW/in³"""
         
         if unit_abbreviation == PowerDensityUnits.MegawattPerCubicInch:
-            return """"""
+            return """MW/in³"""
         
         if unit_abbreviation == PowerDensityUnits.GigawattPerCubicInch:
-            return """"""
+            return """GW/in³"""
         
         if unit_abbreviation == PowerDensityUnits.TerawattPerCubicInch:
-            return """"""
+            return """TW/in³"""
         
         if unit_abbreviation == PowerDensityUnits.PicowattPerCubicFoot:
-            return """"""
+            return """pW/ft³"""
         
         if unit_abbreviation == PowerDensityUnits.NanowattPerCubicFoot:
-            return """"""
+            return """nW/ft³"""
         
         if unit_abbreviation == PowerDensityUnits.MicrowattPerCubicFoot:
-            return """"""
+            return """μW/ft³"""
         
         if unit_abbreviation == PowerDensityUnits.MilliwattPerCubicFoot:
-            return """"""
+            return """mW/ft³"""
         
         if unit_abbreviation == PowerDensityUnits.DeciwattPerCubicFoot:
-            return """"""
+            return """dW/ft³"""
         
         if unit_abbreviation == PowerDensityUnits.DecawattPerCubicFoot:
-            return """"""
+            return """daW/ft³"""
         
         if unit_abbreviation == PowerDensityUnits.KilowattPerCubicFoot:
-            return """"""
+            return """kW/ft³"""
         
         if unit_abbreviation == PowerDensityUnits.MegawattPerCubicFoot:
-            return """"""
+            return """MW/ft³"""
         
         if unit_abbreviation == PowerDensityUnits.GigawattPerCubicFoot:
-            return """"""
+            return """GW/ft³"""
         
         if unit_abbreviation == PowerDensityUnits.TerawattPerCubicFoot:
-            return """"""
+            return """TW/ft³"""
         
         if unit_abbreviation == PowerDensityUnits.PicowattPerLiter:
-            return """"""
+            return """pW/l"""
         
         if unit_abbreviation == PowerDensityUnits.NanowattPerLiter:
-            return """"""
+            return """nW/l"""
         
         if unit_abbreviation == PowerDensityUnits.MicrowattPerLiter:
-            return """"""
+            return """μW/l"""
         
         if unit_abbreviation == PowerDensityUnits.MilliwattPerLiter:
-            return """"""
+            return """mW/l"""
         
         if unit_abbreviation == PowerDensityUnits.DeciwattPerLiter:
-            return """"""
+            return """dW/l"""
         
         if unit_abbreviation == PowerDensityUnits.DecawattPerLiter:
-            return """"""
+            return """daW/l"""
         
         if unit_abbreviation == PowerDensityUnits.KilowattPerLiter:
-            return """"""
+            return """kW/l"""
         
         if unit_abbreviation == PowerDensityUnits.MegawattPerLiter:
-            return """"""
+            return """MW/l"""
         
         if unit_abbreviation == PowerDensityUnits.GigawattPerLiter:
-            return """"""
+            return """GW/l"""
         
         if unit_abbreviation == PowerDensityUnits.TerawattPerLiter:
-            return """"""
-        
-
-    def __str__(self):
-        return self.to_string()
-
-
-    def __add__(self, other):
-        if not isinstance(other, PowerDensity):
-            raise TypeError("unsupported operand type(s) for +: 'PowerDensity' and '{}'".format(type(other).__name__))
-        return PowerDensity(self.__value + other.__value)
-
-
-    def __mul__(self, other):
-        if not isinstance(other, PowerDensity):
-            raise TypeError("unsupported operand type(s) for *: 'PowerDensity' and '{}'".format(type(other).__name__))
-        return PowerDensity(self.__value * other.__value)
-
-
-    def __sub__(self, other):
-        if not isinstance(other, PowerDensity):
-            raise TypeError("unsupported operand type(s) for -: 'PowerDensity' and '{}'".format(type(other).__name__))
-        return PowerDensity(self.__value - other.__value)
-
-
-    def __truediv__(self, other):
-        if not isinstance(other, PowerDensity):
-            raise TypeError("unsupported operand type(s) for /: 'PowerDensity' and '{}'".format(type(other).__name__))
-        return PowerDensity(self.__value / other.__value)
-
-
-    def __mod__(self, other):
-        if not isinstance(other, PowerDensity):
-            raise TypeError("unsupported operand type(s) for %: 'PowerDensity' and '{}'".format(type(other).__name__))
-        return PowerDensity(self.__value % other.__value)
-
-
-    def __pow__(self, other):
-        if not isinstance(other, PowerDensity):
-            raise TypeError("unsupported operand type(s) for **: 'PowerDensity' and '{}'".format(type(other).__name__))
-        return PowerDensity(self.__value ** other.__value)
-
-
-    def __eq__(self, other):
-        if not isinstance(other, PowerDensity):
-            raise TypeError("unsupported operand type(s) for ==: 'PowerDensity' and '{}'".format(type(other).__name__))
-        return self.__value == other.__value
-
-
-    def __lt__(self, other):
-        if not isinstance(other, PowerDensity):
-            raise TypeError("unsupported operand type(s) for <: 'PowerDensity' and '{}'".format(type(other).__name__))
-        return self.__value < other.__value
-
-
-    def __gt__(self, other):
-        if not isinstance(other, PowerDensity):
-            raise TypeError("unsupported operand type(s) for >: 'PowerDensity' and '{}'".format(type(other).__name__))
-        return self.__value > other.__value
-
-
-    def __le__(self, other):
-        if not isinstance(other, PowerDensity):
-            raise TypeError("unsupported operand type(s) for <=: 'PowerDensity' and '{}'".format(type(other).__name__))
-        return self.__value <= other.__value
-
-
-    def __ge__(self, other):
-        if not isinstance(other, PowerDensity):
-            raise TypeError("unsupported operand type(s) for >=: 'PowerDensity' and '{}'".format(type(other).__name__))
-        return self.__value >= other.__value
\ No newline at end of file
+            return """TW/l"""
+        
\ No newline at end of file
