@@ -1,6 +1,8 @@
 from enum import Enum
 import math
-import string
+
+from ..abstract_unit import AbstractMeasure
+
 
 
 class PressureUnits(Enum):
@@ -254,7 +256,7 @@ class PressureUnits(Enum):
         """
         
 
-class Pressure:
+class Pressure(AbstractMeasure):
     """
     Pressure (symbol: P or p) is the ratio of force to the area over which that force is distributed. Pressure is force per unit area applied in a direction perpendicular to the surface of an object. Gauge pressure (also spelled gage pressure)[a] is the pressure relative to the local atmospheric or ambient pressure. Pressure is measured in any unit of force divided by any unit of area. The SI unit of pressure is the newton per square metre, which is called the pascal (Pa) after the seventeenth-century philosopher and scientist Blaise Pascal. A pressure of 1 Pa is small; it approximately equals the pressure exerted by a dollar bill resting flat on a table. Everyday pressures are often stated in kilopascals (1 kPa = 1000 Pa).
 
@@ -263,9 +265,11 @@ class Pressure:
         from_unit (PressureUnits): The Pressure unit to create from, The default unit is Pascal
     """
     def __init__(self, value: float, from_unit: PressureUnits = PressureUnits.Pascal):
-        if math.isnan(value):
-            raise ValueError('Invalid unit: value is NaN')
-        self.__value = self.__convert_to_base(value, from_unit)
+        # Do not validate type, to allow working with numpay arrays and similar objects who supports all arithmetic 
+        # operations, but they are not a number, see #14 
+        # if math.isnan(value):
+        #     raise ValueError('Invalid unit: value is NaN')
+        self._value = self.__convert_to_base(value, from_unit)
         
         self.__pascals = None
         
@@ -366,8 +370,11 @@ class Pressure:
         self.__centimeters_of_water_column = None
         
 
+    def convert(self, unit: PressureUnits) -> float:
+        return self.__convert_from_base(unit)
+
     def __convert_from_base(self, from_unit: PressureUnits) -> float:
-        value = self.__value
+        value = self._value
         
         if from_unit == PressureUnits.Pascal:
             return (value)
@@ -673,7 +680,7 @@ class Pressure:
 
     @property
     def base_value(self) -> float:
-        return self.__value
+        return self._value
 
     
     @staticmethod
@@ -1950,7 +1957,7 @@ class Pressure:
         return self.__centimeters_of_water_column
 
     
-    def to_string(self, unit: PressureUnits = PressureUnits.Pascal) -> string:
+    def to_string(self, unit: PressureUnits = PressureUnits.Pascal) -> str:
         """
         Format the Pressure to string.
         Note! the default format for Pressure is Pascal.
@@ -2039,75 +2046,75 @@ class Pressure:
             return f"""{self.feet_of_elevation} ft of elevation"""
         
         if unit == PressureUnits.Micropascal:
-            return f"""{self.micropascals} """
+            return f"""{self.micropascals} μPa"""
         
         if unit == PressureUnits.Millipascal:
-            return f"""{self.millipascals} """
+            return f"""{self.millipascals} mPa"""
         
         if unit == PressureUnits.Decapascal:
-            return f"""{self.decapascals} """
+            return f"""{self.decapascals} daPa"""
         
         if unit == PressureUnits.Hectopascal:
-            return f"""{self.hectopascals} """
+            return f"""{self.hectopascals} hPa"""
         
         if unit == PressureUnits.Kilopascal:
-            return f"""{self.kilopascals} """
+            return f"""{self.kilopascals} kPa"""
         
         if unit == PressureUnits.Megapascal:
-            return f"""{self.megapascals} """
+            return f"""{self.megapascals} MPa"""
         
         if unit == PressureUnits.Gigapascal:
-            return f"""{self.gigapascals} """
+            return f"""{self.gigapascals} GPa"""
         
         if unit == PressureUnits.Microbar:
-            return f"""{self.microbars} """
+            return f"""{self.microbars} μbar"""
         
         if unit == PressureUnits.Millibar:
-            return f"""{self.millibars} """
+            return f"""{self.millibars} mbar"""
         
         if unit == PressureUnits.Centibar:
-            return f"""{self.centibars} """
+            return f"""{self.centibars} cbar"""
         
         if unit == PressureUnits.Decibar:
-            return f"""{self.decibars} """
+            return f"""{self.decibars} dbar"""
         
         if unit == PressureUnits.Kilobar:
-            return f"""{self.kilobars} """
+            return f"""{self.kilobars} kbar"""
         
         if unit == PressureUnits.Megabar:
-            return f"""{self.megabars} """
+            return f"""{self.megabars} Mbar"""
         
         if unit == PressureUnits.KilonewtonPerSquareMeter:
-            return f"""{self.kilonewtons_per_square_meter} """
+            return f"""{self.kilonewtons_per_square_meter} kN/m²"""
         
         if unit == PressureUnits.MeganewtonPerSquareMeter:
-            return f"""{self.meganewtons_per_square_meter} """
+            return f"""{self.meganewtons_per_square_meter} MN/m²"""
         
         if unit == PressureUnits.KilonewtonPerSquareCentimeter:
-            return f"""{self.kilonewtons_per_square_centimeter} """
+            return f"""{self.kilonewtons_per_square_centimeter} kN/cm²"""
         
         if unit == PressureUnits.KilonewtonPerSquareMillimeter:
-            return f"""{self.kilonewtons_per_square_millimeter} """
+            return f"""{self.kilonewtons_per_square_millimeter} kN/mm²"""
         
         if unit == PressureUnits.KilopoundForcePerSquareInch:
-            return f"""{self.kilopounds_force_per_square_inch} """
+            return f"""{self.kilopounds_force_per_square_inch} kpsi"""
         
         if unit == PressureUnits.KilopoundForcePerSquareMil:
-            return f"""{self.kilopounds_force_per_square_mil} """
+            return f"""{self.kilopounds_force_per_square_mil} klb/mil²"""
         
         if unit == PressureUnits.KilopoundForcePerSquareFoot:
-            return f"""{self.kilopounds_force_per_square_foot} """
+            return f"""{self.kilopounds_force_per_square_foot} klb/ft²"""
         
         if unit == PressureUnits.MillimeterOfWaterColumn:
-            return f"""{self.millimeters_of_water_column} """
+            return f"""{self.millimeters_of_water_column} mmH₂O"""
         
         if unit == PressureUnits.CentimeterOfWaterColumn:
-            return f"""{self.centimeters_of_water_column} """
+            return f"""{self.centimeters_of_water_column} cmH₂O"""
         
-        return f'{self.__value}'
+        return f'{self._value}'
 
 
-    def get_unit_abbreviation(self, unit_abbreviation: PressureUnits = PressureUnits.Pascal) -> string:
+    def get_unit_abbreviation(self, unit_abbreviation: PressureUnits = PressureUnits.Pascal) -> str:
         """
         Get Pressure unit abbreviation.
         Note! the default abbreviation for Pressure is Pascal.
@@ -2196,137 +2203,68 @@ class Pressure:
             return """ft of elevation"""
         
         if unit_abbreviation == PressureUnits.Micropascal:
-            return """"""
+            return """μPa"""
         
         if unit_abbreviation == PressureUnits.Millipascal:
-            return """"""
+            return """mPa"""
         
         if unit_abbreviation == PressureUnits.Decapascal:
-            return """"""
+            return """daPa"""
         
         if unit_abbreviation == PressureUnits.Hectopascal:
-            return """"""
+            return """hPa"""
         
         if unit_abbreviation == PressureUnits.Kilopascal:
-            return """"""
+            return """kPa"""
         
         if unit_abbreviation == PressureUnits.Megapascal:
-            return """"""
+            return """MPa"""
         
         if unit_abbreviation == PressureUnits.Gigapascal:
-            return """"""
+            return """GPa"""
         
         if unit_abbreviation == PressureUnits.Microbar:
-            return """"""
+            return """μbar"""
         
         if unit_abbreviation == PressureUnits.Millibar:
-            return """"""
+            return """mbar"""
         
         if unit_abbreviation == PressureUnits.Centibar:
-            return """"""
+            return """cbar"""
         
         if unit_abbreviation == PressureUnits.Decibar:
-            return """"""
+            return """dbar"""
         
         if unit_abbreviation == PressureUnits.Kilobar:
-            return """"""
+            return """kbar"""
         
         if unit_abbreviation == PressureUnits.Megabar:
-            return """"""
+            return """Mbar"""
         
         if unit_abbreviation == PressureUnits.KilonewtonPerSquareMeter:
-            return """"""
+            return """kN/m²"""
         
         if unit_abbreviation == PressureUnits.MeganewtonPerSquareMeter:
-            return """"""
+            return """MN/m²"""
         
         if unit_abbreviation == PressureUnits.KilonewtonPerSquareCentimeter:
-            return """"""
+            return """kN/cm²"""
         
         if unit_abbreviation == PressureUnits.KilonewtonPerSquareMillimeter:
-            return """"""
+            return """kN/mm²"""
         
         if unit_abbreviation == PressureUnits.KilopoundForcePerSquareInch:
-            return """"""
+            return """kpsi"""
         
         if unit_abbreviation == PressureUnits.KilopoundForcePerSquareMil:
-            return """"""
+            return """klb/mil²"""
         
         if unit_abbreviation == PressureUnits.KilopoundForcePerSquareFoot:
-            return """"""
+            return """klb/ft²"""
         
         if unit_abbreviation == PressureUnits.MillimeterOfWaterColumn:
-            return """"""
+            return """mmH₂O"""
         
         if unit_abbreviation == PressureUnits.CentimeterOfWaterColumn:
-            return """"""
-        
-
-    def __str__(self):
-        return self.to_string()
-
-
-    def __add__(self, other):
-        if not isinstance(other, Pressure):
-            raise TypeError("unsupported operand type(s) for +: 'Pressure' and '{}'".format(type(other).__name__))
-        return Pressure(self.__value + other.__value)
-
-
-    def __mul__(self, other):
-        if not isinstance(other, Pressure):
-            raise TypeError("unsupported operand type(s) for *: 'Pressure' and '{}'".format(type(other).__name__))
-        return Pressure(self.__value * other.__value)
-
-
-    def __sub__(self, other):
-        if not isinstance(other, Pressure):
-            raise TypeError("unsupported operand type(s) for -: 'Pressure' and '{}'".format(type(other).__name__))
-        return Pressure(self.__value - other.__value)
-
-
-    def __truediv__(self, other):
-        if not isinstance(other, Pressure):
-            raise TypeError("unsupported operand type(s) for /: 'Pressure' and '{}'".format(type(other).__name__))
-        return Pressure(self.__value / other.__value)
-
-
-    def __mod__(self, other):
-        if not isinstance(other, Pressure):
-            raise TypeError("unsupported operand type(s) for %: 'Pressure' and '{}'".format(type(other).__name__))
-        return Pressure(self.__value % other.__value)
-
-
-    def __pow__(self, other):
-        if not isinstance(other, Pressure):
-            raise TypeError("unsupported operand type(s) for **: 'Pressure' and '{}'".format(type(other).__name__))
-        return Pressure(self.__value ** other.__value)
-
-
-    def __eq__(self, other):
-        if not isinstance(other, Pressure):
-            raise TypeError("unsupported operand type(s) for ==: 'Pressure' and '{}'".format(type(other).__name__))
-        return self.__value == other.__value
-
-
-    def __lt__(self, other):
-        if not isinstance(other, Pressure):
-            raise TypeError("unsupported operand type(s) for <: 'Pressure' and '{}'".format(type(other).__name__))
-        return self.__value < other.__value
-
-
-    def __gt__(self, other):
-        if not isinstance(other, Pressure):
-            raise TypeError("unsupported operand type(s) for >: 'Pressure' and '{}'".format(type(other).__name__))
-        return self.__value > other.__value
-
-
-    def __le__(self, other):
-        if not isinstance(other, Pressure):
-            raise TypeError("unsupported operand type(s) for <=: 'Pressure' and '{}'".format(type(other).__name__))
-        return self.__value <= other.__value
-
-
-    def __ge__(self, other):
-        if not isinstance(other, Pressure):
-            raise TypeError("unsupported operand type(s) for >=: 'Pressure' and '{}'".format(type(other).__name__))
-        return self.__value >= other.__value
\ No newline at end of file
+            return """cmH₂O"""
+        
\ No newline at end of file
