@@ -1,6 +1,8 @@
 from enum import Enum
 import math
-import string
+
+from ..abstract_unit import AbstractMeasure
+
 
 
 class PressureChangeRateUnits(Enum):
@@ -38,6 +40,16 @@ class PressureChangeRateUnits(Enum):
             
         """
         
+        BarPerSecond = 'bar_per_second'
+        """
+            
+        """
+        
+        BarPerMinute = 'bar_per_minute'
+        """
+            
+        """
+        
         KilopascalPerSecond = 'kilopascal_per_second'
         """
             
@@ -78,8 +90,18 @@ class PressureChangeRateUnits(Enum):
             
         """
         
+        MillibarPerSecond = 'millibar_per_second'
+        """
+            
+        """
+        
+        MillibarPerMinute = 'millibar_per_minute'
+        """
+            
+        """
+        
 
-class PressureChangeRate:
+class PressureChangeRate(AbstractMeasure):
     """
     Pressure change rate is the ratio of the pressure change to the time during which the change occurred (value of pressure changes per unit time).
 
@@ -88,9 +110,11 @@ class PressureChangeRate:
         from_unit (PressureChangeRateUnits): The PressureChangeRate unit to create from, The default unit is PascalPerSecond
     """
     def __init__(self, value: float, from_unit: PressureChangeRateUnits = PressureChangeRateUnits.PascalPerSecond):
-        if math.isnan(value):
-            raise ValueError('Invalid unit: value is NaN')
-        self.__value = self.__convert_to_base(value, from_unit)
+        # Do not validate type, to allow working with numpay arrays and similar objects who supports all arithmetic 
+        # operations, but they are not a number, see #14 
+        # if math.isnan(value):
+        #     raise ValueError('Invalid unit: value is NaN')
+        self._value = self.__convert_to_base(value, from_unit)
         
         self.__pascals_per_second = None
         
@@ -104,6 +128,10 @@ class PressureChangeRate:
         
         self.__pounds_force_per_square_inch_per_minute = None
         
+        self.__bars_per_second = None
+        
+        self.__bars_per_minute = None
+        
         self.__kilopascals_per_second = None
         
         self.__megapascals_per_second = None
@@ -120,9 +148,16 @@ class PressureChangeRate:
         
         self.__megapounds_force_per_square_inch_per_minute = None
         
+        self.__millibars_per_second = None
+        
+        self.__millibars_per_minute = None
+        
+
+    def convert(self, unit: PressureChangeRateUnits) -> float:
+        return self.__convert_from_base(unit)
 
     def __convert_from_base(self, from_unit: PressureChangeRateUnits) -> float:
-        value = self.__value
+        value = self._value
         
         if from_unit == PressureChangeRateUnits.PascalPerSecond:
             return (value)
@@ -142,6 +177,12 @@ class PressureChangeRate:
         if from_unit == PressureChangeRateUnits.PoundForcePerSquareInchPerMinute:
             return (value / 6.894757293168361e3 * 60)
         
+        if from_unit == PressureChangeRateUnits.BarPerSecond:
+            return (value / 1e5)
+        
+        if from_unit == PressureChangeRateUnits.BarPerMinute:
+            return (value / 1e5 * 60)
+        
         if from_unit == PressureChangeRateUnits.KilopascalPerSecond:
             return ((value) / 1000.0)
         
@@ -166,6 +207,12 @@ class PressureChangeRate:
         if from_unit == PressureChangeRateUnits.MegapoundForcePerSquareInchPerMinute:
             return ((value / 6.894757293168361e3 * 60) / 1000000.0)
         
+        if from_unit == PressureChangeRateUnits.MillibarPerSecond:
+            return ((value / 1e5) / 0.001)
+        
+        if from_unit == PressureChangeRateUnits.MillibarPerMinute:
+            return ((value / 1e5 * 60) / 0.001)
+        
         return None
 
 
@@ -189,6 +236,12 @@ class PressureChangeRate:
         if to_unit == PressureChangeRateUnits.PoundForcePerSquareInchPerMinute:
             return (value * 6.894757293168361e3 / 60)
         
+        if to_unit == PressureChangeRateUnits.BarPerSecond:
+            return (value * 1e5)
+        
+        if to_unit == PressureChangeRateUnits.BarPerMinute:
+            return (value * 1e5 / 60)
+        
         if to_unit == PressureChangeRateUnits.KilopascalPerSecond:
             return ((value) * 1000.0)
         
@@ -213,12 +266,18 @@ class PressureChangeRate:
         if to_unit == PressureChangeRateUnits.MegapoundForcePerSquareInchPerMinute:
             return ((value * 6.894757293168361e3 / 60) * 1000000.0)
         
+        if to_unit == PressureChangeRateUnits.MillibarPerSecond:
+            return ((value * 1e5) * 0.001)
+        
+        if to_unit == PressureChangeRateUnits.MillibarPerMinute:
+            return ((value * 1e5 / 60) * 0.001)
+        
         return None
 
 
     @property
     def base_value(self) -> float:
-        return self.__value
+        return self._value
 
     
     @staticmethod
@@ -311,6 +370,36 @@ class PressureChangeRate:
         return PressureChangeRate(pounds_force_per_square_inch_per_minute, PressureChangeRateUnits.PoundForcePerSquareInchPerMinute)
 
     
+    @staticmethod
+    def from_bars_per_second(bars_per_second: float):
+        """
+        Create a new instance of PressureChangeRate from a value in bars_per_second.
+
+        
+
+        :param meters: The PressureChangeRate value in bars_per_second.
+        :type bars_per_second: float
+        :return: A new instance of PressureChangeRate.
+        :rtype: PressureChangeRate
+        """
+        return PressureChangeRate(bars_per_second, PressureChangeRateUnits.BarPerSecond)
+
+    
+    @staticmethod
+    def from_bars_per_minute(bars_per_minute: float):
+        """
+        Create a new instance of PressureChangeRate from a value in bars_per_minute.
+
+        
+
+        :param meters: The PressureChangeRate value in bars_per_minute.
+        :type bars_per_minute: float
+        :return: A new instance of PressureChangeRate.
+        :rtype: PressureChangeRate
+        """
+        return PressureChangeRate(bars_per_minute, PressureChangeRateUnits.BarPerMinute)
+
+    
     @staticmethod
     def from_kilopascals_per_second(kilopascals_per_second: float):
         """
@@ -431,6 +520,36 @@ class PressureChangeRate:
         return PressureChangeRate(megapounds_force_per_square_inch_per_minute, PressureChangeRateUnits.MegapoundForcePerSquareInchPerMinute)
 
     
+    @staticmethod
+    def from_millibars_per_second(millibars_per_second: float):
+        """
+        Create a new instance of PressureChangeRate from a value in millibars_per_second.
+
+        
+
+        :param meters: The PressureChangeRate value in millibars_per_second.
+        :type millibars_per_second: float
+        :return: A new instance of PressureChangeRate.
+        :rtype: PressureChangeRate
+        """
+        return PressureChangeRate(millibars_per_second, PressureChangeRateUnits.MillibarPerSecond)
+
+    
+    @staticmethod
+    def from_millibars_per_minute(millibars_per_minute: float):
+        """
+        Create a new instance of PressureChangeRate from a value in millibars_per_minute.
+
+        
+
+        :param meters: The PressureChangeRate value in millibars_per_minute.
+        :type millibars_per_minute: float
+        :return: A new instance of PressureChangeRate.
+        :rtype: PressureChangeRate
+        """
+        return PressureChangeRate(millibars_per_minute, PressureChangeRateUnits.MillibarPerMinute)
+
+    
     @property
     def pascals_per_second(self) -> float:
         """
@@ -497,6 +616,28 @@ class PressureChangeRate:
         return self.__pounds_force_per_square_inch_per_minute
 
     
+    @property
+    def bars_per_second(self) -> float:
+        """
+        
+        """
+        if self.__bars_per_second != None:
+            return self.__bars_per_second
+        self.__bars_per_second = self.__convert_from_base(PressureChangeRateUnits.BarPerSecond)
+        return self.__bars_per_second
+
+    
+    @property
+    def bars_per_minute(self) -> float:
+        """
+        
+        """
+        if self.__bars_per_minute != None:
+            return self.__bars_per_minute
+        self.__bars_per_minute = self.__convert_from_base(PressureChangeRateUnits.BarPerMinute)
+        return self.__bars_per_minute
+
+    
     @property
     def kilopascals_per_second(self) -> float:
         """
@@ -585,7 +726,29 @@ class PressureChangeRate:
         return self.__megapounds_force_per_square_inch_per_minute
 
     
-    def to_string(self, unit: PressureChangeRateUnits = PressureChangeRateUnits.PascalPerSecond) -> string:
+    @property
+    def millibars_per_second(self) -> float:
+        """
+        
+        """
+        if self.__millibars_per_second != None:
+            return self.__millibars_per_second
+        self.__millibars_per_second = self.__convert_from_base(PressureChangeRateUnits.MillibarPerSecond)
+        return self.__millibars_per_second
+
+    
+    @property
+    def millibars_per_minute(self) -> float:
+        """
+        
+        """
+        if self.__millibars_per_minute != None:
+            return self.__millibars_per_minute
+        self.__millibars_per_minute = self.__convert_from_base(PressureChangeRateUnits.MillibarPerMinute)
+        return self.__millibars_per_minute
+
+    
+    def to_string(self, unit: PressureChangeRateUnits = PressureChangeRateUnits.PascalPerSecond) -> str:
         """
         Format the PressureChangeRate to string.
         Note! the default format for PressureChangeRate is PascalPerSecond.
@@ -610,34 +773,46 @@ class PressureChangeRate:
         if unit == PressureChangeRateUnits.PoundForcePerSquareInchPerMinute:
             return f"""{self.pounds_force_per_square_inch_per_minute} psi/min"""
         
+        if unit == PressureChangeRateUnits.BarPerSecond:
+            return f"""{self.bars_per_second} bar/s"""
+        
+        if unit == PressureChangeRateUnits.BarPerMinute:
+            return f"""{self.bars_per_minute} bar/min"""
+        
         if unit == PressureChangeRateUnits.KilopascalPerSecond:
-            return f"""{self.kilopascals_per_second} """
+            return f"""{self.kilopascals_per_second} kPa/s"""
         
         if unit == PressureChangeRateUnits.MegapascalPerSecond:
-            return f"""{self.megapascals_per_second} """
+            return f"""{self.megapascals_per_second} MPa/s"""
         
         if unit == PressureChangeRateUnits.KilopascalPerMinute:
-            return f"""{self.kilopascals_per_minute} """
+            return f"""{self.kilopascals_per_minute} kPa/min"""
         
         if unit == PressureChangeRateUnits.MegapascalPerMinute:
-            return f"""{self.megapascals_per_minute} """
+            return f"""{self.megapascals_per_minute} MPa/min"""
         
         if unit == PressureChangeRateUnits.KilopoundForcePerSquareInchPerSecond:
-            return f"""{self.kilopounds_force_per_square_inch_per_second} """
+            return f"""{self.kilopounds_force_per_square_inch_per_second} kpsi/s"""
         
         if unit == PressureChangeRateUnits.MegapoundForcePerSquareInchPerSecond:
-            return f"""{self.megapounds_force_per_square_inch_per_second} """
+            return f"""{self.megapounds_force_per_square_inch_per_second} Mpsi/s"""
         
         if unit == PressureChangeRateUnits.KilopoundForcePerSquareInchPerMinute:
-            return f"""{self.kilopounds_force_per_square_inch_per_minute} """
+            return f"""{self.kilopounds_force_per_square_inch_per_minute} kpsi/min"""
         
         if unit == PressureChangeRateUnits.MegapoundForcePerSquareInchPerMinute:
-            return f"""{self.megapounds_force_per_square_inch_per_minute} """
+            return f"""{self.megapounds_force_per_square_inch_per_minute} Mpsi/min"""
         
-        return f'{self.__value}'
+        if unit == PressureChangeRateUnits.MillibarPerSecond:
+            return f"""{self.millibars_per_second} mbar/s"""
+        
+        if unit == PressureChangeRateUnits.MillibarPerMinute:
+            return f"""{self.millibars_per_minute} mbar/min"""
+        
+        return f'{self._value}'
 
 
-    def get_unit_abbreviation(self, unit_abbreviation: PressureChangeRateUnits = PressureChangeRateUnits.PascalPerSecond) -> string:
+    def get_unit_abbreviation(self, unit_abbreviation: PressureChangeRateUnits = PressureChangeRateUnits.PascalPerSecond) -> str:
         """
         Get PressureChangeRate unit abbreviation.
         Note! the default abbreviation for PressureChangeRate is PascalPerSecond.
@@ -662,96 +837,39 @@ class PressureChangeRate:
         if unit_abbreviation == PressureChangeRateUnits.PoundForcePerSquareInchPerMinute:
             return """psi/min"""
         
+        if unit_abbreviation == PressureChangeRateUnits.BarPerSecond:
+            return """bar/s"""
+        
+        if unit_abbreviation == PressureChangeRateUnits.BarPerMinute:
+            return """bar/min"""
+        
         if unit_abbreviation == PressureChangeRateUnits.KilopascalPerSecond:
-            return """"""
+            return """kPa/s"""
         
         if unit_abbreviation == PressureChangeRateUnits.MegapascalPerSecond:
-            return """"""
+            return """MPa/s"""
         
         if unit_abbreviation == PressureChangeRateUnits.KilopascalPerMinute:
-            return """"""
+            return """kPa/min"""
         
         if unit_abbreviation == PressureChangeRateUnits.MegapascalPerMinute:
-            return """"""
+            return """MPa/min"""
         
         if unit_abbreviation == PressureChangeRateUnits.KilopoundForcePerSquareInchPerSecond:
-            return """"""
+            return """kpsi/s"""
         
         if unit_abbreviation == PressureChangeRateUnits.MegapoundForcePerSquareInchPerSecond:
-            return """"""
+            return """Mpsi/s"""
         
         if unit_abbreviation == PressureChangeRateUnits.KilopoundForcePerSquareInchPerMinute:
-            return """"""
+            return """kpsi/min"""
         
         if unit_abbreviation == PressureChangeRateUnits.MegapoundForcePerSquareInchPerMinute:
-            return """"""
+            return """Mpsi/min"""
         
-
-    def __str__(self):
-        return self.to_string()
-
-
-    def __add__(self, other):
-        if not isinstance(other, PressureChangeRate):
-            raise TypeError("unsupported operand type(s) for +: 'PressureChangeRate' and '{}'".format(type(other).__name__))
-        return PressureChangeRate(self.__value + other.__value)
-
-
-    def __mul__(self, other):
-        if not isinstance(other, PressureChangeRate):
-            raise TypeError("unsupported operand type(s) for *: 'PressureChangeRate' and '{}'".format(type(other).__name__))
-        return PressureChangeRate(self.__value * other.__value)
-
-
-    def __sub__(self, other):
-        if not isinstance(other, PressureChangeRate):
-            raise TypeError("unsupported operand type(s) for -: 'PressureChangeRate' and '{}'".format(type(other).__name__))
-        return PressureChangeRate(self.__value - other.__value)
-
-
-    def __truediv__(self, other):
-        if not isinstance(other, PressureChangeRate):
-            raise TypeError("unsupported operand type(s) for /: 'PressureChangeRate' and '{}'".format(type(other).__name__))
-        return PressureChangeRate(self.__value / other.__value)
-
-
-    def __mod__(self, other):
-        if not isinstance(other, PressureChangeRate):
-            raise TypeError("unsupported operand type(s) for %: 'PressureChangeRate' and '{}'".format(type(other).__name__))
-        return PressureChangeRate(self.__value % other.__value)
-
-
-    def __pow__(self, other):
-        if not isinstance(other, PressureChangeRate):
-            raise TypeError("unsupported operand type(s) for **: 'PressureChangeRate' and '{}'".format(type(other).__name__))
-        return PressureChangeRate(self.__value ** other.__value)
-
-
-    def __eq__(self, other):
-        if not isinstance(other, PressureChangeRate):
-            raise TypeError("unsupported operand type(s) for ==: 'PressureChangeRate' and '{}'".format(type(other).__name__))
-        return self.__value == other.__value
-
-
-    def __lt__(self, other):
-        if not isinstance(other, PressureChangeRate):
-            raise TypeError("unsupported operand type(s) for <: 'PressureChangeRate' and '{}'".format(type(other).__name__))
-        return self.__value < other.__value
-
-
-    def __gt__(self, other):
-        if not isinstance(other, PressureChangeRate):
-            raise TypeError("unsupported operand type(s) for >: 'PressureChangeRate' and '{}'".format(type(other).__name__))
-        return self.__value > other.__value
-
-
-    def __le__(self, other):
-        if not isinstance(other, PressureChangeRate):
-            raise TypeError("unsupported operand type(s) for <=: 'PressureChangeRate' and '{}'".format(type(other).__name__))
-        return self.__value <= other.__value
-
-
-    def __ge__(self, other):
-        if not isinstance(other, PressureChangeRate):
-            raise TypeError("unsupported operand type(s) for >=: 'PressureChangeRate' and '{}'".format(type(other).__name__))
-        return self.__value >= other.__value
\ No newline at end of file
+        if unit_abbreviation == PressureChangeRateUnits.MillibarPerSecond:
+            return """mbar/s"""
+        
+        if unit_abbreviation == PressureChangeRateUnits.MillibarPerMinute:
+            return """mbar/min"""
+        
\ No newline at end of file
