@@ -1,6 +1,8 @@
 from enum import Enum
 import math
-import string
+
+from ..abstract_unit import AbstractMeasure
+
 
 
 class ReciprocalAreaUnits(Enum):
@@ -64,7 +66,7 @@ class ReciprocalAreaUnits(Enum):
         """
         
 
-class ReciprocalArea:
+class ReciprocalArea(AbstractMeasure):
     """
     Reciprocal area (Inverse-square) quantity is used to specify a physical quantity inversely proportional to the square of the distance.
 
@@ -73,9 +75,11 @@ class ReciprocalArea:
         from_unit (ReciprocalAreaUnits): The ReciprocalArea unit to create from, The default unit is InverseSquareMeter
     """
     def __init__(self, value: float, from_unit: ReciprocalAreaUnits = ReciprocalAreaUnits.InverseSquareMeter):
-        if math.isnan(value):
-            raise ValueError('Invalid unit: value is NaN')
-        self.__value = self.__convert_to_base(value, from_unit)
+        # Do not validate type, to allow working with numpay arrays and similar objects who supports all arithmetic 
+        # operations, but they are not a number, see #14 
+        # if math.isnan(value):
+        #     raise ValueError('Invalid unit: value is NaN')
+        self._value = self.__convert_to_base(value, from_unit)
         
         self.__inverse_square_meters = None
         
@@ -100,8 +104,11 @@ class ReciprocalArea:
         self.__inverse_square_inches = None
         
 
+    def convert(self, unit: ReciprocalAreaUnits) -> float:
+        return self.__convert_from_base(unit)
+
     def __convert_from_base(self, from_unit: ReciprocalAreaUnits) -> float:
-        value = self.__value
+        value = self._value
         
         if from_unit == ReciprocalAreaUnits.InverseSquareMeter:
             return (value)
@@ -179,7 +186,7 @@ class ReciprocalArea:
 
     @property
     def base_value(self) -> float:
-        return self.__value
+        return self._value
 
     
     @staticmethod
@@ -468,7 +475,7 @@ class ReciprocalArea:
         return self.__inverse_square_inches
 
     
-    def to_string(self, unit: ReciprocalAreaUnits = ReciprocalAreaUnits.InverseSquareMeter) -> string:
+    def to_string(self, unit: ReciprocalAreaUnits = ReciprocalAreaUnits.InverseSquareMeter) -> str:
         """
         Format the ReciprocalArea to string.
         Note! the default format for ReciprocalArea is InverseSquareMeter.
@@ -508,10 +515,10 @@ class ReciprocalArea:
         if unit == ReciprocalAreaUnits.InverseSquareInch:
             return f"""{self.inverse_square_inches} in⁻²"""
         
-        return f'{self.__value}'
+        return f'{self._value}'
 
 
-    def get_unit_abbreviation(self, unit_abbreviation: ReciprocalAreaUnits = ReciprocalAreaUnits.InverseSquareMeter) -> string:
+    def get_unit_abbreviation(self, unit_abbreviation: ReciprocalAreaUnits = ReciprocalAreaUnits.InverseSquareMeter) -> str:
         """
         Get ReciprocalArea unit abbreviation.
         Note! the default abbreviation for ReciprocalArea is InverseSquareMeter.
@@ -550,73 +557,4 @@ class ReciprocalArea:
         
         if unit_abbreviation == ReciprocalAreaUnits.InverseSquareInch:
             return """in⁻²"""
-        
-
-    def __str__(self):
-        return self.to_string()
-
-
-    def __add__(self, other):
-        if not isinstance(other, ReciprocalArea):
-            raise TypeError("unsupported operand type(s) for +: 'ReciprocalArea' and '{}'".format(type(other).__name__))
-        return ReciprocalArea(self.__value + other.__value)
-
-
-    def __mul__(self, other):
-        if not isinstance(other, ReciprocalArea):
-            raise TypeError("unsupported operand type(s) for *: 'ReciprocalArea' and '{}'".format(type(other).__name__))
-        return ReciprocalArea(self.__value * other.__value)
-
-
-    def __sub__(self, other):
-        if not isinstance(other, ReciprocalArea):
-            raise TypeError("unsupported operand type(s) for -: 'ReciprocalArea' and '{}'".format(type(other).__name__))
-        return ReciprocalArea(self.__value - other.__value)
-
-
-    def __truediv__(self, other):
-        if not isinstance(other, ReciprocalArea):
-            raise TypeError("unsupported operand type(s) for /: 'ReciprocalArea' and '{}'".format(type(other).__name__))
-        return ReciprocalArea(self.__value / other.__value)
-
-
-    def __mod__(self, other):
-        if not isinstance(other, ReciprocalArea):
-            raise TypeError("unsupported operand type(s) for %: 'ReciprocalArea' and '{}'".format(type(other).__name__))
-        return ReciprocalArea(self.__value % other.__value)
-
-
-    def __pow__(self, other):
-        if not isinstance(other, ReciprocalArea):
-            raise TypeError("unsupported operand type(s) for **: 'ReciprocalArea' and '{}'".format(type(other).__name__))
-        return ReciprocalArea(self.__value ** other.__value)
-
-
-    def __eq__(self, other):
-        if not isinstance(other, ReciprocalArea):
-            raise TypeError("unsupported operand type(s) for ==: 'ReciprocalArea' and '{}'".format(type(other).__name__))
-        return self.__value == other.__value
-
-
-    def __lt__(self, other):
-        if not isinstance(other, ReciprocalArea):
-            raise TypeError("unsupported operand type(s) for <: 'ReciprocalArea' and '{}'".format(type(other).__name__))
-        return self.__value < other.__value
-
-
-    def __gt__(self, other):
-        if not isinstance(other, ReciprocalArea):
-            raise TypeError("unsupported operand type(s) for >: 'ReciprocalArea' and '{}'".format(type(other).__name__))
-        return self.__value > other.__value
-
-
-    def __le__(self, other):
-        if not isinstance(other, ReciprocalArea):
-            raise TypeError("unsupported operand type(s) for <=: 'ReciprocalArea' and '{}'".format(type(other).__name__))
-        return self.__value <= other.__value
-
-
-    def __ge__(self, other):
-        if not isinstance(other, ReciprocalArea):
-            raise TypeError("unsupported operand type(s) for >=: 'ReciprocalArea' and '{}'".format(type(other).__name__))
-        return self.__value >= other.__value
\ No newline at end of file
+        
\ No newline at end of file
