@@ -1,6 +1,8 @@
 from enum import Enum
 import math
-import string
+
+from ..abstract_unit import AbstractMeasure
+
 
 
 class ReciprocalLengthUnits(Enum):
@@ -59,7 +61,7 @@ class ReciprocalLengthUnits(Enum):
         """
         
 
-class ReciprocalLength:
+class ReciprocalLength(AbstractMeasure):
     """
     Reciprocal (Inverse) Length is used in various fields of science and mathematics. It is defined as the inverse value of a length unit.
 
@@ -68,9 +70,11 @@ class ReciprocalLength:
         from_unit (ReciprocalLengthUnits): The ReciprocalLength unit to create from, The default unit is InverseMeter
     """
     def __init__(self, value: float, from_unit: ReciprocalLengthUnits = ReciprocalLengthUnits.InverseMeter):
-        if math.isnan(value):
-            raise ValueError('Invalid unit: value is NaN')
-        self.__value = self.__convert_to_base(value, from_unit)
+        # Do not validate type, to allow working with numpay arrays and similar objects who supports all arithmetic 
+        # operations, but they are not a number, see #14 
+        # if math.isnan(value):
+        #     raise ValueError('Invalid unit: value is NaN')
+        self._value = self.__convert_to_base(value, from_unit)
         
         self.__inverse_meters = None
         
@@ -93,8 +97,11 @@ class ReciprocalLength:
         self.__inverse_microinches = None
         
 
+    def convert(self, unit: ReciprocalLengthUnits) -> float:
+        return self.__convert_from_base(unit)
+
     def __convert_from_base(self, from_unit: ReciprocalLengthUnits) -> float:
-        value = self.__value
+        value = self._value
         
         if from_unit == ReciprocalLengthUnits.InverseMeter:
             return (value)
@@ -106,7 +113,7 @@ class ReciprocalLength:
             return (value / 1e3)
         
         if from_unit == ReciprocalLengthUnits.InverseMile:
-            return (value * 1609.34)
+            return (value * 1609.344)
         
         if from_unit == ReciprocalLengthUnits.InverseYard:
             return (value * 0.9144)
@@ -141,7 +148,7 @@ class ReciprocalLength:
             return (value * 1e3)
         
         if to_unit == ReciprocalLengthUnits.InverseMile:
-            return (value / 1609.34)
+            return (value / 1609.344)
         
         if to_unit == ReciprocalLengthUnits.InverseYard:
             return (value / 0.9144)
@@ -166,7 +173,7 @@ class ReciprocalLength:
 
     @property
     def base_value(self) -> float:
-        return self.__value
+        return self._value
 
     
     @staticmethod
@@ -429,7 +436,7 @@ class ReciprocalLength:
         return self.__inverse_microinches
 
     
-    def to_string(self, unit: ReciprocalLengthUnits = ReciprocalLengthUnits.InverseMeter) -> string:
+    def to_string(self, unit: ReciprocalLengthUnits = ReciprocalLengthUnits.InverseMeter) -> str:
         """
         Format the ReciprocalLength to string.
         Note! the default format for ReciprocalLength is InverseMeter.
@@ -466,10 +473,10 @@ class ReciprocalLength:
         if unit == ReciprocalLengthUnits.InverseMicroinch:
             return f"""{self.inverse_microinches} µin⁻¹"""
         
-        return f'{self.__value}'
+        return f'{self._value}'
 
 
-    def get_unit_abbreviation(self, unit_abbreviation: ReciprocalLengthUnits = ReciprocalLengthUnits.InverseMeter) -> string:
+    def get_unit_abbreviation(self, unit_abbreviation: ReciprocalLengthUnits = ReciprocalLengthUnits.InverseMeter) -> str:
         """
         Get ReciprocalLength unit abbreviation.
         Note! the default abbreviation for ReciprocalLength is InverseMeter.
@@ -505,73 +512,4 @@ class ReciprocalLength:
         
         if unit_abbreviation == ReciprocalLengthUnits.InverseMicroinch:
             return """µin⁻¹"""
-        
-
-    def __str__(self):
-        return self.to_string()
-
-
-    def __add__(self, other):
-        if not isinstance(other, ReciprocalLength):
-            raise TypeError("unsupported operand type(s) for +: 'ReciprocalLength' and '{}'".format(type(other).__name__))
-        return ReciprocalLength(self.__value + other.__value)
-
-
-    def __mul__(self, other):
-        if not isinstance(other, ReciprocalLength):
-            raise TypeError("unsupported operand type(s) for *: 'ReciprocalLength' and '{}'".format(type(other).__name__))
-        return ReciprocalLength(self.__value * other.__value)
-
-
-    def __sub__(self, other):
-        if not isinstance(other, ReciprocalLength):
-            raise TypeError("unsupported operand type(s) for -: 'ReciprocalLength' and '{}'".format(type(other).__name__))
-        return ReciprocalLength(self.__value - other.__value)
-
-
-    def __truediv__(self, other):
-        if not isinstance(other, ReciprocalLength):
-            raise TypeError("unsupported operand type(s) for /: 'ReciprocalLength' and '{}'".format(type(other).__name__))
-        return ReciprocalLength(self.__value / other.__value)
-
-
-    def __mod__(self, other):
-        if not isinstance(other, ReciprocalLength):
-            raise TypeError("unsupported operand type(s) for %: 'ReciprocalLength' and '{}'".format(type(other).__name__))
-        return ReciprocalLength(self.__value % other.__value)
-
-
-    def __pow__(self, other):
-        if not isinstance(other, ReciprocalLength):
-            raise TypeError("unsupported operand type(s) for **: 'ReciprocalLength' and '{}'".format(type(other).__name__))
-        return ReciprocalLength(self.__value ** other.__value)
-
-
-    def __eq__(self, other):
-        if not isinstance(other, ReciprocalLength):
-            raise TypeError("unsupported operand type(s) for ==: 'ReciprocalLength' and '{}'".format(type(other).__name__))
-        return self.__value == other.__value
-
-
-    def __lt__(self, other):
-        if not isinstance(other, ReciprocalLength):
-            raise TypeError("unsupported operand type(s) for <: 'ReciprocalLength' and '{}'".format(type(other).__name__))
-        return self.__value < other.__value
-
-
-    def __gt__(self, other):
-        if not isinstance(other, ReciprocalLength):
-            raise TypeError("unsupported operand type(s) for >: 'ReciprocalLength' and '{}'".format(type(other).__name__))
-        return self.__value > other.__value
-
-
-    def __le__(self, other):
-        if not isinstance(other, ReciprocalLength):
-            raise TypeError("unsupported operand type(s) for <=: 'ReciprocalLength' and '{}'".format(type(other).__name__))
-        return self.__value <= other.__value
-
-
-    def __ge__(self, other):
-        if not isinstance(other, ReciprocalLength):
-            raise TypeError("unsupported operand type(s) for >=: 'ReciprocalLength' and '{}'".format(type(other).__name__))
-        return self.__value >= other.__value
\ No newline at end of file
+        
\ No newline at end of file
