@@ -1,6 +1,8 @@
 from enum import Enum
 import math
-import string
+
+from ..abstract_unit import AbstractMeasure
+
 
 
 class RotationalSpeedUnits(Enum):
@@ -74,7 +76,7 @@ class RotationalSpeedUnits(Enum):
         """
         
 
-class RotationalSpeed:
+class RotationalSpeed(AbstractMeasure):
     """
     Rotational speed (sometimes called speed of revolution) is the number of complete rotations, revolutions, cycles, or turns per time unit. Rotational speed is a cyclic frequency, measured in radians per second or in hertz in the SI System by scientists, or in revolutions per minute (rpm or min-1) or revolutions per second in everyday life. The symbol for rotational speed is ω (the Greek lowercase letter "omega").
 
@@ -83,9 +85,11 @@ class RotationalSpeed:
         from_unit (RotationalSpeedUnits): The RotationalSpeed unit to create from, The default unit is RadianPerSecond
     """
     def __init__(self, value: float, from_unit: RotationalSpeedUnits = RotationalSpeedUnits.RadianPerSecond):
-        if math.isnan(value):
-            raise ValueError('Invalid unit: value is NaN')
-        self.__value = self.__convert_to_base(value, from_unit)
+        # Do not validate type, to allow working with numpay arrays and similar objects who supports all arithmetic 
+        # operations, but they are not a number, see #14 
+        # if math.isnan(value):
+        #     raise ValueError('Invalid unit: value is NaN')
+        self._value = self.__convert_to_base(value, from_unit)
         
         self.__radians_per_second = None
         
@@ -114,8 +118,11 @@ class RotationalSpeed:
         self.__millidegrees_per_second = None
         
 
+    def convert(self, unit: RotationalSpeedUnits) -> float:
+        return self.__convert_from_base(unit)
+
     def __convert_from_base(self, from_unit: RotationalSpeedUnits) -> float:
-        value = self.__value
+        value = self._value
         
         if from_unit == RotationalSpeedUnits.RadianPerSecond:
             return (value)
@@ -205,7 +212,7 @@ class RotationalSpeed:
 
     @property
     def base_value(self) -> float:
-        return self.__value
+        return self._value
 
     
     @staticmethod
@@ -546,7 +553,7 @@ class RotationalSpeed:
         return self.__millidegrees_per_second
 
     
-    def to_string(self, unit: RotationalSpeedUnits = RotationalSpeedUnits.RadianPerSecond) -> string:
+    def to_string(self, unit: RotationalSpeedUnits = RotationalSpeedUnits.RadianPerSecond) -> str:
         """
         Format the RotationalSpeed to string.
         Note! the default format for RotationalSpeed is RadianPerSecond.
@@ -569,33 +576,33 @@ class RotationalSpeed:
             return f"""{self.revolutions_per_minute} rpm"""
         
         if unit == RotationalSpeedUnits.NanoradianPerSecond:
-            return f"""{self.nanoradians_per_second} """
+            return f"""{self.nanoradians_per_second} nrad/s"""
         
         if unit == RotationalSpeedUnits.MicroradianPerSecond:
-            return f"""{self.microradians_per_second} """
+            return f"""{self.microradians_per_second} μrad/s"""
         
         if unit == RotationalSpeedUnits.MilliradianPerSecond:
-            return f"""{self.milliradians_per_second} """
+            return f"""{self.milliradians_per_second} mrad/s"""
         
         if unit == RotationalSpeedUnits.CentiradianPerSecond:
-            return f"""{self.centiradians_per_second} """
+            return f"""{self.centiradians_per_second} crad/s"""
         
         if unit == RotationalSpeedUnits.DeciradianPerSecond:
-            return f"""{self.deciradians_per_second} """
+            return f"""{self.deciradians_per_second} drad/s"""
         
         if unit == RotationalSpeedUnits.NanodegreePerSecond:
-            return f"""{self.nanodegrees_per_second} """
+            return f"""{self.nanodegrees_per_second} n°/s"""
         
         if unit == RotationalSpeedUnits.MicrodegreePerSecond:
-            return f"""{self.microdegrees_per_second} """
+            return f"""{self.microdegrees_per_second} μ°/s"""
         
         if unit == RotationalSpeedUnits.MillidegreePerSecond:
-            return f"""{self.millidegrees_per_second} """
+            return f"""{self.millidegrees_per_second} m°/s"""
         
-        return f'{self.__value}'
+        return f'{self._value}'
 
 
-    def get_unit_abbreviation(self, unit_abbreviation: RotationalSpeedUnits = RotationalSpeedUnits.RadianPerSecond) -> string:
+    def get_unit_abbreviation(self, unit_abbreviation: RotationalSpeedUnits = RotationalSpeedUnits.RadianPerSecond) -> str:
         """
         Get RotationalSpeed unit abbreviation.
         Note! the default abbreviation for RotationalSpeed is RadianPerSecond.
@@ -618,95 +625,26 @@ class RotationalSpeed:
             return """rpm"""
         
         if unit_abbreviation == RotationalSpeedUnits.NanoradianPerSecond:
-            return """"""
+            return """nrad/s"""
         
         if unit_abbreviation == RotationalSpeedUnits.MicroradianPerSecond:
-            return """"""
+            return """μrad/s"""
         
         if unit_abbreviation == RotationalSpeedUnits.MilliradianPerSecond:
-            return """"""
+            return """mrad/s"""
         
         if unit_abbreviation == RotationalSpeedUnits.CentiradianPerSecond:
-            return """"""
+            return """crad/s"""
         
         if unit_abbreviation == RotationalSpeedUnits.DeciradianPerSecond:
-            return """"""
+            return """drad/s"""
         
         if unit_abbreviation == RotationalSpeedUnits.NanodegreePerSecond:
-            return """"""
+            return """n°/s"""
         
         if unit_abbreviation == RotationalSpeedUnits.MicrodegreePerSecond:
-            return """"""
+            return """μ°/s"""
         
         if unit_abbreviation == RotationalSpeedUnits.MillidegreePerSecond:
-            return """"""
-        
-
-    def __str__(self):
-        return self.to_string()
-
-
-    def __add__(self, other):
-        if not isinstance(other, RotationalSpeed):
-            raise TypeError("unsupported operand type(s) for +: 'RotationalSpeed' and '{}'".format(type(other).__name__))
-        return RotationalSpeed(self.__value + other.__value)
-
-
-    def __mul__(self, other):
-        if not isinstance(other, RotationalSpeed):
-            raise TypeError("unsupported operand type(s) for *: 'RotationalSpeed' and '{}'".format(type(other).__name__))
-        return RotationalSpeed(self.__value * other.__value)
-
-
-    def __sub__(self, other):
-        if not isinstance(other, RotationalSpeed):
-            raise TypeError("unsupported operand type(s) for -: 'RotationalSpeed' and '{}'".format(type(other).__name__))
-        return RotationalSpeed(self.__value - other.__value)
-
-
-    def __truediv__(self, other):
-        if not isinstance(other, RotationalSpeed):
-            raise TypeError("unsupported operand type(s) for /: 'RotationalSpeed' and '{}'".format(type(other).__name__))
-        return RotationalSpeed(self.__value / other.__value)
-
-
-    def __mod__(self, other):
-        if not isinstance(other, RotationalSpeed):
-            raise TypeError("unsupported operand type(s) for %: 'RotationalSpeed' and '{}'".format(type(other).__name__))
-        return RotationalSpeed(self.__value % other.__value)
-
-
-    def __pow__(self, other):
-        if not isinstance(other, RotationalSpeed):
-            raise TypeError("unsupported operand type(s) for **: 'RotationalSpeed' and '{}'".format(type(other).__name__))
-        return RotationalSpeed(self.__value ** other.__value)
-
-
-    def __eq__(self, other):
-        if not isinstance(other, RotationalSpeed):
-            raise TypeError("unsupported operand type(s) for ==: 'RotationalSpeed' and '{}'".format(type(other).__name__))
-        return self.__value == other.__value
-
-
-    def __lt__(self, other):
-        if not isinstance(other, RotationalSpeed):
-            raise TypeError("unsupported operand type(s) for <: 'RotationalSpeed' and '{}'".format(type(other).__name__))
-        return self.__value < other.__value
-
-
-    def __gt__(self, other):
-        if not isinstance(other, RotationalSpeed):
-            raise TypeError("unsupported operand type(s) for >: 'RotationalSpeed' and '{}'".format(type(other).__name__))
-        return self.__value > other.__value
-
-
-    def __le__(self, other):
-        if not isinstance(other, RotationalSpeed):
-            raise TypeError("unsupported operand type(s) for <=: 'RotationalSpeed' and '{}'".format(type(other).__name__))
-        return self.__value <= other.__value
-
-
-    def __ge__(self, other):
-        if not isinstance(other, RotationalSpeed):
-            raise TypeError("unsupported operand type(s) for >=: 'RotationalSpeed' and '{}'".format(type(other).__name__))
-        return self.__value >= other.__value
\ No newline at end of file
+            return """m°/s"""
+        
\ No newline at end of file
