@@ -1,6 +1,8 @@
 from enum import Enum
 import math
-import string
+
+from ..abstract_unit import AbstractMeasure
+
 
 
 class RotationalStiffnessUnits(Enum):
@@ -174,7 +176,7 @@ class RotationalStiffnessUnits(Enum):
         """
         
 
-class RotationalStiffness:
+class RotationalStiffness(AbstractMeasure):
     """
     https://en.wikipedia.org/wiki/Stiffness#Rotational_stiffness
 
@@ -183,9 +185,11 @@ class RotationalStiffness:
         from_unit (RotationalStiffnessUnits): The RotationalStiffness unit to create from, The default unit is NewtonMeterPerRadian
     """
     def __init__(self, value: float, from_unit: RotationalStiffnessUnits = RotationalStiffnessUnits.NewtonMeterPerRadian):
-        if math.isnan(value):
-            raise ValueError('Invalid unit: value is NaN')
-        self.__value = self.__convert_to_base(value, from_unit)
+        # Do not validate type, to allow working with numpay arrays and similar objects who supports all arithmetic 
+        # operations, but they are not a number, see #14 
+        # if math.isnan(value):
+        #     raise ValueError('Invalid unit: value is NaN')
+        self._value = self.__convert_to_base(value, from_unit)
         
         self.__newton_meters_per_radian = None
         
@@ -254,8 +258,11 @@ class RotationalStiffness:
         self.__meganewton_millimeters_per_radian = None
         
 
+    def convert(self, unit: RotationalStiffnessUnits) -> float:
+        return self.__convert_from_base(unit)
+
     def __convert_from_base(self, from_unit: RotationalStiffnessUnits) -> float:
-        value = self.__value
+        value = self._value
         
         if from_unit == RotationalStiffnessUnits.NewtonMeterPerRadian:
             return (value)
@@ -465,7 +472,7 @@ class RotationalStiffness:
 
     @property
     def base_value(self) -> float:
-        return self.__value
+        return self._value
 
     
     @staticmethod
@@ -1326,7 +1333,7 @@ class RotationalStiffness:
         return self.__meganewton_millimeters_per_radian
 
     
-    def to_string(self, unit: RotationalStiffnessUnits = RotationalStiffnessUnits.NewtonMeterPerRadian) -> string:
+    def to_string(self, unit: RotationalStiffnessUnits = RotationalStiffnessUnits.NewtonMeterPerRadian) -> str:
         """
         Format the RotationalStiffness to string.
         Note! the default format for RotationalStiffness is NewtonMeterPerRadian.
@@ -1355,87 +1362,87 @@ class RotationalStiffness:
             return f"""{self.pound_force_feet_per_radian} lbf·ft/rad"""
         
         if unit == RotationalStiffnessUnits.KilonewtonMeterPerRadian:
-            return f"""{self.kilonewton_meters_per_radian} """
+            return f"""{self.kilonewton_meters_per_radian} kN·m/rad"""
         
         if unit == RotationalStiffnessUnits.MeganewtonMeterPerRadian:
-            return f"""{self.meganewton_meters_per_radian} """
+            return f"""{self.meganewton_meters_per_radian} MN·m/rad"""
         
         if unit == RotationalStiffnessUnits.NanonewtonMillimeterPerDegree:
-            return f"""{self.nanonewton_millimeters_per_degree} """
+            return f"""{self.nanonewton_millimeters_per_degree} nN·mm/deg"""
         
         if unit == RotationalStiffnessUnits.MicronewtonMillimeterPerDegree:
-            return f"""{self.micronewton_millimeters_per_degree} """
+            return f"""{self.micronewton_millimeters_per_degree} μN·mm/deg"""
         
         if unit == RotationalStiffnessUnits.MillinewtonMillimeterPerDegree:
-            return f"""{self.millinewton_millimeters_per_degree} """
+            return f"""{self.millinewton_millimeters_per_degree} mN·mm/deg"""
         
         if unit == RotationalStiffnessUnits.CentinewtonMillimeterPerDegree:
-            return f"""{self.centinewton_millimeters_per_degree} """
+            return f"""{self.centinewton_millimeters_per_degree} cN·mm/deg"""
         
         if unit == RotationalStiffnessUnits.DecinewtonMillimeterPerDegree:
-            return f"""{self.decinewton_millimeters_per_degree} """
+            return f"""{self.decinewton_millimeters_per_degree} dN·mm/deg"""
         
         if unit == RotationalStiffnessUnits.DecanewtonMillimeterPerDegree:
-            return f"""{self.decanewton_millimeters_per_degree} """
+            return f"""{self.decanewton_millimeters_per_degree} daN·mm/deg"""
         
         if unit == RotationalStiffnessUnits.KilonewtonMillimeterPerDegree:
-            return f"""{self.kilonewton_millimeters_per_degree} """
+            return f"""{self.kilonewton_millimeters_per_degree} kN·mm/deg"""
         
         if unit == RotationalStiffnessUnits.MeganewtonMillimeterPerDegree:
-            return f"""{self.meganewton_millimeters_per_degree} """
+            return f"""{self.meganewton_millimeters_per_degree} MN·mm/deg"""
         
         if unit == RotationalStiffnessUnits.NanonewtonMeterPerDegree:
-            return f"""{self.nanonewton_meters_per_degree} """
+            return f"""{self.nanonewton_meters_per_degree} nN·m/deg"""
         
         if unit == RotationalStiffnessUnits.MicronewtonMeterPerDegree:
-            return f"""{self.micronewton_meters_per_degree} """
+            return f"""{self.micronewton_meters_per_degree} μN·m/deg"""
         
         if unit == RotationalStiffnessUnits.MillinewtonMeterPerDegree:
-            return f"""{self.millinewton_meters_per_degree} """
+            return f"""{self.millinewton_meters_per_degree} mN·m/deg"""
         
         if unit == RotationalStiffnessUnits.CentinewtonMeterPerDegree:
-            return f"""{self.centinewton_meters_per_degree} """
+            return f"""{self.centinewton_meters_per_degree} cN·m/deg"""
         
         if unit == RotationalStiffnessUnits.DecinewtonMeterPerDegree:
-            return f"""{self.decinewton_meters_per_degree} """
+            return f"""{self.decinewton_meters_per_degree} dN·m/deg"""
         
         if unit == RotationalStiffnessUnits.DecanewtonMeterPerDegree:
-            return f"""{self.decanewton_meters_per_degree} """
+            return f"""{self.decanewton_meters_per_degree} daN·m/deg"""
         
         if unit == RotationalStiffnessUnits.KilonewtonMeterPerDegree:
-            return f"""{self.kilonewton_meters_per_degree} """
+            return f"""{self.kilonewton_meters_per_degree} kN·m/deg"""
         
         if unit == RotationalStiffnessUnits.MeganewtonMeterPerDegree:
-            return f"""{self.meganewton_meters_per_degree} """
+            return f"""{self.meganewton_meters_per_degree} MN·m/deg"""
         
         if unit == RotationalStiffnessUnits.NanonewtonMillimeterPerRadian:
-            return f"""{self.nanonewton_millimeters_per_radian} """
+            return f"""{self.nanonewton_millimeters_per_radian} nN·mm/rad"""
         
         if unit == RotationalStiffnessUnits.MicronewtonMillimeterPerRadian:
-            return f"""{self.micronewton_millimeters_per_radian} """
+            return f"""{self.micronewton_millimeters_per_radian} μN·mm/rad"""
         
         if unit == RotationalStiffnessUnits.MillinewtonMillimeterPerRadian:
-            return f"""{self.millinewton_millimeters_per_radian} """
+            return f"""{self.millinewton_millimeters_per_radian} mN·mm/rad"""
         
         if unit == RotationalStiffnessUnits.CentinewtonMillimeterPerRadian:
-            return f"""{self.centinewton_millimeters_per_radian} """
+            return f"""{self.centinewton_millimeters_per_radian} cN·mm/rad"""
         
         if unit == RotationalStiffnessUnits.DecinewtonMillimeterPerRadian:
-            return f"""{self.decinewton_millimeters_per_radian} """
+            return f"""{self.decinewton_millimeters_per_radian} dN·mm/rad"""
         
         if unit == RotationalStiffnessUnits.DecanewtonMillimeterPerRadian:
-            return f"""{self.decanewton_millimeters_per_radian} """
+            return f"""{self.decanewton_millimeters_per_radian} daN·mm/rad"""
         
         if unit == RotationalStiffnessUnits.KilonewtonMillimeterPerRadian:
-            return f"""{self.kilonewton_millimeters_per_radian} """
+            return f"""{self.kilonewton_millimeters_per_radian} kN·mm/rad"""
         
         if unit == RotationalStiffnessUnits.MeganewtonMillimeterPerRadian:
-            return f"""{self.meganewton_millimeters_per_radian} """
+            return f"""{self.meganewton_millimeters_per_radian} MN·mm/rad"""
         
-        return f'{self.__value}'
+        return f'{self._value}'
 
 
-    def get_unit_abbreviation(self, unit_abbreviation: RotationalStiffnessUnits = RotationalStiffnessUnits.NewtonMeterPerRadian) -> string:
+    def get_unit_abbreviation(self, unit_abbreviation: RotationalStiffnessUnits = RotationalStiffnessUnits.NewtonMeterPerRadian) -> str:
         """
         Get RotationalStiffness unit abbreviation.
         Note! the default abbreviation for RotationalStiffness is NewtonMeterPerRadian.
@@ -1464,149 +1471,80 @@ class RotationalStiffness:
             return """lbf·ft/rad"""
         
         if unit_abbreviation == RotationalStiffnessUnits.KilonewtonMeterPerRadian:
-            return """"""
+            return """kN·m/rad"""
         
         if unit_abbreviation == RotationalStiffnessUnits.MeganewtonMeterPerRadian:
-            return """"""
+            return """MN·m/rad"""
         
         if unit_abbreviation == RotationalStiffnessUnits.NanonewtonMillimeterPerDegree:
-            return """"""
+            return """nN·mm/deg"""
         
         if unit_abbreviation == RotationalStiffnessUnits.MicronewtonMillimeterPerDegree:
-            return """"""
+            return """μN·mm/deg"""
         
         if unit_abbreviation == RotationalStiffnessUnits.MillinewtonMillimeterPerDegree:
-            return """"""
+            return """mN·mm/deg"""
         
         if unit_abbreviation == RotationalStiffnessUnits.CentinewtonMillimeterPerDegree:
-            return """"""
+            return """cN·mm/deg"""
         
         if unit_abbreviation == RotationalStiffnessUnits.DecinewtonMillimeterPerDegree:
-            return """"""
+            return """dN·mm/deg"""
         
         if unit_abbreviation == RotationalStiffnessUnits.DecanewtonMillimeterPerDegree:
-            return """"""
+            return """daN·mm/deg"""
         
         if unit_abbreviation == RotationalStiffnessUnits.KilonewtonMillimeterPerDegree:
-            return """"""
+            return """kN·mm/deg"""
         
         if unit_abbreviation == RotationalStiffnessUnits.MeganewtonMillimeterPerDegree:
-            return """"""
+            return """MN·mm/deg"""
         
         if unit_abbreviation == RotationalStiffnessUnits.NanonewtonMeterPerDegree:
-            return """"""
+            return """nN·m/deg"""
         
         if unit_abbreviation == RotationalStiffnessUnits.MicronewtonMeterPerDegree:
-            return """"""
+            return """μN·m/deg"""
         
         if unit_abbreviation == RotationalStiffnessUnits.MillinewtonMeterPerDegree:
-            return """"""
+            return """mN·m/deg"""
         
         if unit_abbreviation == RotationalStiffnessUnits.CentinewtonMeterPerDegree:
-            return """"""
+            return """cN·m/deg"""
         
         if unit_abbreviation == RotationalStiffnessUnits.DecinewtonMeterPerDegree:
-            return """"""
+            return """dN·m/deg"""
         
         if unit_abbreviation == RotationalStiffnessUnits.DecanewtonMeterPerDegree:
-            return """"""
+            return """daN·m/deg"""
         
         if unit_abbreviation == RotationalStiffnessUnits.KilonewtonMeterPerDegree:
-            return """"""
+            return """kN·m/deg"""
         
         if unit_abbreviation == RotationalStiffnessUnits.MeganewtonMeterPerDegree:
-            return """"""
+            return """MN·m/deg"""
         
         if unit_abbreviation == RotationalStiffnessUnits.NanonewtonMillimeterPerRadian:
-            return """"""
+            return """nN·mm/rad"""
         
         if unit_abbreviation == RotationalStiffnessUnits.MicronewtonMillimeterPerRadian:
-            return """"""
+            return """μN·mm/rad"""
         
         if unit_abbreviation == RotationalStiffnessUnits.MillinewtonMillimeterPerRadian:
-            return """"""
+            return """mN·mm/rad"""
         
         if unit_abbreviation == RotationalStiffnessUnits.CentinewtonMillimeterPerRadian:
-            return """"""
+            return """cN·mm/rad"""
         
         if unit_abbreviation == RotationalStiffnessUnits.DecinewtonMillimeterPerRadian:
-            return """"""
+            return """dN·mm/rad"""
         
         if unit_abbreviation == RotationalStiffnessUnits.DecanewtonMillimeterPerRadian:
-            return """"""
+            return """daN·mm/rad"""
         
         if unit_abbreviation == RotationalStiffnessUnits.KilonewtonMillimeterPerRadian:
-            return """"""
+            return """kN·mm/rad"""
         
         if unit_abbreviation == RotationalStiffnessUnits.MeganewtonMillimeterPerRadian:
-            return """"""
-        
-
-    def __str__(self):
-        return self.to_string()
-
-
-    def __add__(self, other):
-        if not isinstance(other, RotationalStiffness):
-            raise TypeError("unsupported operand type(s) for +: 'RotationalStiffness' and '{}'".format(type(other).__name__))
-        return RotationalStiffness(self.__value + other.__value)
-
-
-    def __mul__(self, other):
-        if not isinstance(other, RotationalStiffness):
-            raise TypeError("unsupported operand type(s) for *: 'RotationalStiffness' and '{}'".format(type(other).__name__))
-        return RotationalStiffness(self.__value * other.__value)
-
-
-    def __sub__(self, other):
-        if not isinstance(other, RotationalStiffness):
-            raise TypeError("unsupported operand type(s) for -: 'RotationalStiffness' and '{}'".format(type(other).__name__))
-        return RotationalStiffness(self.__value - other.__value)
-
-
-    def __truediv__(self, other):
-        if not isinstance(other, RotationalStiffness):
-            raise TypeError("unsupported operand type(s) for /: 'RotationalStiffness' and '{}'".format(type(other).__name__))
-        return RotationalStiffness(self.__value / other.__value)
-
-
-    def __mod__(self, other):
-        if not isinstance(other, RotationalStiffness):
-            raise TypeError("unsupported operand type(s) for %: 'RotationalStiffness' and '{}'".format(type(other).__name__))
-        return RotationalStiffness(self.__value % other.__value)
-
-
-    def __pow__(self, other):
-        if not isinstance(other, RotationalStiffness):
-            raise TypeError("unsupported operand type(s) for **: 'RotationalStiffness' and '{}'".format(type(other).__name__))
-        return RotationalStiffness(self.__value ** other.__value)
-
-
-    def __eq__(self, other):
-        if not isinstance(other, RotationalStiffness):
-            raise TypeError("unsupported operand type(s) for ==: 'RotationalStiffness' and '{}'".format(type(other).__name__))
-        return self.__value == other.__value
-
-
-    def __lt__(self, other):
-        if not isinstance(other, RotationalStiffness):
-            raise TypeError("unsupported operand type(s) for <: 'RotationalStiffness' and '{}'".format(type(other).__name__))
-        return self.__value < other.__value
-
-
-    def __gt__(self, other):
-        if not isinstance(other, RotationalStiffness):
-            raise TypeError("unsupported operand type(s) for >: 'RotationalStiffness' and '{}'".format(type(other).__name__))
-        return self.__value > other.__value
-
-
-    def __le__(self, other):
-        if not isinstance(other, RotationalStiffness):
-            raise TypeError("unsupported operand type(s) for <=: 'RotationalStiffness' and '{}'".format(type(other).__name__))
-        return self.__value <= other.__value
-
-
-    def __ge__(self, other):
-        if not isinstance(other, RotationalStiffness):
-            raise TypeError("unsupported operand type(s) for >=: 'RotationalStiffness' and '{}'".format(type(other).__name__))
-        return self.__value >= other.__value
\ No newline at end of file
+            return """MN·mm/rad"""
+        
\ No newline at end of file
