@@ -1,6 +1,8 @@
 from enum import Enum
 import math
-import string
+
+from ..abstract_unit import AbstractMeasure
+
 
 
 class SpecificEnergyUnits(Enum):
@@ -159,7 +161,7 @@ class SpecificEnergyUnits(Enum):
         """
         
 
-class SpecificEnergy:
+class SpecificEnergy(AbstractMeasure):
     """
     The SpecificEnergy
 
@@ -168,9 +170,11 @@ class SpecificEnergy:
         from_unit (SpecificEnergyUnits): The SpecificEnergy unit to create from, The default unit is JoulePerKilogram
     """
     def __init__(self, value: float, from_unit: SpecificEnergyUnits = SpecificEnergyUnits.JoulePerKilogram):
-        if math.isnan(value):
-            raise ValueError('Invalid unit: value is NaN')
-        self.__value = self.__convert_to_base(value, from_unit)
+        # Do not validate type, to allow working with numpay arrays and similar objects who supports all arithmetic 
+        # operations, but they are not a number, see #14 
+        # if math.isnan(value):
+        #     raise ValueError('Invalid unit: value is NaN')
+        self._value = self.__convert_to_base(value, from_unit)
         
         self.__joules_per_kilogram = None
         
@@ -233,8 +237,11 @@ class SpecificEnergy:
         self.__gigawatt_hours_per_pound = None
         
 
+    def convert(self, unit: SpecificEnergyUnits) -> float:
+        return self.__convert_from_base(unit)
+
     def __convert_from_base(self, from_unit: SpecificEnergyUnits) -> float:
-        value = self.__value
+        value = self._value
         
         if from_unit == SpecificEnergyUnits.JoulePerKilogram:
             return (value)
@@ -426,7 +433,7 @@ class SpecificEnergy:
 
     @property
     def base_value(self) -> float:
-        return self.__value
+        return self._value
 
     
     @staticmethod
@@ -1209,7 +1216,7 @@ class SpecificEnergy:
         return self.__gigawatt_hours_per_pound
 
     
-    def to_string(self, unit: SpecificEnergyUnits = SpecificEnergyUnits.JoulePerKilogram) -> string:
+    def to_string(self, unit: SpecificEnergyUnits = SpecificEnergyUnits.JoulePerKilogram) -> str:
         """
         Format the SpecificEnergy to string.
         Note! the default format for SpecificEnergy is JoulePerKilogram.
@@ -1244,72 +1251,72 @@ class SpecificEnergy:
             return f"""{self.btu_per_pound} btu/lb"""
         
         if unit == SpecificEnergyUnits.KilojoulePerKilogram:
-            return f"""{self.kilojoules_per_kilogram} """
+            return f"""{self.kilojoules_per_kilogram} kJ/kg"""
         
         if unit == SpecificEnergyUnits.MegajoulePerKilogram:
-            return f"""{self.megajoules_per_kilogram} """
+            return f"""{self.megajoules_per_kilogram} MJ/kg"""
         
         if unit == SpecificEnergyUnits.KilocaloriePerGram:
-            return f"""{self.kilocalories_per_gram} """
+            return f"""{self.kilocalories_per_gram} kcal/g"""
         
         if unit == SpecificEnergyUnits.KilowattHourPerKilogram:
-            return f"""{self.kilowatt_hours_per_kilogram} """
+            return f"""{self.kilowatt_hours_per_kilogram} kWh/kg"""
         
         if unit == SpecificEnergyUnits.MegawattHourPerKilogram:
-            return f"""{self.megawatt_hours_per_kilogram} """
+            return f"""{self.megawatt_hours_per_kilogram} MWh/kg"""
         
         if unit == SpecificEnergyUnits.GigawattHourPerKilogram:
-            return f"""{self.gigawatt_hours_per_kilogram} """
+            return f"""{self.gigawatt_hours_per_kilogram} GWh/kg"""
         
         if unit == SpecificEnergyUnits.KilowattDayPerKilogram:
-            return f"""{self.kilowatt_days_per_kilogram} """
+            return f"""{self.kilowatt_days_per_kilogram} kWd/kg"""
         
         if unit == SpecificEnergyUnits.MegawattDayPerKilogram:
-            return f"""{self.megawatt_days_per_kilogram} """
+            return f"""{self.megawatt_days_per_kilogram} MWd/kg"""
         
         if unit == SpecificEnergyUnits.GigawattDayPerKilogram:
-            return f"""{self.gigawatt_days_per_kilogram} """
+            return f"""{self.gigawatt_days_per_kilogram} GWd/kg"""
         
         if unit == SpecificEnergyUnits.TerawattDayPerKilogram:
-            return f"""{self.terawatt_days_per_kilogram} """
+            return f"""{self.terawatt_days_per_kilogram} TWd/kg"""
         
         if unit == SpecificEnergyUnits.KilowattDayPerTonne:
-            return f"""{self.kilowatt_days_per_tonne} """
+            return f"""{self.kilowatt_days_per_tonne} kWd/t"""
         
         if unit == SpecificEnergyUnits.MegawattDayPerTonne:
-            return f"""{self.megawatt_days_per_tonne} """
+            return f"""{self.megawatt_days_per_tonne} MWd/t"""
         
         if unit == SpecificEnergyUnits.GigawattDayPerTonne:
-            return f"""{self.gigawatt_days_per_tonne} """
+            return f"""{self.gigawatt_days_per_tonne} GWd/t"""
         
         if unit == SpecificEnergyUnits.TerawattDayPerTonne:
-            return f"""{self.terawatt_days_per_tonne} """
+            return f"""{self.terawatt_days_per_tonne} TWd/t"""
         
         if unit == SpecificEnergyUnits.KilowattDayPerShortTon:
-            return f"""{self.kilowatt_days_per_short_ton} """
+            return f"""{self.kilowatt_days_per_short_ton} kWd/ST"""
         
         if unit == SpecificEnergyUnits.MegawattDayPerShortTon:
-            return f"""{self.megawatt_days_per_short_ton} """
+            return f"""{self.megawatt_days_per_short_ton} MWd/ST"""
         
         if unit == SpecificEnergyUnits.GigawattDayPerShortTon:
-            return f"""{self.gigawatt_days_per_short_ton} """
+            return f"""{self.gigawatt_days_per_short_ton} GWd/ST"""
         
         if unit == SpecificEnergyUnits.TerawattDayPerShortTon:
-            return f"""{self.terawatt_days_per_short_ton} """
+            return f"""{self.terawatt_days_per_short_ton} TWd/ST"""
         
         if unit == SpecificEnergyUnits.KilowattHourPerPound:
-            return f"""{self.kilowatt_hours_per_pound} """
+            return f"""{self.kilowatt_hours_per_pound} kWh/lbs"""
         
         if unit == SpecificEnergyUnits.MegawattHourPerPound:
-            return f"""{self.megawatt_hours_per_pound} """
+            return f"""{self.megawatt_hours_per_pound} MWh/lbs"""
         
         if unit == SpecificEnergyUnits.GigawattHourPerPound:
-            return f"""{self.gigawatt_hours_per_pound} """
+            return f"""{self.gigawatt_hours_per_pound} GWh/lbs"""
         
-        return f'{self.__value}'
+        return f'{self._value}'
 
 
-    def get_unit_abbreviation(self, unit_abbreviation: SpecificEnergyUnits = SpecificEnergyUnits.JoulePerKilogram) -> string:
+    def get_unit_abbreviation(self, unit_abbreviation: SpecificEnergyUnits = SpecificEnergyUnits.JoulePerKilogram) -> str:
         """
         Get SpecificEnergy unit abbreviation.
         Note! the default abbreviation for SpecificEnergy is JoulePerKilogram.
@@ -1344,134 +1351,65 @@ class SpecificEnergy:
             return """btu/lb"""
         
         if unit_abbreviation == SpecificEnergyUnits.KilojoulePerKilogram:
-            return """"""
+            return """kJ/kg"""
         
         if unit_abbreviation == SpecificEnergyUnits.MegajoulePerKilogram:
-            return """"""
+            return """MJ/kg"""
         
         if unit_abbreviation == SpecificEnergyUnits.KilocaloriePerGram:
-            return """"""
+            return """kcal/g"""
         
         if unit_abbreviation == SpecificEnergyUnits.KilowattHourPerKilogram:
-            return """"""
+            return """kWh/kg"""
         
         if unit_abbreviation == SpecificEnergyUnits.MegawattHourPerKilogram:
-            return """"""
+            return """MWh/kg"""
         
         if unit_abbreviation == SpecificEnergyUnits.GigawattHourPerKilogram:
-            return """"""
+            return """GWh/kg"""
         
         if unit_abbreviation == SpecificEnergyUnits.KilowattDayPerKilogram:
-            return """"""
+            return """kWd/kg"""
         
         if unit_abbreviation == SpecificEnergyUnits.MegawattDayPerKilogram:
-            return """"""
+            return """MWd/kg"""
         
         if unit_abbreviation == SpecificEnergyUnits.GigawattDayPerKilogram:
-            return """"""
+            return """GWd/kg"""
         
         if unit_abbreviation == SpecificEnergyUnits.TerawattDayPerKilogram:
-            return """"""
+            return """TWd/kg"""
         
         if unit_abbreviation == SpecificEnergyUnits.KilowattDayPerTonne:
-            return """"""
+            return """kWd/t"""
         
         if unit_abbreviation == SpecificEnergyUnits.MegawattDayPerTonne:
-            return """"""
+            return """MWd/t"""
         
         if unit_abbreviation == SpecificEnergyUnits.GigawattDayPerTonne:
-            return """"""
+            return """GWd/t"""
         
         if unit_abbreviation == SpecificEnergyUnits.TerawattDayPerTonne:
-            return """"""
+            return """TWd/t"""
         
         if unit_abbreviation == SpecificEnergyUnits.KilowattDayPerShortTon:
-            return """"""
+            return """kWd/ST"""
         
         if unit_abbreviation == SpecificEnergyUnits.MegawattDayPerShortTon:
-            return """"""
+            return """MWd/ST"""
         
         if unit_abbreviation == SpecificEnergyUnits.GigawattDayPerShortTon:
-            return """"""
+            return """GWd/ST"""
         
         if unit_abbreviation == SpecificEnergyUnits.TerawattDayPerShortTon:
-            return """"""
+            return """TWd/ST"""
         
         if unit_abbreviation == SpecificEnergyUnits.KilowattHourPerPound:
-            return """"""
+            return """kWh/lbs"""
         
         if unit_abbreviation == SpecificEnergyUnits.MegawattHourPerPound:
-            return """"""
+            return """MWh/lbs"""
         
         if unit_abbreviation == SpecificEnergyUnits.GigawattHourPerPound:
-            return """"""
-        
-
-    def __str__(self):
-        return self.to_string()
-
-
-    def __add__(self, other):
-        if not isinstance(other, SpecificEnergy):
-            raise TypeError("unsupported operand type(s) for +: 'SpecificEnergy' and '{}'".format(type(other).__name__))
-        return SpecificEnergy(self.__value + other.__value)
-
-
-    def __mul__(self, other):
-        if not isinstance(other, SpecificEnergy):
-            raise TypeError("unsupported operand type(s) for *: 'SpecificEnergy' and '{}'".format(type(other).__name__))
-        return SpecificEnergy(self.__value * other.__value)
-
-
-    def __sub__(self, other):
-        if not isinstance(other, SpecificEnergy):
-            raise TypeError("unsupported operand type(s) for -: 'SpecificEnergy' and '{}'".format(type(other).__name__))
-        return SpecificEnergy(self.__value - other.__value)
-
-
-    def __truediv__(self, other):
-        if not isinstance(other, SpecificEnergy):
-            raise TypeError("unsupported operand type(s) for /: 'SpecificEnergy' and '{}'".format(type(other).__name__))
-        return SpecificEnergy(self.__value / other.__value)
-
-
-    def __mod__(self, other):
-        if not isinstance(other, SpecificEnergy):
-            raise TypeError("unsupported operand type(s) for %: 'SpecificEnergy' and '{}'".format(type(other).__name__))
-        return SpecificEnergy(self.__value % other.__value)
-
-
-    def __pow__(self, other):
-        if not isinstance(other, SpecificEnergy):
-            raise TypeError("unsupported operand type(s) for **: 'SpecificEnergy' and '{}'".format(type(other).__name__))
-        return SpecificEnergy(self.__value ** other.__value)
-
-
-    def __eq__(self, other):
-        if not isinstance(other, SpecificEnergy):
-            raise TypeError("unsupported operand type(s) for ==: 'SpecificEnergy' and '{}'".format(type(other).__name__))
-        return self.__value == other.__value
-
-
-    def __lt__(self, other):
-        if not isinstance(other, SpecificEnergy):
-            raise TypeError("unsupported operand type(s) for <: 'SpecificEnergy' and '{}'".format(type(other).__name__))
-        return self.__value < other.__value
-
-
-    def __gt__(self, other):
-        if not isinstance(other, SpecificEnergy):
-            raise TypeError("unsupported operand type(s) for >: 'SpecificEnergy' and '{}'".format(type(other).__name__))
-        return self.__value > other.__value
-
-
-    def __le__(self, other):
-        if not isinstance(other, SpecificEnergy):
-            raise TypeError("unsupported operand type(s) for <=: 'SpecificEnergy' and '{}'".format(type(other).__name__))
-        return self.__value <= other.__value
-
-
-    def __ge__(self, other):
-        if not isinstance(other, SpecificEnergy):
-            raise TypeError("unsupported operand type(s) for >=: 'SpecificEnergy' and '{}'".format(type(other).__name__))
-        return self.__value >= other.__value
\ No newline at end of file
+            return """GWh/lbs"""
+        
\ No newline at end of file
