@@ -1,6 +1,8 @@
 from enum import Enum
 import math
-import string
+
+from ..abstract_unit import AbstractMeasure
+
 
 
 class SpecificEntropyUnits(Enum):
@@ -54,7 +56,7 @@ class SpecificEntropyUnits(Enum):
         """
         
 
-class SpecificEntropy:
+class SpecificEntropy(AbstractMeasure):
     """
     Specific entropy is an amount of energy required to raise temperature of a substance by 1 Kelvin per unit mass.
 
@@ -63,9 +65,11 @@ class SpecificEntropy:
         from_unit (SpecificEntropyUnits): The SpecificEntropy unit to create from, The default unit is JoulePerKilogramKelvin
     """
     def __init__(self, value: float, from_unit: SpecificEntropyUnits = SpecificEntropyUnits.JoulePerKilogramKelvin):
-        if math.isnan(value):
-            raise ValueError('Invalid unit: value is NaN')
-        self.__value = self.__convert_to_base(value, from_unit)
+        # Do not validate type, to allow working with numpay arrays and similar objects who supports all arithmetic 
+        # operations, but they are not a number, see #14 
+        # if math.isnan(value):
+        #     raise ValueError('Invalid unit: value is NaN')
+        self._value = self.__convert_to_base(value, from_unit)
         
         self.__joules_per_kilogram_kelvin = None
         
@@ -86,8 +90,11 @@ class SpecificEntropy:
         self.__kilocalories_per_gram_kelvin = None
         
 
+    def convert(self, unit: SpecificEntropyUnits) -> float:
+        return self.__convert_from_base(unit)
+
     def __convert_from_base(self, from_unit: SpecificEntropyUnits) -> float:
-        value = self.__value
+        value = self._value
         
         if from_unit == SpecificEntropyUnits.JoulePerKilogramKelvin:
             return (value)
@@ -153,7 +160,7 @@ class SpecificEntropy:
 
     @property
     def base_value(self) -> float:
-        return self.__value
+        return self._value
 
     
     @staticmethod
@@ -390,7 +397,7 @@ class SpecificEntropy:
         return self.__kilocalories_per_gram_kelvin
 
     
-    def to_string(self, unit: SpecificEntropyUnits = SpecificEntropyUnits.JoulePerKilogramKelvin) -> string:
+    def to_string(self, unit: SpecificEntropyUnits = SpecificEntropyUnits.JoulePerKilogramKelvin) -> str:
         """
         Format the SpecificEntropy to string.
         Note! the default format for SpecificEntropy is JoulePerKilogramKelvin.
@@ -410,24 +417,24 @@ class SpecificEntropy:
             return f"""{self.btus_per_pound_fahrenheit} BTU/lb·°F"""
         
         if unit == SpecificEntropyUnits.KilojoulePerKilogramKelvin:
-            return f"""{self.kilojoules_per_kilogram_kelvin} """
+            return f"""{self.kilojoules_per_kilogram_kelvin} kJ/kg.K"""
         
         if unit == SpecificEntropyUnits.MegajoulePerKilogramKelvin:
-            return f"""{self.megajoules_per_kilogram_kelvin} """
+            return f"""{self.megajoules_per_kilogram_kelvin} MJ/kg.K"""
         
         if unit == SpecificEntropyUnits.KilojoulePerKilogramDegreeCelsius:
-            return f"""{self.kilojoules_per_kilogram_degree_celsius} """
+            return f"""{self.kilojoules_per_kilogram_degree_celsius} kJ/kg.C"""
         
         if unit == SpecificEntropyUnits.MegajoulePerKilogramDegreeCelsius:
-            return f"""{self.megajoules_per_kilogram_degree_celsius} """
+            return f"""{self.megajoules_per_kilogram_degree_celsius} MJ/kg.C"""
         
         if unit == SpecificEntropyUnits.KilocaloriePerGramKelvin:
-            return f"""{self.kilocalories_per_gram_kelvin} """
+            return f"""{self.kilocalories_per_gram_kelvin} kcal/g.K"""
         
-        return f'{self.__value}'
+        return f'{self._value}'
 
 
-    def get_unit_abbreviation(self, unit_abbreviation: SpecificEntropyUnits = SpecificEntropyUnits.JoulePerKilogramKelvin) -> string:
+    def get_unit_abbreviation(self, unit_abbreviation: SpecificEntropyUnits = SpecificEntropyUnits.JoulePerKilogramKelvin) -> str:
         """
         Get SpecificEntropy unit abbreviation.
         Note! the default abbreviation for SpecificEntropy is JoulePerKilogramKelvin.
@@ -447,86 +454,17 @@ class SpecificEntropy:
             return """BTU/lb·°F"""
         
         if unit_abbreviation == SpecificEntropyUnits.KilojoulePerKilogramKelvin:
-            return """"""
+            return """kJ/kg.K"""
         
         if unit_abbreviation == SpecificEntropyUnits.MegajoulePerKilogramKelvin:
-            return """"""
+            return """MJ/kg.K"""
         
         if unit_abbreviation == SpecificEntropyUnits.KilojoulePerKilogramDegreeCelsius:
-            return """"""
+            return """kJ/kg.C"""
         
         if unit_abbreviation == SpecificEntropyUnits.MegajoulePerKilogramDegreeCelsius:
-            return """"""
+            return """MJ/kg.C"""
         
         if unit_abbreviation == SpecificEntropyUnits.KilocaloriePerGramKelvin:
-            return """"""
-        
-
-    def __str__(self):
-        return self.to_string()
-
-
-    def __add__(self, other):
-        if not isinstance(other, SpecificEntropy):
-            raise TypeError("unsupported operand type(s) for +: 'SpecificEntropy' and '{}'".format(type(other).__name__))
-        return SpecificEntropy(self.__value + other.__value)
-
-
-    def __mul__(self, other):
-        if not isinstance(other, SpecificEntropy):
-            raise TypeError("unsupported operand type(s) for *: 'SpecificEntropy' and '{}'".format(type(other).__name__))
-        return SpecificEntropy(self.__value * other.__value)
-
-
-    def __sub__(self, other):
-        if not isinstance(other, SpecificEntropy):
-            raise TypeError("unsupported operand type(s) for -: 'SpecificEntropy' and '{}'".format(type(other).__name__))
-        return SpecificEntropy(self.__value - other.__value)
-
-
-    def __truediv__(self, other):
-        if not isinstance(other, SpecificEntropy):
-            raise TypeError("unsupported operand type(s) for /: 'SpecificEntropy' and '{}'".format(type(other).__name__))
-        return SpecificEntropy(self.__value / other.__value)
-
-
-    def __mod__(self, other):
-        if not isinstance(other, SpecificEntropy):
-            raise TypeError("unsupported operand type(s) for %: 'SpecificEntropy' and '{}'".format(type(other).__name__))
-        return SpecificEntropy(self.__value % other.__value)
-
-
-    def __pow__(self, other):
-        if not isinstance(other, SpecificEntropy):
-            raise TypeError("unsupported operand type(s) for **: 'SpecificEntropy' and '{}'".format(type(other).__name__))
-        return SpecificEntropy(self.__value ** other.__value)
-
-
-    def __eq__(self, other):
-        if not isinstance(other, SpecificEntropy):
-            raise TypeError("unsupported operand type(s) for ==: 'SpecificEntropy' and '{}'".format(type(other).__name__))
-        return self.__value == other.__value
-
-
-    def __lt__(self, other):
-        if not isinstance(other, SpecificEntropy):
-            raise TypeError("unsupported operand type(s) for <: 'SpecificEntropy' and '{}'".format(type(other).__name__))
-        return self.__value < other.__value
-
-
-    def __gt__(self, other):
-        if not isinstance(other, SpecificEntropy):
-            raise TypeError("unsupported operand type(s) for >: 'SpecificEntropy' and '{}'".format(type(other).__name__))
-        return self.__value > other.__value
-
-
-    def __le__(self, other):
-        if not isinstance(other, SpecificEntropy):
-            raise TypeError("unsupported operand type(s) for <=: 'SpecificEntropy' and '{}'".format(type(other).__name__))
-        return self.__value <= other.__value
-
-
-    def __ge__(self, other):
-        if not isinstance(other, SpecificEntropy):
-            raise TypeError("unsupported operand type(s) for >=: 'SpecificEntropy' and '{}'".format(type(other).__name__))
-        return self.__value >= other.__value
\ No newline at end of file
+            return """kcal/g.K"""
+        
\ No newline at end of file
