@@ -1,6 +1,8 @@
 from enum import Enum
 import math
-import string
+
+from ..abstract_unit import AbstractMeasure
+
 
 
 class SpecificWeightUnits(Enum):
@@ -94,7 +96,7 @@ class SpecificWeightUnits(Enum):
         """
         
 
-class SpecificWeight:
+class SpecificWeight(AbstractMeasure):
     """
     The SpecificWeight, or more precisely, the volumetric weight density, of a substance is its weight per unit volume.
 
@@ -103,9 +105,11 @@ class SpecificWeight:
         from_unit (SpecificWeightUnits): The SpecificWeight unit to create from, The default unit is NewtonPerCubicMeter
     """
     def __init__(self, value: float, from_unit: SpecificWeightUnits = SpecificWeightUnits.NewtonPerCubicMeter):
-        if math.isnan(value):
-            raise ValueError('Invalid unit: value is NaN')
-        self.__value = self.__convert_to_base(value, from_unit)
+        # Do not validate type, to allow working with numpay arrays and similar objects who supports all arithmetic 
+        # operations, but they are not a number, see #14 
+        # if math.isnan(value):
+        #     raise ValueError('Invalid unit: value is NaN')
+        self._value = self.__convert_to_base(value, from_unit)
         
         self.__newtons_per_cubic_millimeter = None
         
@@ -142,8 +146,11 @@ class SpecificWeight:
         self.__kilopounds_force_per_cubic_foot = None
         
 
+    def convert(self, unit: SpecificWeightUnits) -> float:
+        return self.__convert_from_base(unit)
+
     def __convert_from_base(self, from_unit: SpecificWeightUnits) -> float:
-        value = self.__value
+        value = self._value
         
         if from_unit == SpecificWeightUnits.NewtonPerCubicMillimeter:
             return (value * 0.000000001)
@@ -257,7 +264,7 @@ class SpecificWeight:
 
     @property
     def base_value(self) -> float:
-        return self.__value
+        return self._value
 
     
     @staticmethod
@@ -702,7 +709,7 @@ class SpecificWeight:
         return self.__kilopounds_force_per_cubic_foot
 
     
-    def to_string(self, unit: SpecificWeightUnits = SpecificWeightUnits.NewtonPerCubicMeter) -> string:
+    def to_string(self, unit: SpecificWeightUnits = SpecificWeightUnits.NewtonPerCubicMeter) -> str:
         """
         Format the SpecificWeight to string.
         Note! the default format for SpecificWeight is NewtonPerCubicMeter.
@@ -743,27 +750,27 @@ class SpecificWeight:
             return f"""{self.tonnes_force_per_cubic_meter} tf/m³"""
         
         if unit == SpecificWeightUnits.KilonewtonPerCubicMillimeter:
-            return f"""{self.kilonewtons_per_cubic_millimeter} """
+            return f"""{self.kilonewtons_per_cubic_millimeter} kN/mm³"""
         
         if unit == SpecificWeightUnits.KilonewtonPerCubicCentimeter:
-            return f"""{self.kilonewtons_per_cubic_centimeter} """
+            return f"""{self.kilonewtons_per_cubic_centimeter} kN/cm³"""
         
         if unit == SpecificWeightUnits.KilonewtonPerCubicMeter:
-            return f"""{self.kilonewtons_per_cubic_meter} """
+            return f"""{self.kilonewtons_per_cubic_meter} kN/m³"""
         
         if unit == SpecificWeightUnits.MeganewtonPerCubicMeter:
-            return f"""{self.meganewtons_per_cubic_meter} """
+            return f"""{self.meganewtons_per_cubic_meter} MN/m³"""
         
         if unit == SpecificWeightUnits.KilopoundForcePerCubicInch:
-            return f"""{self.kilopounds_force_per_cubic_inch} """
+            return f"""{self.kilopounds_force_per_cubic_inch} klbf/in³"""
         
         if unit == SpecificWeightUnits.KilopoundForcePerCubicFoot:
-            return f"""{self.kilopounds_force_per_cubic_foot} """
+            return f"""{self.kilopounds_force_per_cubic_foot} klbf/ft³"""
         
-        return f'{self.__value}'
+        return f'{self._value}'
 
 
-    def get_unit_abbreviation(self, unit_abbreviation: SpecificWeightUnits = SpecificWeightUnits.NewtonPerCubicMeter) -> string:
+    def get_unit_abbreviation(self, unit_abbreviation: SpecificWeightUnits = SpecificWeightUnits.NewtonPerCubicMeter) -> str:
         """
         Get SpecificWeight unit abbreviation.
         Note! the default abbreviation for SpecificWeight is NewtonPerCubicMeter.
@@ -804,89 +811,20 @@ class SpecificWeight:
             return """tf/m³"""
         
         if unit_abbreviation == SpecificWeightUnits.KilonewtonPerCubicMillimeter:
-            return """"""
+            return """kN/mm³"""
         
         if unit_abbreviation == SpecificWeightUnits.KilonewtonPerCubicCentimeter:
-            return """"""
+            return """kN/cm³"""
         
         if unit_abbreviation == SpecificWeightUnits.KilonewtonPerCubicMeter:
-            return """"""
+            return """kN/m³"""
         
         if unit_abbreviation == SpecificWeightUnits.MeganewtonPerCubicMeter:
-            return """"""
+            return """MN/m³"""
         
         if unit_abbreviation == SpecificWeightUnits.KilopoundForcePerCubicInch:
-            return """"""
+            return """klbf/in³"""
         
         if unit_abbreviation == SpecificWeightUnits.KilopoundForcePerCubicFoot:
-            return """"""
-        
-
-    def __str__(self):
-        return self.to_string()
-
-
-    def __add__(self, other):
-        if not isinstance(other, SpecificWeight):
-            raise TypeError("unsupported operand type(s) for +: 'SpecificWeight' and '{}'".format(type(other).__name__))
-        return SpecificWeight(self.__value + other.__value)
-
-
-    def __mul__(self, other):
-        if not isinstance(other, SpecificWeight):
-            raise TypeError("unsupported operand type(s) for *: 'SpecificWeight' and '{}'".format(type(other).__name__))
-        return SpecificWeight(self.__value * other.__value)
-
-
-    def __sub__(self, other):
-        if not isinstance(other, SpecificWeight):
-            raise TypeError("unsupported operand type(s) for -: 'SpecificWeight' and '{}'".format(type(other).__name__))
-        return SpecificWeight(self.__value - other.__value)
-
-
-    def __truediv__(self, other):
-        if not isinstance(other, SpecificWeight):
-            raise TypeError("unsupported operand type(s) for /: 'SpecificWeight' and '{}'".format(type(other).__name__))
-        return SpecificWeight(self.__value / other.__value)
-
-
-    def __mod__(self, other):
-        if not isinstance(other, SpecificWeight):
-            raise TypeError("unsupported operand type(s) for %: 'SpecificWeight' and '{}'".format(type(other).__name__))
-        return SpecificWeight(self.__value % other.__value)
-
-
-    def __pow__(self, other):
-        if not isinstance(other, SpecificWeight):
-            raise TypeError("unsupported operand type(s) for **: 'SpecificWeight' and '{}'".format(type(other).__name__))
-        return SpecificWeight(self.__value ** other.__value)
-
-
-    def __eq__(self, other):
-        if not isinstance(other, SpecificWeight):
-            raise TypeError("unsupported operand type(s) for ==: 'SpecificWeight' and '{}'".format(type(other).__name__))
-        return self.__value == other.__value
-
-
-    def __lt__(self, other):
-        if not isinstance(other, SpecificWeight):
-            raise TypeError("unsupported operand type(s) for <: 'SpecificWeight' and '{}'".format(type(other).__name__))
-        return self.__value < other.__value
-
-
-    def __gt__(self, other):
-        if not isinstance(other, SpecificWeight):
-            raise TypeError("unsupported operand type(s) for >: 'SpecificWeight' and '{}'".format(type(other).__name__))
-        return self.__value > other.__value
-
-
-    def __le__(self, other):
-        if not isinstance(other, SpecificWeight):
-            raise TypeError("unsupported operand type(s) for <=: 'SpecificWeight' and '{}'".format(type(other).__name__))
-        return self.__value <= other.__value
-
-
-    def __ge__(self, other):
-        if not isinstance(other, SpecificWeight):
-            raise TypeError("unsupported operand type(s) for >=: 'SpecificWeight' and '{}'".format(type(other).__name__))
-        return self.__value >= other.__value
\ No newline at end of file
+            return """klbf/ft³"""
+        
\ No newline at end of file
