@@ -1,6 +1,8 @@
 from enum import Enum
 import math
-import string
+
+from ..abstract_unit import AbstractMeasure
+
 
 
 class SpeedUnits(Enum):
@@ -174,7 +176,7 @@ class SpeedUnits(Enum):
         """
         
 
-class Speed:
+class Speed(AbstractMeasure):
     """
     In everyday use and in kinematics, the speed of an object is the magnitude of its velocity (the rate of change of its position); it is thus a scalar quantity.[1] The average speed of an object in an interval of time is the distance travelled by the object divided by the duration of the interval;[2] the instantaneous speed is the limit of the average speed as the duration of the time interval approaches zero.
 
@@ -183,9 +185,11 @@ class Speed:
         from_unit (SpeedUnits): The Speed unit to create from, The default unit is MeterPerSecond
     """
     def __init__(self, value: float, from_unit: SpeedUnits = SpeedUnits.MeterPerSecond):
-        if math.isnan(value):
-            raise ValueError('Invalid unit: value is NaN')
-        self.__value = self.__convert_to_base(value, from_unit)
+        # Do not validate type, to allow working with numpay arrays and similar objects who supports all arithmetic 
+        # operations, but they are not a number, see #14 
+        # if math.isnan(value):
+        #     raise ValueError('Invalid unit: value is NaN')
+        self._value = self.__convert_to_base(value, from_unit)
         
         self.__meters_per_second = None
         
@@ -254,8 +258,11 @@ class Speed:
         self.__kilometers_per_hour = None
         
 
+    def convert(self, unit: SpeedUnits) -> float:
+        return self.__convert_from_base(unit)
+
     def __convert_from_base(self, from_unit: SpeedUnits) -> float:
-        value = self.__value
+        value = self._value
         
         if from_unit == SpeedUnits.MeterPerSecond:
             return (value)
@@ -465,7 +472,7 @@ class Speed:
 
     @property
     def base_value(self) -> float:
-        return self.__value
+        return self._value
 
     
     @staticmethod
@@ -1326,7 +1333,7 @@ class Speed:
         return self.__kilometers_per_hour
 
     
-    def to_string(self, unit: SpeedUnits = SpeedUnits.MeterPerSecond) -> string:
+    def to_string(self, unit: SpeedUnits = SpeedUnits.MeterPerSecond) -> str:
         """
         Format the Speed to string.
         Note! the default format for Speed is MeterPerSecond.
@@ -1388,54 +1395,54 @@ class Speed:
             return f"""{self.mach} M"""
         
         if unit == SpeedUnits.NanometerPerSecond:
-            return f"""{self.nanometers_per_second} """
+            return f"""{self.nanometers_per_second} nm/s"""
         
         if unit == SpeedUnits.MicrometerPerSecond:
-            return f"""{self.micrometers_per_second} """
+            return f"""{self.micrometers_per_second} μm/s"""
         
         if unit == SpeedUnits.MillimeterPerSecond:
-            return f"""{self.millimeters_per_second} """
+            return f"""{self.millimeters_per_second} mm/s"""
         
         if unit == SpeedUnits.CentimeterPerSecond:
-            return f"""{self.centimeters_per_second} """
+            return f"""{self.centimeters_per_second} cm/s"""
         
         if unit == SpeedUnits.DecimeterPerSecond:
-            return f"""{self.decimeters_per_second} """
+            return f"""{self.decimeters_per_second} dm/s"""
         
         if unit == SpeedUnits.KilometerPerSecond:
-            return f"""{self.kilometers_per_second} """
+            return f"""{self.kilometers_per_second} km/s"""
         
         if unit == SpeedUnits.NanometerPerMinute:
-            return f"""{self.nanometers_per_minutes} """
+            return f"""{self.nanometers_per_minutes} nm/min"""
         
         if unit == SpeedUnits.MicrometerPerMinute:
-            return f"""{self.micrometers_per_minutes} """
+            return f"""{self.micrometers_per_minutes} μm/min"""
         
         if unit == SpeedUnits.MillimeterPerMinute:
-            return f"""{self.millimeters_per_minutes} """
+            return f"""{self.millimeters_per_minutes} mm/min"""
         
         if unit == SpeedUnits.CentimeterPerMinute:
-            return f"""{self.centimeters_per_minutes} """
+            return f"""{self.centimeters_per_minutes} cm/min"""
         
         if unit == SpeedUnits.DecimeterPerMinute:
-            return f"""{self.decimeters_per_minutes} """
+            return f"""{self.decimeters_per_minutes} dm/min"""
         
         if unit == SpeedUnits.KilometerPerMinute:
-            return f"""{self.kilometers_per_minutes} """
+            return f"""{self.kilometers_per_minutes} km/min"""
         
         if unit == SpeedUnits.MillimeterPerHour:
-            return f"""{self.millimeters_per_hour} """
+            return f"""{self.millimeters_per_hour} mm/h"""
         
         if unit == SpeedUnits.CentimeterPerHour:
-            return f"""{self.centimeters_per_hour} """
+            return f"""{self.centimeters_per_hour} cm/h"""
         
         if unit == SpeedUnits.KilometerPerHour:
-            return f"""{self.kilometers_per_hour} """
+            return f"""{self.kilometers_per_hour} km/h"""
         
-        return f'{self.__value}'
+        return f'{self._value}'
 
 
-    def get_unit_abbreviation(self, unit_abbreviation: SpeedUnits = SpeedUnits.MeterPerSecond) -> string:
+    def get_unit_abbreviation(self, unit_abbreviation: SpeedUnits = SpeedUnits.MeterPerSecond) -> str:
         """
         Get Speed unit abbreviation.
         Note! the default abbreviation for Speed is MeterPerSecond.
@@ -1497,116 +1504,47 @@ class Speed:
             return """M"""
         
         if unit_abbreviation == SpeedUnits.NanometerPerSecond:
-            return """"""
+            return """nm/s"""
         
         if unit_abbreviation == SpeedUnits.MicrometerPerSecond:
-            return """"""
+            return """μm/s"""
         
         if unit_abbreviation == SpeedUnits.MillimeterPerSecond:
-            return """"""
+            return """mm/s"""
         
         if unit_abbreviation == SpeedUnits.CentimeterPerSecond:
-            return """"""
+            return """cm/s"""
         
         if unit_abbreviation == SpeedUnits.DecimeterPerSecond:
-            return """"""
+            return """dm/s"""
         
         if unit_abbreviation == SpeedUnits.KilometerPerSecond:
-            return """"""
+            return """km/s"""
         
         if unit_abbreviation == SpeedUnits.NanometerPerMinute:
-            return """"""
+            return """nm/min"""
         
         if unit_abbreviation == SpeedUnits.MicrometerPerMinute:
-            return """"""
+            return """μm/min"""
         
         if unit_abbreviation == SpeedUnits.MillimeterPerMinute:
-            return """"""
+            return """mm/min"""
         
         if unit_abbreviation == SpeedUnits.CentimeterPerMinute:
-            return """"""
+            return """cm/min"""
         
         if unit_abbreviation == SpeedUnits.DecimeterPerMinute:
-            return """"""
+            return """dm/min"""
         
         if unit_abbreviation == SpeedUnits.KilometerPerMinute:
-            return """"""
+            return """km/min"""
         
         if unit_abbreviation == SpeedUnits.MillimeterPerHour:
-            return """"""
+            return """mm/h"""
         
         if unit_abbreviation == SpeedUnits.CentimeterPerHour:
-            return """"""
+            return """cm/h"""
         
         if unit_abbreviation == SpeedUnits.KilometerPerHour:
-            return """"""
-        
-
-    def __str__(self):
-        return self.to_string()
-
-
-    def __add__(self, other):
-        if not isinstance(other, Speed):
-            raise TypeError("unsupported operand type(s) for +: 'Speed' and '{}'".format(type(other).__name__))
-        return Speed(self.__value + other.__value)
-
-
-    def __mul__(self, other):
-        if not isinstance(other, Speed):
-            raise TypeError("unsupported operand type(s) for *: 'Speed' and '{}'".format(type(other).__name__))
-        return Speed(self.__value * other.__value)
-
-
-    def __sub__(self, other):
-        if not isinstance(other, Speed):
-            raise TypeError("unsupported operand type(s) for -: 'Speed' and '{}'".format(type(other).__name__))
-        return Speed(self.__value - other.__value)
-
-
-    def __truediv__(self, other):
-        if not isinstance(other, Speed):
-            raise TypeError("unsupported operand type(s) for /: 'Speed' and '{}'".format(type(other).__name__))
-        return Speed(self.__value / other.__value)
-
-
-    def __mod__(self, other):
-        if not isinstance(other, Speed):
-            raise TypeError("unsupported operand type(s) for %: 'Speed' and '{}'".format(type(other).__name__))
-        return Speed(self.__value % other.__value)
-
-
-    def __pow__(self, other):
-        if not isinstance(other, Speed):
-            raise TypeError("unsupported operand type(s) for **: 'Speed' and '{}'".format(type(other).__name__))
-        return Speed(self.__value ** other.__value)
-
-
-    def __eq__(self, other):
-        if not isinstance(other, Speed):
-            raise TypeError("unsupported operand type(s) for ==: 'Speed' and '{}'".format(type(other).__name__))
-        return self.__value == other.__value
-
-
-    def __lt__(self, other):
-        if not isinstance(other, Speed):
-            raise TypeError("unsupported operand type(s) for <: 'Speed' and '{}'".format(type(other).__name__))
-        return self.__value < other.__value
-
-
-    def __gt__(self, other):
-        if not isinstance(other, Speed):
-            raise TypeError("unsupported operand type(s) for >: 'Speed' and '{}'".format(type(other).__name__))
-        return self.__value > other.__value
-
-
-    def __le__(self, other):
-        if not isinstance(other, Speed):
-            raise TypeError("unsupported operand type(s) for <=: 'Speed' and '{}'".format(type(other).__name__))
-        return self.__value <= other.__value
-
-
-    def __ge__(self, other):
-        if not isinstance(other, Speed):
-            raise TypeError("unsupported operand type(s) for >=: 'Speed' and '{}'".format(type(other).__name__))
-        return self.__value >= other.__value
\ No newline at end of file
+            return """km/h"""
+        
\ No newline at end of file
