@@ -1,6 +1,8 @@
 from enum import Enum
 import math
-import string
+
+from ..abstract_unit import AbstractMeasure
+
 
 
 class StandardVolumeFlowUnits(Enum):
@@ -54,7 +56,7 @@ class StandardVolumeFlowUnits(Enum):
         """
         
 
-class StandardVolumeFlow:
+class StandardVolumeFlow(AbstractMeasure):
     """
     The molar flow rate of a gas corrected to standardized conditions of temperature and pressure thus representing a fixed number of moles of gas regardless of composition and actual flow conditions.
 
@@ -63,9 +65,11 @@ class StandardVolumeFlow:
         from_unit (StandardVolumeFlowUnits): The StandardVolumeFlow unit to create from, The default unit is StandardCubicMeterPerSecond
     """
     def __init__(self, value: float, from_unit: StandardVolumeFlowUnits = StandardVolumeFlowUnits.StandardCubicMeterPerSecond):
-        if math.isnan(value):
-            raise ValueError('Invalid unit: value is NaN')
-        self.__value = self.__convert_to_base(value, from_unit)
+        # Do not validate type, to allow working with numpay arrays and similar objects who supports all arithmetic 
+        # operations, but they are not a number, see #14 
+        # if math.isnan(value):
+        #     raise ValueError('Invalid unit: value is NaN')
+        self._value = self.__convert_to_base(value, from_unit)
         
         self.__standard_cubic_meters_per_second = None
         
@@ -86,8 +90,11 @@ class StandardVolumeFlow:
         self.__standard_cubic_feet_per_hour = None
         
 
+    def convert(self, unit: StandardVolumeFlowUnits) -> float:
+        return self.__convert_from_base(unit)
+
     def __convert_from_base(self, from_unit: StandardVolumeFlowUnits) -> float:
-        value = self.__value
+        value = self._value
         
         if from_unit == StandardVolumeFlowUnits.StandardCubicMeterPerSecond:
             return (value)
@@ -153,7 +160,7 @@ class StandardVolumeFlow:
 
     @property
     def base_value(self) -> float:
-        return self.__value
+        return self._value
 
     
     @staticmethod
@@ -390,7 +397,7 @@ class StandardVolumeFlow:
         return self.__standard_cubic_feet_per_hour
 
     
-    def to_string(self, unit: StandardVolumeFlowUnits = StandardVolumeFlowUnits.StandardCubicMeterPerSecond) -> string:
+    def to_string(self, unit: StandardVolumeFlowUnits = StandardVolumeFlowUnits.StandardCubicMeterPerSecond) -> str:
         """
         Format the StandardVolumeFlow to string.
         Note! the default format for StandardVolumeFlow is StandardCubicMeterPerSecond.
@@ -424,10 +431,10 @@ class StandardVolumeFlow:
         if unit == StandardVolumeFlowUnits.StandardCubicFootPerHour:
             return f"""{self.standard_cubic_feet_per_hour} scfh"""
         
-        return f'{self.__value}'
+        return f'{self._value}'
 
 
-    def get_unit_abbreviation(self, unit_abbreviation: StandardVolumeFlowUnits = StandardVolumeFlowUnits.StandardCubicMeterPerSecond) -> string:
+    def get_unit_abbreviation(self, unit_abbreviation: StandardVolumeFlowUnits = StandardVolumeFlowUnits.StandardCubicMeterPerSecond) -> str:
         """
         Get StandardVolumeFlow unit abbreviation.
         Note! the default abbreviation for StandardVolumeFlow is StandardCubicMeterPerSecond.
@@ -460,73 +467,4 @@ class StandardVolumeFlow:
         
         if unit_abbreviation == StandardVolumeFlowUnits.StandardCubicFootPerHour:
             return """scfh"""
-        
-
-    def __str__(self):
-        return self.to_string()
-
-
-    def __add__(self, other):
-        if not isinstance(other, StandardVolumeFlow):
-            raise TypeError("unsupported operand type(s) for +: 'StandardVolumeFlow' and '{}'".format(type(other).__name__))
-        return StandardVolumeFlow(self.__value + other.__value)
-
-
-    def __mul__(self, other):
-        if not isinstance(other, StandardVolumeFlow):
-            raise TypeError("unsupported operand type(s) for *: 'StandardVolumeFlow' and '{}'".format(type(other).__name__))
-        return StandardVolumeFlow(self.__value * other.__value)
-
-
-    def __sub__(self, other):
-        if not isinstance(other, StandardVolumeFlow):
-            raise TypeError("unsupported operand type(s) for -: 'StandardVolumeFlow' and '{}'".format(type(other).__name__))
-        return StandardVolumeFlow(self.__value - other.__value)
-
-
-    def __truediv__(self, other):
-        if not isinstance(other, StandardVolumeFlow):
-            raise TypeError("unsupported operand type(s) for /: 'StandardVolumeFlow' and '{}'".format(type(other).__name__))
-        return StandardVolumeFlow(self.__value / other.__value)
-
-
-    def __mod__(self, other):
-        if not isinstance(other, StandardVolumeFlow):
-            raise TypeError("unsupported operand type(s) for %: 'StandardVolumeFlow' and '{}'".format(type(other).__name__))
-        return StandardVolumeFlow(self.__value % other.__value)
-
-
-    def __pow__(self, other):
-        if not isinstance(other, StandardVolumeFlow):
-            raise TypeError("unsupported operand type(s) for **: 'StandardVolumeFlow' and '{}'".format(type(other).__name__))
-        return StandardVolumeFlow(self.__value ** other.__value)
-
-
-    def __eq__(self, other):
-        if not isinstance(other, StandardVolumeFlow):
-            raise TypeError("unsupported operand type(s) for ==: 'StandardVolumeFlow' and '{}'".format(type(other).__name__))
-        return self.__value == other.__value
-
-
-    def __lt__(self, other):
-        if not isinstance(other, StandardVolumeFlow):
-            raise TypeError("unsupported operand type(s) for <: 'StandardVolumeFlow' and '{}'".format(type(other).__name__))
-        return self.__value < other.__value
-
-
-    def __gt__(self, other):
-        if not isinstance(other, StandardVolumeFlow):
-            raise TypeError("unsupported operand type(s) for >: 'StandardVolumeFlow' and '{}'".format(type(other).__name__))
-        return self.__value > other.__value
-
-
-    def __le__(self, other):
-        if not isinstance(other, StandardVolumeFlow):
-            raise TypeError("unsupported operand type(s) for <=: 'StandardVolumeFlow' and '{}'".format(type(other).__name__))
-        return self.__value <= other.__value
-
-
-    def __ge__(self, other):
-        if not isinstance(other, StandardVolumeFlow):
-            raise TypeError("unsupported operand type(s) for >=: 'StandardVolumeFlow' and '{}'".format(type(other).__name__))
-        return self.__value >= other.__value
\ No newline at end of file
+        
\ No newline at end of file
