@@ -1,6 +1,8 @@
 from enum import Enum
 import math
-import string
+
+from ..abstract_unit import AbstractMeasure
+
 
 
 class TemperatureChangeRateUnits(Enum):
@@ -59,7 +61,7 @@ class TemperatureChangeRateUnits(Enum):
         """
         
 
-class TemperatureChangeRate:
+class TemperatureChangeRate(AbstractMeasure):
     """
     Temperature change rate is the ratio of the temperature change to the time during which the change occurred (value of temperature changes per unit time).
 
@@ -68,9 +70,11 @@ class TemperatureChangeRate:
         from_unit (TemperatureChangeRateUnits): The TemperatureChangeRate unit to create from, The default unit is DegreeCelsiusPerSecond
     """
     def __init__(self, value: float, from_unit: TemperatureChangeRateUnits = TemperatureChangeRateUnits.DegreeCelsiusPerSecond):
-        if math.isnan(value):
-            raise ValueError('Invalid unit: value is NaN')
-        self.__value = self.__convert_to_base(value, from_unit)
+        # Do not validate type, to allow working with numpay arrays and similar objects who supports all arithmetic 
+        # operations, but they are not a number, see #14 
+        # if math.isnan(value):
+        #     raise ValueError('Invalid unit: value is NaN')
+        self._value = self.__convert_to_base(value, from_unit)
         
         self.__degrees_celsius_per_second = None
         
@@ -93,8 +97,11 @@ class TemperatureChangeRate:
         self.__kilodegrees_celsius_per_second = None
         
 
+    def convert(self, unit: TemperatureChangeRateUnits) -> float:
+        return self.__convert_from_base(unit)
+
     def __convert_from_base(self, from_unit: TemperatureChangeRateUnits) -> float:
-        value = self.__value
+        value = self._value
         
         if from_unit == TemperatureChangeRateUnits.DegreeCelsiusPerSecond:
             return (value)
@@ -166,7 +173,7 @@ class TemperatureChangeRate:
 
     @property
     def base_value(self) -> float:
-        return self.__value
+        return self._value
 
     
     @staticmethod
@@ -429,7 +436,7 @@ class TemperatureChangeRate:
         return self.__kilodegrees_celsius_per_second
 
     
-    def to_string(self, unit: TemperatureChangeRateUnits = TemperatureChangeRateUnits.DegreeCelsiusPerSecond) -> string:
+    def to_string(self, unit: TemperatureChangeRateUnits = TemperatureChangeRateUnits.DegreeCelsiusPerSecond) -> str:
         """
         Format the TemperatureChangeRate to string.
         Note! the default format for TemperatureChangeRate is DegreeCelsiusPerSecond.
@@ -443,33 +450,33 @@ class TemperatureChangeRate:
             return f"""{self.degrees_celsius_per_minute} °C/min"""
         
         if unit == TemperatureChangeRateUnits.NanodegreeCelsiusPerSecond:
-            return f"""{self.nanodegrees_celsius_per_second} """
+            return f"""{self.nanodegrees_celsius_per_second} n°C/s"""
         
         if unit == TemperatureChangeRateUnits.MicrodegreeCelsiusPerSecond:
-            return f"""{self.microdegrees_celsius_per_second} """
+            return f"""{self.microdegrees_celsius_per_second} μ°C/s"""
         
         if unit == TemperatureChangeRateUnits.MillidegreeCelsiusPerSecond:
-            return f"""{self.millidegrees_celsius_per_second} """
+            return f"""{self.millidegrees_celsius_per_second} m°C/s"""
         
         if unit == TemperatureChangeRateUnits.CentidegreeCelsiusPerSecond:
-            return f"""{self.centidegrees_celsius_per_second} """
+            return f"""{self.centidegrees_celsius_per_second} c°C/s"""
         
         if unit == TemperatureChangeRateUnits.DecidegreeCelsiusPerSecond:
-            return f"""{self.decidegrees_celsius_per_second} """
+            return f"""{self.decidegrees_celsius_per_second} d°C/s"""
         
         if unit == TemperatureChangeRateUnits.DecadegreeCelsiusPerSecond:
-            return f"""{self.decadegrees_celsius_per_second} """
+            return f"""{self.decadegrees_celsius_per_second} da°C/s"""
         
         if unit == TemperatureChangeRateUnits.HectodegreeCelsiusPerSecond:
-            return f"""{self.hectodegrees_celsius_per_second} """
+            return f"""{self.hectodegrees_celsius_per_second} h°C/s"""
         
         if unit == TemperatureChangeRateUnits.KilodegreeCelsiusPerSecond:
-            return f"""{self.kilodegrees_celsius_per_second} """
+            return f"""{self.kilodegrees_celsius_per_second} k°C/s"""
         
-        return f'{self.__value}'
+        return f'{self._value}'
 
 
-    def get_unit_abbreviation(self, unit_abbreviation: TemperatureChangeRateUnits = TemperatureChangeRateUnits.DegreeCelsiusPerSecond) -> string:
+    def get_unit_abbreviation(self, unit_abbreviation: TemperatureChangeRateUnits = TemperatureChangeRateUnits.DegreeCelsiusPerSecond) -> str:
         """
         Get TemperatureChangeRate unit abbreviation.
         Note! the default abbreviation for TemperatureChangeRate is DegreeCelsiusPerSecond.
@@ -483,95 +490,26 @@ class TemperatureChangeRate:
             return """°C/min"""
         
         if unit_abbreviation == TemperatureChangeRateUnits.NanodegreeCelsiusPerSecond:
-            return """"""
+            return """n°C/s"""
         
         if unit_abbreviation == TemperatureChangeRateUnits.MicrodegreeCelsiusPerSecond:
-            return """"""
+            return """μ°C/s"""
         
         if unit_abbreviation == TemperatureChangeRateUnits.MillidegreeCelsiusPerSecond:
-            return """"""
+            return """m°C/s"""
         
         if unit_abbreviation == TemperatureChangeRateUnits.CentidegreeCelsiusPerSecond:
-            return """"""
+            return """c°C/s"""
         
         if unit_abbreviation == TemperatureChangeRateUnits.DecidegreeCelsiusPerSecond:
-            return """"""
+            return """d°C/s"""
         
         if unit_abbreviation == TemperatureChangeRateUnits.DecadegreeCelsiusPerSecond:
-            return """"""
+            return """da°C/s"""
         
         if unit_abbreviation == TemperatureChangeRateUnits.HectodegreeCelsiusPerSecond:
-            return """"""
+            return """h°C/s"""
         
         if unit_abbreviation == TemperatureChangeRateUnits.KilodegreeCelsiusPerSecond:
-            return """"""
-        
-
-    def __str__(self):
-        return self.to_string()
-
-
-    def __add__(self, other):
-        if not isinstance(other, TemperatureChangeRate):
-            raise TypeError("unsupported operand type(s) for +: 'TemperatureChangeRate' and '{}'".format(type(other).__name__))
-        return TemperatureChangeRate(self.__value + other.__value)
-
-
-    def __mul__(self, other):
-        if not isinstance(other, TemperatureChangeRate):
-            raise TypeError("unsupported operand type(s) for *: 'TemperatureChangeRate' and '{}'".format(type(other).__name__))
-        return TemperatureChangeRate(self.__value * other.__value)
-
-
-    def __sub__(self, other):
-        if not isinstance(other, TemperatureChangeRate):
-            raise TypeError("unsupported operand type(s) for -: 'TemperatureChangeRate' and '{}'".format(type(other).__name__))
-        return TemperatureChangeRate(self.__value - other.__value)
-
-
-    def __truediv__(self, other):
-        if not isinstance(other, TemperatureChangeRate):
-            raise TypeError("unsupported operand type(s) for /: 'TemperatureChangeRate' and '{}'".format(type(other).__name__))
-        return TemperatureChangeRate(self.__value / other.__value)
-
-
-    def __mod__(self, other):
-        if not isinstance(other, TemperatureChangeRate):
-            raise TypeError("unsupported operand type(s) for %: 'TemperatureChangeRate' and '{}'".format(type(other).__name__))
-        return TemperatureChangeRate(self.__value % other.__value)
-
-
-    def __pow__(self, other):
-        if not isinstance(other, TemperatureChangeRate):
-            raise TypeError("unsupported operand type(s) for **: 'TemperatureChangeRate' and '{}'".format(type(other).__name__))
-        return TemperatureChangeRate(self.__value ** other.__value)
-
-
-    def __eq__(self, other):
-        if not isinstance(other, TemperatureChangeRate):
-            raise TypeError("unsupported operand type(s) for ==: 'TemperatureChangeRate' and '{}'".format(type(other).__name__))
-        return self.__value == other.__value
-
-
-    def __lt__(self, other):
-        if not isinstance(other, TemperatureChangeRate):
-            raise TypeError("unsupported operand type(s) for <: 'TemperatureChangeRate' and '{}'".format(type(other).__name__))
-        return self.__value < other.__value
-
-
-    def __gt__(self, other):
-        if not isinstance(other, TemperatureChangeRate):
-            raise TypeError("unsupported operand type(s) for >: 'TemperatureChangeRate' and '{}'".format(type(other).__name__))
-        return self.__value > other.__value
-
-
-    def __le__(self, other):
-        if not isinstance(other, TemperatureChangeRate):
-            raise TypeError("unsupported operand type(s) for <=: 'TemperatureChangeRate' and '{}'".format(type(other).__name__))
-        return self.__value <= other.__value
-
-
-    def __ge__(self, other):
-        if not isinstance(other, TemperatureChangeRate):
-            raise TypeError("unsupported operand type(s) for >=: 'TemperatureChangeRate' and '{}'".format(type(other).__name__))
-        return self.__value >= other.__value
\ No newline at end of file
+            return """k°C/s"""
+        
\ No newline at end of file
