@@ -1,6 +1,8 @@
 from enum import Enum
 import math
-import string
+
+from ..abstract_unit import AbstractMeasure
+
 
 
 class TorqueUnits(Enum):
@@ -134,7 +136,7 @@ class TorqueUnits(Enum):
         """
         
 
-class Torque:
+class Torque(AbstractMeasure):
     """
     Torque, moment or moment of force (see the terminology below), is the tendency of a force to rotate an object about an axis,[1] fulcrum, or pivot. Just as a force is a push or a pull, a torque can be thought of as a twist to an object. Mathematically, torque is defined as the cross product of the lever-arm distance and force, which tends to produce rotation. Loosely speaking, torque is a measure of the turning force on an object such as a bolt or a flywheel. For example, pushing or pulling the handle of a wrench connected to a nut or bolt produces a torque (turning force) that loosens or tightens the nut or bolt.
 
@@ -143,9 +145,11 @@ class Torque:
         from_unit (TorqueUnits): The Torque unit to create from, The default unit is NewtonMeter
     """
     def __init__(self, value: float, from_unit: TorqueUnits = TorqueUnits.NewtonMeter):
-        if math.isnan(value):
-            raise ValueError('Invalid unit: value is NaN')
-        self.__value = self.__convert_to_base(value, from_unit)
+        # Do not validate type, to allow working with numpay arrays and similar objects who supports all arithmetic 
+        # operations, but they are not a number, see #14 
+        # if math.isnan(value):
+        #     raise ValueError('Invalid unit: value is NaN')
+        self._value = self.__convert_to_base(value, from_unit)
         
         self.__newton_millimeters = None
         
@@ -198,8 +202,11 @@ class Torque:
         self.__megapound_force_feet = None
         
 
+    def convert(self, unit: TorqueUnits) -> float:
+        return self.__convert_from_base(unit)
+
     def __convert_from_base(self, from_unit: TorqueUnits) -> float:
-        value = self.__value
+        value = self._value
         
         if from_unit == TorqueUnits.NewtonMillimeter:
             return (value * 1000)
@@ -361,7 +368,7 @@ class Torque:
 
     @property
     def base_value(self) -> float:
-        return self.__value
+        return self._value
 
     
     @staticmethod
@@ -1014,7 +1021,7 @@ class Torque:
         return self.__megapound_force_feet
 
     
-    def to_string(self, unit: TorqueUnits = TorqueUnits.NewtonMeter) -> string:
+    def to_string(self, unit: TorqueUnits = TorqueUnits.NewtonMeter) -> str:
         """
         Format the Torque to string.
         Note! the default format for Torque is NewtonMeter.
@@ -1067,39 +1074,39 @@ class Torque:
             return f"""{self.tonne_force_meters} tf·m"""
         
         if unit == TorqueUnits.KilonewtonMillimeter:
-            return f"""{self.kilonewton_millimeters} """
+            return f"""{self.kilonewton_millimeters} kN·mm"""
         
         if unit == TorqueUnits.MeganewtonMillimeter:
-            return f"""{self.meganewton_millimeters} """
+            return f"""{self.meganewton_millimeters} MN·mm"""
         
         if unit == TorqueUnits.KilonewtonCentimeter:
-            return f"""{self.kilonewton_centimeters} """
+            return f"""{self.kilonewton_centimeters} kN·cm"""
         
         if unit == TorqueUnits.MeganewtonCentimeter:
-            return f"""{self.meganewton_centimeters} """
+            return f"""{self.meganewton_centimeters} MN·cm"""
         
         if unit == TorqueUnits.KilonewtonMeter:
-            return f"""{self.kilonewton_meters} """
+            return f"""{self.kilonewton_meters} kN·m"""
         
         if unit == TorqueUnits.MeganewtonMeter:
-            return f"""{self.meganewton_meters} """
+            return f"""{self.meganewton_meters} MN·m"""
         
         if unit == TorqueUnits.KilopoundForceInch:
-            return f"""{self.kilopound_force_inches} """
+            return f"""{self.kilopound_force_inches} klbf·in"""
         
         if unit == TorqueUnits.MegapoundForceInch:
-            return f"""{self.megapound_force_inches} """
+            return f"""{self.megapound_force_inches} Mlbf·in"""
         
         if unit == TorqueUnits.KilopoundForceFoot:
-            return f"""{self.kilopound_force_feet} """
+            return f"""{self.kilopound_force_feet} klbf·ft"""
         
         if unit == TorqueUnits.MegapoundForceFoot:
-            return f"""{self.megapound_force_feet} """
+            return f"""{self.megapound_force_feet} Mlbf·ft"""
         
-        return f'{self.__value}'
+        return f'{self._value}'
 
 
-    def get_unit_abbreviation(self, unit_abbreviation: TorqueUnits = TorqueUnits.NewtonMeter) -> string:
+    def get_unit_abbreviation(self, unit_abbreviation: TorqueUnits = TorqueUnits.NewtonMeter) -> str:
         """
         Get Torque unit abbreviation.
         Note! the default abbreviation for Torque is NewtonMeter.
@@ -1152,101 +1159,32 @@ class Torque:
             return """tf·m"""
         
         if unit_abbreviation == TorqueUnits.KilonewtonMillimeter:
-            return """"""
+            return """kN·mm"""
         
         if unit_abbreviation == TorqueUnits.MeganewtonMillimeter:
-            return """"""
+            return """MN·mm"""
         
         if unit_abbreviation == TorqueUnits.KilonewtonCentimeter:
-            return """"""
+            return """kN·cm"""
         
         if unit_abbreviation == TorqueUnits.MeganewtonCentimeter:
-            return """"""
+            return """MN·cm"""
         
         if unit_abbreviation == TorqueUnits.KilonewtonMeter:
-            return """"""
+            return """kN·m"""
         
         if unit_abbreviation == TorqueUnits.MeganewtonMeter:
-            return """"""
+            return """MN·m"""
         
         if unit_abbreviation == TorqueUnits.KilopoundForceInch:
-            return """"""
+            return """klbf·in"""
         
         if unit_abbreviation == TorqueUnits.MegapoundForceInch:
-            return """"""
+            return """Mlbf·in"""
         
         if unit_abbreviation == TorqueUnits.KilopoundForceFoot:
-            return """"""
+            return """klbf·ft"""
         
         if unit_abbreviation == TorqueUnits.MegapoundForceFoot:
-            return """"""
-        
-
-    def __str__(self):
-        return self.to_string()
-
-
-    def __add__(self, other):
-        if not isinstance(other, Torque):
-            raise TypeError("unsupported operand type(s) for +: 'Torque' and '{}'".format(type(other).__name__))
-        return Torque(self.__value + other.__value)
-
-
-    def __mul__(self, other):
-        if not isinstance(other, Torque):
-            raise TypeError("unsupported operand type(s) for *: 'Torque' and '{}'".format(type(other).__name__))
-        return Torque(self.__value * other.__value)
-
-
-    def __sub__(self, other):
-        if not isinstance(other, Torque):
-            raise TypeError("unsupported operand type(s) for -: 'Torque' and '{}'".format(type(other).__name__))
-        return Torque(self.__value - other.__value)
-
-
-    def __truediv__(self, other):
-        if not isinstance(other, Torque):
-            raise TypeError("unsupported operand type(s) for /: 'Torque' and '{}'".format(type(other).__name__))
-        return Torque(self.__value / other.__value)
-
-
-    def __mod__(self, other):
-        if not isinstance(other, Torque):
-            raise TypeError("unsupported operand type(s) for %: 'Torque' and '{}'".format(type(other).__name__))
-        return Torque(self.__value % other.__value)
-
-
-    def __pow__(self, other):
-        if not isinstance(other, Torque):
-            raise TypeError("unsupported operand type(s) for **: 'Torque' and '{}'".format(type(other).__name__))
-        return Torque(self.__value ** other.__value)
-
-
-    def __eq__(self, other):
-        if not isinstance(other, Torque):
-            raise TypeError("unsupported operand type(s) for ==: 'Torque' and '{}'".format(type(other).__name__))
-        return self.__value == other.__value
-
-
-    def __lt__(self, other):
-        if not isinstance(other, Torque):
-            raise TypeError("unsupported operand type(s) for <: 'Torque' and '{}'".format(type(other).__name__))
-        return self.__value < other.__value
-
-
-    def __gt__(self, other):
-        if not isinstance(other, Torque):
-            raise TypeError("unsupported operand type(s) for >: 'Torque' and '{}'".format(type(other).__name__))
-        return self.__value > other.__value
-
-
-    def __le__(self, other):
-        if not isinstance(other, Torque):
-            raise TypeError("unsupported operand type(s) for <=: 'Torque' and '{}'".format(type(other).__name__))
-        return self.__value <= other.__value
-
-
-    def __ge__(self, other):
-        if not isinstance(other, Torque):
-            raise TypeError("unsupported operand type(s) for >=: 'Torque' and '{}'".format(type(other).__name__))
-        return self.__value >= other.__value
\ No newline at end of file
+            return """Mlbf·ft"""
+        
\ No newline at end of file
