@@ -1,6 +1,8 @@
 from enum import Enum
 import math
-import string
+
+from ..abstract_unit import AbstractMeasure
+
 
 
 class TorquePerLengthUnits(Enum):
@@ -114,7 +116,7 @@ class TorquePerLengthUnits(Enum):
         """
         
 
-class TorquePerLength:
+class TorquePerLength(AbstractMeasure):
     """
     The magnitude of torque per unit length.
 
@@ -123,9 +125,11 @@ class TorquePerLength:
         from_unit (TorquePerLengthUnits): The TorquePerLength unit to create from, The default unit is NewtonMeterPerMeter
     """
     def __init__(self, value: float, from_unit: TorquePerLengthUnits = TorquePerLengthUnits.NewtonMeterPerMeter):
-        if math.isnan(value):
-            raise ValueError('Invalid unit: value is NaN')
-        self.__value = self.__convert_to_base(value, from_unit)
+        # Do not validate type, to allow working with numpay arrays and similar objects who supports all arithmetic 
+        # operations, but they are not a number, see #14 
+        # if math.isnan(value):
+        #     raise ValueError('Invalid unit: value is NaN')
+        self._value = self.__convert_to_base(value, from_unit)
         
         self.__newton_millimeters_per_meter = None
         
@@ -170,8 +174,11 @@ class TorquePerLength:
         self.__megapound_force_feet_per_foot = None
         
 
+    def convert(self, unit: TorquePerLengthUnits) -> float:
+        return self.__convert_from_base(unit)
+
     def __convert_from_base(self, from_unit: TorquePerLengthUnits) -> float:
-        value = self.__value
+        value = self._value
         
         if from_unit == TorquePerLengthUnits.NewtonMillimeterPerMeter:
             return (value * 1000)
@@ -309,7 +316,7 @@ class TorquePerLength:
 
     @property
     def base_value(self) -> float:
-        return self.__value
+        return self._value
 
     
     @staticmethod
@@ -858,7 +865,7 @@ class TorquePerLength:
         return self.__megapound_force_feet_per_foot
 
     
-    def to_string(self, unit: TorquePerLengthUnits = TorquePerLengthUnits.NewtonMeterPerMeter) -> string:
+    def to_string(self, unit: TorquePerLengthUnits = TorquePerLengthUnits.NewtonMeterPerMeter) -> str:
         """
         Format the TorquePerLength to string.
         Note! the default format for TorquePerLength is NewtonMeterPerMeter.
@@ -899,39 +906,39 @@ class TorquePerLength:
             return f"""{self.tonne_force_meters_per_meter} tf·m/m"""
         
         if unit == TorquePerLengthUnits.KilonewtonMillimeterPerMeter:
-            return f"""{self.kilonewton_millimeters_per_meter} """
+            return f"""{self.kilonewton_millimeters_per_meter} kN·mm/m"""
         
         if unit == TorquePerLengthUnits.MeganewtonMillimeterPerMeter:
-            return f"""{self.meganewton_millimeters_per_meter} """
+            return f"""{self.meganewton_millimeters_per_meter} MN·mm/m"""
         
         if unit == TorquePerLengthUnits.KilonewtonCentimeterPerMeter:
-            return f"""{self.kilonewton_centimeters_per_meter} """
+            return f"""{self.kilonewton_centimeters_per_meter} kN·cm/m"""
         
         if unit == TorquePerLengthUnits.MeganewtonCentimeterPerMeter:
-            return f"""{self.meganewton_centimeters_per_meter} """
+            return f"""{self.meganewton_centimeters_per_meter} MN·cm/m"""
         
         if unit == TorquePerLengthUnits.KilonewtonMeterPerMeter:
-            return f"""{self.kilonewton_meters_per_meter} """
+            return f"""{self.kilonewton_meters_per_meter} kN·m/m"""
         
         if unit == TorquePerLengthUnits.MeganewtonMeterPerMeter:
-            return f"""{self.meganewton_meters_per_meter} """
+            return f"""{self.meganewton_meters_per_meter} MN·m/m"""
         
         if unit == TorquePerLengthUnits.KilopoundForceInchPerFoot:
-            return f"""{self.kilopound_force_inches_per_foot} """
+            return f"""{self.kilopound_force_inches_per_foot} klbf·in/ft"""
         
         if unit == TorquePerLengthUnits.MegapoundForceInchPerFoot:
-            return f"""{self.megapound_force_inches_per_foot} """
+            return f"""{self.megapound_force_inches_per_foot} Mlbf·in/ft"""
         
         if unit == TorquePerLengthUnits.KilopoundForceFootPerFoot:
-            return f"""{self.kilopound_force_feet_per_foot} """
+            return f"""{self.kilopound_force_feet_per_foot} klbf·ft/ft"""
         
         if unit == TorquePerLengthUnits.MegapoundForceFootPerFoot:
-            return f"""{self.megapound_force_feet_per_foot} """
+            return f"""{self.megapound_force_feet_per_foot} Mlbf·ft/ft"""
         
-        return f'{self.__value}'
+        return f'{self._value}'
 
 
-    def get_unit_abbreviation(self, unit_abbreviation: TorquePerLengthUnits = TorquePerLengthUnits.NewtonMeterPerMeter) -> string:
+    def get_unit_abbreviation(self, unit_abbreviation: TorquePerLengthUnits = TorquePerLengthUnits.NewtonMeterPerMeter) -> str:
         """
         Get TorquePerLength unit abbreviation.
         Note! the default abbreviation for TorquePerLength is NewtonMeterPerMeter.
@@ -972,101 +979,32 @@ class TorquePerLength:
             return """tf·m/m"""
         
         if unit_abbreviation == TorquePerLengthUnits.KilonewtonMillimeterPerMeter:
-            return """"""
+            return """kN·mm/m"""
         
         if unit_abbreviation == TorquePerLengthUnits.MeganewtonMillimeterPerMeter:
-            return """"""
+            return """MN·mm/m"""
         
         if unit_abbreviation == TorquePerLengthUnits.KilonewtonCentimeterPerMeter:
-            return """"""
+            return """kN·cm/m"""
         
         if unit_abbreviation == TorquePerLengthUnits.MeganewtonCentimeterPerMeter:
-            return """"""
+            return """MN·cm/m"""
         
         if unit_abbreviation == TorquePerLengthUnits.KilonewtonMeterPerMeter:
-            return """"""
+            return """kN·m/m"""
         
         if unit_abbreviation == TorquePerLengthUnits.MeganewtonMeterPerMeter:
-            return """"""
+            return """MN·m/m"""
         
         if unit_abbreviation == TorquePerLengthUnits.KilopoundForceInchPerFoot:
-            return """"""
+            return """klbf·in/ft"""
         
         if unit_abbreviation == TorquePerLengthUnits.MegapoundForceInchPerFoot:
-            return """"""
+            return """Mlbf·in/ft"""
         
         if unit_abbreviation == TorquePerLengthUnits.KilopoundForceFootPerFoot:
-            return """"""
+            return """klbf·ft/ft"""
         
         if unit_abbreviation == TorquePerLengthUnits.MegapoundForceFootPerFoot:
-            return """"""
-        
-
-    def __str__(self):
-        return self.to_string()
-
-
-    def __add__(self, other):
-        if not isinstance(other, TorquePerLength):
-            raise TypeError("unsupported operand type(s) for +: 'TorquePerLength' and '{}'".format(type(other).__name__))
-        return TorquePerLength(self.__value + other.__value)
-
-
-    def __mul__(self, other):
-        if not isinstance(other, TorquePerLength):
-            raise TypeError("unsupported operand type(s) for *: 'TorquePerLength' and '{}'".format(type(other).__name__))
-        return TorquePerLength(self.__value * other.__value)
-
-
-    def __sub__(self, other):
-        if not isinstance(other, TorquePerLength):
-            raise TypeError("unsupported operand type(s) for -: 'TorquePerLength' and '{}'".format(type(other).__name__))
-        return TorquePerLength(self.__value - other.__value)
-
-
-    def __truediv__(self, other):
-        if not isinstance(other, TorquePerLength):
-            raise TypeError("unsupported operand type(s) for /: 'TorquePerLength' and '{}'".format(type(other).__name__))
-        return TorquePerLength(self.__value / other.__value)
-
-
-    def __mod__(self, other):
-        if not isinstance(other, TorquePerLength):
-            raise TypeError("unsupported operand type(s) for %: 'TorquePerLength' and '{}'".format(type(other).__name__))
-        return TorquePerLength(self.__value % other.__value)
-
-
-    def __pow__(self, other):
-        if not isinstance(other, TorquePerLength):
-            raise TypeError("unsupported operand type(s) for **: 'TorquePerLength' and '{}'".format(type(other).__name__))
-        return TorquePerLength(self.__value ** other.__value)
-
-
-    def __eq__(self, other):
-        if not isinstance(other, TorquePerLength):
-            raise TypeError("unsupported operand type(s) for ==: 'TorquePerLength' and '{}'".format(type(other).__name__))
-        return self.__value == other.__value
-
-
-    def __lt__(self, other):
-        if not isinstance(other, TorquePerLength):
-            raise TypeError("unsupported operand type(s) for <: 'TorquePerLength' and '{}'".format(type(other).__name__))
-        return self.__value < other.__value
-
-
-    def __gt__(self, other):
-        if not isinstance(other, TorquePerLength):
-            raise TypeError("unsupported operand type(s) for >: 'TorquePerLength' and '{}'".format(type(other).__name__))
-        return self.__value > other.__value
-
-
-    def __le__(self, other):
-        if not isinstance(other, TorquePerLength):
-            raise TypeError("unsupported operand type(s) for <=: 'TorquePerLength' and '{}'".format(type(other).__name__))
-        return self.__value <= other.__value
-
-
-    def __ge__(self, other):
-        if not isinstance(other, TorquePerLength):
-            raise TypeError("unsupported operand type(s) for >=: 'TorquePerLength' and '{}'".format(type(other).__name__))
-        return self.__value >= other.__value
\ No newline at end of file
+            return """Mlbf·ft/ft"""
+        
\ No newline at end of file
