@@ -1,6 +1,8 @@
 from enum import Enum
 import math
-import string
+
+from ..abstract_unit import AbstractMeasure
+
 
 
 class VolumeUnits(Enum):
@@ -70,7 +72,7 @@ class VolumeUnits(Enum):
         
         ImperialGallon = 'imperial_gallon'
         """
-            
+            The British imperial gallon (frequently called simply "gallon") is defined as exactly 4.54609 litres.
         """
         
         ImperialOunce = 'imperial_ounce'
@@ -80,7 +82,7 @@ class VolumeUnits(Enum):
         
         UsGallon = 'us_gallon'
         """
-            
+            The US liquid gallon (frequently called simply "gallon") is legally defined as 231 cubic inches, which is exactly 3.785411784 litres.
         """
         
         UsOunce = 'us_ounce'
@@ -148,6 +150,11 @@ class VolumeUnits(Enum):
             
         """
         
+        ImperialQuart = 'imperial_quart'
+        """
+            
+        """
+        
         UsPint = 'us_pint'
         """
             
@@ -274,7 +281,7 @@ class VolumeUnits(Enum):
         """
         
 
-class Volume:
+class Volume(AbstractMeasure):
     """
     Volume is the quantity of three-dimensional space enclosed by some closed boundary, for example, the space that a substance (solid, liquid, gas, or plasma) or shape occupies or contains.[1] Volume is often quantified numerically using the SI derived unit, the cubic metre. The volume of a container is generally understood to be the capacity of the container, i. e. the amount of fluid (gas or liquid) that the container could hold, rather than the amount of space the container itself displaces.
 
@@ -283,9 +290,11 @@ class Volume:
         from_unit (VolumeUnits): The Volume unit to create from, The default unit is CubicMeter
     """
     def __init__(self, value: float, from_unit: VolumeUnits = VolumeUnits.CubicMeter):
-        if math.isnan(value):
-            raise ValueError('Invalid unit: value is NaN')
-        self.__value = self.__convert_to_base(value, from_unit)
+        # Do not validate type, to allow working with numpay arrays and similar objects who supports all arithmetic 
+        # operations, but they are not a number, see #14 
+        # if math.isnan(value):
+        #     raise ValueError('Invalid unit: value is NaN')
+        self._value = self.__convert_to_base(value, from_unit)
         
         self.__liters = None
         
@@ -343,6 +352,8 @@ class Volume:
         
         self.__us_quarts = None
         
+        self.__imperial_quarts = None
+        
         self.__us_pints = None
         
         self.__acre_feet = None
@@ -394,8 +405,11 @@ class Volume:
         self.__megaus_gallons = None
         
 
+    def convert(self, unit: VolumeUnits) -> float:
+        return self.__convert_from_base(unit)
+
     def __convert_from_base(self, from_unit: VolumeUnits) -> float:
-        value = self.__value
+        value = self._value
         
         if from_unit == VolumeUnits.Liter:
             return (value * 1e3)
@@ -431,16 +445,16 @@ class Volume:
             return (value / 2.8316846592e-2)
         
         if from_unit == VolumeUnits.CubicInch:
-            return (value / (1.6387 * 1e-5))
+            return (value / 1.6387064e-5)
         
         if from_unit == VolumeUnits.ImperialGallon:
-            return (value / 0.00454609000000181429905810072407)
+            return (value / 0.00454609)
         
         if from_unit == VolumeUnits.ImperialOunce:
             return (value / 2.8413062499962901241875439064617e-5)
         
         if from_unit == VolumeUnits.UsGallon:
-            return (value / 0.00378541)
+            return (value / 0.003785411784)
         
         if from_unit == VolumeUnits.UsOunce:
             return (value / 2.957352956253760505068307980135e-5)
@@ -481,6 +495,9 @@ class Volume:
         if from_unit == VolumeUnits.UsQuart:
             return (value / 9.46352946e-4)
         
+        if from_unit == VolumeUnits.ImperialQuart:
+            return (value / 1.1365225e-3)
+        
         if from_unit == VolumeUnits.UsPint:
             return (value / 4.73176473e-4)
         
@@ -536,25 +553,25 @@ class Volume:
             return ((value / 2.8316846592e-2) / 1000000.0)
         
         if from_unit == VolumeUnits.KiloimperialGallon:
-            return ((value / 0.00454609000000181429905810072407) / 1000.0)
+            return ((value / 0.00454609) / 1000.0)
         
         if from_unit == VolumeUnits.MegaimperialGallon:
-            return ((value / 0.00454609000000181429905810072407) / 1000000.0)
+            return ((value / 0.00454609) / 1000000.0)
         
         if from_unit == VolumeUnits.DecausGallon:
-            return ((value / 0.00378541) / 10.0)
+            return ((value / 0.003785411784) / 10.0)
         
         if from_unit == VolumeUnits.DeciusGallon:
-            return ((value / 0.00378541) / 0.1)
+            return ((value / 0.003785411784) / 0.1)
         
         if from_unit == VolumeUnits.HectousGallon:
-            return ((value / 0.00378541) / 100.0)
+            return ((value / 0.003785411784) / 100.0)
         
         if from_unit == VolumeUnits.KilousGallon:
-            return ((value / 0.00378541) / 1000.0)
+            return ((value / 0.003785411784) / 1000.0)
         
         if from_unit == VolumeUnits.MegausGallon:
-            return ((value / 0.00378541) / 1000000.0)
+            return ((value / 0.003785411784) / 1000000.0)
         
         return None
 
@@ -595,16 +612,16 @@ class Volume:
             return (value * 2.8316846592e-2)
         
         if to_unit == VolumeUnits.CubicInch:
-            return (value * 1.6387 * 1e-5)
+            return (value * 1.6387064e-5)
         
         if to_unit == VolumeUnits.ImperialGallon:
-            return (value * 0.00454609000000181429905810072407)
+            return (value * 0.00454609)
         
         if to_unit == VolumeUnits.ImperialOunce:
             return (value * 2.8413062499962901241875439064617e-5)
         
         if to_unit == VolumeUnits.UsGallon:
-            return (value * 0.00378541)
+            return (value * 0.003785411784)
         
         if to_unit == VolumeUnits.UsOunce:
             return (value * 2.957352956253760505068307980135e-5)
@@ -645,6 +662,9 @@ class Volume:
         if to_unit == VolumeUnits.UsQuart:
             return (value * 9.46352946e-4)
         
+        if to_unit == VolumeUnits.ImperialQuart:
+            return (value * 1.1365225e-3)
+        
         if to_unit == VolumeUnits.UsPint:
             return (value * 4.73176473e-4)
         
@@ -700,32 +720,32 @@ class Volume:
             return ((value * 2.8316846592e-2) * 1000000.0)
         
         if to_unit == VolumeUnits.KiloimperialGallon:
-            return ((value * 0.00454609000000181429905810072407) * 1000.0)
+            return ((value * 0.00454609) * 1000.0)
         
         if to_unit == VolumeUnits.MegaimperialGallon:
-            return ((value * 0.00454609000000181429905810072407) * 1000000.0)
+            return ((value * 0.00454609) * 1000000.0)
         
         if to_unit == VolumeUnits.DecausGallon:
-            return ((value * 0.00378541) * 10.0)
+            return ((value * 0.003785411784) * 10.0)
         
         if to_unit == VolumeUnits.DeciusGallon:
-            return ((value * 0.00378541) * 0.1)
+            return ((value * 0.003785411784) * 0.1)
         
         if to_unit == VolumeUnits.HectousGallon:
-            return ((value * 0.00378541) * 100.0)
+            return ((value * 0.003785411784) * 100.0)
         
         if to_unit == VolumeUnits.KilousGallon:
-            return ((value * 0.00378541) * 1000.0)
+            return ((value * 0.003785411784) * 1000.0)
         
         if to_unit == VolumeUnits.MegausGallon:
-            return ((value * 0.00378541) * 1000000.0)
+            return ((value * 0.003785411784) * 1000000.0)
         
         return None
 
 
     @property
     def base_value(self) -> float:
-        return self.__value
+        return self._value
 
     
     @staticmethod
@@ -913,7 +933,7 @@ class Volume:
         """
         Create a new instance of Volume from a value in imperial_gallons.
 
-        
+        The British imperial gallon (frequently called simply "gallon") is defined as exactly 4.54609 litres.
 
         :param meters: The Volume value in imperial_gallons.
         :type imperial_gallons: float
@@ -943,7 +963,7 @@ class Volume:
         """
         Create a new instance of Volume from a value in us_gallons.
 
-        
+        The US liquid gallon (frequently called simply "gallon") is legally defined as 231 cubic inches, which is exactly 3.785411784 litres.
 
         :param meters: The Volume value in us_gallons.
         :type us_gallons: float
@@ -1148,6 +1168,21 @@ class Volume:
         return Volume(us_quarts, VolumeUnits.UsQuart)
 
     
+    @staticmethod
+    def from_imperial_quarts(imperial_quarts: float):
+        """
+        Create a new instance of Volume from a value in imperial_quarts.
+
+        
+
+        :param meters: The Volume value in imperial_quarts.
+        :type imperial_quarts: float
+        :return: A new instance of Volume.
+        :rtype: Volume
+        """
+        return Volume(imperial_quarts, VolumeUnits.ImperialQuart)
+
+    
     @staticmethod
     def from_us_pints(us_pints: float):
         """
@@ -1658,7 +1693,7 @@ class Volume:
     @property
     def imperial_gallons(self) -> float:
         """
-        
+        The British imperial gallon (frequently called simply "gallon") is defined as exactly 4.54609 litres.
         """
         if self.__imperial_gallons != None:
             return self.__imperial_gallons
@@ -1680,7 +1715,7 @@ class Volume:
     @property
     def us_gallons(self) -> float:
         """
-        
+        The US liquid gallon (frequently called simply "gallon") is legally defined as 231 cubic inches, which is exactly 3.785411784 litres.
         """
         if self.__us_gallons != None:
             return self.__us_gallons
@@ -1831,6 +1866,17 @@ class Volume:
         return self.__us_quarts
 
     
+    @property
+    def imperial_quarts(self) -> float:
+        """
+        
+        """
+        if self.__imperial_quarts != None:
+            return self.__imperial_quarts
+        self.__imperial_quarts = self.__convert_from_base(VolumeUnits.ImperialQuart)
+        return self.__imperial_quarts
+
+    
     @property
     def us_pints(self) -> float:
         """
@@ -2106,7 +2152,7 @@ class Volume:
         return self.__megaus_gallons
 
     
-    def to_string(self, unit: VolumeUnits = VolumeUnits.CubicMeter) -> string:
+    def to_string(self, unit: VolumeUnits = VolumeUnits.CubicMeter) -> str:
         """
         Format the Volume to string.
         Note! the default format for Volume is CubicMeter.
@@ -2197,6 +2243,9 @@ class Volume:
         if unit == VolumeUnits.UsQuart:
             return f"""{self.us_quarts} qt (U.S.)"""
         
+        if unit == VolumeUnits.ImperialQuart:
+            return f"""{self.imperial_quarts} qt (imp.)"""
+        
         if unit == VolumeUnits.UsPint:
             return f"""{self.us_pints} pt (U.S.)"""
         
@@ -2210,72 +2259,72 @@ class Volume:
             return f"""{self.board_feet} bf"""
         
         if unit == VolumeUnits.Nanoliter:
-            return f"""{self.nanoliters} """
+            return f"""{self.nanoliters} nl"""
         
         if unit == VolumeUnits.Microliter:
-            return f"""{self.microliters} """
+            return f"""{self.microliters} μl"""
         
         if unit == VolumeUnits.Milliliter:
-            return f"""{self.milliliters} """
+            return f"""{self.milliliters} ml"""
         
         if unit == VolumeUnits.Centiliter:
-            return f"""{self.centiliters} """
+            return f"""{self.centiliters} cl"""
         
         if unit == VolumeUnits.Deciliter:
-            return f"""{self.deciliters} """
+            return f"""{self.deciliters} dl"""
         
         if unit == VolumeUnits.Decaliter:
-            return f"""{self.decaliters} """
+            return f"""{self.decaliters} dal"""
         
         if unit == VolumeUnits.Hectoliter:
-            return f"""{self.hectoliters} """
+            return f"""{self.hectoliters} hl"""
         
         if unit == VolumeUnits.Kiloliter:
-            return f"""{self.kiloliters} """
+            return f"""{self.kiloliters} kl"""
         
         if unit == VolumeUnits.Megaliter:
-            return f"""{self.megaliters} """
+            return f"""{self.megaliters} Ml"""
         
         if unit == VolumeUnits.HectocubicMeter:
-            return f"""{self.hectocubic_meters} """
+            return f"""{self.hectocubic_meters} hm³"""
         
         if unit == VolumeUnits.KilocubicMeter:
-            return f"""{self.kilocubic_meters} """
+            return f"""{self.kilocubic_meters} km³"""
         
         if unit == VolumeUnits.HectocubicFoot:
-            return f"""{self.hectocubic_feet} """
+            return f"""{self.hectocubic_feet} hft³"""
         
         if unit == VolumeUnits.KilocubicFoot:
-            return f"""{self.kilocubic_feet} """
+            return f"""{self.kilocubic_feet} kft³"""
         
         if unit == VolumeUnits.MegacubicFoot:
-            return f"""{self.megacubic_feet} """
+            return f"""{self.megacubic_feet} Mft³"""
         
         if unit == VolumeUnits.KiloimperialGallon:
-            return f"""{self.kiloimperial_gallons} """
+            return f"""{self.kiloimperial_gallons} kgal (imp.)"""
         
         if unit == VolumeUnits.MegaimperialGallon:
-            return f"""{self.megaimperial_gallons} """
+            return f"""{self.megaimperial_gallons} Mgal (imp.)"""
         
         if unit == VolumeUnits.DecausGallon:
-            return f"""{self.decaus_gallons} """
+            return f"""{self.decaus_gallons} dagal (U.S.)"""
         
         if unit == VolumeUnits.DeciusGallon:
-            return f"""{self.decius_gallons} """
+            return f"""{self.decius_gallons} dgal (U.S.)"""
         
         if unit == VolumeUnits.HectousGallon:
-            return f"""{self.hectous_gallons} """
+            return f"""{self.hectous_gallons} hgal (U.S.)"""
         
         if unit == VolumeUnits.KilousGallon:
-            return f"""{self.kilous_gallons} """
+            return f"""{self.kilous_gallons} kgal (U.S.)"""
         
         if unit == VolumeUnits.MegausGallon:
-            return f"""{self.megaus_gallons} """
+            return f"""{self.megaus_gallons} Mgal (U.S.)"""
         
-        return f'{self.__value}'
+        return f'{self._value}'
 
 
-    def get_unit_abbreviation(self, unit_abbreviation: VolumeUnits = VolumeUnits.CubicMeter) -> string:
+    def get_unit_abbreviation(self, unit_abbreviation: VolumeUnits = VolumeUnits.CubicMeter) -> str:
         """
         Get Volume unit abbreviation.
         Note! the default abbreviation for Volume is CubicMeter.
@@ -2366,6 +2415,9 @@ class Volume:
         if unit_abbreviation == VolumeUnits.UsQuart:
             return """qt (U.S.)"""
         
+        if unit_abbreviation == VolumeUnits.ImperialQuart:
+            return """qt (imp.)"""
+        
         if unit_abbreviation == VolumeUnits.UsPint:
             return """pt (U.S.)"""
         
@@ -2379,134 +2431,65 @@ class Volume:
             return """bf"""
         
         if unit_abbreviation == VolumeUnits.Nanoliter:
-            return """"""
+            return """nl"""
         
         if unit_abbreviation == VolumeUnits.Microliter:
-            return """"""
+            return """μl"""
         
         if unit_abbreviation == VolumeUnits.Milliliter:
-            return """"""
+            return """ml"""
         
         if unit_abbreviation == VolumeUnits.Centiliter:
-            return """"""
+            return """cl"""
         
         if unit_abbreviation == VolumeUnits.Deciliter:
-            return """"""
+            return """dl"""
         
         if unit_abbreviation == VolumeUnits.Decaliter:
-            return """"""
+            return """dal"""
         
         if unit_abbreviation == VolumeUnits.Hectoliter:
-            return """"""
+            return """hl"""
         
         if unit_abbreviation == VolumeUnits.Kiloliter:
-            return """"""
+            return """kl"""
         
         if unit_abbreviation == VolumeUnits.Megaliter:
-            return """"""
+            return """Ml"""
         
         if unit_abbreviation == VolumeUnits.HectocubicMeter:
-            return """"""
+            return """hm³"""
         
         if unit_abbreviation == VolumeUnits.KilocubicMeter:
-            return """"""
+            return """km³"""
         
         if unit_abbreviation == VolumeUnits.HectocubicFoot:
-            return """"""
+            return """hft³"""
         
         if unit_abbreviation == VolumeUnits.KilocubicFoot:
-            return """"""
+            return """kft³"""
         
         if unit_abbreviation == VolumeUnits.MegacubicFoot:
-            return """"""
+            return """Mft³"""
         
         if unit_abbreviation == VolumeUnits.KiloimperialGallon:
-            return """"""
+            return """kgal (imp.)"""
         
         if unit_abbreviation == VolumeUnits.MegaimperialGallon:
-            return """"""
+            return """Mgal (imp.)"""
         
         if unit_abbreviation == VolumeUnits.DecausGallon:
-            return """"""
+            return """dagal (U.S.)"""
         
         if unit_abbreviation == VolumeUnits.DeciusGallon:
-            return """"""
+            return """dgal (U.S.)"""
         
         if unit_abbreviation == VolumeUnits.HectousGallon:
-            return """"""
+            return """hgal (U.S.)"""
         
         if unit_abbreviation == VolumeUnits.KilousGallon:
-            return """"""
+            return """kgal (U.S.)"""
         
         if unit_abbreviation == VolumeUnits.MegausGallon:
-            return """"""
-        
-
-    def __str__(self):
-        return self.to_string()
-
-
-    def __add__(self, other):
-        if not isinstance(other, Volume):
-            raise TypeError("unsupported operand type(s) for +: 'Volume' and '{}'".format(type(other).__name__))
-        return Volume(self.__value + other.__value)
-
-
-    def __mul__(self, other):
-        if not isinstance(other, Volume):
-            raise TypeError("unsupported operand type(s) for *: 'Volume' and '{}'".format(type(other).__name__))
-        return Volume(self.__value * other.__value)
-
-
-    def __sub__(self, other):
-        if not isinstance(other, Volume):
-            raise TypeError("unsupported operand type(s) for -: 'Volume' and '{}'".format(type(other).__name__))
-        return Volume(self.__value - other.__value)
-
-
-    def __truediv__(self, other):
-        if not isinstance(other, Volume):
-            raise TypeError("unsupported operand type(s) for /: 'Volume' and '{}'".format(type(other).__name__))
-        return Volume(self.__value / other.__value)
-
-
-    def __mod__(self, other):
-        if not isinstance(other, Volume):
-            raise TypeError("unsupported operand type(s) for %: 'Volume' and '{}'".format(type(other).__name__))
-        return Volume(self.__value % other.__value)
-
-
-    def __pow__(self, other):
-        if not isinstance(other, Volume):
-            raise TypeError("unsupported operand type(s) for **: 'Volume' and '{}'".format(type(other).__name__))
-        return Volume(self.__value ** other.__value)
-
-
-    def __eq__(self, other):
-        if not isinstance(other, Volume):
-            raise TypeError("unsupported operand type(s) for ==: 'Volume' and '{}'".format(type(other).__name__))
-        return self.__value == other.__value
-
-
-    def __lt__(self, other):
-        if not isinstance(other, Volume):
-            raise TypeError("unsupported operand type(s) for <: 'Volume' and '{}'".format(type(other).__name__))
-        return self.__value < other.__value
-
-
-    def __gt__(self, other):
-        if not isinstance(other, Volume):
-            raise TypeError("unsupported operand type(s) for >: 'Volume' and '{}'".format(type(other).__name__))
-        return self.__value > other.__value
-
-
-    def __le__(self, other):
-        if not isinstance(other, Volume):
-            raise TypeError("unsupported operand type(s) for <=: 'Volume' and '{}'".format(type(other).__name__))
-        return self.__value <= other.__value
-
-
-    def __ge__(self, other):
-        if not isinstance(other, Volume):
-            raise TypeError("unsupported operand type(s) for >=: 'Volume' and '{}'".format(type(other).__name__))
-        return self.__value >= other.__value
\ No newline at end of file
+            return """Mgal (U.S.)"""
+        
\ No newline at end of file
