@@ -1,6 +1,8 @@
 from enum import Enum
 import math
-import string
+
+from ..abstract_unit import AbstractMeasure
+
 
 
 class VolumeConcentrationUnits(Enum):
@@ -109,7 +111,7 @@ class VolumeConcentrationUnits(Enum):
         """
         
 
-class VolumeConcentration:
+class VolumeConcentration(AbstractMeasure):
     """
     The volume concentration (not to be confused with volume fraction) is defined as the volume of a constituent divided by the total volume of the mixture.
 
@@ -118,9 +120,11 @@ class VolumeConcentration:
         from_unit (VolumeConcentrationUnits): The VolumeConcentration unit to create from, The default unit is DecimalFraction
     """
     def __init__(self, value: float, from_unit: VolumeConcentrationUnits = VolumeConcentrationUnits.DecimalFraction):
-        if math.isnan(value):
-            raise ValueError('Invalid unit: value is NaN')
-        self.__value = self.__convert_to_base(value, from_unit)
+        # Do not validate type, to allow working with numpay arrays and similar objects who supports all arithmetic 
+        # operations, but they are not a number, see #14 
+        # if math.isnan(value):
+        #     raise ValueError('Invalid unit: value is NaN')
+        self._value = self.__convert_to_base(value, from_unit)
         
         self.__decimal_fractions = None
         
@@ -163,8 +167,11 @@ class VolumeConcentration:
         self.__deciliters_per_mililiter = None
         
 
+    def convert(self, unit: VolumeConcentrationUnits) -> float:
+        return self.__convert_from_base(unit)
+
     def __convert_from_base(self, from_unit: VolumeConcentrationUnits) -> float:
-        value = self.__value
+        value = self._value
         
         if from_unit == VolumeConcentrationUnits.DecimalFraction:
             return (value)
@@ -296,7 +303,7 @@ class VolumeConcentration:
 
     @property
     def base_value(self) -> float:
-        return self.__value
+        return self._value
 
     
     @staticmethod
@@ -819,7 +826,7 @@ class VolumeConcentration:
         return self.__deciliters_per_mililiter
 
     
-    def to_string(self, unit: VolumeConcentrationUnits = VolumeConcentrationUnits.DecimalFraction) -> string:
+    def to_string(self, unit: VolumeConcentrationUnits = VolumeConcentrationUnits.DecimalFraction) -> str:
         """
         Format the VolumeConcentration to string.
         Note! the default format for VolumeConcentration is DecimalFraction.
@@ -851,45 +858,45 @@ class VolumeConcentration:
             return f"""{self.parts_per_trillion} ppt"""
         
         if unit == VolumeConcentrationUnits.PicolitersPerLiter:
-            return f"""{self.picoliters_per_liter} """
+            return f"""{self.picoliters_per_liter} pL/L"""
         
         if unit == VolumeConcentrationUnits.NanolitersPerLiter:
-            return f"""{self.nanoliters_per_liter} """
+            return f"""{self.nanoliters_per_liter} nL/L"""
         
         if unit == VolumeConcentrationUnits.MicrolitersPerLiter:
-            return f"""{self.microliters_per_liter} """
+            return f"""{self.microliters_per_liter} μL/L"""
         
         if unit == VolumeConcentrationUnits.MillilitersPerLiter:
-            return f"""{self.milliliters_per_liter} """
+            return f"""{self.milliliters_per_liter} mL/L"""
         
         if unit == VolumeConcentrationUnits.CentilitersPerLiter:
-            return f"""{self.centiliters_per_liter} """
+            return f"""{self.centiliters_per_liter} cL/L"""
         
         if unit == VolumeConcentrationUnits.DecilitersPerLiter:
-            return f"""{self.deciliters_per_liter} """
+            return f"""{self.deciliters_per_liter} dL/L"""
         
         if unit == VolumeConcentrationUnits.PicolitersPerMililiter:
-            return f"""{self.picoliters_per_mililiter} """
+            return f"""{self.picoliters_per_mililiter} pL/mL"""
         
         if unit == VolumeConcentrationUnits.NanolitersPerMililiter:
-            return f"""{self.nanoliters_per_mililiter} """
+            return f"""{self.nanoliters_per_mililiter} nL/mL"""
         
         if unit == VolumeConcentrationUnits.MicrolitersPerMililiter:
-            return f"""{self.microliters_per_mililiter} """
+            return f"""{self.microliters_per_mililiter} μL/mL"""
         
         if unit == VolumeConcentrationUnits.MillilitersPerMililiter:
-            return f"""{self.milliliters_per_mililiter} """
+            return f"""{self.milliliters_per_mililiter} mL/mL"""
         
         if unit == VolumeConcentrationUnits.CentilitersPerMililiter:
-            return f"""{self.centiliters_per_mililiter} """
+            return f"""{self.centiliters_per_mililiter} cL/mL"""
         
         if unit == VolumeConcentrationUnits.DecilitersPerMililiter:
-            return f"""{self.deciliters_per_mililiter} """
+            return f"""{self.deciliters_per_mililiter} dL/mL"""
         
-        return f'{self.__value}'
+        return f'{self._value}'
 
 
-    def get_unit_abbreviation(self, unit_abbreviation: VolumeConcentrationUnits = VolumeConcentrationUnits.DecimalFraction) -> string:
+    def get_unit_abbreviation(self, unit_abbreviation: VolumeConcentrationUnits = VolumeConcentrationUnits.DecimalFraction) -> str:
         """
         Get VolumeConcentration unit abbreviation.
         Note! the default abbreviation for VolumeConcentration is DecimalFraction.
@@ -921,107 +928,38 @@ class VolumeConcentration:
             return """ppt"""
         
         if unit_abbreviation == VolumeConcentrationUnits.PicolitersPerLiter:
-            return """"""
+            return """pL/L"""
         
         if unit_abbreviation == VolumeConcentrationUnits.NanolitersPerLiter:
-            return """"""
+            return """nL/L"""
         
         if unit_abbreviation == VolumeConcentrationUnits.MicrolitersPerLiter:
-            return """"""
+            return """μL/L"""
         
         if unit_abbreviation == VolumeConcentrationUnits.MillilitersPerLiter:
-            return """"""
+            return """mL/L"""
         
         if unit_abbreviation == VolumeConcentrationUnits.CentilitersPerLiter:
-            return """"""
+            return """cL/L"""
         
         if unit_abbreviation == VolumeConcentrationUnits.DecilitersPerLiter:
-            return """"""
+            return """dL/L"""
         
         if unit_abbreviation == VolumeConcentrationUnits.PicolitersPerMililiter:
-            return """"""
+            return """pL/mL"""
         
         if unit_abbreviation == VolumeConcentrationUnits.NanolitersPerMililiter:
-            return """"""
+            return """nL/mL"""
         
         if unit_abbreviation == VolumeConcentrationUnits.MicrolitersPerMililiter:
-            return """"""
+            return """μL/mL"""
         
         if unit_abbreviation == VolumeConcentrationUnits.MillilitersPerMililiter:
-            return """"""
+            return """mL/mL"""
         
         if unit_abbreviation == VolumeConcentrationUnits.CentilitersPerMililiter:
-            return """"""
+            return """cL/mL"""
         
         if unit_abbreviation == VolumeConcentrationUnits.DecilitersPerMililiter:
-            return """"""
-        
-
-    def __str__(self):
-        return self.to_string()
-
-
-    def __add__(self, other):
-        if not isinstance(other, VolumeConcentration):
-            raise TypeError("unsupported operand type(s) for +: 'VolumeConcentration' and '{}'".format(type(other).__name__))
-        return VolumeConcentration(self.__value + other.__value)
-
-
-    def __mul__(self, other):
-        if not isinstance(other, VolumeConcentration):
-            raise TypeError("unsupported operand type(s) for *: 'VolumeConcentration' and '{}'".format(type(other).__name__))
-        return VolumeConcentration(self.__value * other.__value)
-
-
-    def __sub__(self, other):
-        if not isinstance(other, VolumeConcentration):
-            raise TypeError("unsupported operand type(s) for -: 'VolumeConcentration' and '{}'".format(type(other).__name__))
-        return VolumeConcentration(self.__value - other.__value)
-
-
-    def __truediv__(self, other):
-        if not isinstance(other, VolumeConcentration):
-            raise TypeError("unsupported operand type(s) for /: 'VolumeConcentration' and '{}'".format(type(other).__name__))
-        return VolumeConcentration(self.__value / other.__value)
-
-
-    def __mod__(self, other):
-        if not isinstance(other, VolumeConcentration):
-            raise TypeError("unsupported operand type(s) for %: 'VolumeConcentration' and '{}'".format(type(other).__name__))
-        return VolumeConcentration(self.__value % other.__value)
-
-
-    def __pow__(self, other):
-        if not isinstance(other, VolumeConcentration):
-            raise TypeError("unsupported operand type(s) for **: 'VolumeConcentration' and '{}'".format(type(other).__name__))
-        return VolumeConcentration(self.__value ** other.__value)
-
-
-    def __eq__(self, other):
-        if not isinstance(other, VolumeConcentration):
-            raise TypeError("unsupported operand type(s) for ==: 'VolumeConcentration' and '{}'".format(type(other).__name__))
-        return self.__value == other.__value
-
-
-    def __lt__(self, other):
-        if not isinstance(other, VolumeConcentration):
-            raise TypeError("unsupported operand type(s) for <: 'VolumeConcentration' and '{}'".format(type(other).__name__))
-        return self.__value < other.__value
-
-
-    def __gt__(self, other):
-        if not isinstance(other, VolumeConcentration):
-            raise TypeError("unsupported operand type(s) for >: 'VolumeConcentration' and '{}'".format(type(other).__name__))
-        return self.__value > other.__value
-
-
-    def __le__(self, other):
-        if not isinstance(other, VolumeConcentration):
-            raise TypeError("unsupported operand type(s) for <=: 'VolumeConcentration' and '{}'".format(type(other).__name__))
-        return self.__value <= other.__value
-
-
-    def __ge__(self, other):
-        if not isinstance(other, VolumeConcentration):
-            raise TypeError("unsupported operand type(s) for >=: 'VolumeConcentration' and '{}'".format(type(other).__name__))
-        return self.__value >= other.__value
\ No newline at end of file
+            return """dL/mL"""
+        
\ No newline at end of file
