@@ -1,6 +1,8 @@
 from enum import Enum
 import math
-import string
+
+from ..abstract_unit import AbstractMeasure
+
 
 
 class VolumetricHeatCapacityUnits(Enum):
@@ -54,7 +56,7 @@ class VolumetricHeatCapacityUnits(Enum):
         """
         
 
-class VolumetricHeatCapacity:
+class VolumetricHeatCapacity(AbstractMeasure):
     """
     The volumetric heat capacity is the amount of energy that must be added, in the form of heat, to one unit of volume of the material in order to cause an increase of one unit in its temperature.
 
@@ -63,9 +65,11 @@ class VolumetricHeatCapacity:
         from_unit (VolumetricHeatCapacityUnits): The VolumetricHeatCapacity unit to create from, The default unit is JoulePerCubicMeterKelvin
     """
     def __init__(self, value: float, from_unit: VolumetricHeatCapacityUnits = VolumetricHeatCapacityUnits.JoulePerCubicMeterKelvin):
-        if math.isnan(value):
-            raise ValueError('Invalid unit: value is NaN')
-        self.__value = self.__convert_to_base(value, from_unit)
+        # Do not validate type, to allow working with numpay arrays and similar objects who supports all arithmetic 
+        # operations, but they are not a number, see #14 
+        # if math.isnan(value):
+        #     raise ValueError('Invalid unit: value is NaN')
+        self._value = self.__convert_to_base(value, from_unit)
         
         self.__joules_per_cubic_meter_kelvin = None
         
@@ -86,8 +90,11 @@ class VolumetricHeatCapacity:
         self.__kilocalories_per_cubic_centimeter_degree_celsius = None
         
 
+    def convert(self, unit: VolumetricHeatCapacityUnits) -> float:
+        return self.__convert_from_base(unit)
+
     def __convert_from_base(self, from_unit: VolumetricHeatCapacityUnits) -> float:
-        value = self.__value
+        value = self._value
         
         if from_unit == VolumetricHeatCapacityUnits.JoulePerCubicMeterKelvin:
             return (value)
@@ -153,7 +160,7 @@ class VolumetricHeatCapacity:
 
     @property
     def base_value(self) -> float:
-        return self.__value
+        return self._value
 
     
     @staticmethod
@@ -390,7 +397,7 @@ class VolumetricHeatCapacity:
         return self.__kilocalories_per_cubic_centimeter_degree_celsius
 
     
-    def to_string(self, unit: VolumetricHeatCapacityUnits = VolumetricHeatCapacityUnits.JoulePerCubicMeterKelvin) -> string:
+    def to_string(self, unit: VolumetricHeatCapacityUnits = VolumetricHeatCapacityUnits.JoulePerCubicMeterKelvin) -> str:
         """
         Format the VolumetricHeatCapacity to string.
         Note! the default format for VolumetricHeatCapacity is JoulePerCubicMeterKelvin.
@@ -410,24 +417,24 @@ class VolumetricHeatCapacity:
             return f"""{self.btus_per_cubic_foot_degree_fahrenheit} BTU/ft³·°F"""
         
         if unit == VolumetricHeatCapacityUnits.KilojoulePerCubicMeterKelvin:
-            return f"""{self.kilojoules_per_cubic_meter_kelvin} """
+            return f"""{self.kilojoules_per_cubic_meter_kelvin} kJ/m³·K"""
         
         if unit == VolumetricHeatCapacityUnits.MegajoulePerCubicMeterKelvin:
-            return f"""{self.megajoules_per_cubic_meter_kelvin} """
+            return f"""{self.megajoules_per_cubic_meter_kelvin} MJ/m³·K"""
         
         if unit == VolumetricHeatCapacityUnits.KilojoulePerCubicMeterDegreeCelsius:
-            return f"""{self.kilojoules_per_cubic_meter_degree_celsius} """
+            return f"""{self.kilojoules_per_cubic_meter_degree_celsius} kJ/m³·°C"""
         
         if unit == VolumetricHeatCapacityUnits.MegajoulePerCubicMeterDegreeCelsius:
-            return f"""{self.megajoules_per_cubic_meter_degree_celsius} """
+            return f"""{self.megajoules_per_cubic_meter_degree_celsius} MJ/m³·°C"""
         
         if unit == VolumetricHeatCapacityUnits.KilocaloriePerCubicCentimeterDegreeCelsius:
-            return f"""{self.kilocalories_per_cubic_centimeter_degree_celsius} """
+            return f"""{self.kilocalories_per_cubic_centimeter_degree_celsius} kcal/cm³·°C"""
         
-        return f'{self.__value}'
+        return f'{self._value}'
 
 
-    def get_unit_abbreviation(self, unit_abbreviation: VolumetricHeatCapacityUnits = VolumetricHeatCapacityUnits.JoulePerCubicMeterKelvin) -> string:
+    def get_unit_abbreviation(self, unit_abbreviation: VolumetricHeatCapacityUnits = VolumetricHeatCapacityUnits.JoulePerCubicMeterKelvin) -> str:
         """
         Get VolumetricHeatCapacity unit abbreviation.
         Note! the default abbreviation for VolumetricHeatCapacity is JoulePerCubicMeterKelvin.
@@ -447,86 +454,17 @@ class VolumetricHeatCapacity:
             return """BTU/ft³·°F"""
         
         if unit_abbreviation == VolumetricHeatCapacityUnits.KilojoulePerCubicMeterKelvin:
-            return """"""
+            return """kJ/m³·K"""
         
         if unit_abbreviation == VolumetricHeatCapacityUnits.MegajoulePerCubicMeterKelvin:
-            return """"""
+            return """MJ/m³·K"""
         
         if unit_abbreviation == VolumetricHeatCapacityUnits.KilojoulePerCubicMeterDegreeCelsius:
-            return """"""
+            return """kJ/m³·°C"""
         
         if unit_abbreviation == VolumetricHeatCapacityUnits.MegajoulePerCubicMeterDegreeCelsius:
-            return """"""
+            return """MJ/m³·°C"""
         
         if unit_abbreviation == VolumetricHeatCapacityUnits.KilocaloriePerCubicCentimeterDegreeCelsius:
-            return """"""
-        
-
-    def __str__(self):
-        return self.to_string()
-
-
-    def __add__(self, other):
-        if not isinstance(other, VolumetricHeatCapacity):
-            raise TypeError("unsupported operand type(s) for +: 'VolumetricHeatCapacity' and '{}'".format(type(other).__name__))
-        return VolumetricHeatCapacity(self.__value + other.__value)
-
-
-    def __mul__(self, other):
-        if not isinstance(other, VolumetricHeatCapacity):
-            raise TypeError("unsupported operand type(s) for *: 'VolumetricHeatCapacity' and '{}'".format(type(other).__name__))
-        return VolumetricHeatCapacity(self.__value * other.__value)
-
-
-    def __sub__(self, other):
-        if not isinstance(other, VolumetricHeatCapacity):
-            raise TypeError("unsupported operand type(s) for -: 'VolumetricHeatCapacity' and '{}'".format(type(other).__name__))
-        return VolumetricHeatCapacity(self.__value - other.__value)
-
-
-    def __truediv__(self, other):
-        if not isinstance(other, VolumetricHeatCapacity):
-            raise TypeError("unsupported operand type(s) for /: 'VolumetricHeatCapacity' and '{}'".format(type(other).__name__))
-        return VolumetricHeatCapacity(self.__value / other.__value)
-
-
-    def __mod__(self, other):
-        if not isinstance(other, VolumetricHeatCapacity):
-            raise TypeError("unsupported operand type(s) for %: 'VolumetricHeatCapacity' and '{}'".format(type(other).__name__))
-        return VolumetricHeatCapacity(self.__value % other.__value)
-
-
-    def __pow__(self, other):
-        if not isinstance(other, VolumetricHeatCapacity):
-            raise TypeError("unsupported operand type(s) for **: 'VolumetricHeatCapacity' and '{}'".format(type(other).__name__))
-        return VolumetricHeatCapacity(self.__value ** other.__value)
-
-
-    def __eq__(self, other):
-        if not isinstance(other, VolumetricHeatCapacity):
-            raise TypeError("unsupported operand type(s) for ==: 'VolumetricHeatCapacity' and '{}'".format(type(other).__name__))
-        return self.__value == other.__value
-
-
-    def __lt__(self, other):
-        if not isinstance(other, VolumetricHeatCapacity):
-            raise TypeError("unsupported operand type(s) for <: 'VolumetricHeatCapacity' and '{}'".format(type(other).__name__))
-        return self.__value < other.__value
-
-
-    def __gt__(self, other):
-        if not isinstance(other, VolumetricHeatCapacity):
-            raise TypeError("unsupported operand type(s) for >: 'VolumetricHeatCapacity' and '{}'".format(type(other).__name__))
-        return self.__value > other.__value
-
-
-    def __le__(self, other):
-        if not isinstance(other, VolumetricHeatCapacity):
-            raise TypeError("unsupported operand type(s) for <=: 'VolumetricHeatCapacity' and '{}'".format(type(other).__name__))
-        return self.__value <= other.__value
-
-
-    def __ge__(self, other):
-        if not isinstance(other, VolumetricHeatCapacity):
-            raise TypeError("unsupported operand type(s) for >=: 'VolumetricHeatCapacity' and '{}'".format(type(other).__name__))
-        return self.__value >= other.__value
\ No newline at end of file
+            return """kcal/cm³·°C"""
+        
\ No newline at end of file
